@@ -11,7 +11,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.uivcard.inc.php 17901 2007-01-24 15:59:38Z Caeies $ */
+  /* $Id: class.uivcard.inc.php 4899 2010-02-23 19:09:19Z sigurd $ */
 
 	class uivcard
 	{
@@ -71,9 +71,9 @@
 
 		function out()
 		{
-			$ab_id   = $GLOBALS['HTTP_GET_VARS']['ab_id'] ? $GLOBALS['HTTP_GET_VARS']['ab_id'] : $GLOBALS['HTTP_POST_VARS']['ab_id'];
-			$nolname = $GLOBALS['HTTP_GET_VARS']['nolname'];
-			$nofname = $GLOBALS['HTTP_GET_VARS']['nofname'];
+			$ab_id   = phpgw::get_var('ab_id');
+			$nolname = phpgw::get_var('nolname');
+			$nofname = phpgw::get_var('nofname');
 
 			if($nolname || $nofname)
 			{
@@ -83,14 +83,12 @@
 
 			if(!$ab_id)
 			{
-				Header('Location: ' . $GLOBALS['phpgw']->link('/addressbook/index.php'));
-				$GLOBALS['phpgw']->common->phpgw_exit();
+				$GLOBALS['phpgw']->redirect_link('/addressbook/index.php');
 			}
 
 			if(!$this->contacts->check_edit($ab_id))
 			{
-				Header("Location: " . $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'addressbook.uiaddressbook.index')));
-				$GLOBALS['phpgw']->common->phpgw_exit();
+				$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'addressbook.uiaddressbook.index'));
 			}
 			
 			// First, make sure they have permission to this entry
@@ -194,11 +192,11 @@
 				if($lastname == '')
 				{
 					/* Run away here. */
-					Header('Location: ' . $GLOBALS['phpgw']->link('/index.php',"menuaction=addressbook.uivcard.out&nolname=1&ab_id=$ab_id"));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction' => 'addressbook.uivcard.out', 'nolname' => 1, 'ab_id' => $ab_id));
 				}
 				if($firstname == '')
 				{
-					Header('Location: ' . $GLOBALS['phpgw']->link('/index.php',"menuaction=addressbook.uivcard.out&nofname=1&ab_id=$ab_id"));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction' => 'addressbook.uivcard.out', 'nofname' => 1, 'ab_id' =>$ab_id));
 				}
 
 				if ($email)
@@ -268,4 +266,3 @@
 			}
 		}
 	}
-?>
