@@ -9,68 +9,70 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uilog.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: class.uilog.inc.php 1228 2008-06-12 19:18:18Z sigurd $ */
 
-	class uilog
+	class admin_uilog
 	{
-		var $template;
-		var $public_functions = array
+		public $public_functions = array
 		(
 			'list_log'	=> true,
 			'purge_log'	=> true
 		);
 
-		function uilog()
+		public function __construct()
 		{
 			if ($GLOBALS['phpgw']->acl->check('error_log_access',1,'admin'))
 			{
 				$GLOBALS['phpgw']->redirect_link('/index.php');
 			}
 			
-			$this->bo         = createobject('admin.bolog');
-			$this->nextmatchs = createobject('phpgwapi.nextmatchs');
-			$this->template   =& $GLOBALS['phpgw']->template;
-
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'admin::admin::error_log';
 		}
 
-		function list_log()
+		public function list_log()
 		{
 			if ($GLOBALS['phpgw']->acl->check('error_log_access',1,'admin'))
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php');
+				$GLOBALS['phpgw']->redirect_link('/admin/index.php');
 			}
 			
 			$account_id		= phpgw::get_var('account_id', 'int');
-			$start			= phpgw::get_var('start', 'int', 'POST', 0);
-			$sort			= phpgw::get_var('sort', 'int', 'POST',0);
-			$order			= phpgw::get_var('order', 'int', 'POST',0);
-			
-			$this->template->set_file(array
-			(
-				'errorlog'		=> 'errorlog_view.tpl',
-				'form_button'	=> 'form_button_script.tpl'
-			));
-
-			$this->template->set_block('errorlog','list');
-			$this->template->set_block('errorlog','row');
-			$this->template->set_block('errorlog','row_empty');
+			$start			= phpgw::get_var('start', 'int', 'POST');
+			$sort			= phpgw::get_var('sort', 'int', 'POST');
+			$order			= phpgw::get_var('order', 'int', 'POST');
 			
+		
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('Admin').' - '.lang('View error log');
 			if ( $account_id )
 			{
 				$GLOBALS['phpgw_info']['flags']['app_header'] .= ' ' . lang('for') . ' ' . $GLOBALS['phpgw']->common->grab_owner_name($account_id);
 			}
 			
-			$GLOBALS['phpgw']->common->phpgw_header();
-			echo parse_navbar();
+			$GLOBALS['phpgw']->common->phpgw_header(true);
 
-			$total_records = $this->bo->total($account_id);
+			$bo = createObject('admin.bolog');
+			$nextmatches = createObject('phpgwapi.nextmatchs');
+
+			$t   =& $GLOBALS['phpgw']->template;
+			$t->set_root(PHPGW_APP_TPL);
+
+			$t->set_file(array
+			(
+				'errorlog'		=> 'errorlog_view.tpl',
+				'form_button'	=> 'form_button_script.tpl'
+			));
+
+			$t->set_block('errorlog','list');
+			$t->set_block('errorlog','row');
+			$t->set_block('errorlog','row_empty');
+	
+			$total_records = $bo->total($account_id);
 
 			$var = array
 			(
-				'nextmatchs_left'  => $this->nextmatchs->left('/index.php',$start,$total_records,'&menuaction=admin.uilog.list_log&account_id=' . $account_id),
-				'nextmatchs_right' => $this->nextmatchs->right('/index.php',$start,$total_records,'&menuaction=admin.uilog.list_log&account_id=' . $account_id),
-				'showing'          => $this->nextmatchs->show_hits($total_records,$start),
+				'nextmatchs_left'  => $nextmatches->left('/index.php',$start,$total_records,'&menuaction=admin.uilog.list_log&account_id=' . $account_id),
+				'nextmatchs_right' => $nextmatches->right('/index.php',$start,$total_records,'&menuaction=admin.uilog.list_log&account_id=' . $account_id),
+				'showing'          => $nextmatches->show_hits($total_records,$start),
 				'lang_loginid'     => lang('LoginID'),
 				'lang_date'        => lang('time'),
 				'lang_app'         => lang('module'),
@@ -81,26 +83,25 @@
 				'lang_total'       => lang('Total')
 			);
 
-			$this->template->set_var($var);
+			$t->set_var($var);
 
-			$records = $this->bo->list_log($account_id,$start,$order,$sort);
+			$records = $bo->list_log($account_id, $start, $order, $sort);
 			if ( !is_array($records) || !count($records) )
 			{
-				$this->template->set_var(array
+				$t->set_var(array
 				(
 					'row_message'	=> lang('No error log records exist for this user'),
 					'tr_class'		=> 'row_on'
 				));
-				$this->template->fp('rows_access','row_empty',True);
+				$t->fp('rows_access', 'row_empty', true);
 			}
 			else
 			{
 				$tr_class = '';
 				foreach ( $records as $record )
 				{
-
-					$tr_class = $this->nextmatchs->alternate_row_class($tr_class);
-					$this->template->set_var(array
+					$tr_class = $nextmatches->alternate_row_class($tr_class);
+					$t->set_var(array
 					(
 						'row_date' 		=> $record['log_date'],
 						'row_loginid'   => $record['log_account_lid'],
@@ -111,7 +112,7 @@
 						'row_message'   => $record['log_msg'],
 						'tr_class'		=> $tr_class
 					));
-					$this->template->fp('rows_access','row',True);
+					$t->parse('rows_access', 'row', true);
 				}
 			}
 
@@ -119,32 +120,36 @@
 			{
 				if ( $account_id ) 
 				{
-					$var = Array(
-						'submit_button' => lang('Submit'),
+					$var = array
+					(
+						'submit_button'			=> lang('Submit'),
 						'action_url_button'     => $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uilog.purge_log', 'account_id' => $account_id)),
-						'action_text_button'    => ' '.lang('Delete all log records for ').$GLOBALS['phpgw']->common->grab_owner_name($account_id),
+						'action_text_button'    => ' '.lang('Delete all log records for %1', $GLOBALS['phpgw']->common->grab_owner_name($account_id)),
 						'action_confirm_button' => '',
 						'action_extra_field'    => ''
 					);
 				}
 				else 
 				{
-					$var = Array(
-						'submit_button' => lang('Submit'),
+					$var = array
+					(
+						'submit_button'			=> lang('Submit'),
 						'action_url_button'     => $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uilog.purge_log') ),
 						'action_text_button'    => ' '.lang('Delete all log records'),
 						'action_confirm_button' => '',
 						'action_extra_field'    => ''
 					);
 				}
-				$this->template->set_var($var);
-				$var['purge_log_button'] = $this->template->fp('button', 'form_button', True);
-				$this->template->set_var($var);
+				$t->set_var($var);
+				$var['purge_log_button'] = $t->fp('button', 'form_button', true);
+
+				$t->set_var($var);
 			}
 
 			if ( $account_id ) 
 			{
-				$var = array('footer_total' => lang('Total records for %1 : %2', $GLOBALS['phpgw']->common->grab_owner_name($account_id), $total_records) );
+				$account_name = $GLOBALS['phpgw']->common->grab_owner_name($account_id);
+				$var = array('footer_total' => lang('Total records for %1 : %2', $account_name, $total_records) );
 			}
 			else
 			{
@@ -152,20 +157,19 @@
 			}
 
 			// create the menu on the left, if needed
-			$menuClass = CreateObject('admin.uimenuclass');
-			$var['rows'] = $menuClass->createHTMLCode('view_account');
+			//$var['rows'] = createObject('admin.uimenuclass')->createHTMLCode('view_account');
 
-			$this->template->set_var($var);
-			$this->template->pfp('out','list');
+			//$t->set_var($var);
+			$t->pfp('out', 'list');
 		}
 		
-		function purge_log()
+		public function purge_log()
 		{
 			if ($GLOBALS['phpgw']->acl->check('error_log_access',1,'admin'))
 			{
 				$GLOBALS['phpgw']->redirect_link('/index.php');
 			}
-			$this->bo->purge_log( phpgw::get_var('account_id', 'int') );
+			execMethod('admin.bolog.purge_log', phpgw::get_var('account_id', 'int') );
 			$GLOBALS['phpgw']->redirect_link('index.php', array('menuaction', 'admin.uilog.list_log'));
 		}
 	}
