@@ -139,6 +139,7 @@
 			self::add_javascript('booking', 'booking', 'datatable.js');
 			phpgwapi_yui::load_widget('datatable');
 			phpgwapi_yui::load_widget('paginator');
+
 			$data = array(
 				'form' => array(
 					'toolbar' => array(
@@ -148,7 +149,44 @@
 								'value' => lang('New application'),
 								'href' => self::link(array('menuaction' => 'booking.uiapplication.add'))
 							),
+							array('type' => 'filter', 
+								'name' => 'status',
+                                'text' => lang('Status').':',
+                                'list' => array(
+                                    array(
+                                        'id' => 'none',
+                                        'name' => lang('Not selected')
+                                    ), 
+                                    array(
+                                        'id' => 'NEW',
+                                        'name' => lang('NEW')
+                                    ), 
+                                    array(
+                                        'id' => 'PENDING',
+                                        'name' =>  lang('PENDING')
+                                    ), 
+                                    array(
+                                        'id' => 'REJECTED',
+                                        'name' => lang('REJECTED')
+                                    ), 
+                                    array(
+                                        'id' => 'ACCEPTED',
+                                        'name' => lang('ACCEPTED')
+                                    )
+                                )
+                            ),
+							array('type' => 'filter', 
+								'name' => 'buildings',
+                                'text' => lang('Building').':',
+                                'list' => $this->bo->so->get_buildings(),
+							),
+							array('type' => 'filter', 
+								'name' => 'activities',
+                                'text' => lang('Activity').':',
+                                'list' => $this->bo->so->get_activities_main_level(),
+							),
 							array('type' => 'text', 
+                                'text' => lang('searchfield'),
 								'name' => 'query'
 							),
 							array(
@@ -161,7 +199,7 @@
 								'value' => $_SESSION['showall'] ? lang('Show only active') : lang('Show all'),
 								'href' => self::link(array('menuaction' => $this->url_prefix.'.toggle_show_inactive'))
 							),
-						)
+						),
 					),
 				),
 				'datatable' => array(
@@ -176,6 +214,10 @@
 							'key' => 'status',
 							'label' => lang('Status')
 						),
+						array(
+							'key' => 'building_name',
+							'label' => lang('Building')
+						),
 						array(
 							'key' => 'what',
 							'label' => lang('What')
@@ -201,8 +243,9 @@
 							'hidden' => true
 						)
 					)
-				)
+				),
 			);
+
 			self::render_template('datatable', $data);
 		}
 
@@ -219,7 +262,41 @@
 			if(isset($_SESSION['showall']))
 			{
 				$filters['status'] = array('NEW', 'PENDING','REJECTED', 'ACCEPTED');
-			}
+                $testdata =  phpgw::get_var('buildings', 'int', 'REQUEST', null);
+                if ($testdata != 0) {
+                    $filters['building_name'] = $this->bo->so->get_building(phpgw::get_var('buildings', 'int', 'REQUEST', null));        
+                } else {
+                    unset($filters['building_name']);                
+                }
+                $testdata2 =  phpgw::get_var('activities', 'int', 'REQUEST', null);
+                if ($testdata2 != 0) {
+                    $filters['activity_id'] = $this->bo->so->get_activities(phpgw::get_var('activities', 'int', 'REQUEST', null));        
+                } else {
+                    unset($filters['activity_id']);                
+                }
+                
+			} else {
+				if (phpgw::get_var('status') == 'none')
+				{
+					$filters['status'] = array('NEW', 'PENDING','REJECTED', 'ACCEPTED');
+				} 
+				else
+				{
+                $filters['status'] = phpgw::get_var('status');
+				}
+                $testdata =  phpgw::get_var('buildings', 'int', 'REQUEST', null);
+                if ($testdata != 0) {
+                    $filters['building_name'] = $this->bo->so->get_building(phpgw::get_var('buildings', 'int', 'REQUEST', null));        
+                } else {
+                    unset($filters['building_name']);                
+                }
+                $testdata2 =  phpgw::get_var('activities', 'int', 'REQUEST', null);
+                if ($testdata2 != 0) {
+                    $filters['activity_id'] = $this->bo->so->get_activities(phpgw::get_var('activities', 'int', 'REQUEST', null));        
+                } else {
+                    unset($filters['activity_id']);                
+                }
+            }
 
 			$params = array(
 				'start' => phpgw::get_var('startIndex', 'int', 'REQUEST', 0),
@@ -231,6 +308,7 @@
 			);
 
 			$applications = $this->bo->so->read($params);
+
 			foreach($applications['results'] as &$application)
 			{
 				$application['status'] = lang($application['status']);
@@ -250,6 +328,7 @@
 				}
 			}
 			array_walk($applications["results"], array($this, "_add_links"), "booking.uiapplication.show");
+
 			return $this->yui_results($applications);
 		}
 		
@@ -351,6 +430,20 @@
 				$application['owner_id'] = $GLOBALS['phpgw_info']['user']['account_id'];
 
 				$errors = $this->validate($application);
+				if ($_POST['contact_email'] != $_POST['contact_email2']) {
+					$errors['email'] = lang('The e-mail addresses you entered do not match');
+					$application['contact_email2'] = $_POST['contact_email2'];
+				} else {
+					$application['contact_email2'] = $_POST['contact_email2'];
+				}
+
+				foreach($application['agegroups'] as $ag)
+				{
+					if($ag['male'] > 9999 || $ag['female'] > 9999) {
+						$errors['agegroups'] = lang('Agegroups kan not be larger than 9999 peoples');
+					}
+				}
+
 				if(!$errors)
 				{
 					$comment_text = $this->create_accepted_documents_comment_text($application);
@@ -362,6 +455,7 @@
 					$receipt = $this->bo->add($application);
 					$application['id'] = $receipt['id'];
 					$this->bo->send_notification($application, true);
+                    $this->bo->so->update_id_string();
 					$this->flash(lang("Your application has now been registered and a confirmation email has been sent to you.")."<br />".
 								 lang("A Case officer will review your application as soon as possible."));
 					$this->redirect(array('menuaction' => $this->url_prefix . '.show', 'id'=>$receipt['id'], 'secret'=>$application['secret']));
@@ -376,8 +470,15 @@
 			array_set_default($application, 'resources', array(get_var('resource', int, 'GET')));
 			}
 			array_set_default($application, 'building_id', phpgw::get_var('building_id', 'GET'));
+
 			array_set_default($application, 'building_name', phpgw::get_var('building_name', 'GET'));
 			
+			if (strstr($application['building_name'],"%")){
+				$search = array('%C3%85', '%C3%A5', '%C3%98', '%C3%B8', '%C3%86', '%C3%A6');
+				$replace = array ('Å','å','Ø','ø','Æ','æ');
+				$application['building_name'] = str_replace($search, $replace, $application['building_name']);
+			}
+			
 			if(phpgw::get_var('from_', 'GET'))
 			{
 				$default_dates = array_map(array(self, '_combine_dates'), phpgw::get_var('from_', 'GET'), phpgw::get_var('to_', 'GET'));
@@ -405,7 +506,8 @@
 			$agegroups = $this->agegroup_bo->fetch_age_groups();
 			$agegroups = $agegroups['results'];
 			$audience = $this->audience_bo->fetch_target_audience();
-			$application['audience_json'] = json_encode($audience['results']);
+			$application['audience_json'] = json_encode(array_map('intval',$application['audience']));
+
 			$audience = $audience['results'];
 			$this->install_customer_identifier_ui($application);
 			$application['customer_identifier_types']['ssn'] = 'Date of birth or SSN';
