@@ -19,16 +19,19 @@
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => false),
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
+				'deactivate_calendar' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 0),
+				'deactivate_application' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 0),
+				'deactivate_sendmessage' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 0),
 				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
 				'homepage' => array('type' => 'text', 'nullable' => False),
 				'location_code' => array('type' => 'varchar','precision' => '50','nullable' => True),
-				'phone' => array('type' => 'varchar','precision' => '50','nullable' => False, 'default'=>''),
-				'email' => array('type' => 'varchar','precision' => '50','nullable' => False, 'default'=>''),
-				'street' => array('type' => 'varchar','precision' => '255', 'nullable' => False, 'default'=>''),
-				'zip_code' => array('type' => 'varchar','precision' => '255', 'nullable' => False, 'default'=>''),
-				'district' => array('type' => 'varchar','precision' => '255', 'nullable' => False, 'default'=>''),
-				'city' => array('type' => 'varchar','precision' => '255', 'nullable' => False, 'default'=>''),
-				'description' => array('type' => 'text', 'nullable' => False, 'default'=>''),
+				'phone' => array('type' => 'varchar','precision' => '50','nullable' => True),
+				'email' => array('type' => 'varchar','precision' => '50','nullable' => True),
+				'street' => array('type' => 'varchar','precision' => '255', 'nullable' => True),
+				'zip_code' => array('type' => 'varchar','precision' => '255', 'nullable' => True),
+				'district' => array('type' => 'varchar','precision' => '255', 'nullable' => True),
+				'city' => array('type' => 'varchar','precision' => '255', 'nullable' => True),
+				'description' => array('type' => 'text', 'nullable' => True),
 			),
 			'pk' => array('id'),
 			'fk' => array(),
@@ -54,9 +57,9 @@
 				'ssn' => array('type' => 'varchar', 'precision' => '12', 'nullable' => True,),
 				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
 				'homepage' => array('type' => 'text', 'nullable' => True),
-				'phone' => array('type' => 'varchar','precision' => '50','nullable' => False, 'default'=>''),
-				'email' => array('type' => 'varchar','precision' => '50','nullable' => False, 'default'=>''),
-				'description' => array('type' => 'varchar','precision' => '1000','nullable' => False, 'default'=>''),
+				'phone' => array('type' => 'varchar','precision' => '50','nullable' => True),
+				'email' => array('type' => 'varchar','precision' => '50','nullable' => True),
+				'description' => array('type' => 'varchar','precision' => '1000','nullable' => True),
 			),
 			'pk' => array('id'),
 			'fk' => array(),
@@ -70,13 +73,13 @@
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
 				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
 				'homepage' => array('type' => 'text', 'nullable' => True),
-				'phone' => array('type' => 'varchar','precision' => '50','nullable' => False, 'default'=>''),
-				'email' => array('type' => 'varchar','precision' => '50','nullable' => False, 'default'=>''),
-				'street' => array('type' => 'varchar','precision' => '255', 'nullable' => False, 'default'=>''),
-				'zip_code' => array('type' => 'varchar','precision' => '255', 'nullable' => False, 'default'=>''),
-				'district' => array('type' => 'varchar','precision' => '255', 'nullable' => False, 'default'=>''),
-				'city' => array('type' => 'varchar','precision' => '255', 'nullable' => False, 'default'=>''),
-				'description' => array('type' => 'text', 'nullable' => False, 'default'=>''),
+				'phone' => array('type' => 'varchar','precision' => '50','nullable' => True),
+				'email' => array('type' => 'varchar','precision' => '50','nullable' => True),
+				'street' => array('type' => 'varchar','precision' => '255', 'nullable' => True),
+				'zip_code' => array('type' => 'varchar','precision' => '255', 'nullable' => True),
+				'district' => array('type' => 'varchar','precision' => '255', 'nullable' => True),
+				'city' => array('type' => 'varchar','precision' => '255', 'nullable' => True),
+				'description' => array('type' => 'text', 'nullable' => True),
 				'activity_id' => array('type' => 'int','precision' => '4','nullable' => True),
 				'customer_identifier_type' => array('type' => 'varchar',  'precision' => '255', 'nullable' => True),
 				'customer_number' => array('type' => 'text', 'nullable' => True),
@@ -84,6 +87,7 @@
 				'customer_ssn' => array('type' => 'varchar',  'precision' => '12', 'nullable' => True),
 				'customer_internal' => array('type' => 'int', 'nullable' => False, 'precision' => '4', 'default' => 1),
 				'shortname' => array('type' => 'varchar','precision' => '11', 'nullable' => True),			
+				'show_in_portal' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 0),
 		),
 			'pk' => array('id'),
 			'fk' => array(
@@ -98,7 +102,7 @@
 				'building_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
 				'type' => array('type' => 'varchar', 'precision' => '50', 'nullable' => False),
-				'description' => array('type' => 'text', 'nullable' => False, 'default'=>''),
+				'description' => array('type' => 'text', 'nullable' => True),
 				'activity_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'sort' => array('type' => 'int','precision' => '4','nullable' => False,'default' => 0),
 			),
@@ -114,10 +118,11 @@
 				'id' => array('type' => 'auto', 'nullable' => false),
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
 				'organization_id' => array('type' => 'int','precision' => '4','nullable' => False),
-				'description' => array('type' => 'text', 'nullable' => False, 'default'=>''),
+				'description' => array('type' => 'text', 'nullable' => True),
 				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
 				'activity_id' => array('type' => 'int','precision' => '4','nullable' => True),
 				'shortname' => array('type' => 'varchar','precision' => '11', 'nullable' => True),			
+				'show_in_portal' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 0),
 		),
 			'pk' => array('id'),
 			'fk' => array(
@@ -163,12 +168,14 @@
 		'bb_application' => array(
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => False),
+				'id_string' => array('type' => 'varchar','precision' => '20', 'nullable' => False, 'default' => '0'),
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
 				'display_in_dashboard' => array('type' => 'int', 'nullable' => False, 'precision' => '4', 'default' => 1),
 				'status' => array('type' => 'text', 'nullable'=> False),
-				'created' => array('type' => 'timestamp', 'nullable'=> False, 'default' => 'now'),
-				'modified' => array('type' => 'timestamp', 'nullable'=> False, 'default' => 'now'),
+				'created' => array('type' => 'timestamp', 'nullable'=> False, 'default' => 'current_timestamp'),
+				'modified' => array('type' => 'timestamp', 'nullable'=> False),
 				'frontend_modified' => array('type' => 'timestamp', 'nullable'=> True),
+				'building_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'activity_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'description' => array('type' => 'text', 'nullable' => False),
 				'contact_name' => array('type' => 'text', 'nullable' => False),
@@ -194,12 +201,14 @@
 		'bb_allocation' => array(
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => False),
+				'id_string' => array('type' => 'varchar','precision' => '20', 'nullable' => False, 'default' => '0'),
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
+				'building_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'application_id' => array('type' => 'int','precision' => '4','nullable' => True),
 				'organization_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'from_' => array('type' => 'timestamp','nullable' => False),
 				'to_' => array('type' => 'timestamp','nullable' => False),
-				'cost' => array('type' => 'decimal','precision' => '10', 'scale'=>'2', 'nullable' => False),
+				'cost' => array('type' => 'decimal', 'precision' => 10, 'scale' => 2,'nullable' => True,'default' => '0.0'),
 				'season_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'completed' => array('type' => 'int', 'precision' => '4', 'nullable' => False, 'default' => 0),
 			),
@@ -217,12 +226,13 @@
 				'group_id' => array('type' => 'int', 'precision' => 4,'nullable' => False),
 				'from_' => array('type' => 'timestamp','nullable' => False),
 				'to_' => array('type' => 'timestamp','nullable' => False),
+				'building_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'allocation_id' => array('type' => 'int', 'precision' => 4,'nullable' => True),
 				'season_id' => array('type' => 'int', 'precision' => 4,'nullable' => False),
 				'active' => array('type' => 'int', 'precision' => 4,'nullable' => False,'default' => '1'),
 				'activity_id' => array('type' => 'int', 'precision' => 4,'nullable' => False),
 				'completed' => array('type' => 'int', 'precision' => 4,'nullable' => False,'default' => '0'),
-				'cost' => array('type' => 'decimal', 'precision' => 10, 'scale' => 2,'nullable' => False,'default' => '0.0'),
+				'cost' => array('type' => 'decimal', 'precision' => 10, 'scale' => 2,'nullable' => True,'default' => '0.0'),
 				'application_id' => array('type' => 'int', 'precision' => 4,'nullable' => True),
 				'reminder' => array('type' => 'int', 'precision' => 4,'nullable' => False,'default' => '0'),
 				'secret' => array('type' => 'text','nullable' => False),
@@ -270,7 +280,7 @@
 				'season_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'organization_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'wday' => array('type' => 'int','precision' => '4','nullable' => False),
-				'cost' => array('type' => 'decimal','precision' => '10', 'scale'=>'2', 'nullable' => False),
+				'cost' => array('type' => 'decimal', 'precision' => 10, 'scale' => 2,'nullable' => True,'default' => '0.0'),
 				'from_' => array('type' => 'time','nullable' => False),
 				'to_' => array('type' => 'time','nullable' => False),
 			),
@@ -328,7 +338,7 @@
 				'time' => array('type' => 'timestamp', 'nullable' => False),
 				'author' => array('type' => 'text', 'nullable' => False),
 				'comment' => array('type' => 'text', 'nullable' => False),
-				'type' => array('type' => 'text', 'nullable' => False, 'default'=>'comment'),
+				'type' => array('type' => 'varchar',  'precision' => '20', 'nullable' => false, 'default' => 'comment'),
 			),
 			'pk' => array('id'),
 			'fk' => array(
@@ -475,10 +485,10 @@
 		'bb_organization_contact' => array(
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => false),
-				'name' => array('type' => 'varchar', 'precision' => '50', 'nullable' => false, 'default'=>''),
-				'ssn' => array('type' => 'varchar',  'precision' => '12', 'nullable' => false, 'default'=>''),
-				'phone' => array('type' => 'varchar', 'precision' => '50', 'nullable' => false, 'default'=>''),
-				'email' => array('type' => 'varchar', 'precision' => '50', 'nullable' => false, 'default'=>''),
+				'name' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
+				'ssn' => array('type' => 'varchar',  'precision' => '12', 'nullable' => True),
+				'phone' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
+				'email' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
 				'organization_id' => array('type' => 'int', 'precision' => '4', 'nullable' => false),
 			),
 			'pk' => array('id'),
@@ -491,9 +501,9 @@
 		'bb_group_contact' => array(
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => false),
-				'name' => array('type' => 'varchar', 'precision' => '50', 'nullable' => false, 'default'=>''),
-				'phone' => array('type' => 'varchar', 'precision' => '50', 'nullable' => false, 'default'=>''),
-				'email' => array('type' => 'varchar', 'precision' => '50', 'nullable' => false, 'default'=>''),
+				'name' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
+				'phone' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
+				'email' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
 				'group_id' => array('type' => 'int', 'precision' => '4', 'nullable' => false),
 			),
 			'pk' => array('id'),
@@ -506,16 +516,20 @@
 		'bb_event' => array(
 			'fd' => array(
 				'id' => array('type' => 'auto','nullable' => False),
+				'id_string' => array('type' => 'varchar','precision' => '20', 'nullable' => False, 'default' => '0'),
 				'active' => array('type' => 'int', 'precision' => 4,'nullable' => False,'default' => '1'),
 				'activity_id' => array('type' => 'int', 'precision' => 4,'nullable' => False),
 				'description' => array('type' => 'text','nullable' => False),
 				'from_' => array('type' => 'timestamp','nullable' => False),
 				'to_' => array('type' => 'timestamp','nullable' => False),
-				'cost' => array('type' => 'decimal', 'precision' => 10, 'scale' => 2,'nullable' => False),
+				'cost' => array('type' => 'decimal', 'precision' => 10, 'scale' => 2,'nullable' => True,'default' => '0.0'),
+				'building_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'contact_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'contact_email' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'contact_phone' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'completed' => array('type' => 'int', 'precision' => 4,'nullable' => False,'default' => '0'),
+				'customer_organization_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => True),
+				'customer_organization_id' => array('type' => 'int', 'precision' => 4,'nullable' => True),
 				'customer_identifier_type' => array('type' => 'varchar', 'precision' => 255,'nullable' => True),
 				'customer_organization_number' => array('type' => 'varchar', 'precision' => 9,'nullable' => True),
 				'customer_ssn' => array('type' => 'varchar', 'precision' => 12,'nullable' => True),
@@ -580,7 +594,7 @@
 				'time' => array('type' => 'timestamp', 'nullable' => False),
 				'author' => array('type' => 'text', 'nullable' => False),
 				'comment' => array('type' => 'text', 'nullable' => False),
-				'type' => array('type' => 'text', 'nullable' => False, 'default'=>'comment'),
+				'type' => array('type' => 'varchar',  'precision' => '20', 'nullable' => false, 'default' => 'comment'),
 			),
 			'pk' => array('id'),
 			'fk' => array(
@@ -645,7 +659,7 @@
 				'reservation_type' 	=> array('type' => 'varchar', 'precision' => '70', 'nullable' => False),
 				'reservation_id' 		=> array('type' => 'int', 'precision' => '4', 'nullable' => False),
 				'season_id' 			=> array('type' => 'int', 'precision' => '4'),
-				'cost' => array('type' => 'decimal','precision' => '10', 'scale'=>'2', 'nullable' => False),
+				'cost' => array('type' => 'decimal', 'precision' => 10, 'scale' => 2,'nullable' => True,'default' => '0.0'),
 				'from_' => array('type' => 'timestamp', 'nullable' => false),
 				'to_' => array('type' => 'timestamp', 'nullable' => false),
 				'organization_id' 		=> array('type' => 'int', 'precision' => '4'),
@@ -727,7 +741,7 @@
 		'bb_billing_sequential_number_generator' => array(
 			'fd' => array(
 				'id' 		=> array('type' => 'auto', 'nullable' => False),
-				'name'   => array('type' => 'text', 'nullable' => False),
+				'name' => array('type' => 'varchar','precision' => '100','nullable' => False),// FIXME
 				'value'	=> array('type' => 'int', 'precision' => '4', 'nullable' => False, 'default' => 0),
 			),
 			'pk' => array('id'),
@@ -742,17 +756,30 @@
 				'created' => array('type' => 'timestamp', 'nullable' => False,'default' => 'current_timestamp'),
 				'display_in_dashboard' => array('type' => 'int', 'nullable' => False, 'precision' => '4', 'default' => 1),
 				'building_id' => array('type' => 'int', 'precision' => '4'),
+				'building_name' => array('type' => 'varchar', 'precision' => '50','nullable' => False),
 				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
-				'phone' => array('type' => 'varchar','precision' => '50','nullable' => False),
-				'email' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'phone' => array('type' => 'varchar','precision' => '50','nullable' => true),
+				'email' => array('type' => 'varchar','precision' => '50','nullable' => true),
 				'message' => array('type' => 'text', 'nullable' => False),
-				'type' => array('type' => 'text', 'nullable' => False, 'default'=>'message'),
-				'status' => array('type' => 'text', 'nullable' => False, 'default'=>'new'),
+				'type' => array('type' => 'varchar',  'precision' => '20', 'nullable' => false, 'default' => 'comment'),
+				'status' => array('type' => 'varchar',  'precision' => '20', 'nullable' => false, 'default' => 'NEW'),
 			),
 			'pk' => array('id'),
 			'fk' => array(),
 			'ix' => array(),
 			'uc' => array()
-		)
+		),
+		'bb_documentation' => array(
+			'fd' => array(
+				'id' => array('type' => 'auto', 'nullable' => false),
+				'name' => array('type' => 'varchar', 'precision' => '255', 'nullable' => false),
+				'category' => array('type' => 'varchar', 'precision' => '150', 'nullable' => false),
+				'description' => array('type' => 'text', 'nullable' => true),
+			),
+			'pk' => array('id'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array()
+		),
 
 	);
