@@ -13,6 +13,7 @@
 			'edit' =>				true,
 			'report_numbers' =>		true,
 			'massupdate' =>			true,
+			'cancel' =>		    	true,
 		);
 
 		public function __construct()
@@ -23,6 +24,7 @@
 			$this->allocation_bo = CreateObject('booking.boallocation');
 			$this->season_bo = CreateObject('booking.boseason');
 			$this->building_bo = CreateObject('booking.bobuilding');
+			$this->system_message_bo = CreateObject('booking.bosystem_message');
 		}
 
 		private function item_link(&$item, $key)
@@ -75,11 +77,12 @@
 			$booking = array();
 			$booking['building_id'] = phpgw::get_var('building_id', 'int', 'GET');
 			$allocation_id = phpgw::get_var('allocation_id', 'int', 'GET');
-			$booking['resources'] = phpgw::get_var('resources', 'int', 'GET');
-			$booking['from_'] = phpgw::get_var('from_', 'str', 'GET');
-			$booking['to_'] = phpgw::get_var('to_', 'str', 'GET');
+            #The string replace is a workaround for a problem at Bergen Kommune 
+            $booking['from_'] = str_replace('%3A',':',phpgw::get_var('from_', 'str', 'GET'));
+            $booking['to_'] = str_replace('%3A',':',phpgw::get_var('to_', 'str', 'GET'));
 			$time_from = split(" ",phpgw::get_var('from_', 'str', 'GET'));
 			$time_to = 	split(" ",phpgw::get_var('to_', 'str', 'GET'));
+
 			$step = phpgw::get_var('step', 'str', 'POST');
 			if (! isset($step)) $step = 1;
 			$invalid_dates = array();
@@ -94,7 +97,9 @@
 				$booking['building_id'] = $building['id'];
 				$booking['building_name'] = $building['name'];
 				array_set_default($booking, 'resources', array(get_var('resource', int, 'GET')));
-			}
+			} else {
+				$season = $this->season_bo->read_single($_POST['season_id']);
+            }
 			if($_SERVER['REQUEST_METHOD'] == 'POST')
 			{
 				$today = getdate();
@@ -123,18 +128,18 @@
 				$errors = $this->bo->validate($booking);
 
 
-				if (strtotime($_POST['from_']) < $today[0])
-				{
-					if($_POST['recurring'] == 'on' || $_POST['outseason'] == 'on')
-					{					
-						$errors['booking'] = lang('Can not repeat from a date in the past');
-					}
-					else
-					{
-						$errors['booking'] = lang('Can not create a booking in the past');
-					}
-				} 
-				if (!$allocation_id &&  $_POST['outseason'] == 'on')
+#				if (strtotime($_POST['from_']) < $today[0])
+#				{
+#					if($_POST['recurring'] == 'on' || $_POST['outseason'] == 'on')
+#					{					
+#						$errors['booking'] = lang('Can not repeat from a date in the past');
+#					}
+#					else
+#					{
+#						$errors['booking'] = lang('Can not create a booking in the past');
+#					}
+#				} 
+				if (!$season['id'] &&  $_POST['outseason'] == 'on')
 				{
 					$errors['booking'] = lang('This booking is not connected to a season');
 				}	
@@ -210,13 +215,12 @@
 			$groups = $this->group_bo->so->read(array('filters'=>array('organization_id'=>$allocation['organization_id'], 'active'=>1)));
 			$groups = $groups['results'];
 			$booking['organization_name'] = $allocation['organization_name'];
-			$resouces_full = $this->resource_bo->so->read(array('filters'=>array('id'=>$booking['resources']), 'sort'=>'name'));
+			$resources_full = $this->resource_bo->so->read(array('filters'=>array('id'=>$booking['resources']), 'sort'=>'name'));
 			$res_names = array();
-			foreach($resouces_full['results'] as $res)
+			foreach($resources_full['results'] as $res)
 			{
 				$res_names[] = array('id' => $res['id'],'name' => $res['name']);
 			}
-
 			if ($step < 2) 
 			{
 				self::render_template('booking_new', array('booking' => $booking, 
@@ -300,29 +304,131 @@
 
 		public function edit()
 		{
+
 			$id = intval(phpgw::get_var('id', 'GET'));
 			$booking = $this->bo->read_single($id);
 			$booking['building'] = $this->building_bo->so->read_single($booking['building_id']);
 			$booking['building_name'] = $booking['building']['name'];
 			$allocation = $this->allocation_bo->read_single($booking['allocation_id']);
 			$errors = array();
+			$update_count = 0;
+			$today = getdate();
+			$step = intval(phpgw::get_var('step', 'POST'));
+
 			if($_SERVER['REQUEST_METHOD'] == 'POST')
 			{
-				array_set_default($_POST, 'resources', array());
-				$booking = array_merge($booking, extract_values($_POST, $this->fields));
-				$this->agegroup_bo->extract_form_data($booking);
-				$errors = $this->bo->validate($booking);
-				if(!$errors)
+
+				if (!($_POST['recurring'] == 'on' || $_POST['outseason'] == 'on')){
+
+					array_set_default($_POST, 'resources', array());
+					$booking = array_merge($booking, extract_values($_POST, $this->fields));
+					$this->agegroup_bo->extract_form_data($booking);
+					$errors = $this->bo->validate($booking);
+				
+					if (strtotime($_POST['from_']) < ($today[0]-60*60*24*7*2))
+					{
+						$errors['booking'] = lang('You cant edit a booking that is older than 2 weeks');
+					}										
+					if (!$errors) {
+						$receipt = $this->bo->update($booking);
+						$this->redirect(array('menuaction' => 'bookingfrontend.uibuilding.schedule', 'id'=>$booking['building_id']));
+					}
+				} 
+				else 
 				{
-					$receipt = $this->bo->update($booking);
-					$this->redirect(array('menuaction' => 'bookingfrontend.uibuilding.schedule', 'id'=>$booking['building_id']));
+					$step++;
+
+					if (strtotime($_POST['from_']) < ($today[0]-60*60*24*7*2) && $step != 3)
+					{					
+						$errors['booking'] = lang('You cant update bookings that is older than 2 weeks');
+					}
+
+					if (!$booking['allocation_id'] &&  $_POST['outseason'] == 'on')
+					{
+						$errors['booking'] = lang('This booking is not connected to a season');
+					}	
+
+					if (!$errors)
+					{
+
+						if ($_POST['recurring'] == 'on') {
+							$repeat_until = strtotime($_POST['repeat_until'])+60*60*24; 
+						} 
+						else
+						{
+							$repeat_until = strtotime($season['to_'])+60*60*24; 
+							$_POST['repeat_until'] = $season['to_'];
+						} 
+
+						$max_dato = strtotime($_POST['to_']); // highest date from input
+	
+						$season = $this->season_bo->read_single($booking['season_id']);
+				
+						$where_clauses[] = sprintf("bb_booking.from_ >= '%s 00:00:00'", date('Y-m-d', strtotime($_POST['from_'])));
+						if ($_POST['recurring'] == 'on') {
+							$where_clauses[] = sprintf("bb_booking.to_ < '%s 00:00:00'", date('Y-m-d', $repeat_until));
+						}
+						$params['filters']['where'] = $where_clauses;
+						$params['filters']['season_id'] = $booking['season_id'];
+						$params['filters']['group_id'] = $booking['group_id'];
+
+						$bookings = $this->bo->so->read($params);
+
+						if ($step == 2)
+						{
+							
+							$_SESSION['audience'] = $_POST['audience'];
+							$_SESSION['male'] = $_POST['male'];
+							$_SESSION['female'] = $_POST['female'];
+						
+						}
+
+						if ($step == 3)
+						{
+							foreach($bookings['results'] as $b)
+							{
+								//reformatting the post variable to fit the booking object
+								$temp_agegroup = array();
+								$sexes = array('male', 'female');
+								foreach($sexes as $sex)
+								{
+									$i = 0;
+									foreach($_SESSION[$sex] as $agegroup_id => $value)
+									{
+										$temp_agegroup[$i]['agegroup_id'] = $agegroup_id;
+										$temp_agegroup[$i][$sex] = $value;
+										$i++;
+									}
+								}
+
+								$b['agegroups'] = $temp_agegroup;
+								$b['audience'] = $_SESSION['audience'];
+								$b['group_id'] =$_POST['group_id'];
+								$b['activity_id'] = $_POST['activity_id'];
+								$errors = $this->bo->validate($b);
+								if(!$errors)
+								{
+
+									$receipt = $this->bo->update($b);
+									$update_count++;
+									
+								}
+							}
+							unset($_SESSION['female']);
+							unset($_SESSION['male']);
+							unset($_SESSION['audience']);
+
+						}
+					}
 				}
 			}
 			$this->flash_form_errors($errors);
 			self::add_javascript('bookingfrontend', 'bookingfrontend', 'booking.js');
-			$booking['resources_json'] = json_encode(array_map('intval', $booking['resources']));
+			if ($step < 2) {
+				$booking['resources_json'] = json_encode(array_map('intval', $booking['resources']));
+				$booking['organization_name'] = $group['organization_name'];
+			}
 			$booking['cancel_link'] = self::link(array('menuaction' => 'bookingfrontend.uibuilding.schedule', 'id' => $booking['building_id']));
-			$booking['update_link'] = self::link(array('menuaction' => 'bookingfrontend.uibooking.massupdate', 'id' => $booking['id']));
 			$agegroups = $this->agegroup_bo->fetch_age_groups();
 			$agegroups = $agegroups['results'];
 			$audience = $this->audience_bo->fetch_target_audience();
@@ -332,8 +438,37 @@
 			$group = $this->group_bo->so->read_single($booking['group_id']);
 			$groups = $this->group_bo->so->read(array('filters'=>array('organization_id'=>$group['organization_id'], 'active'=>1)));
 			$groups =  $groups['results'];
-			$booking['organization_name'] = $group['organization_name'];
-			self::render_template('booking_edit', array('booking' => $booking, 'activities' => $activities, 'agegroups' => $agegroups, 'audience' => $audience, 'groups' => $groups));
+			if ($step < 2) 
+			{
+				self::render_template('booking_edit', array('booking' => $booking, 
+					'activities' => $activities, 
+					'agegroups' => $agegroups, 
+					'audience' => $audience, 
+					'groups' => $groups, 
+					'step' => $step, 
+					'repeat_until' => $_POST['repeat_until'],
+					'recurring' => $_POST['recurring'],
+					'outseason' => $_POST['outseason'],
+					)
+				);
+			} 
+			else if ($step >= 2) 
+			{
+				self::render_template('booking_edit_preview', array('booking' => $booking, 
+					'bookings' => $bookings,
+					'agegroups' => $agegroups,
+					'audience' => $audience,
+					'groups' => $groups,
+					'activities' => $activities,
+					'step' => $step,
+					'repeat_until' => $_POST['repeat_until'],
+					'recurring' => $_POST['recurring'],
+					'outseason' => $_POST['outseason'],
+					'group_id' => $_POST['group_id'],
+					'activity_id' => $_POST['activity_id'],
+					'update_count' => $update_count)
+				);
+			}
 		}
 
 		public function massupdate()
@@ -427,6 +562,51 @@
 					);
 		}
 
+		public function cancel()
+		{
+        	$booking = $this->bo->read_single(intval(phpgw::get_var('id', 'GET')));
+
+   			$errors = array();
+			if($_SERVER['REQUEST_METHOD'] == 'POST')
+            {
+            
+                $from = $_POST['from_'];
+                $to =  $_POST['to_'];
+                $organization_id = $_POST['organization_id'];
+                $outseason = $_POST['outseason'];
+                $recurring = $_POST['recurring'];
+                $repeat_until = $_POST['repeat_until'];
+                $field_interval = $_POST['field_interval'];
+                $delete_allocation = $_POST['delete_allocation'];
+
+				date_default_timezone_set("Europe/Oslo");
+				$date = new DateTime(phpgw::get_var('date'));
+				$system_message = array();
+				$system_message['building_id'] = intval($booking['building_id']);
+				$system_message['building_name'] = $this->bo->so->get_building($system_message['building_id']);
+				$system_message['created'] =  $date->format('Y-m-d  H:m');
+				$system_message = array_merge($system_message, extract_values($_POST, array('message')));
+                $system_message['type'] = 'cancelation';
+				$system_message['status'] = 'NEW';
+				$system_message['name'] = ' ';
+				$system_message['phone'] = ' ';
+				$system_message['email'] = ' ';
+				$system_message['title'] = lang('Cancelation of booking from')." ".$booking['group_name'];
+
+                $link = self::link(array('menuaction' => 'booking.uibooking.delete','id' => $booking['id'], 'outseason' => $outseason, 'recurring' => $recurring, 'repeat_until' => $repeat_until, 'field_interval' => $field_interval, 'delete_allocation' => $delete_allocation));
+                $link = mb_strcut($link,16,strlen($link));
+                $system_message['message'] = $system_message['message']."\n\n".lang('To cancel booking use this link')." - <a href='".$link."'>".lang('Delete')."</a>";
+				$receipt = $this->system_message_bo->add($system_message);
+				$this->redirect(array('menuaction' =>  'bookingfrontend.uibuilding.schedule', 'id' => $system_message['building_id']));
+
+            }
+            $this->flash_form_errors($errors);
+			$allocation['cancel_link'] = self::link(array('menuaction' => 'bookingfrontend.uibuilding.schedule', 'id' => $allocation['building_id']));
+
+			$this->use_yui_editor();
+			self::render_template('booking_cancel', array('booking'=>$booking));
+        }		
+
 		public function info()
 		{
 			$booking = $this->bo->read_single(intval(phpgw::get_var('id', 'GET')));
@@ -445,8 +625,10 @@
 			
 			$bouser = CreateObject('bookingfrontend.bouser');
 			if($bouser->is_group_admin($booking['group_id']))
+            {
 				$booking['edit_link'] = self::link(array('menuaction' => 'bookingfrontend.uibooking.edit', 'id' => $booking['id']));
-				
+				$booking['cancel_link'] = self::link(array('menuaction' => 'bookingfrontend.uibooking.cancel', 'id' => $booking['id']));
+            }
 			$booking['when'] = pretty_timestamp($booking['from_']).' - '.pretty_timestamp($booking['to_']);
 			self::render_template('booking_info', array('booking'=>$booking));
 			$GLOBALS['phpgw']->xslttpl->set_output('wml'); // Evil hack to disable page chrome
