@@ -27,11 +27,11 @@
 			{
 				$search = array(
 					'results'    => $this->bo->search($searchterm),
-					'searchterm' => $searchterm,
+					'searchterm' => $searchterm
 				);
 			}
 			
-			$params = is_null($search) ? array() : array('search' => $search);
+			$params = is_null($search) ? array('frontimage' => "{$GLOBALS['phpgw_info']['server']['webserver_url']}/phpgwapi/templates/bkbooking/images/newlayout/forsidebilde.jpg") : array('search' => $search);
 
 			self::render_template('search', $params);
 		}
