@@ -12,7 +12,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: class.bocalendar.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: class.bocalendar.inc.php 2428 2009-02-22 20:52:15Z sigurd $ */
 
 	phpgw::import_class('phpgwapi.datetime');
 
@@ -137,6 +137,9 @@
 		var $num_months;
 
 		var $save_owner;
+		var $return_to;
+
+		protected $_jscal;
 
 		public function __construct($session = false)
 		{
@@ -504,17 +507,22 @@
 		{
 			$data = $GLOBALS['phpgw']->session->appsession('session_data','calendar');
 			print_debug('Read',_debug_array($data,False));
+			// no data is returned as an empty string
+			if ( !$data )
+			{
+				return;
+			}
 
 			$this->filter = $data['filter'];
 			$this->cat_id = $data['cat_id'];
-			$this->sortby = (isset($data['sortby']) && $data['sortby']? $data['sortby']:'');
-			$this->owner  = intval($data['owner']);
-			$this->save_owner = (isset($data['save_owner'])?intval($data['save_owner']):0)	;
-			$this->year   = intval($data['year']);
-			$this->month  = intval($data['month']);
-			$this->day    = intval($data['day']);
-			$this->num_months = (isset($data['num_months'])?intval($data['num_months']):0);
-			$this->return_to = (isset($data['return_to'])?$data['return_to']:'');
+			$this->sortby = isset($data['sortby']) && $data['sortby'] ? $data['sortby']:'';
+			$this->owner  = (int) $data['owner'];
+			$this->save_owner = isset($data['save_owner']) ? (int) $data['save_owner'] : 0;
+			$this->year   = (int) $data['year'];
+			$this->month  = (int) $data['month'];
+			$this->day    = (int) $data['day'];
+			$this->num_months = isset($data['num_months']) ? (int) $data['num_months'] : 0;
+			$this->return_to = isset($data['return_to']) ? $data['return_to'] : array();
 		}
 
 		function read_entry($id = 0)
@@ -686,21 +694,24 @@
 		{
 			$l_cal = isset($params['cal']) && $params['cal'] ? $params['cal'] : phpgw::get_var('cal', 'string', 'POST');
 			$l_participants = isset($params['participants']) ? $params['participants'] : phpgw::get_var('participants', 'string', 'POST');
-			$l_categories = $params['categories'] ? $params['categories'] : phpgw::get_var('categories', 'strint', 'POST');
-			$l_start = isset($params['start']) && $params['start'] ? $params['start'] : phpgw::get_var('start', 'int', 'POST');
-			$l_end = isset($params['end']) && $params['end'] ? $params['end'] : phpgw::get_var('end', 'int', 'POST');
+			$l_categories = isset($params['categories']) ? $params['categories'] : phpgw::get_var('categories', 'string', 'POST');
+			$l_start = isset($params['start']) && $params['start'] ? $params['start'] : phpgw::get_var('start', 'string', 'POST');
+			$l_end = isset($params['end']) && $params['end'] ? $params['end'] : phpgw::get_var('end', 'string', 'POST');
 			$l_recur_enddate = isset($params['recur_enddate']) && $params['recur_enddate'] ? $params['recur_enddate'] : phpgw::get_var('recur_enddate', 'string', 'POST'); // probbaly can be bool
-			$l_recur_exception = explode (',', $_POST['recur_exception']);
+			$l_recur_exception = explode(',', phpgw::get_var('recur_exception', 'string', 'POST') );
 
 			$send_to_ui = true;
 			if($this->debug)
 			{
 				$send_to_ui = true;
 			}
+
+			/* no idea what is meant to happen here and triggers a lot of notices
 			if($p_cal || $p_participants || $p_start || $p_end || $p_recur_enddata)
 			{
 				$send_to_ui = false;
 			}
+			*/
 			
 			print_debug('ID',$l_cal['id']);
 
@@ -767,7 +778,8 @@
 					$this->so->add_attribute('id',$l_cal['id']);
 				}
 
-				if($l_cal['rpt_use_end'] != 'y')
+				if ( !isset($l_cal['rpt_use_end'])
+					|| $l_cal['rpt_use_end'] != 'y')
 				{
 					$l_recur_enddate['year'] = 0;
 					$l_recur_enddate['month'] = 0;
@@ -775,7 +787,7 @@
 				}
 				elseif (isset($l_recur_enddate['str']))
 				{
-					$l_recur_enddate = $this->jscal->input2date($l_recur_enddate['str'],False,'mday');
+					$l_recur_enddate = $this->_jscal->input2date($l_recur_enddate['str'],False,'mday');
 				}
 
 				switch(intval($l_cal['recur_type']))
@@ -831,11 +843,11 @@
 						}
 						else
 						{
-							if (($accept_type = substr($parts[$i],-1,1)) == '0' || intval($accept_type) > 0)
+							if (($accept_type = substr($participant, -1, 1)) == '0' || intval($accept_type) > 0)
 							{
 								$accept_type = 'U';
 							}
-							$this->so->add_attribute('participants', $accept_type, intval($participant));
+							$this->so->add_attribute('participants', $accept_type, (int) $participant);
 						}
 					}
 				}
@@ -895,7 +907,7 @@
 					);
 				}
 
-				$event[recur_exception] = $l_recur_exception;
+				$event['recur_exception'] = $l_recur_exception;
 
 				$this->store_to_appsession($event);
 				$datetime_check = $this->validate_update($event);
@@ -911,11 +923,12 @@
 					$GLOBALS['phpgw']->common->phpgw_exit(True);
 				}
 
-				if($event['id'])
+				if ( isset($event['id']) )
 				{
 					$event_ids[] = $event['id'];
 				}
-				if($event['reference'])
+
+				if ( isset($event['reference']) )
 				{
 					$event_ids[] = $event['reference'];
 				}
@@ -949,12 +962,11 @@
 			}
 			else
 			{
-				if(!$event['id'])
+				if ( !isset($event['id']) )
 				{
 					$this->so->cal->event = $event;
 					$this->so->add_entry($event);
 					$this->send_update(MSG_ADDED,$event['participants'],'',$this->get_cached_event());
-					print_debug('New Event ID',$event['id']);
 				}
 				else
 				{
@@ -988,7 +1000,11 @@
 				$year = $this->year;
 			}
 			$holiday = CreateObject('calendar.boholiday');
-			$holiday->prepare_read_holidays($year,$this->owner);
+			
+			$account = $this->contacts->are_users($this->owner);
+	//		_debug_array($account[0]['account_id']);
+			
+			$holiday->prepare_read_holidays($year,$account[0]['account_id']);
 			$this->cached_holidays = $holiday->read_holiday();
 			unset($holiday);
 		}
@@ -1067,11 +1083,11 @@
 		{
 			if (isset($time_param['str']))
 			{
-				if (!is_object($this->jscal))
+				if (!is_object($this->_jscal))
 				{
-					$this->jscal = CreateObject('phpgwapi.jscalendar');
+					$this->_jscal = CreateObject('phpgwapi.jscalendar');
 				}
-				$time_param += $this->jscal->input2date($time_param['str'],False,'mday');
+				$time_param += $this->_jscal->input2date($time_param['str'],False,'mday');
 				unset($time_param['str']);
 			}
 			if ($this->prefs['common']['timeformat'] == '12')
@@ -2386,6 +2402,7 @@
 		 */
 		function send_update($msg_type,$to_notify,$old_event,$new_event=False,$user=False)
 		{
+			$returncode = true;
 			//echo "<p>bocalendar::send_update(type=$msg_type,to_notify="; print_r($to_notify); echo ", old_event="; print_r($old_event); echo ", new_event="; print_r($new_event); echo ", user=$user)</p>\n";
 			if (!is_array($to_notify))
 			{
@@ -2517,14 +2534,13 @@
 					print_debug('UserID',$userid);
 
 					$preferences = CreateObject('phpgwapi.preferences',$userid);
-					$part_prefs = $preferences->read_repository();
+					$part_prefs = $preferences->read();
 
 					if (!$this->update_requested($userid,$part_prefs,$msg_type,$old_event,$new_event))
 					{
 						continue;
 					}
-					$GLOBALS['phpgw']->accounts->get_account_name($userid,$lid,$details['to-firstname'],$details['to-lastname']);
-					$details['to-fullname'] = $GLOBALS['phpgw']->common->display_fullname('',$details['to-firstname'],$details['to-lastname']);
+					$details['to-fullname'] = (string) $GLOBALS['phpgw']->accounts->get($userid);
 
 					$to = $preferences->email_address($userid);
 					if (empty($to) || $to[0] == '@' || $to[0] == '$')	// we have no valid email-address
@@ -2595,8 +2611,9 @@
 			}
 			unset($send);
 		
-			if((is_int($this->user) && $this->user != $temp_user['account_id']) ||
-				(is_string($this->user) && $this->user != $temp_user['account_lid']))
+			if( isset($this->user) 
+				&& ( (is_int($this->user) && $this->user != $temp_user['account_id'])
+				|| (is_string($this->user) && $this->user != $temp_user['account_lid'])) )
 			{
 				$GLOBALS['phpgw_info']['user'] = $temp_user;
 			}
@@ -2873,7 +2890,7 @@
 		 */
 		function event2array($event)
 		{
-			$user_timezone = phpgw_datetime::user_timezone();
+			$user_timezone = phpgwapi_datetime::user_timezone();
 
 			if ( !is_object($GLOBALS['phpgw']->contacts) )
 			{
@@ -2893,6 +2910,7 @@
 			);
 
 			$cats = array();
+			$cat_string[] = '';
 			$this->cat->categories($this->owner,'calendar');
 			if(strpos($event['category'],','))
 			{
@@ -2904,6 +2922,11 @@
 			}
 			foreach($cats as $cat_id)
 			{
+				if ( !$cat_id )
+				{
+					continue;
+				}
+
 				list($cat) = $this->cat->return_single($cat_id);
 				$cat_string[] = $cat['name'];
 			}
@@ -2927,12 +2950,19 @@
 				'data'	=> $GLOBALS['phpgw']->common->show_date($this->maketime($event['end']) - $user_timezone)
 			);
 
-			$pri = array(
+			$pri = array
+			(
 				1	=> lang('Low'),
 				2	=> lang('Normal'),
 		  		3	=> lang('High')
 			);
-			$var['priority'] = array(
+			if ( !$event['priority'] )
+			{
+				$event['priority'] = 1;
+			}
+
+			$var['priority'] = array
+			(
 				'field'	=> lang('Priority'),
 				'data'	=> $pri[$event['priority']]
 			);
@@ -2942,17 +2972,19 @@
 				'data'	=> $GLOBALS['phpgw']->contacts->get_name_of_person_id($event['owner'])
 			);
 
-			$var['updated'] = array(
+			$var['updated'] = array
+			(
 				'field'	=> lang('Updated'),
 				'data'	=> $GLOBALS['phpgw']->common->show_date($this->maketime($event['modtime']) - $user_timezone)
 			);
 
-			$var['access'] = array(
+			$var['access'] = array
+			(
 				'field'	=> lang('Access'),
 				'data'	=> $event['public'] ? lang('Public') : lang('Privat')
 			);
 
-			if(@isset($event['groups'][0]))
+			if ( isset($event['groups'][0]) )
 			{
 				$cal_grps = '';
 				for($i=0;$i<count($event['groups']);$i++)
@@ -2964,7 +2996,8 @@
 					}
 				}
 
-				$var['groups'] = array(
+				$var['groups'] = array
+				(
 					'field'	=> lang('Groups'),
 					'data'	=> $cal_grps
 				);
@@ -3141,17 +3174,17 @@
 		{
 			$fields = array ('contact_id', 'org_name');
 
-			$criteria_search[] = sql_criteria::token_begin('org_name', $lookup);
+			$criteria_search[] = phpgwapi_sql_criteria::token_begin('org_name', $lookup);
 
-			$criteria[] = sql_criteria::_append_or($criteria_search);
+			$criteria[] = phpgwapi_sql_criteria::_append_or($criteria_search);
 			$criteria[] = $this->contacts->criteria_for_index($GLOBALS['phpgw_info']['user']['account_id']);
 
 			if ( $cat_id )
 			{
-				$criteria[] = sql_criteria::_equal('cat_id', phpgw::get_var('cat_id', 'int', 'bool') );
+				$criteria[] = phpgwapi_sql_criteria::_equal('cat_id', phpgw::get_var('cat_id', 'int', 'bool') );
 			}
 
-			$criteria_token = sql_criteria::_append_and($criteria);
+			$criteria_token = phpgwapi_sql_criteria::_append_and($criteria);
 			return $this->contacts->get_orgs($fields, 0, 0, 'org_name', 'ASC', '', $criteria_token);
 		}
 
@@ -3168,18 +3201,18 @@
 			//echo "lookup == $lookup and user_id == {$GLOBALS['phpgw_info']['user']['account_id']}";
 			$fields = array ('contact_id', 'per_first_name', 'per_last_name');
 
-			$criteria_search[] = sql_criteria::token_begin('per_first_name', $lookup);
-			$criteria_search[] = sql_criteria::token_begin('per_last_name', $lookup);
+			$criteria_search[] = phpgwapi_sql_criteria::token_begin('per_first_name', $lookup);
+			$criteria_search[] = phpgwapi_sql_criteria::token_begin('per_last_name', $lookup);
 
-			$criteria[] = sql_criteria::_append_or($criteria_search);
+			$criteria[] = phpgwapi_sql_criteria::_append_or($criteria_search);
 			$criteria[] = $this->contacts->criteria_for_index((int) $GLOBALS['phpgw_info']['user']['account_id']);
 
 			if ( $cat_id )
 			{
-				$criteria[] = sql_criteria::_equal('cat_id', phpgw::get_var('cat_id', 'int', 'bool') );
+				$criteria[] = phpgwapi_sql_criteria::_equal('cat_id', phpgw::get_var('cat_id', 'int', 'bool') );
 			}
 
-			$criteria_token = sql_criteria::_append_and($criteria);
+			$criteria_token = phpgwapi_sql_criteria::_append_and($criteria);
 			return $this->contacts->get_persons($fields, 0, 0, 'per_first_name, per_last_name', 'ASC', '', $criteria_token);
 		}
 
@@ -3253,4 +3286,3 @@
 			return $cat_colors;
 		}
 	}
-?>
