@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: class.boholiday.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: class.boholiday.inc.php 1906 2008-11-28 22:47:27Z sigurd $ */
 
 	class calendar_boholiday
 	{
@@ -198,7 +198,7 @@
 			if($this->owner != $GLOBALS['phpgw_info']['user']['account_id'])
 			{
 				$owner_pref = CreateObject('phpgwapi.preferences',$owner);
-				$owner_prefs = $owner_pref->read_repository();
+				$owner_prefs = $owner_pref->read();
 				if(@$owner_prefs['common']['country'])
 				{
 					$this->locales[] = $owner_prefs['common']['country'];
@@ -419,7 +419,7 @@
 		{
 			if(!@$GLOBALS['phpgw_info']['user']['apps']['admin'])
 			{
-				Header('Location: ' . $GLOBALS['phpgw']->link('/index.php'));
+				$GLOBALS['phpgw']->redirect_link('/index.php');
 			}
 		}
 		
