@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: class.calendar_holiday.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: class.calendar_holiday.inc.php 4696 2010-02-01 22:48:22Z sigurd $ */
 
 class calendar_holiday
 {
@@ -39,7 +39,7 @@ class calendar_holiday
 		if($owner_id != $phpgw_info['user']['account_id'])
 		{
 			$owner_pref = CreateObject('phpgwapi.preferences',$owner_id);
-			$owner_prefs = $owner_pref->read_repository();
+			$owner_prefs = $owner_pref->read();
 			if(isset($owner_prefs['calendar']['locale']) && $owner_prefs['common']['country'])
 			{
 				$this->users['owner'] = $owner_prefs['common']['country'];
@@ -61,10 +61,10 @@ class calendar_holiday
 
 	function is_network_load_needed($locale)
 	{
-		$sql = "SELECT count(*) FROM phpgw_cal_holidays WHERE locale='".$locale."'";
+		$sql = "SELECT count(*) as cnt FROM phpgw_cal_holidays WHERE locale='".$locale."'";
 		$this->db->query($sql,__LINE__,__FILE__);
 		$this->db->next_record();
-		$rows = $this->db->f(0);
+		$rows = $this->db->f('cnt');
 		if($rows==0)
 		{
 			$this->load_from_network($locale);
