@@ -12,7 +12,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.socalendar_sql.inc.php 4696 2010-02-01 22:48:22Z sigurd $ */
+  /* $Id: class.socalendar_sql.inc.php 7215 2011-04-12 20:06:07Z sigurdne $ */
 
 phpgw::import_class('phpgwapi.datetime');
 
@@ -92,7 +92,7 @@ class calendar_socalendar_ extends calendar_socalendar__
 			$this->delete_event( (int) $this->stream->f('cal_id'));
 		}
 //		$this->stream->lock(array('phpgw_cal_user'));
-		if ( $this->stream->Transaction )
+		if ( $this->stream->get_transaction() )
 		{
 			$this->global_lock = true;
 		}
@@ -507,7 +507,7 @@ class calendar_socalendar_ extends calendar_socalendar__
 		);
 		$this->stream->lock($locks);
 */
-		if ( $this->stream->Transaction )
+		if ( $this->stream->get_transaction() )
 		{
 			$this->global_lock = true;
 		}
