@@ -13,7 +13,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_settings.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: hook_settings.inc.php 1415 2008-07-10 09:07:24Z sigurd $ */
 
 	ExecMethod('calendar.bocalendar.check_set_default_prefs');
 
@@ -132,7 +132,7 @@
 	{
 		foreach($groups as $group)
 		{
-			$options[$group['account_id']] = $GLOBALS['phpgw']->common->grab_owner_name($group['account_id']);
+			$options[$group->id] = $GLOBALS['phpgw']->common->grab_owner_name($group->id);
 		}
 	}
 	create_select_box('Preselected group for entering the planner','planner_start_with_group',$options,
