@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package demo
 	* @subpackage demo
- 	* @version $Id: class.uidemo.inc.php 1781 2008-11-02 19:51:19Z sigurd $
+ 	* @version $Id: class.uidemo.inc.php 6640 2010-12-03 14:59:43Z sigurdne $
 	*/
 
 	/*
@@ -558,6 +558,10 @@
 					{
 						$receipt['error'][]=array('msg'=>lang('Please enter a zip code !'));
 					}
+					else if(!ctype_digit($values['zip']))
+					{
+						$receipt['error'][]=array('msg'=>lang('Please enter a integer as zip code !'));
+					}
 					if(!$values['town'])
 					{
 						$receipt['error'][]=array('msg'=>lang('Please enter a town !'));
