@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.boaction.inc.php,v 1.25 2006/12/21 12:34:15 sigurdne Exp $
+	* @version $Id: class.boaction.inc.php 4237 2009-11-27 23:17:21Z sigurd $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 	
@@ -61,9 +61,13 @@
 		
 		var $next_obj;
 		
-		function boaction()
+		public function __construct()
 		{
-			//return;
+			if ( !isset($GLOBALS['phpgw']->msg) || !is_object($GLOBALS['phpgw']->msg) )
+			{
+				$GLOBALS['phpgw']->msg = CreateObject("email.mail_msg");
+				$GLOBALS['phpgw']->msg->initialize_mail_msg();
+			}
 		}
 		
 		/*!
@@ -615,7 +619,7 @@
 				$this->next_obj->index();
 			}
 			// (e) cleanup
-			if (is_object($GLOBALS['phpgw']->msg))
+			if (isset($GLOBALS['phpgw']->msg) && is_object($GLOBALS['phpgw']->msg))
 			{
 				if ($this->debug > 0) { $GLOBALS['phpgw']->msg->dbug->out('email.boaction.delmov ('.__LINE__.'): oops, not LEFT yet, cleanup and unset ->msg object<br />'); }
 				// close down ALL mailserver streams
