@@ -53,6 +53,11 @@
 		{
 			// This module uses XSLT templates
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
+			
+			$this->config	= CreateObject('phpgwapi.config','frontend');
+			$this->config->read();
+			$use_fellesdata = $this->config->config_data['use_fellesdata'];
+			$logo_path = $this->config->config_data['logo_path'];
 
 			// Get the mode: in frame or full screen
 			$mode = phpgwapi_cache::session_get('frontend', 'noframework');
@@ -60,14 +65,16 @@
 			
 			/* Get the tabs and check to see whether the user has specified a tab or has a selected tab on session */
 			$tabs = $this->get_tabs();
-			$type = phpgw::get_var('type', 'int', 'REQUEST');
-			$tab = isset($type) ? $type : phpgwapi_cache::session_get('frontend','tab');
-			$selected = isset($tab) ? $tab : array_shift(array_keys($tabs));
+			$location_id = phpgw::get_var('location_id', 'int', 'REQUEST');
+			$tab = isset($location_id) ? $location_id : phpgwapi_cache::session_get('frontend','tab');
+			$selected = isset($tab) && $tab ? $tab : array_shift(array_keys($tabs));
 			$this->tabs = $GLOBALS['phpgw']->common->create_tabs($tabs, $selected);
 			phpgwapi_cache::session_set('frontend','tab',$selected);
 			
 			// Get header state
 			$this->header_state = phpgwapi_cache::session_get('frontend', 'header_state');
+			$this->header_state['use_fellesdata'] = $use_fellesdata;
+			$this->header_state['logo_path'] = $logo_path;
 			
 			// Get navigation parameters
 			$param_selected_location = phpgw::get_var('location'); 			// New location selected from locations list
@@ -118,56 +125,66 @@
 			else if(isset($param_only_org_unit)) 
 			{
 				//TODO: check permissions
-				
-				$name_and_result_number = frontend_bofellesdata::get_instance()->get_organisational_unit_info($param_only_org_unit);
-				
-				//Specify unit
-				$org_unit_ids = array(
-					array(
-						"ORG_UNIT_ID" => $param_only_org_unit,
-						"ORG_NAME" => $name_and_result_number['UNIT_NAME'],
-						"UNIT_ID" => $name_and_result_number['UNIT_NUMBER']
-					)
-				);
-								
-				//Update header state
-				$this->header_state['org_unit'] = $org_unit_ids;
-				$this->header_state['number_of_org_units'] = '1';
-				//$this->header_state['selected_org_unit'] = $name_and_result_number['UNIT_NUMBER'];
-				$this->header_state['selected_org_unit'] = $param_only_org_unit;
-				
-				//Update locations
-				$property_locations = frontend_borental::get_property_locations($org_unit_ids);
-				$property_locations_update = true;
-				
-				$noframework = false; // In regular frames
-				phpgwapi_cache::session_set('frontend', 'noframework', $noframework); // Store mode on session
-				$GLOBALS['phpgw_info']['flags']['menu_selection'] = "frontend::{$selected}";
-				$this->insert_links_on_header_state();
+				if($use_fellesdata){
+					$name_and_result_number = frontend_bofellesdata::get_instance()->get_organisational_unit_info($param_only_org_unit);
+									
+					//Specify unit
+					$org_unit_ids = array(
+						array(
+							"ORG_UNIT_ID" => $param_only_org_unit,
+							"ORG_NAME" => $name_and_result_number['UNIT_NAME'],
+							"UNIT_ID" => $name_and_result_number['UNIT_NUMBER']
+						)
+					);
+									
+					//Update header state
+					$this->header_state['org_unit'] = $org_unit_ids;
+					$this->header_state['number_of_org_units'] = '1';
+					//$this->header_state['selected_org_unit'] = $name_and_result_number['UNIT_NUMBER'];
+					$this->header_state['selected_org_unit'] = $param_only_org_unit;
+					
+					//Update locations
+					$property_locations = frontend_borental::get_property_locations($org_unit_ids);
+					$property_locations_update = true;
+					
+					$noframework = false; // In regular frames
+					phpgwapi_cache::session_set('frontend', 'noframework', $noframework); // Store mode on session
+					$GLOBALS['phpgw_info']['flags']['menu_selection'] = "frontend::{$selected}";
+					$this->insert_links_on_header_state();
+				}
 			} 
 			/* No state, first visit after login, or refresh request*/
-			else if(!isset($this->header_state) || isset($refresh))
+			else if(!isset($this->header_state) || isset($refresh) || !isset($this->header_state['locations']))
 			{
-				//Specify organisational units
-				$org_units = frontend_bofellesdata::get_instance()->get_result_units($GLOBALS['phpgw_info']['user']['account_lid']);
-				
-				//Merge with delegation units
-				$delegation_org_ids = frontend_bofrontend::get_delegations($GLOBALS['phpgw_info']['user']['account_id']);
-				if(count($delegation_org_ids) > 0)
+				if($use_fellesdata)
 				{
-					$delegation_units = frontend_bofellesdata::get_instance()->populate_result_units($delegation_org_ids);
-					$org_units = array_merge($org_units,$delegation_units);
+					//Specify organisational units
+					$org_units = frontend_bofellesdata::get_instance()->get_result_units($GLOBALS['phpgw_info']['user']['account_lid']);
+					
+					//Merge with delegation units
+					$delegation_org_ids = frontend_bofrontend::get_delegations($GLOBALS['phpgw_info']['user']['account_id']);
+					if(count($delegation_org_ids) > 0)
+					{
+						$delegation_units = frontend_bofellesdata::get_instance()->populate_result_units($delegation_org_ids);
+						$org_units = array_merge($org_units,$delegation_units);
+					}
+					
+					//Update org units on header state
+					$this->header_state['org_unit'] = $org_units;
+					$this->header_state['number_of_org_units'] = count($org_units);
+					$this->header_state['selected_org_unit'] = 'all';
+					
+					//Update locations
+					$property_locations = frontend_borental::get_property_locations($org_units);
+				}
+				else 
+				{
+					//If no organisational database is in use: get rented properties based on username
+					$usernames[] = $GLOBALS['phpgw_info']['user']['account_lid'];
+					$property_locations = frontend_borental::get_property_locations($usernames);
 				}
 				
-				//Update org units on header state
-				$this->header_state['org_unit'] = $org_units;
-				$this->header_state['number_of_org_units'] = count($org_units);
-				$this->header_state['selected_org_unit'] = 'all';
-				
-				//Update locations
-				$property_locations = frontend_borental::get_property_locations($org_units);
 				$property_locations_update = true;
-
 				$this->insert_links_on_header_state();
 				
 			}
@@ -225,6 +242,7 @@
 
 				phpgwapi_cache::session_clear('frontend','contract_state');
 				phpgwapi_cache::session_clear('frontend','contract_state_in');
+				phpgwapi_cache::session_clear('frontend','contract_state_ex');
 			}
 			/* Store the header state on the session*/
 			$bomessenger = CreateObject('messenger.bomessenger');
@@ -240,8 +258,6 @@
 						
 			phpgwapi_cache::session_set('frontend', 'header_state', $this->header_state);
 
-			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/templates/bkbooking/css/frontend.css');
-			
 			$GLOBALS['phpgw']->css->add_external_file('frontend/templates/base/base.css');
 			$GLOBALS['phpgw_info']['flags']['noframework'] = true;
 		}
@@ -262,11 +278,36 @@
 					$location_id = $GLOBALS['phpgw']->locations->get_id('frontend', $location);
 					$tabs[$location_id] = array(
 						'label' => lang($name),
-						'link'  => $GLOBALS['phpgw']->link('/',array('menuaction' => "frontend.ui{$name}.index", 'type'=>$location_id, 'noframework' => $noframework))
+						'link'  => $GLOBALS['phpgw']->link('/',array('menuaction' => "frontend.ui{$name}.index", 'location_id'=>$location_id, 'noframework' => $noframework))
+					);
+				}
+				unset($location);
+			}
+			
+
+			// this one is for generic entitysupport from the app 'property'
+			$entity_frontend = isset($this->config->config_data['entity_frontend']) && $this->config->config_data['entity_frontend'] ? $this->config->config_data['entity_frontend'] : array();
+
+			if($entity_frontend)
+			{
+				$entity			= CreateObject('property.soadmin_entity');
+			}
+
+			foreach ($entity_frontend as $location)
+			{
+				if ( $GLOBALS['phpgw']->acl->check($location, PHPGW_ACL_READ, 'property') )
+				{
+					$location_id = $GLOBALS['phpgw']->locations->get_id('property', $location);
+					$location_arr = explode('.', $location);
+					
+					$category = $entity->read_single_category($location_arr[2], $location_arr[3]);
+					$tabs[$location_id] = array(
+						'label' => $category['name'],
+						'link'  => $GLOBALS['phpgw']->link('/',array('menuaction' => "frontend.uientity.index", 'location_id' => $location_id, 'noframework' => $noframework))
 					);
 				}
 			}
-			
+
 			$extra_tabs = phpgwapi_cache::session_get('frontend', 'extra_tabs');
 			
 			if(isset($extra_tabs))
@@ -281,8 +322,28 @@
 		
 		function insert_links_on_header_state()
 		{
+			$help_url = "";
+			//check if help-document exists in VFS. If not, use manual.
+			$help_in_vfs = true;
+			$fileName = '/frontend/help/NO/helpdesk.index.pdf';
+			$vfs = CreateObject('phpgwapi.vfs');
+			$vfs->override_acl = 1;
+	
+			$file = array('string' => $fileName, RELATIVE_NONE);
+			if($vfs->file_exists($file)){
+				$help_in_vfs = true;
+			}
 			
-			$help_url = "javascript:openwindow('"
+			if($help_in_vfs)
+			{
+				$help_url = "javascript:openwindow('"
+						 . $GLOBALS['phpgw']->link('/index.php', array
+						 (
+						 	'menuaction'=> 'frontend.uidocumentupload.read_helpfile_from_vfs',
+						 	'app' => 'frontend'
+						 )) . "','700','600')";
+			}else{			
+				$help_url = "javascript:openwindow('"
 						 . $GLOBALS['phpgw']->link('/index.php', array
 						 (
 						 	'menuaction'=> 'manual.uimanual.help',
@@ -290,13 +351,14 @@
 						 	'section' => isset($GLOBALS['phpgw_info']['apps']['manual']['section']) ? $GLOBALS['phpgw_info']['apps']['manual']['section'] : '',
 						 	'referer' => phpgw::get_var('menuaction')
 						 )) . "','700','600')";
+			}
 			
 			$contact_url = "javascript:openwindow('"
 				 . $GLOBALS['phpgw']->link('/index.php', array
 				 (
 				 	'menuaction'=> 'manual.uimanual.help',
 				 	'app' => $GLOBALS['phpgw_info']['flags']['currentapp'],
-				 	'section' => 'contact_BKB'
+				 	'section' => 'contact'
 				 )) . "','700','600')";
 		 
 			$folder_url = "javascript:openwindow('"
@@ -399,7 +461,7 @@
 		{
 			//Forward to helpdesk
 			$location_id = $GLOBALS['phpgw']->locations->get_id('frontend', '.ticket');
-			$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'frontend.uihelpdesk.index', 'type' => $location_id));
+			$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'frontend.uihelpdesk.index', 'location_id' => $location_id));
 		}
 
 
@@ -409,9 +471,7 @@
 			$GLOBALS['phpgw_info']['flags']['nofooter'] = true;
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = false;
 
-			$config = CreateObject('phpgwapi.config','frontend');
-			$config->read();
-			$doc_type = $config->config_data['picture_building_cat'] ? $config->config_data['picture_building_cat'] : 'profilbilder';
+			$doc_type = $this->config->config_data['picture_building_cat'] ? $this->config->config_data['picture_building_cat'] : 'profilbilder';
 
 			// Get object id from params or use 'dummy'
 			$location_code = phpgw::get_var('loc_code') ? phpgw::get_var('loc_code') : 'dummy';
@@ -440,11 +500,20 @@
 			{
 				$mime_type = $ls_array[0]['mime_type'];
 			}
-			
+
 			if(isset($document) && $document != '')
 			{
 				header('Content-type: ' . $mime_type);
-				echo $document;
+
+				if(function_exists('imagejpeg'))
+				{
+					$source = "{$GLOBALS['phpgw_info']['server']['files_dir']}{$ls_array[0]['directory']}/{$ls_array[0]['name']}";
+					$this->create_thumb($source,173);
+				}
+				else
+				{
+					echo $document;
+				}
 
 				$GLOBALS['phpgw']->common->phpgw_exit();
 			}
@@ -453,4 +522,47 @@
 				$GLOBALS['phpgw']->redirect_link('templates/base/images/missing_picture.png');
 			}
  		}
+
+		function create_thumb($source,$target_height = 100)
+		{
+			$size = getimagesize($source);
+			$width = $size[0];
+			$height = $size[1];
+
+			$target_width = round($width*($target_height/$height));
+
+			if ($width > $height)
+			{
+				$x = ceil(($width - $height) / 2 );
+				$width = $height;
+			}
+			else if($height > $width)
+			{
+				$y = ceil(($height - $width) / 2);
+				$height = $width;
+			}
+
+			$new_im = ImageCreatetruecolor($target_width,$target_height);
+
+			@$imgInfo = getimagesize($source);
+
+			if ($imgInfo[2] == IMAGETYPE_JPEG)
+			{
+				$im = imagecreatefromjpeg($source);
+				imagecopyresampled($new_im,$im,0,0,$x,$y,$target_width,$target_height,$width,$height);
+				imagejpeg($new_im,$dest,75); // Thumbnail quality (Value from 1 to 100)
+			}
+			else if ($imgInfo[2] == IMAGETYPE_GIF)
+			{
+				$im = imagecreatefromgif($source);
+				imagecopyresampled($new_im,$im,0,0,$x,$y,$target_width,$target_height,$width,$height);
+				imagegif($new_im,$dest);
+			}
+			else if ($imgInfo[2] == IMAGETYPE_PNG)
+			{
+				$im = imagecreatefrompng($source);
+				imagecopyresampled($new_im,$im,0,0,$x,$y,$target_width,$target_height,$width,$height);
+				imagepng($new_im,$dest);
+			}
+		}
 	}
