@@ -7,7 +7,7 @@
 	 * @copyright Copyright (C) 2010 Free Software Foundation, Inc. http://www.fsf.org/
 	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	 * @package Frontend
-	 * @version $Id: class.uihelpdesk.inc.php 5698 2010-05-10 12:42:43Z yngve.espelid $
+	 * @version $Id: class.uihelpdesk.inc.php 7227 2011-04-15 11:51:34Z sigurdne $
 	 */
 
 	/*
@@ -52,6 +52,8 @@
 
 		public function index()
 		{
+			$GLOBALS['phpgw_info']['apps']['manual']['section'] = 'helpdesk.index';
+			$this->insert_links_on_header_state();
 			$bo	= CreateObject('property.botts',true);
 
 			$dry_run = false;
@@ -141,6 +143,10 @@
 			if(isset($this->location_code) && $this->location_code != '')
 			{
 				$bo->location_code = $this->location_code;
+				//to make sure the list select "All" not only the open ones
+				if(phpgw::get_var("status_id")== ""){
+					$bo->status_id = 'all';
+				}
 				$ticket_list = $bo->read('','','',$dry_run);
 			}
 			else
@@ -173,7 +179,7 @@
 
 				$status['O'] = array
 				(
-					'status'			=> isset($this->bo->config->config_data['tts_lang_open']) && $this->bo->config->config_data['tts_lang_open'] ? $this->bo->config->config_data['tts_lang_open'] : lang('Open'),
+					'status'			=> isset($bo->config->config_data['tts_lang_open']) && $bo->config->config_data['tts_lang_open'] ? $bo->config->config_data['tts_lang_open'] : lang('Open'),
 				);
 
 				$custom_status	= $bo->get_custom_status();
@@ -389,7 +395,8 @@
 
 		public function view()
 		{
-			$bo	= CreateObject('property.botts',true);
+			$GLOBALS['phpgw']->translation->add_app('property');
+			$bo	= CreateObject('property.botts');
 			$ticketid = phpgw::get_var('id');
 			$ticket = $bo->read_single($ticketid);
 
@@ -417,12 +424,14 @@
 			$vendor_id = $ticket['vendor_id'];
 			if(isset($vendor_id) && $vendor_id != '')
 			{
-				$contacts	= CreateObject('property.soactor');
-				$contacts->role='vendor';
+				$contacts	= CreateObject('property.sogeneric');
+				$contacts->get_location_info('vendor',false);
+
 				$custom 		= createObject('property.custom_fields');
 				$vendor_data['attributes'] = $custom->find('property','.vendor', 0, '', 'ASC', 'attrib_sort', true, true);
 
-				$vendor_data	= $contacts->read_single($vendor_id,$vendor_data);
+				$vendor_data	= $contacts->read_single(array('id' => $vendor_id),$vendor_data);
+
 				if(is_array($vendor_data))
 				{
 					foreach($vendor_data['attributes'] as $attribute)
@@ -435,7 +444,7 @@
 					}
 				}
 			}
-			
+
 			$notes = $bo->read_additional_notes($ticketid);
 			//$history = $bo->read_record_history($ticketid);
 
@@ -517,6 +526,17 @@
 			$missingfields  = false;
 			$msglog         = array();
 
+			// Read default assign-to-group from config
+			$config = CreateObject('phpgwapi.config', 'frontend');
+			$config->read();
+			$default_cat = $config->config_data['tts_default_cat'] ? $config->config_data['tts_default_cat'] : 0;
+					
+			if(!$default_cat)
+			{
+				throw new Exception('Default category is not set in config');
+				$GLOBALS['phpgw']->common->phpgw_exit();
+			}
+
 			if(isset($values['save']))
 			{
 				foreach($values as $key => $value)
@@ -529,27 +549,36 @@
 
 				if(!$missingfields && !phpgw::get_var('added'))
 				{
-					// Read default assign-to-group from config
-					$config = CreateObject('phpgwapi.config', 'frontend');
-					$config->read();
-					$default_group = $config->config_data['tts_default_group'];
+					$location  = array
+					(
+						'loc1'  => $location_details['loc1'],
+						'loc2'  => $location_details['loc2']
+					);
+
+					$assignedto = execMethod('property.boresponsible.get_responsible', array('location' => $location, 'cat_id' => $default_cat));
+
+					if(!$assignedto)
+					{
+						$default_group = $config->config_data['tts_default_group'];
+					}
+					else
+					{
+						$default_group = 0;
+					}
 
 					$ticket = array(
 						'origin'    => null,
 						'origin_id' => null,
-						'cat_id'    => 11,
+						'cat_id'    => $values['cat_id'],
 						'group_id'  => ($default_group ? $default_group : null),
-						'assignedto'=> null,
+						'assignedto'=> $assignedto,
 						'priority'  => 3,
 						'status'    => 'O', // O = Open
 						'subject'   => $values['title'],
 						'details'   => $values['locationdesc'].":\n\n".$values['description'],
 						'apply'     => lang('Apply'),
 						'contact_id'=> 0,
-						'location'  => array(
-							'loc1'  => $location_details['loc1'],
-							'loc2'  => $location_details['loc2']
-						),
+						'location'  => $location,
 						'street_name'   => $location_details['street_name'],
 						'street_number' => $location_details['street_number'],
 						'location_name' => $location_details['loc1_name'],
@@ -604,14 +633,36 @@
 				}
 			}
 
+
+			$tts_frontend_cat_selected = $config->config_data['tts_frontend_cat'] ? $config->config_data['tts_frontend_cat'] : array();
+
+			$cats	= CreateObject('phpgwapi.categories', -1, 'property', '.ticket');
+			$cats->supress_info = true;
+			$categories = $cats->return_sorted_array(0, false, '', '', '', true, '', false);
+
+			$category_list = array();
+			foreach ( $categories as $category)
+			{
+				if ( in_array($category['id'], $tts_frontend_cat_selected))
+				{
+					$category_list[] = array
+					(
+						'id'		=> $category['id'],
+						'name'		=> $category['name'],
+						'selected'	=> $category['id'] == $default_cat ? 1 : 0
+					); 
+				}
+			}
+
 			$data = array(
-				'redirect'		=> isset($redirect) ? $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'frontend.uihelpdesk.index')) : null,
-				'msgbox_data'   => $GLOBALS['phpgw']->common->msgbox($GLOBALS['phpgw']->common->msgbox_data($msglog)),
-				'form_action'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'frontend.uihelpdesk.add_ticket', 'noframework' => '1')),
-				'title'         => $values['title'],
-				'locationdesc'  => $values['locationdesc'],
-				'description'   => $values['description'],
-				'noform'        => $noform
+				'redirect'			=> isset($redirect) ? $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'frontend.uihelpdesk.index')) : null,
+				'msgbox_data'   	=> $GLOBALS['phpgw']->common->msgbox($GLOBALS['phpgw']->common->msgbox_data($msglog)),
+				'form_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'frontend.uihelpdesk.add_ticket', 'noframework' => '1')),
+				'title'         	=> $values['title'],
+				'locationdesc'  	=> $values['locationdesc'],
+				'description'   	=> $values['description'],
+				'noform'        	=> $noform,
+				'category_list'		=> $category_list
 			);
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('frontend','helpdesk'));
