@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage admin
- 	* @version $Id: class.socategory.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.socategory.inc.php 2655 2009-05-03 17:27:03Z sigurd $
 	*/
 
 	/**
@@ -20,13 +20,10 @@
 	{
 		public function __construct()
 		{
-		//	$this->currentapp	= 'hrm';
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon		= CreateObject('hrm.bocommon');
-			$this->db			= $this->bocommon->new_db();
-
-			$this->join			=& $this->bocommon->join;
-			$this->like			=& $this->bocommon->like;
+			$this->db 			= & $GLOBALS['phpgw']->db;
+			$this->like 		= & $this->db->like;
+			$this->join 		= & $this->db->join;
 		}
 
 		function read($data)
@@ -67,8 +64,7 @@
 
 			if($query)
 			{
-				$query = preg_replace("/'/",'',$query);
-				$query = preg_replace('/"/','',$query);
+				$query = $this->db->db_addslashes($query);
 
 				$querymethod = " where id $this->like '%$query%' or descr $this->like '%$query%'";
 			}
@@ -118,7 +114,7 @@
 					break;
 				case 'qualification':
 					$table='phpgw_hrm_quali_category';
-					break;					
+					break;
 			}
 
 			return $table;
@@ -194,5 +190,5 @@
 				);
 			}
 			return $categories;
-		}		
+		}
 	}
