@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage user
- 	* @version $Id: class.souser.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.souser.inc.php 4416 2009-12-25 17:33:44Z sigurd $
 	*/
 
 	/**
@@ -24,16 +24,12 @@
 
 		public function __construct()
 		{
-		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bocommon	= CreateObject('hrm.bocommon');
-			$this->db           	= $this->bocommon->new_db();
-
-			$this->acl		= CreateObject('phpgwapi.acl');
-			$this->grants		= $this->acl->get_grants('hrm','.user');
-			$this->left_join	=& $this->bocommon->left_join;
-			$this->join			=& $this->bocommon->join;
-			$this->like			=& $this->bocommon->like;
+			$this->db 			= & $GLOBALS['phpgw']->db;
+			$this->like 		= & $this->db->like;
+			$this->join 		= & $this->db->join;
+			$this->left_join	= & $this->db->left_join;
+			$this->grants		= $GLOBALS['phpgw']->acl->get_grants('hrm','.user');
 		}
 
 		function read($data)
@@ -47,20 +43,22 @@
 				$allrows	= isset($data['allrows']) && $data['allrows'] ? $data['allrows'] : false;
 			}
 
-			if ( !isset($GLOBALS['phpgw']->accounts) || !is_object($GLOBALS['phpgw']->accounts) )
-			{
-				$GLOBALS['phpgw']->accounts = createObject('phpgwapi.accounts');
-			}
 			$accounts =& $GLOBALS['phpgw']->accounts;
-			
-			$account_info = $accounts->get_list('accounts', $start, $sort, $order, $query);
+
+			$list = $accounts->get_list('accounts', $start, $sort, $order, $query);
 			$this->total_records = $accounts->total;
 
-			foreach ( $account_info as &$account )
+			$account_info = array();
+			foreach ( $list as $entry )
 			{
-				$account['grants'] = isset($this->grants[$account['account_id']]) ? $this->grants[$account['account_id']] : 0;
+				$account_info[] = array
+				(
+					'grants'			=> isset($this->grants[$entry->id]) ? $this->grants[$entry->id] : 0,
+					'account_firstname'	=> $entry->firstname,
+					'account_lastname'	=> $entry->lastname,
+					'account_id'		=> $entry->id
+				);
 			}
-
 			return $account_info;
 		}
 
@@ -86,6 +84,7 @@
 					'reference'		=> $this->db->f('reference', true),
 					'skill'			=> $this->db->f('skill'),
 					'place_id'		=> $this->db->f('place_id'),
+					'credits'		=> (int)$this->db->f('credits'),
 					'entry_date'	=> $this->db->f('entry_date'),
 					'owner'			=> $this->db->f('owner')
 				);
@@ -97,18 +96,11 @@
 		{
 			if(is_array($data))
 			{
-				if ($data['start'])
-				{
-					$start=$data['start'];
-				}
-				else
-				{
-					$start=0;
-				}
-				$query		= (isset($data['query'])?$data['query']:'');
-				$sort		= (isset($data['sort'])?$data['sort']:'DESC');
-				$order		= (isset($data['order'])?$data['order']:'');
-				$allrows	= (isset($data['allrows'])?$data['allrows']:'');
+				$start		= isset($data['start']) && $data['start'] ? $data['start'] : 0;
+				$query		= isset($data['query']) ? $data['query'] : '';
+				$sort		= isset($data['sort']) && $data['sort'] ? $data['sort'] : 'ASC';
+				$order		= isset($data['order']) && $data['order'] ? $data['order'] : 'category DESC, start_date';
+				$allrows	= isset($data['allrows']) ? $data['allrows'] : '';
 			}
 
 			$user_id = $data['user_id'];
@@ -124,7 +116,7 @@
 			}
 
 			$sql = "SELECT phpgw_hrm_training.id as training_id,phpgw_hrm_training.title as title, phpgw_hrm_training.start_date,"
-				. " phpgw_hrm_training.end_date,phpgw_hrm_training_place.name as place, phpgw_hrm_training_category.descr as category"
+				. " phpgw_hrm_training.end_date,phpgw_hrm_training_place.name as place, phpgw_hrm_training_category.descr as category, credits"
 				. " FROM phpgw_hrm_training $this->left_join phpgw_hrm_training_place on phpgw_hrm_training.place_id=phpgw_hrm_training_place.id"
 				. " $this->join phpgw_hrm_training_category ON phpgw_hrm_training.category = phpgw_hrm_training_category.id"
 				. " WHERE phpgw_hrm_training.user_id=" . intval($user_id);
@@ -142,6 +134,7 @@
 					'end_date'		=> $this->db->f('end_date'),
 					'title'			=> $this->db->f('title', true),
 					'place'			=> $this->db->f('place', true),
+					'credits'		=> (int)$this->db->f('credits'),
 					'category'		=> $this->db->f('category', true)
 				);
 
@@ -155,7 +148,7 @@
 			$values['new_place_address'] = $this->db->db_addslashes($values['new_place_address']);
 			$values['new_place_town'] = $this->db->db_addslashes($values['new_place_town']);
 			$values['new_place_descr'] = $this->db->db_addslashes($values['new_place_descr']);
-			$values['place_id'] = $this->bocommon->next_id('phpgw_hrm_training_place');
+			$values['place_id'] = $this->db->next_id('phpgw_hrm_training_place');
 
 			$insert_values=array(
 				$values['place_id'],
@@ -166,7 +159,7 @@
 				$values['new_place_remark'],
 				);
 
-			$insert_values	= $this->bocommon->validate_db_insert($insert_values);
+			$insert_values	= $this->db->validate_insert($insert_values);
 			$this->db->query("INSERT INTO phpgw_hrm_training_place (id,name,address,zip,town, remark) "
 				. "VALUES ($insert_values)",__LINE__,__FILE__);
 
@@ -185,7 +178,7 @@
 				$values['place_id'] = $this->add_place($values);
 			}
 
-			$training_id = $this->bocommon->next_id('phpgw_hrm_training');
+			$training_id = $this->db->next_id('phpgw_hrm_training');
 
 			$insert_values=array(
 				$training_id,
@@ -197,14 +190,15 @@
 				$values['reference'],
 				$values['skill'],
 				$values['place_id'],
+				(int)$values['credits'],
 				$values['descr'],
 				time(),
 				$this->account
 				);
 
-			$insert_values	= $this->bocommon->validate_db_insert($insert_values);
+			$insert_values	= $this->db->validate_insert($insert_values);
 
-			$this->db->query("INSERT INTO phpgw_hrm_training (id,user_id,category,title,start_date,end_date,reference,skill,place_id,descr,entry_date,owner) "
+			$this->db->query("INSERT INTO phpgw_hrm_training (id,user_id,category,title,start_date,end_date,reference,skill,place_id,credits,descr,entry_date,owner) "
 				. "VALUES ($insert_values)",__LINE__,__FILE__);
 
 			$receipt['message'][]=array('msg'=>lang('training item has been saved'));
@@ -232,8 +226,9 @@
 			$value_set['reference']		= $this->db->db_addslashes($values['reference']);
 			$value_set['skill']			= $values['skill'];
 			$value_set['place_id']		= $values['place_id'];
+			$value_set['credits']		= (int)$values['credits'];
 
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $this->db->validate_update($value_set);
 
 			$table='phpgw_hrm_training';
 
