@@ -8,11 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage core
- 	* @version $Id: hook_settings.inc.php 16382 2006-02-06 13:29:16Z sigurdne $
+ 	* @version $Id: hook_settings.inc.php 719 2008-02-07 08:31:39Z sigurd $
 	*/
 
-	$yes_and_no = array(
-		'True' => 'Yes',
-		''     => 'No'
-	);
-
+	create_select_box('show horisontal menues','horisontal_menus',array('no' => 'No','yes' => 'Yes'),'Horisontal menues are shown in top of page');
