@@ -7,7 +7,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
- 	* @version $Id: index.php 17552 2006-11-15 14:14:35Z sigurdne $
+ 	* @version $Id: index.php 978 2008-05-11 08:38:47Z sigurd $
 	*/
 
 	/**
@@ -21,8 +21,8 @@
 
 
 	$GLOBALS['phpgw_info']['flags'] = array(
-		'noheader'   	=> True,
-		'nonavbar'   	=> True,
+		'noheader'   	=> true,
+		'nonavbar'   	=> true,
 		'currentapp'	=> $currentapp
 		);
 
@@ -40,4 +40,4 @@
 	}
 
 	$GLOBALS['phpgw']->redirect_link('/index.php',$start_page);
-?>
+
