@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2000-2008 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: index.php 6052 2010-06-13 20:29:30Z sigurd $
+	* @version $Id: index.php 7159 2011-04-02 11:40:46Z sigurdne $
 	*/
 
 	/*
@@ -40,9 +40,16 @@
 
 	$invalid_data = false;
 	// This is the preliminary menuaction driver for the new multi-layered design
-	if (isset($_GET['menuaction']))
+	if (isset($_GET['menuaction']) || isset($_POST['menuaction']))
 	{
-		list($app,$class,$method) = explode('.',$_GET['menuaction']);
+		if(isset($_GET['menuaction']))
+		{
+			list($app,$class,$method) = explode('.',$_GET['menuaction']);
+		}
+		else
+		{
+			list($app,$class,$method) = explode('.',$_POST['menuaction']);
+		}
 		if (! $app || ! $class || ! $method)
 		{
 			$invalid_data = true;
