@@ -10,7 +10,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License v2 or later
 	* @package phpgroupware
 	* @subpackage phpgwapi
-	* @version $Id: class.accounts_.inc.php 6151 2010-06-28 08:54:17Z sigurd $
+	* @version $Id: class.accounts_.inc.php 6815 2011-01-21 08:03:56Z sigurdne $
 	*/
 
 	/*
@@ -452,7 +452,7 @@
 		public function read()
 		{
 			if ( !is_object($this->account)
-				|| $this->account->id <> !$this->account_id )
+				|| $this->account->id != $this->account_id )
 			{
 				$this->read_repository();
 			}
