@@ -10,7 +10,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License v2 or later
 	* @package phpgroupware
 	* @subpackage phpgwapi
-	* @version $Id: class.accounts_sql.inc.php 6151 2010-06-28 08:54:17Z sigurd $
+	* @version $Id: class.accounts_sql.inc.php 7215 2011-04-12 20:06:07Z sigurdne $
 	*/
 
 	/*
@@ -100,7 +100,7 @@
 		 */
 		public function create_group_account($account)
 		{
-			if ( $this->db->Transaction )
+			if ( $this->db->get_transaction() )
 			{
 				$this->global_lock = true;
 			}
@@ -154,7 +154,7 @@
 		 */
 		public function create_user_account($account)
 		{
-			if ( $this->db->Transaction )
+			if ( $this->db->get_transaction() )
 			{
 				$this->global_lock = true;
 			}
