@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License v2 or later
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.acl.inc.php 5820 2010-05-27 12:18:48Z sigurd $
+	* @version $Id: class.acl.inc.php 7215 2011-04-12 20:06:07Z sigurdne $
 	*/
 
 	/*
@@ -409,7 +409,7 @@
 			unset($subs);
 			unset($_locations);
 
-			if ( $this->_db->Transaction )
+			if ( $this->_db->get_transaction() )
 			{
 				$this->global_lock = true;
 			}
@@ -480,8 +480,12 @@
 			}
 
 			// using stored prosedures
-			$sql = 'INSERT INTO phpgw_acl (acl_account, acl_rights, acl_grantor, acl_type, location_id)'
-							. ' VALUES(?, ?, ?, ?, ?)';
+			$sql = 'INSERT INTO phpgw_acl (acl_account, acl_rights, acl_grantor, acl_type, location_id, modified_on, modified_by)'
+							. ' VALUES(?, ?, ?, ?, ?, ?, ?)';
+
+			$now 			= time();
+			$mod_account	= $GLOBALS['phpgw_info']['user']['account_id'] ? $GLOBALS['phpgw_info']['user']['account_id'] : -1;
+
 			$valueset=array();
 
 			foreach ( $new_data as $loc_id => $grants )
@@ -495,28 +499,38 @@
 							1	=> array
 							(
 								'value'	=> $acct_id,
-								'type'	=> PDO::PARAM_INT
+								'type'	=> 1 //PDO::PARAM_INT
 							),
 							2	=> array
 							(
 								'value'	=> $rights,
-								'type'	=>	PDO::PARAM_INT
+								'type'	=>	1 //PDO::PARAM_INT
 							),
 							3	=> array
 							(
 								'value'	=> $grantor,
-								'type'	=> PDO::PARAM_INT
+								'type'	=> 1 //PDO::PARAM_INT
 							),
 							4	=> array
 							(
 								'value'	=> $mask,
-								'type'	=>	PDO::PARAM_INT
+								'type'	=>	1 //PDO::PARAM_INT
 							),
 							5	=> array
 							(
 								'value'	=> $loc_id,
-								'type'	=> PDO::PARAM_INT
-							),								
+								'type'	=> 1 //PDO::PARAM_INT
+							),
+							6	=> array
+							(
+								'value'	=> $now,
+								'type'	=> 1 //PDO::PARAM_INT
+							),
+							7	=> array
+							(
+								'value'	=> $mod_account,
+								'type'	=> 1 //PDO::PARAM_INT
+							)
 						);
 					}
 				}
@@ -529,7 +543,7 @@
 
 			/*remove duplicates*/
 
-			$sql = "SELECT * FROM phpgw_acl WHERE acl_account = {$acct_id}"
+			$sql = "SELECT acl_account, acl_rights, acl_grantor, acl_type, location_id FROM phpgw_acl WHERE acl_account = {$acct_id}"
 			. ' GROUP BY acl_account, acl_rights, acl_grantor, acl_type, location_id';
 			$this->_db->query($sql,__LINE__,__FILE__);
 
@@ -551,28 +565,38 @@
 						1	=> array
 						(
 							'value'	=> $_acl_account,
-							'type'	=> PDO::PARAM_INT
+							'type'	=> 1 //PDO::PARAM_INT
 						),
 						2	=> array
 						(
 							'value'	=> $_acl_rights,
-							'type'	=>	PDO::PARAM_INT
+							'type'	=>	1 //PDO::PARAM_INT
 						),
 						3	=> array
 						(
 							'value'	=> $_acl_grantor,
-							'type'	=> PDO::PARAM_INT
+							'type'	=> 1 //PDO::PARAM_INT
 						),
 						4	=> array
 						(
 							'value'	=> $_acl_type,
-							'type'	=>	PDO::PARAM_INT
+							'type'	=>	1 //PDO::PARAM_INT
 						),
 						5	=> array
 						(
 							'value'	=> $_location_id,
-							'type'	=> PDO::PARAM_INT
-						),								
+							'type'	=> 1 //PDO::PARAM_INT
+						),
+						6	=> array
+						(
+							'value'	=> $now,
+							'type'	=> 1 //PDO::PARAM_INT
+						),
+						7	=> array
+						(
+							'value'	=> $mod_account,
+							'type'	=> 1 //PDO::PARAM_INT
+						)
 					);
 				}
 		//		$test[$_acl_account][$_acl_grantor][$_acl_type][$_location_id] = true;
@@ -582,8 +606,8 @@
 					. " WHERE acl_account = {$acct_id}";
 			$this->_db->query($sql, __LINE__, __FILE__);
 
-			$sql = 'INSERT INTO phpgw_acl (acl_account, acl_rights, acl_grantor, acl_type, location_id)'
-							. ' VALUES(?, ?, ?, ?, ?)';
+			$sql = 'INSERT INTO phpgw_acl (acl_account, acl_rights, acl_grantor, acl_type, location_id, modified_on, modified_by)'
+							. ' VALUES(?, ?, ?, ?, ?, ?, ?)';
 
 			$this->_db->insert($sql, $unique_data, __LINE__, __FILE__);
 			unset($unique_data);
@@ -647,6 +671,9 @@
 			. ' GROUP BY acl_account, acl_rights, acl_grantor, acl_type, location_id';
 			$this->_db->query($sql,__LINE__,__FILE__);
 
+			$now 			= time();
+			$mod_account	= $GLOBALS['phpgw_info']['user']['account_id'] ? $GLOBALS['phpgw_info']['user']['account_id'] : -1;
+
 			$cache_info = array();
 			while($this->_db->next_record())
 			{
@@ -657,36 +684,46 @@
 					1	=> array
 					(
 						'value'	=> $this->_db->f('acl_account'),
-						'type'	=> PDO::PARAM_INT
+						'type'	=> 1 //PDO::PARAM_INT
 					),
 					2	=> array
 					(
 						'value'	=> $this->_db->f('acl_rights'),
-						'type'	=>	PDO::PARAM_INT
+						'type'	=>	1 //PDO::PARAM_INT
 					),
 					3	=> array
 					(
 						'value'	=> $this->_db->f('acl_grantor'),
-						'type'	=> PDO::PARAM_INT
+						'type'	=> 1 //PDO::PARAM_INT
 					),
 					4	=> array
 					(
 						'value'	=> (int) $this->_db->f('acl_type'),
-						'type'	=>	PDO::PARAM_INT
+						'type'	=>	1 //PDO::PARAM_INT
 					),
 					5	=> array
 					(
 						'value'	=> $this->_db->f('location_id'),
-						'type'	=> PDO::PARAM_INT
-					),								
+						'type'	=> 1 //PDO::PARAM_INT
+					),
+					6	=> array
+					(
+						'value'	=> $now,
+						'type'	=> 1 //PDO::PARAM_INT
+					),
+					7	=> array
+					(
+						'value'	=> $mod_account,
+						'type'	=> 1 //PDO::PARAM_INT
+					)
 				);
 			}
 
 			$sql = "DELETE FROM phpgw_acl {$condition}";
 			$this->_db->query($sql, __LINE__, __FILE__);
 
-			$sql = 'INSERT INTO phpgw_acl (acl_account, acl_rights, acl_grantor, acl_type, location_id)'
-							. ' VALUES(?, ?, ?, ?, ?)';
+			$sql = 'INSERT INTO phpgw_acl (acl_account, acl_rights, acl_grantor, acl_type, location_id, modified_on, modified_by)'
+							. ' VALUES(?, ?, ?, ?, ?, ?, ?)';
 
 			$this->_db->insert($sql, $unique_data, __LINE__, __FILE__);
 			unset($unique_data);
@@ -964,10 +1001,13 @@
 				$inherit_location[] = $this->_db->f('location_id');
 			}
 
+			$now 			= time();
+			$mod_account	= $GLOBALS['phpgw_info']['user']['account_id'] ? $GLOBALS['phpgw_info']['user']['account_id'] : -1;
+
 			foreach ( $inherit_location as $acl_location )
 			{
-				$sql = 'INSERT INTO phpgw_acl (location_id, acl_account, acl_rights, acl_grantor, acl_type)'
-					. " VALUES ('{$acl_location}', {$account_id}, {$rights}, -1 , 0)";
+				$sql = 'INSERT INTO phpgw_acl (location_id, acl_account, acl_rights, acl_grantor, acl_type, modified_on, modified_by)'
+					. " VALUES ('{$acl_location}', {$account_id}, {$rights}, -1 , 0, {$now}, {$mod_account})";
 				$this->_db->query($sql, __LINE__, __FILE__);
 			}
 
