@@ -2,58 +2,91 @@
 	/**
 	* Applications manager functions
 	* @author Mark Peters <skeeter@phpgroupware.org>
+	* @author Dave Hall <skwashd@phpgroupware.org>
 	* @copyright Copyright (C) 2001,2002 Mark Peters
-	* @copyright Portions Copyright (C) 2003,2004 Free Software Foundation, Inc. http://www.fsf.org/
+	* @copyright Copyright (C) 2003 - 2008 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.applications.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.applications.inc.php 4733 2010-02-04 13:27:53Z sigurd $
 	*/
 
+	/*
+		This program is free software: you can redistribute it and/or modify
+		it under the terms of the GNU Lesser General Public License as published by
+		the Free Software Foundation, either version 2 of the License, or
+		(at your option) any later version.
+
+		This program is distributed in the hope that it will be useful,
+		but WITHOUT ANY WARRANTY; without even the implied warranty of
+		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+		GNU Lesser General Public License for more details.
+
+		You should have received a copy of the GNU Lesser General Public License
+		along with this program.  If not, see <http://www.gnu.org/licenses/>.
+	 */
+
 	/**
 	* Class for managing and installing applications
 	*
 	* @package phpgwapi
 	* @subpackage application
 	*/
-	class applications
+	class phpgwapi_applications
 	{
-		var $account_id;
-		var $data = array();
-		var $db;
-		var $public_functions = array(
+		/**
+		* @var int $account_id the current users' account id
+		*/
+		private $account_id;
+
+		/**
+		* @var array data about the applications installed
+		*/
+		private $data = array();
+
+		/**
+		* @var object $db Local reference to the global database object
+		*/
+		private $db;
+
+		/**
+		* @var array $public_function the methods of the class available via menuaction calls
+		*/
+		public $public_functions = array
+		(
 			'list_methods' => True,
 			'read'         => True
 		);
-		var $xmlrpc_methods = array();
-
 
 		/**
 		* Standard constructor for setting $account_id
 		*
 		* @param integer $account_id Account id
 		*/
-		function applications($account_id = '')
+		public function __construct($account_id = '')
 		{
 			$this->db =& $GLOBALS['phpgw']->db;
-			$this->account_id = get_account_id($account_id);
+			$this->set_account_id($account_id);
+		}
 
-			$this->xmlrpc_methods[] = array(
-				'name'        => 'read',
-				'description' => 'Return a list of applications the current user has access to'
-			);
+		/**
+		* Set the user's id
+		*/
+		public function set_account_id($account_id)
+		{
+			$this->account_id = get_account_id($account_id);
 		}
 
 		/**
 		* Get available xmlrpc or soap methods
 		*
 		* @param string|array $_type Type of methods to list: 'xmlrpc' or 'soap'
-		* @return array Array touple (might be empty) with the following fields in the keys value array: function, signature, docstring
+		* @return array array touple (might be empty) with the following fields in the keys value array: function, signature, docstring
 		* This handles introspection or discovery by the logged in client,
 		* in which case the input might be an array.  The server always calls
 		* this function to fill the server dispatch map using a string.
 		*/
-		function list_methods($_type='xmlrpc')
+		public function list_methods($_type = 'xmlrpc')
 		{
 			if (is_array($_type))
 			{
@@ -62,21 +95,26 @@
 			switch($_type)
 			{
 				case 'xmlrpc':
-					$xml_functions = array(
-						'read' => array(
+					$xml_functions = array
+					(
+						'read' => array
+						(
 							'function'  => 'read',
 							'signature' => array(array(xmlrpcStruct)),
 							'docstring' => lang('Returns struct of users application access')
 						),
-						'list_methods' => array(
+						'list_methods' => array
+						(
 							'function'  => 'list_methods',
-							'signature' => array(array(xmlrpcStruct,xmlrpcString)),
+							'signature' => array(array(xmlrpcStruct, xmlrpcString)),
 							'docstring' => lang('Read this list of methods.')
 						)
 					);
 					return $xml_functions;
+				/* SOAP disabled - no instance variable
 				case 'soap':
 					return $this->soap_functions;
+				*/
 				default:
 					return array();
 			}
@@ -89,31 +127,40 @@
 		/**
 		* Read application repository from ACLs
 		*
-		* @return array|boolean Array with list of available applications or false
+		* @return array|boolean array with list of available applications or false
 		* @access private
 		*/
-		function read_repository()
+		public function read_repository()
 		{
 			if (!isset($GLOBALS['phpgw_info']['apps']) ||
 				!is_array($GLOBALS['phpgw_info']['apps']))
 			{
 				$this->read_installed_apps();
 			}
-			$this->data = Array();
+			$this->data = array();
 			if ( $this->account_id == False )
 			{
 				return array();
 			}
 
 			$apps = $GLOBALS['phpgw']->acl->get_user_applications($this->account_id);
+			$apps_admin = $GLOBALS['phpgw']->acl->get_app_list_for_id('admin', phpgwapi_acl::ADD, $this->account_id);
+			if($apps_admin)
+			{
+				$apps['admin'] = true;
+			}
+			foreach($apps_admin as $app_admin)
+			{
+				$apps[$app_admin] = true;
+			}
+
 			foreach ( $GLOBALS['phpgw_info']['apps'] as $app )
 			{
-				//$check = $GLOBALS['phpgw']->acl->check('run',1,$app[0]);
-				$check = isset($apps[$app['name']]) ? $apps[$app['name']] : False;
-				if ($check)
+				if ( isset($apps[$app['name']]) )
 				{
-					$this->data[$app['name']] = array(
-						'title'   => $GLOBALS['phpgw_info']['apps'][$app['name']]['title'],
+					$this->data[$app['name']] = array
+					(
+						'title'   => $GLOBALS['phpgw']->translation->translate($app['name'], array(),false, $app['name']),
 						'name'    => $app['name'],
 						'enabled' => True,
 						'status'  => $GLOBALS['phpgw_info']['apps'][$app['name']]['status'],
@@ -121,7 +168,6 @@
 					);
 				} 
 			}
-			reset($this->data);
 			return $this->data;
 		}
 
@@ -130,32 +176,32 @@
 		* 
 		* @return array List with applications for the user
 		*/
-		function read()
+		public function read()
 		{
-			if (count($this->data) == 0)
+			if ( !count($this->data) )
 			{
 				$this->read_repository();
 			}
-			reset($this->data);
 			return $this->data;
 		}
 
 		/**
 		* Add an application to a user profile
 		*
-		* @param string|array $apps Array or string containing application names to add for a user
+		* @param string|array $apps array or string containing application names to add for a user
 		* @return array List with applications for the user
 		*/	
-		function add($apps)
+		public function add($apps)
 		{
 			if(is_array($apps))
 			{
-				while($app = each($apps))
+				foreach ( $apps as $app )
 				{
-					$this->data[$app[1]] = array(
-						'title'   => $GLOBALS['phpgw_info']['apps'][$app[1]]['title'],
+					$this->data[$app[1]] = array
+					(
+						'title'   => lang($app[1]),
 						'name'    => $app[1],
-						'enabled' => True,
+						'enabled' => true,
 						'status'  => $GLOBALS['phpgw_info']['apps'][$app[1]]['status'],
 						'id'      => $GLOBALS['phpgw_info']['apps'][$app[1]]['id']
 					);
@@ -163,15 +209,15 @@
 			}
 			else if (is_string($apps))
 			{
-				$this->data[$apps] = array(
-					'title'   => $GLOBALS['phpgw_info']['apps'][$apps]['title'],
+				$this->data[$apps] = array
+				(
+					'title'   => lang($apps),
 					'name'    => $apps,
-					'enabled' => True,
+					'enabled' => true,
 					'status'  => $GLOBALS['phpgw_info']['apps'][$apps]['status'],
 					'id'      => $GLOBALS['phpgw_info']['apps'][$apps]['id']
 				);
 			}
-			reset($this->data);
 			return $this->data;
 		}
 		
@@ -181,13 +227,12 @@
 		* @param string $appname Application name
 		* @return array List with applications for the user
 		*/
-		function delete($appname)
+		public function delete($appname)
 		{
 			if($this->data[$appname])
 			{
 				unset($this->data[$appname]);
 			}
-			reset($this->data);
 			return $this->data;
 		}
 		
@@ -197,12 +242,9 @@
 		* @param array $data Update the list of applications
 		* @return array List with applications for the user
 		*/
-		function update_data($data)
+		public function update_data($data)
 		{
-			reset($data);
-			$this->data = Array();
 			$this->data = $data;
-			reset($this->data);
 			return $this->data;
 		}
 		
@@ -211,19 +253,23 @@
 		*
 		* @return array List with applications for the user
 		*/
-		function save_repository()
+		public function save_repository()
 		{
 			$num_rows = $GLOBALS['phpgw']->acl->delete_repository("%%", 'run', $this->account_id);
-			reset($this->data);
-			while($app = each($this->data))
+
+			if ( !is_array($this->data) || !count($this->data) )
 			{
-				if(!$this->is_system_enabled($app[0]))
+				return array();
+			}
+
+			foreach ( $this->data as $app )
+			{
+				if ( !$this->is_system_enabled($app) )
 				{
 					continue;
 				}
-				$GLOBALS['phpgw']->acl->add_repository($app[0],'run',$this->account_id,1);
+				$GLOBALS['phpgw']->acl->add_repository($app, 'run', $this->account_id, phpgwapi_acl::READ);
 			}
-			reset($this->data);
 			return $this->data;
 		}
 
@@ -231,21 +277,25 @@
 		// These are the non-standard $account_id specific functions
 
 
-		function app_perms()
+		public function app_perms()
 		{
 			if (count($this->data) == 0)
 			{
 				$this->read_repository();
 			}
-			@reset($this->data);
-			while (list ($key) = each ($this->data))
+			foreach ( array_keys($this->data) as $key )
 			{
 				$app[] = $this->data[$key]['name'];
 			}
 			return $app;
 		}
 
-		function read_account_specific()
+		/**
+		* Get the list of installed application available for the current user
+		*
+		* 
+		*/
+		public function read_account_specific()
 		{
 			if (!is_array($GLOBALS['phpgw_info']['apps']))
 			{
@@ -261,8 +311,9 @@
 			{
 				if ($this->is_system_enabled($app))
 				{
-					$this->data[$app] = array(
-						'title'   => $GLOBALS['phpgw_info']['apps'][$app]['title'],
+					$this->data[$app] = array
+					(
+						'title'   => lang($app),
 						'name'    => $app,
 						'enabled' => true,
 						'status'  => $GLOBALS['phpgw_info']['apps'][$app]['status'],
@@ -273,26 +324,28 @@
 			return $this->data;
 		}
 
-
-		// These are the generic functions. Not specific to $account_id
-
+		/*
+		 * These are the generic functions. Not specific to $account_id
+		 */
 
 		/**
 		* Populate array with a list of installed apps
 		*/
-		function read_installed_apps()
+		public function read_installed_apps()
 		{
-			$apps = (array) $this->db->adodb->GetAssoc('select * from phpgw_applications where app_enabled != 0 order by app_order asc');
+			$this->db->fetchmode = 'ASSOC';
+			$sql = 'SELECT * FROM phpgw_applications WHERE app_enabled != 0 ORDER BY app_order ASC';
+			$this->db->query($sql,__LINE__,__FILE__);
+			$apps = $this->db->resultSet;
 			foreach($apps as $key => $value)
 			{
 				$GLOBALS['phpgw_info']['apps'][$value['app_name']] = array
 				(
-					'title'   => $value['app_name'],
 					'name'    => $value['app_name'],
+					'title'   => $GLOBALS['phpgw']->translation->translate($value['app_name'], array(),false, $value['app_name']),
 					'enabled' => true,
 					'status'  => $value['app_enabled'],
 					'id'      => (int) $value['app_id'],
-					'order'   => (int) $value['app_order'],
 					'version' => $value['app_version']
 				);
 			}
@@ -305,40 +358,59 @@
 		* @return boolean True when the application is available otherwise false
 		* @see read_installed_apps()
 		*/
-		function is_system_enabled($appname)
+		public function is_system_enabled($appname)
 		{
-			if(!is_array($GLOBALS['phpgw_info']['apps']))
+			if( !isset($GLOBALS['phpgw_info']['apps']) || !is_array($GLOBALS['phpgw_info']['apps']))
 			{
 				$this->read_installed_apps();
 			}
 			return isset($GLOBALS['phpgw_info']['apps'][$appname]) && $GLOBALS['phpgw_info']['apps'][$appname]['enabled'];
 		}
 
-		function id2name($id)
+		/**
+		* Get the application name associated with the application id
+		*
+		* @param int $id the application id to look up
+		* @return string the application name - empty string if invalid
+		*/
+		public function id2name($id)
 		{
-			@reset($GLOBALS['phpgw_info']['apps']);
-			while (list($appname,$app) = each($GLOBALS['phpgw_info']['apps']))
+			static $names = array();
+
+			if ( !isset($names[$id]) )
 			{
-				if(intval($app['id']) == intval($id))
+				$names[$id] = '';
+				$id = (int) $id;
+				foreach ( $GLOBALS['phpgw_info']['apps'] as $appname => $app )
 				{
-					@reset($GLOBALS['phpgw_info']['apps']);
-					return $appname;
+					if( $app['id'] == $id )
+					{
+						$names[$id] = $appname;
+					}
 				}
 			}
-			@reset($GLOBALS['phpgw_info']['apps']);
-			return '';
+			return $names[$id];
 		}
 		
-		function name2id($appname)
+		/**
+		* Convert an application name to an id
+		*
+		* @param string $appname the application to lookup
+		* @return int the application id - 0 if invalid
+		*/
+		public function name2id($appname)
 		{
-			if(is_array($GLOBALS['phpgw_info']['apps'][$appname]))
+			if ( !isset($GLOBALS['phpgw_info']['apps'])
+				|| !is_array($GLOBALS['phpgw_info']['apps']) )
+			{
+				$this->read_installed_apps();
+			}
+
+			if ( isset($GLOBALS['phpgw_info']['apps'][$appname]) 
+				&& is_array($GLOBALS['phpgw_info']['apps'][$appname]) )
 			{
 				return $GLOBALS['phpgw_info']['apps'][$appname]['id'];
 			}
-			else
-			{
-				return 0;
-			}
+			return 0;
 		}
 	}
-?>
