@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.asyncservice.inc.php 5213 2010-04-16 09:45:19Z sigurd $
+	* @version $Id: class.asyncservice.inc.php 6664 2010-12-09 10:53:30Z sigurdne $
 	*/
 
 	/**
@@ -403,10 +403,9 @@
 						if ($job['account_id'])
 						{
 							$GLOBALS['phpgw']->session->set_account_id($job['account_id']);
-							$GLOBALS['phpgw']->session->account_lid = $GLOBALS['phpgw']->accounts->id2lid($job['account_id']);
-							$GLOBALS['phpgw']->session->account_domain = $domain;
+				//			$GLOBALS['phpgw']->session->account_domain = $domain;
 							$GLOBALS['phpgw']->session->read_repositories(False,False);
-							$GLOBALS['phpgw_info']['user']  = $GLOBALS['phpgw']->session->user;
+							$GLOBALS['phpgw_info']['user']  = $GLOBALS['phpgw']->session->get_user();
 
 							if ($lang != $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'])
 							{
@@ -604,9 +603,22 @@
 
 			if (!is_executable($this->crontab))
 			{
-				//echo "<p>Error: $this->crontab not found !!!</p>";
+				if($this->debug)
+				{
+					echo "<p>Error: $this->crontab not found !!!</p>";
+				}
 				return 0;
 			}
+
+			if (!is_executable($this->php))
+			{
+				if($this->debug)
+				{
+					echo "<p>Error: $this->php not found !!!</p>";
+				}
+				return 0;
+			}
+
 			$times = False;
 			$this->other_cronlines = array();
 			if (($crontab = popen('/bin/sh -c "'.$this->crontab.' -l" 2>&1','r')) !== False)
