@@ -7,7 +7,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.categories.inc.php 5157 2010-04-09 08:34:41Z sigurd $
+	* @version $Id: class.categories.inc.php 7142 2011-03-24 14:09:35Z sigurdne $
 	*/
 
 	/**
@@ -703,9 +703,10 @@
 
 				$cat_list[] = array
 				(
-					'cat_id'	=> $cat['id'],
-					'name'		=> $name,
-					'selected'	=> $sel_cat
+					'cat_id'		=> $cat['id'],
+					'name'			=> $name,
+					'description'	=> $cat['description'],
+					'selected'		=> $sel_cat
 				);
 			}
 
@@ -834,16 +835,29 @@
 				}
 			}
 
+			$this->db->query('SELECT cat_id FROM phpgw_categories WHERE cat_id=' . $cat_id . $subdelete . " AND cat_appname='"
+							. $this->app_name . "'",__LINE__,__FILE__);
+			$_cats = array();
+			while ($this->db->next_record())
+			{
+				$_cats[] = $this->db->f('cat_id');			
+			}
+
 			$this->db->query('DELETE FROM phpgw_categories WHERE cat_id=' . $cat_id . $subdelete . " AND cat_appname='"
 							. $this->app_name . "'",__LINE__,__FILE__);
-			$args = array
-			(
-				'cat_id'	=> $cat_id,
-				'cat_owner'	=> $this->account_id,
-				'location'	=> 'cat_delete',
-				'location_id' => $this->location_id
-			);
-			$GLOBALS['phpgw']->hooks->single($args, $this->app_name);
+			
+			foreach($_cats as $_cat_id)
+			{
+				$args = array
+				(
+					'cat_id'	=> $_cat_id,
+					'cat_owner'	=> $this->account_id,
+					'location'	=> 'cat_delete',
+					'location_id' => $this->location_id
+				);
+
+				$GLOBALS['phpgw']->hooks->single($args, $this->app_name);
+			}
 		}
 
 		/**
