@@ -6,17 +6,18 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage contacts
-	* @version $Id: class.contact_categories.inc.php 15562 2004-12-30 06:47:35Z skwashd $
+	* @version $Id: class.contact_categories.inc.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	/**
 	* Use SQL criteria
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_criteria.inc.php');
+	phpgw::import_class('phpgwapi.sql_criteria');
+
 	/**
 	* Use SQL entity
 	*/
-	include_once(PHPGW_API_INC . '/class.sql_entity.inc.php');
+	phpgw::import_class('phpgwapi.sql_entity');
 
 	/**
 	* Query statements for "categories" table
@@ -24,7 +25,7 @@
 	* @package phpgwapi
 	* @subpackage contacts
 	*/
-	class contact_categories extends sql_entity
+	class contact_categories extends phpgwapi_sql_entity
 	{
 		var $map = array('key_cat_id'		=> array('select'	=> '',
 								 'criteria' 	=> '',
@@ -65,4 +66,3 @@
 			$this->set_elinks('key_cat_id', 'phpgwapi.contact_categories','parent_id');
 		}
 	}
-?>
\ No newline at end of file
