@@ -9,7 +9,7 @@
 	 * @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	 * @package phpgroupware
 	 * @subpackage phpgwapi
-	 * @version $Id: class.custom_fields.inc.php 5042 2010-03-16 14:46:07Z sigurd $
+	 * @version $Id: class.custom_fields.inc.php 7484 2011-08-08 12:44:31Z sigurdne $
 	 */
 
 	/*
@@ -76,6 +76,8 @@
 		*/
 		protected $_total_records = 0;
 
+		protected $global_lock = false;
+
 		/**
 		 * Constructor
 		 *
@@ -116,7 +118,8 @@
 				'link'	=> lang('Link'),
 				'pwd' 	=> lang('password'),
 				'user' 	=> 'phpgw_user',
-				'event'	=> lang('event')
+				'event'	=> lang('event'),
+				'bolean'	=> 'Bolean'
 			);
 
 			$this->_oProc			= createObject('phpgwapi.schema_proc', $GLOBALS['phpgw_info']['server']['db_type']);
@@ -300,7 +303,7 @@
 			{
 				case 'R':
 				case 'CH':
-				case 'LB':
+			//	case 'LB':
 				case 'AB':
 				case 'ABO':
 				case 'VENDOR':
@@ -317,7 +320,14 @@
 
 			unset($attrib);
 
-			$this->_db->transaction_begin();
+			if ( $this->_db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->_db->transaction_begin();
+			}
 
 			$sql = "SELECT id FROM phpgw_cust_attribute"
 				. " WHERE location_id = {$values['location_id']}"
@@ -384,9 +394,12 @@
 
 			$this->_oProc->AddColumn($attrib_table, $values['column_name'], $col_info);
 
-			if ( $this->_db->transaction_commit() )
+			if ( !$this->global_lock )
 			{
-				return $values['id'];
+				if ( $this->_db->transaction_commit() )
+				{
+					return $values['id'];
+				}
 			}
 
 			return 0;
@@ -418,7 +431,7 @@
 				switch ( $attrib['datatype'] )
 				{
 					case 'CH':
-						$attrib['value'] = serialize($attrib['value']);
+						$attrib['value'] = ',' . implode(',', $attrib['value']) . ',';
 						break;
 
 					case 'R':
@@ -540,9 +553,15 @@
 						. " WHERE location_id = {$loc_id} AND attrib_sort > {$attrib_sort} AND group_id = {$group_id}";
 					$this->_db->query($sql, __LINE__, __FILE__);
 				}
+
+				$sql = "DELETE FROM phpgw_cust_choice"
+						. " WHERE location_id = {$loc_id} AND attrib_id = {$attrib_id}";
+				$this->_db->query($sql, __LINE__,__FILE__);
+
 				$sql = "DELETE FROM phpgw_cust_attribute"
 						. " WHERE location_id = {$loc_id} AND id = {$attrib_id}";
 				$this->_db->query($sql, __LINE__,__FILE__);
+
 			}	
 			return $this->_db->transaction_commit();
 		}
@@ -616,7 +635,7 @@
 			{
 				case 'R':
 				case 'CH':
-				case 'LB':
+		//		case 'LB':
 				case 'AB':
 				case 'ABO':
 				case 'VENDOR':
@@ -1574,7 +1593,8 @@
 				'link'		=> 'varchar',
 				'pwd' 		=> 'varchar',
 				'user' 		=> 'int',
-				'event'		=> 'int'
+				'event'		=> 'int',
+				'bolean'	=> 'int'
 			);
 
 			if ( !isset($datatype_text[$datatype]) )
@@ -1606,7 +1626,8 @@
 				'link'		=> 255,
 				'pwd' 		=> 32,
 				'user' 		=> 4,
-				'event'		=> 4
+				'event'		=> 4,
+				'bolean'	=> 2
 			);
 
 			if ( !isset($datatype_precision[$datatype]) )
