@@ -234,6 +234,7 @@
 			{
 				if ( $e && $this->Halt_On_Error == 'yes' )
 				{
+					$this->transaction_abort();
 					if($file)
 					{
 						trigger_error('Error: ' . $e->getMessage() . "<br>SQL: $sql\n in File: $file\n on Line: $line\n", E_USER_ERROR);
@@ -242,9 +243,12 @@
 					{
 						trigger_error("$sql\n". $e->getMessage(), E_USER_ERROR);
 					}
-					$this->transaction_abort();
 					exit;
 				}
+				else if($this->Exception_On_Error)
+				{
+					throw $e;
+				}
 			}
 
 			$this->delayPointer = true;
@@ -261,7 +265,7 @@
 		* @param integer $num_rows number of rows to return (optional), if unset will use $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']
 		* @return integer current query id if sucesful and null if fails
 		*/
-		public function limit_query($Query_String, $offset = -1, $line = '', $file = '', $num_rows = -1)
+		public function limit_query($Query_String, $offset, $line = '', $file = '', $num_rows = 0)
 		{
 			if ( (int) $num_rows <= 0 )
 			{
@@ -282,6 +286,7 @@
 			{
 				if ( $e && $this->Halt_On_Error == 'yes' )
 				{
+					$this->transaction_abort();
 					if($file)
 					{
 						trigger_error('Error: ' . $e->getMessage() . "<br>SQL: $sql\n in File: $file\n on Line: $line\n", E_USER_ERROR);
@@ -290,9 +295,12 @@
 					{
 						trigger_error("$sql\n". $e->getMessage(), E_USER_ERROR);
 					}
-					$this->transaction_abort();
 					exit;
 				}
+				else if($this->Exception_On_Error)
+				{
+					throw $e;
+				}
 			}
 
 			$this->delayPointer = true;
@@ -369,9 +377,21 @@
 		*/
 		public function transaction_abort()
 		{
+			$ret = false;
 			$this->Transaction = false;
-			$this->adodb->FailTrans();
-			return $this->adodb->HasFailedTrans();
+			try
+			{
+				$this->adodb->FailTrans();
+				$ret = $this->adodb->HasFailedTrans();
+			}
+			catch(Exception $e)
+			{
+				if ( $e )
+				{
+					throw $e;
+				}
+			}
+			return $ret;
 		}
 
 		/**
@@ -599,7 +619,7 @@
 		* @param boolean $upper optional, default False. If $upper is true, then the table names (array keys) are upper-cased.
 		* @return array Table meta data
 		*/  
-		public function MetaForeignKeys($table = '', $owner=false, $upper=false)
+		public function MetaForeignKeys($table, $owner=false, $upper=false)
 		{
 			if(!$this->adodb->IsConnected())
 			{
