@@ -308,7 +308,7 @@
 		*/
 		public function query($sql, $line = '', $file = '', $exec = false, $fetch_single = false)
 		{
-
+//_Debug_Array($sql);
 			$this->_get_fetchmode();
 			$this->fetch_single = $fetch_single;
 
@@ -319,7 +319,7 @@
 
 			if(!$exec)
 			{
-				if(preg_match('/(^INSERT INTO|^DELETE FROM|^CREATE TABLE|^DROP TABLE|^ALTER TABLE|^UPDATE)/i', $sql)) // need it for MySQL
+				if(preg_match('/(^INSERT INTO|^DELETE FROM|^CREATE|^DROP|^ALTER|^UPDATE)/i', $sql)) // need it for MySQL and Oracle
 				{
 					$exec = true;
 				}
@@ -360,6 +360,8 @@
 			{
 				if ( $e && $this->Halt_On_Error == 'yes' )
 				{
+					$this->transaction_abort();
+
 					if($file)
 					{
 						trigger_error('Error: ' . $e->getMessage() . "<br>SQL: $sql\n in File: $file\n on Line: $line\n", E_USER_ERROR);
@@ -368,11 +370,13 @@
 					{
 						trigger_error("$sql\n". $e->getMessage(), E_USER_ERROR);
 					}
-					$this->transaction_abort();
 					exit;
 				}
+				else if($this->Exception_On_Error)
+				{
+					throw $e;
+				}
 			}
-
 			$this->delayPointer = true;
 			return true;
 		}
@@ -442,6 +446,8 @@
 			{
 				if ( $e && $this->Halt_On_Error == 'yes' )
 				{
+					$this->transaction_abort();
+
 					if($file)
 					{
 						trigger_error('Error: ' . $e->getMessage() . "<br>SQL: $sql\n in File: $file\n on Line: $line\n", E_USER_ERROR);
@@ -450,9 +456,12 @@
 					{
 						trigger_error("$sql\n". $e->getMessage(), E_USER_ERROR);
 					}
-					$this->transaction_abort();
 					exit;
 				}
+				else if($this->Exception_On_Error)
+				{
+					throw $e;
+				}
 			}
 
 			$this->delayPointer = true;
@@ -554,8 +563,25 @@
 		*/
 		public function transaction_abort()
 		{
-			$this->Transaction = false;
-			return $this->db->rollBack();
+			$ret = false;
+
+			if($this->Transaction)
+			{
+				$this->Transaction = false;
+				try
+				{
+					$ret = $this->db->rollBack();
+				}
+				catch(PDOException $e)
+				{
+					if ( $e )
+					{
+						trigger_error('Error: ' . $e->getMessage(), E_USER_ERROR);
+	//					throw $e;
+					}
+				}
+			}
+			return $ret;
 		}
 
 		/**
@@ -845,18 +871,18 @@
 			switch ( $this->Type )
 			{
 				case 'mysql': // Not testet
-				$this->query("SHOW FULL TABLES",__LINE__, __FILE__);
+					$this->query("SHOW FULL TABLES",__LINE__, __FILE__);
 					foreach($this->resultSet as $entry)
 					{
 						if($include_views)
 						{
-							$return[] =  $entry[0];
+							$return[] =  $entry["Tables_in_{$this->Database}"];
 						}
 						else
 						{
-							if ($entry[1] =='BASE TABLE')
+							if ($entry['Table_type'] =='BASE TABLE')
 							{
-								$return[] =  $entry[0];							
+								$return[] =  $entry["Tables_in_{$this->Database}"];
 							}
 						}
 					} 
