@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.errorlog.inc.php 17062 2006-09-03 06:15:27Z skwashd $
+	* @version $Id: class.errorlog.inc.php 1449 2008-07-19 15:01:32Z sigurd $
 	*/
 
 	/**
@@ -108,7 +108,7 @@
 			$db =& $GLOBALS['phpgw']->db;
 //			$db->lock('phpgw_log');
 			$db->query("insert into phpgw_log (log_date, log_user, log_app, log_severity) values "
-				."('". $GLOBALS['phpgw']->db->to_timestamp(time())
+				."('". date($db->datetime_format())
 				."',".intval($GLOBALS['phpgw']->session->account_id)
 				.",'".$GLOBALS['phpgw_info']['flags']['currentapp']."'"
 				.",'".$this->severity()."'"
