@@ -15,7 +15,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package phpgwapi
 	* @subpackage utilities
- 	* @version $Id: class.excelreader.inc.php 18253 2007-08-31 22:53:03Z sigurdne $
+ 	* @version $Id: class.excelreader.inc.php 682 2008-02-01 12:19:55Z dave $
 	*
 	*/
 
@@ -23,6 +23,6 @@
 	/**
 	* 
 	*/
-	require_once(PHPGW_API_INC . SEP . 'excelreader' . SEP . 'reader.php');
+	require_once(PHPGW_API_INC . '/excelreader/reader.php');
 
 ?>
