@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.gdbutton.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.gdbutton.inc.php 682 2008-02-01 12:19:55Z dave $
 	* @internal Some methods based on former class.graphics 2001 Lars Kneschke
 	*/
 
@@ -37,14 +37,14 @@
 			$this->image		= 0;
 			$this->font_size	= 0;
 			$this->font_text	= '';
-			$this->ttf_font		= PHPGW_SERVER_ROOT . SEP . 'phpgwapi' . SEP . 'fonts' . SEP . 'FreeSans.ttf';
+			$this->ttf_font		= PHPGW_SERVER_ROOT . '/phpgwapi/fonts/FreeSans.ttf';
 			$this->filename		= '';
 
 			$this->xspace		= 4;
 			$this->yspace		= 4;
 
-			$this->save_dir		= $_SERVER['DOCUMENT_ROOT'] . PHPGW_IMAGES_DIR . SEP;
-			$this->img_dir		= PHPGW_IMAGES_DIR . SEP;
+			$this->save_dir		= $_SERVER['DOCUMENT_ROOT'] . PHPGW_IMAGES_DIR . '/';
+			$this->img_dir		= PHPGW_IMAGES_DIR . '/';
 		}
 
 		function button_init()
