@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.gdimage.inc.php 17597 2006-11-26 22:22:01Z sigurdne $
+	* @version $Id: class.gdimage.inc.php 682 2008-02-01 12:19:55Z dave $
 	* @internal This class based on htmlGD.php3 - Double Choco Latte - Source Configuration Management System - Copyright (C) 1999  Michael L. Dean & Tim R. Norman
 	*/
 
@@ -51,8 +51,8 @@
 			$this->hColor = 0;
 			$this->font = 0;
 			$this->type = 'png';			
-			$this->temp_dir	= PHPGW_SERVER_ROOT . SEP . 'phpgwapi' . SEP . 'images' . SEP;
-//			$this->temp_dir	= $GLOBALS['phpgw_info']['server']['temp_dir'] . SEP;
+			$this->temp_dir	= PHPGW_SERVER_ROOT . '/phpgwapi/images/';
+//			$this->temp_dir	= $GLOBALS['phpgw_info']['server']['temp_dir'] . '/';
 		}
 
 		function check_gd()
