@@ -6,13 +6,13 @@
 	 * @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	 * @package phpgwapi
 	 * @subpackage application
-	 * @version $Id: class.hooks.inc.php 18013 2007-03-06 14:30:39Z sigurdne $
+	 * @version $Id: class.hooks.inc.php 6088 2010-06-17 10:30:41Z sigurd $
 	 */
 
 	/*
 	   This program is free software: you can redistribute it and/or modify
 	   it under the terms of the GNU Lesser General Public License as published by
-	   the Free Software Foundation, either version 3 of the License, or
+	   the Free Software Foundation, either version 2 of the License, or
 	   (at your option) any later version.
 
 	   This program is distributed in the hope that it will be useful,
@@ -33,9 +33,9 @@
 	class phpgwapi_hooks
 	{
 		var $found_hooks = Array();
-		var $db = null;
+		protected $db = null;
 
-		function __construct($db = null)
+		public function __construct($db = null)
 		{
 			$this->db = !is_null($db) ? $db : $GLOBALS['phpgw']->db;	// this is to allow setup to set the db
 			$this->read();
@@ -70,7 +70,7 @@
 		 * 	False if no hook exists, True if old hook exists \
 		 * 	and whatever the new methode-hook returns (can be True or False too!).
 		 */
-		function process($args, $order = '', $no_permission_check = False)
+		public function process($args, $order = '', $no_permission_check = False)
 		{
 			//echo "<p>hooks::process("; print_r($args); echo ")</p>\n";
 			if ($order == '')
@@ -79,6 +79,7 @@
 					array($GLOBALS['phpgw_info']['flags']['currentapp']);
 			}
 
+			$results = array();
 			/* First include the ordered apps hook file */
 			foreach($order as $appname)
 			{
@@ -133,7 +134,7 @@
 		 * $no_permission_check should *ONLY* be used when it *HAS* to be. (jengo)
 		 * @return False if no hook exists, True if an old hook exist and whatever the new method-hook returns
 		 */
-		function single($args, $appname = '', $no_permission_check = False,$try_unregistered = False)
+		public function single($args, $appname = '', $no_permission_check = False,$try_unregistered = False)
 		{
 			//echo "<p>hooks::single("; print_r($args); echo ",'$appname','$no_permission_check','$try_unregistered')</p>\n";
 			if (is_array($args))
@@ -148,7 +149,6 @@
 			{
 				$appname = is_array($args) && isset($args['appname']) ? $args['appname'] : $GLOBALS['phpgw_info']['flags']['currentapp'];
 			}
-			$SEP = filesystem_separator();
 
 			/* First include the ordered apps hook file */
 			if (isset($this->found_hooks[$appname][$location]) || $try_unregistered)
@@ -165,7 +165,7 @@
 					{
 						$method = 'hook_'.$location.'.inc.php';
 					}
-					$f = PHPGW_SERVER_ROOT . $SEP . $appname . $SEP . 'inc' . $SEP . $method;
+					$f = PHPGW_SERVER_ROOT . "/{$appname}/inc/{$method}";
 					if ( ( (isset($GLOBALS['phpgw_info']['user']['apps'][$appname]) && $GLOBALS['phpgw_info']['user']['apps'][$appname]) 
 							|| (($no_permission_check || $location == 'config' || $appname == 'phpgwapi') && $appname)) 
 						&& file_exists($f) )
@@ -186,7 +186,7 @@
 		/**
 		 * loop through the applications and count the hooks
 		 */
-		function count($location)
+		public function count($location)
 		{
 			$count = 0;
 			foreach($GLOBALS['phpgw_info']['user']['apps'] as $appname => $data)
@@ -205,23 +205,23 @@
 		 * @param $appname	Application 'name' 
 		 * @param $hooks array with hooks to register, eg $setup_info[$app]['hooks'] or not used for only deregister the hooks
 		 */
-		function register_hooks($appname,$hooks='')
+		public function register_hooks($appname,$hooks='')
 		{
 			if(!$appname)
 			{
 				return False;
 			}
+
 			$db_appname = $this->db->db_addslashes($appname);
 			$this->db->query("DELETE FROM phpgw_hooks WHERE hook_appname='$db_appname'",__LINE__,__FILE__);
 
-			if (!is_array($hooks))	// only deregister
+			if ( !is_array($hooks) )	// only deregister
 			{
 				return True;
 			}
-			//echo "<p>ADDING hooks for: $appname</p>";
-			foreach($hooks as $key => $hook)
+			foreach ( $hooks as $key => $hook )
 			{
-				if (!is_numeric($key))	// new method based hook
+				if ( !is_numeric($key) )	// new method based hook
 				{
 					$location = $key;
 					$filename = $hook;
@@ -242,8 +242,13 @@
 		 * Register the hooks of all applications (used by admin)
 		*
 		 */
-		function register_all_hooks()
+		public function register_all_hooks()
 		{
+			if ( !isset($GLOBALS['phpgw_info']['apps']) || !is_array($GLOBALS['phpgw_info']['apps']) )
+			{
+				$GLOBALS['phpgw']->applications->read_installed_apps();
+			}
+
 			$app_list = array_keys($GLOBALS['phpgw_info']['apps']);
 			$app_list[] = 'phpgwapi';
 
@@ -253,7 +258,7 @@
 				if ( file_exists($f) )
 				{
 					//DO NOT USE include_once here it breaks API hooks - skwashd dec07
-					include($f);
+					include $f;
 					if ( isset($setup_info[$appname]['hooks']) )
 					{
 						$this->register_hooks($appname, $setup_info[$appname]['hooks']);
@@ -262,4 +267,3 @@
 			}
 		}
 	}
-?>
