@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage network
-	* @version $Id: class.http_dav_client.inc.php 17125 2006-09-10 15:53:15Z Caeies $
+	* @version $Id: class.http_dav_client.inc.php 4498 2010-01-14 16:59:33Z sigurd $
 	* @internal At the moment much of this is simply a wrapper around the NET_HTTP_Client class, with some other methods for parsing the returned XML etc Ideally this will eventually use groupware's inbuilt HTTP class
 	*/
 
@@ -29,6 +29,18 @@
 	*/
   define ('DEBUG_CACHEPROP', 0);
 
+	// FIXME - code should be updated to the new PHP5/DOM to parse the XML.
+	if (!function_exists('domxml_open_mem'))
+	{
+		if(is_file(PHPGW_API_INC.'/domxml-php4-to-php5.php'))
+		{
+			require_once PHPGW_API_INC.'/domxml-php4-to-php5.php'; //Load a PHP5 converter
+		}
+		else
+		{
+			throw new Exception(lang('ERROR: you need the DOM XML Functions or a converter'));
+		}
+	}
 
 	/**
 	* DAV parser
@@ -85,7 +97,7 @@
 					{
 						case 'href':
 							$string = urldecode(trim($c->node_value()));
-							$idx = strrpos($string,SEP);
+							$idx = strrpos($string, '/');
 							if( $idx && ($idx == strlen( $string ) - 1 ) )
 							{
 								$string = substr($string, 0, $idx);
@@ -663,7 +675,7 @@ if ( DEBUG_CACHEPROP) echo '<b>cp propfind unseted</b><br />';
 
 			if (strlen($token)) 
 			{
-				$this->http_client->addHeader('If', '<'.$uri.'>'.' (<'.$token.'>)');
+				$this->http_client->addHeader('If', '<'.$srcUri.'>'.' (<'.$token.'>)');
 			}
 			$result = $this->http_client->Copy( $srcUri, $destUri, $overwrite, $scope);
 			$this->http_client->removeHeader('If');
@@ -696,7 +708,7 @@ if (DEBUG_CACHEPROP) _debug_array('cache prop cleared');
 			$this->delete_uri_in_cache($destUri);
 			if (strlen($token)) 
 			{
-				$this->http_client->addHeader('If', '<'.$uri.'>'.' (<'.$token.'>)');
+				$this->http_client->addHeader('If', '<'.$srcUri.'>'.' (<'.$token.'>)');
 			}
 			$result = $this->http_client->Move( $srcUri, $destUri, $overwrite, $scope);
 			$this->http_client->removeHeader('If');
@@ -918,11 +930,11 @@ if (DEBUG_CACHE) echo '<b>cache cleared</b>';
 					$ret = $this->http_client->Unlock($uri,$token);
 				}
 			}
-			elseif ( isset($this->cached_propfind[$uri.SEP]) )
+			elseif ( isset($this->cached_propfind["{$uri}/"]) )
 			{
-				if ( ($ret = $this->cached_propfind[$uri.SEP]) == 207 )
+				if ( ($ret = $this->cached_propfind["{$uri}/"]) == 207 )
 				{
-					$ret = $this->http_client->Unlock($uri.SEP,$token);
+					$ret = $this->http_client->Unlock("{$uri}/",$token);
 				}
 			}
 			else
@@ -931,9 +943,9 @@ if (DEBUG_CACHE) echo '<b>cache cleared</b>';
 				{
 					$this->cached_propfind[$uri] = 207;
 				}
-				elseif( $ret == 301 && ($ret = $this->http_client->Unlock($uri.SEP,$token)) == 204 )
+				elseif( $ret == 301 && ($ret = $this->http_client->Unlock("{$uri}/",$token)) == 204 )
 				{
-					$this->cached_propfind[$uri.SEP] = 207;
+					$this->cached_propfind["{$uri}/"] = 207;
 				}
 			}
 
@@ -977,11 +989,11 @@ if (DEBUG_CACHE) echo '<b>cache cleared</b>';
 					$ret = $this->http_client->Lock($uri, 'exclusive', 'write', $owner);
 				}
 			}
-			elseif ( isset($this->cached_propfind[$uri.SEP]) )
+			elseif ( isset($this->cached_propfind["{$uri}/"]) )
 			{
-				if ( ($ret = $this->cached_propfind[$uri.SEP]) == 207 )
+				if ( ($ret = $this->cached_propfind["{$uri}/"]) == 207 )
 				{
-					$ret = $this->http_client->Lock($uri.SEP, 'exclusive', 'write', $owner);
+					$ret = $this->http_client->Lock("{$uri}/", 'exclusive', 'write', $owner);
 				}
 			}
 			else
@@ -991,9 +1003,9 @@ if (DEBUG_CACHE) echo '<b>cache cleared</b>';
 				{
 					$this->cached_propfind[$uri] = 207;
 				}
-				elseif ( $ret == 301 && ($ret = $this->http_client->Lock($uri.SEP, 'exclusive', 'write', $owner)) == 200)
+				elseif ( $ret == 301 && ($ret = $this->http_client->Lock("{$uri}/", 'exclusive', 'write', $owner)) == 200)
 				{
-					$this->cached_propfind[$uri.SEP] = 207;
+					$this->cached_propfind["{$uri}/"] = 207;
 				}
 			}
 
