@@ -7,7 +7,7 @@
 	* @license LGPL
 	* @package phpgwapi
 	* @subpackage network
-	* @version $Id: class.http_svn_client.inc.php 17196 2006-09-21 08:50:07Z Caeies $
+	* @version $Id: class.http_svn_client.inc.php 4681 2010-01-30 17:06:35Z sigurd $
 	* @internal At the moment much of this is simply a wrapper around the NET_HTTP_Client class, with some other methods for parsing the returned XML etc Ideally this will eventually use groupware's inbuilt HTTP class
 	*/
 
@@ -136,7 +136,10 @@
 		{
 			$svnxml = '<?xml version="1.0" encoding="utf-8" ?>
 			<S:log-report xmlns:S="svn:" xmlns:D="DAV">';
-			$svnxml .= '<S:start-revision>'.$startvers.'</S:start-revision>'; 
+			if($startvers)
+			{
+				$svnxml .= '<S:start-revision>'.$startvers.'</S:start-revision>'; 
+			}
 			$svnxml .= '<S:end-revision>'.$endvers.'</S:end-revision>';   
 			$svnxml .= '<S:path/>';
 			$svnxml.='<S:strict-node-history/>';
@@ -174,6 +177,7 @@
 		{
 			$ret=$this->report($uri,$startvers,$endvers);
 			$xml_result=$this->http_client->getBody();			
+
 			if ( !is_object($this->svn_processor))
 			{
 				$this->svn_processor = new SVNParser();
@@ -243,7 +247,7 @@
 			$numofentry=0;
 			$rjournal=array();
 			
-			while(list ($num, $entry_journal) = each ($journal))
+			while(list (, $entry_journal) = each ($journal))
 			{
 				++$numofentry;
 				$rjournal[]=$entry_journal; 
