@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package phpgwapi
 	* @subpackage utilities
- 	* @version $Id: class.pdf.inc.php 1183 2008-06-09 13:05:26Z sigurd $
+ 	* @version $Id: class.pdf.inc.php 6757 2011-01-12 12:49:58Z sigurdne $
 	*
 	* Example
 	* <code>
@@ -51,7 +51,8 @@
 		{	
 			$browser = createObject('phpgwapi.browser');
 
-			if($browser->BROWSER_AGENT != 'IE')
+//			if($browser->BROWSER_AGENT != 'IE')
+			if(true)
 			{
 				$size = strlen($document);
 				$browser->content_header($document_name .'.pdf','application/pdf', $size);
@@ -104,14 +105,14 @@ HTML;
 		 */
 		protected function _clear_cache($dir)
 		{
-			$min_ctime = 60 * 60;
+			$min_ctime = time() - (60*60);
 			$dir = new DirectoryIterator($dir);
-			foreach ( $dir as $file )
+			foreach ( $dir as $fileinfo )
 			{
-				if ( preg_match('/^PDF_/', $file)
-					&& $file->getCTime() < $min_ctime )
+				if ( preg_match('/^PDF_/', $fileinfo->getFilename())
+					&& $fileinfo->getCTime() < $min_ctime )
 				{
-					unlink($file);
+					unlink($fileinfo->getPathname());
 				}
 			}
 		}
