@@ -9,7 +9,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgroupware
 	* @subpackage phpgwapi
-	* @version $Id: class.phpgw.inc.php 5232 2010-04-19 11:35:16Z sigurd $
+	* @version $Id: class.phpgw.inc.php 7488 2011-08-10 18:26:48Z sigurdne $
 	*/
 
 	/*
@@ -393,8 +393,8 @@
 				// Trim whitespace so it doesn't trip us up
 				$value = trim($value);
 				
-				// This won't be needed in PHP6 as GPC magic quotes are being removed
-				if ( get_magic_quotes_gpc() )
+				// This won't be needed in PHP 5.4 and later as GPC magic quotes are being removed
+				if ( version_compare(PHP_VERSION, '5.3.7') <= 0 && get_magic_quotes_gpc() )
 				{
 						$value = stripslashes($value);
 				}
