@@ -7,7 +7,7 @@
 	 * @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	 * @package phpgwapi
 	 * @subpackage application
-	 * @version $Id: class.preferences.inc.php 5127 2010-04-05 20:03:23Z sigurd $
+	 * @version $Id: class.preferences.inc.php 7215 2011-04-12 20:06:07Z sigurdne $
 	 */
 
 	/**
@@ -608,7 +608,7 @@
 
 			if (! $GLOBALS['phpgw']->acl->check('session_only_preferences',1,'preferences'))
 			{
-				if ( $this->db->Transaction )
+				if ( $this->db->get_transaction() )
 				{
 					$this->global_lock = true;
 				}
