@@ -6,14 +6,14 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.sbox2.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.sbox2.inc.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	/**
 	* Include parent class
 	* @see sbox
 	*/
-	include(PHPGW_API_INC . '/class.sbox.inc.php');
+	phpgw::import_class('phpgwapi.sbox');
 
 	/**
 	* Class for creating select boxes for addresse, projects, array items, ...
@@ -23,4 +23,9 @@
 	*/
 	class phpgwapi_sbox2 extends phpgwapi_sbox
 	{
+		public function __construct()
+		{
+			trigger_error('phpgwapi_sbox2 is no longer used, please port your code to phpgw_sbox', E_USER_NOTICE);
+			parent::__construct();
+		}
 	}
