@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc_mysql.inc.php 2592 2009-04-15 11:34:41Z sigurd $
+	* @version $Id: class.schema_proc_mysql.inc.php 7333 2011-05-31 05:59:50Z sigurdne $
 	*/
  
 	/**
@@ -139,14 +139,25 @@
 
 		function TranslateDefault($sDefault)
 		{
-			switch ($sDefault)
-			{
-				case 'current_date':
-				case 'current_timestamp':
-					return 'now()';
 
+			// Need Strict comparisons for true/false in case of datatype bolean
+			if ($sDefault === true || $sDefault === 'true' || $sDefault === 'True')
+			{
+				$ret= 1;
 			}
-			return "'" . $sDefault . "'";
+			else if ($sDefault === false || $sDefault === 'false' || $sDefault === 'False')
+			{
+				$ret= 0;
+			}
+			else if ($sDefault == 'current_date' || $sDefault == 'current_timestamp')
+			{
+				$ret= 'now()';
+			}
+			else
+			{
+				$ret= "'" . $sDefault . "'";			
+			}
+			return $ret;
 		}
 
 		/* Inverse of above, convert sql column types to array info */
@@ -287,7 +298,7 @@
 
 				/* The rest of this is used only for SQL->array */
 				$colinfo = explode('(',$oProc->m_odb->f(1));
-				$prec = ereg_replace(')','',$colinfo[1]);
+				$prec = str_replace(')','',$colinfo[1]);
 				$scales = explode(',',$prec);
 
 				if($colinfo[0] == 'enum')
