@@ -12,7 +12,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc_pgsql.inc.php 2979 2009-06-09 11:05:20Z sigurd $
+	* @version $Id: class.schema_proc_pgsql.inc.php 7333 2011-05-31 05:59:50Z sigurdne $
 	* @link http://www.greatbridge.org/project/phppgadmin
 	* @internal SQL for table properties taken from phpPgAdmin Version 2.2.1
 	*/
@@ -103,19 +103,33 @@
 				case 'bool':
 					$sTranslated = 'boolean';
 					break;
+				case 'xml':
+					$sTranslated = 'xml';
+					break;
 			}
 			return $sTranslated;
 		}
 
 		function TranslateDefault($sDefault)
 		{
-			switch ($sDefault)
+			// Need Strict comparisons for true/false in case of datatype bolean
+			if ($sDefault === true || $sDefault === 'true' || $sDefault === 'True')
 			{
-				case 'current_date':
-				case 'current_timestamp':
-					return "now()";
+				$ret= 'True';
 			}
-			return "'" . $sDefault . "'";
+			else if ($sDefault === false || $sDefault === 'false' || $sDefault === 'False')
+			{
+				$ret= 'False';
+			}
+			else if ($sDefault == 'current_date' || $sDefault == 'current_timestamp')
+			{
+				$ret= "now()";
+			}
+			else
+			{
+				$ret= "'" . $sDefault . "'";			
+			}
+			return $ret;
 		}
 
 		/* Inverse of above, convert sql column types to array info */
@@ -358,7 +372,7 @@
 					$default = '';
 					$nullcomma = '';
 				}
-				$default = ereg_replace("''","'",$default);
+				$default = str_replace("''","'",$default);
 
 				$this->sCol[] = "\t\t\t\t'" . $colname . "' => array(" . $type . ',' . $null . $nullcomma . $default . '),' . "\n";
 			}
