@@ -6,7 +6,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc_sapdb.inc.php 682 2008-02-01 12:19:55Z dave $
+	* @version $Id: class.schema_proc_sapdb.inc.php 7333 2011-05-31 05:59:50Z sigurdne $
 	*/
 
 	/**
@@ -146,13 +146,24 @@
 		 */
 		function TranslateDefault($sDefault)
 		{
-			switch ($sDefault)
+			// Need Strict comparisons for true/false in case of datatype bolean
+			if ($sDefault === true || $sDefault === 'true' || $sDefault === 'True')
 			{
-				case 'current_date':
-				case 'current_timestamp':
-					return 'TIMESTAMP';
+				$ret= 1;
 			}
-			return "'" . $sDefault . "'";
+			else if ($sDefault === false || $sDefault === 'false' || $sDefault === 'False')
+			{
+				$ret= 0;
+			}
+			else if ($sDefault == 'current_date' || $sDefault == 'current_timestamp')
+			{
+				$ret= 'TIMESTAMP';
+			}
+			else
+			{
+				$ret= "'" . $sDefault . "'";			
+			}
+			return $ret;
 		}
 
 		/**
