@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.service.inc.php 17062 2006-09-03 06:15:27Z skwashd $
+	* @version $Id: class.service.inc.php 682 2008-02-01 12:19:55Z dave $
 	*/
 
 	/**
@@ -15,9 +15,8 @@
 	* 
 	* @package phpgwapi
 	* @subpackage application
-	* @abstract
 	*/
-	class service
+	abstract class service
 	{
 		var $provider = '';
 		var $svc      = '';
