@@ -10,7 +10,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgroupware
 	* @subpackage phpgwapi
-	* @version $Id: class.sessions.inc.php 6091 2010-06-17 10:44:19Z sigurd $
+	* @version $Id: class.sessions.inc.php 7103 2011-03-10 10:23:40Z sigurdne $
 	*/
 
 	/*
@@ -352,7 +352,7 @@
 			$GLOBALS['phpgw']->interserver = createObject('phpgwapi.interserver');
 			$this->_login  = $login;
 			$this->_passwd = $passwd;
-			$login_array = explode('@', $login);
+			$login_array = explode('#', $login);
 			$this->_account_lid = $login_array[0];
 			$now = time();
 
@@ -832,6 +832,7 @@
 		public function set_account_id($account_id = 0)
 		{
 			$this->_account_id = get_account_id($account_id);
+			$this->_account_lid = $GLOBALS['phpgw']->accounts->id2lid($this->_account_id);
 		}
 
 		/**
@@ -1111,20 +1112,23 @@
 
 			$session = $this->read_session($sessionid);
 
-			$timeout = time() - $GLOBALS['phpgw_info']['server']['sessions_timeout'];
-			if ( !isset($session['session_dla'])
-				|| $session['session_dla'] <= $timeout )
+			if ($GLOBALS['phpgw_info']['server']['auth_type'] != 'ntlm') //Timeout make no sense for SSO
 			{
-				if(isset($session['session_dla']))
+				$timeout = time() - $GLOBALS['phpgw_info']['server']['sessions_timeout'];
+				if ( !isset($session['session_dla'])
+					|| $session['session_dla'] <= $timeout )
 				{
-					$this->cd_reason = 10;
+					if(isset($session['session_dla']))
+					{
+						$this->cd_reason = 10;
+					}
+					return false;
 				}
-				return false;
 			}
 
 			$this->_session_flags = $session['session_flags'];
 
-			$lid_data = explode('@', $session['session_lid']);
+			$lid_data = explode('#', $session['session_lid']);
 			$this->_account_lid = $lid_data[0];
 
 			if ( isset($lid_data[1]) )
@@ -1311,6 +1315,16 @@
 			return false;
 		}
 
+		/**
+		* Get userinfo to pass into $GLOBALS['phpgw_info']['user'] for asyncservice
+		*
+		* @return array user
+		*/
+		public function get_user()
+		{
+			return $this->_data;
+		}
+
 		/**
 		 * Get a list of currently logged in sessions
 		 *
@@ -1348,7 +1362,7 @@
 			{
 				$filename = $file->getFilename();
 				// only try php session files
-				if ( !preg_match('/^sess_([a-f0-9]+)$/', $filename) )
+				if ( !preg_match('/^sess_([a-z0-9]+)$/', $filename) )
 				{
 					continue;
 				}
@@ -1446,7 +1460,7 @@
 			}
 			$login	= $this->_db->db_addslashes($login);
 			$sql	= 'SELECT COUNT(*) AS cnt FROM phpgw_access_log'
-					. " WHERE account_id = 0 AND (loginid='{$login}' OR loginid LIKE '$login@%')"
+					. " WHERE account_id = 0 AND (loginid='{$login}' OR loginid LIKE '$login#%')"
 						. " AND li > {$block_time}";
 			$this->_db->query($sql, __LINE__, __FILE__);
 
@@ -1547,7 +1561,7 @@
 			$this->_data['domain']      = $this->_account_domain;
 			$this->_data['sessionid']   = $this->_sessionid;
 			$this->_data['session_ip']  = $this->_get_user_ip();
-			$this->_data['session_lid'] = $this->_account_lid.'@'.$this->_account_domain;
+			$this->_data['session_lid'] = $this->_account_lid.'#'.$this->_account_domain;
 			$this->_data['account_id']  = $this->_account_id;
 			$this->_data['account_lid'] = $this->_account_lid;
 			$this->_data['userid']      = $this->_account_lid;
@@ -1569,7 +1583,7 @@
 		protected function _set_login($login)
 		{
 			$m = array();
-			if ( preg_match('/(.*)@(.*)/', $login, $m) )
+			if ( preg_match('/(.*)#(.*)/', $login, $m) )
 			{
 				$this->_account_lid = $m[1];
 				$this->_account_domain = $m[2];
