@@ -9,7 +9,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup.inc.php 6150 2010-06-26 08:08:50Z sigurd $
+	* @version $Id: class.setup.inc.php 6789 2011-01-17 14:43:03Z sigurdne $
 	*/
 
 	/**
@@ -18,7 +18,7 @@
 	* @package phpgwapi
 	* @subpackage application
 	*/
-	class setup
+	class phpgwapi_setup
 	{
 		var $db;
 		var $oProc;
@@ -35,7 +35,7 @@
 		var $tbl_config;
 		var $tbl_hooks;
 
-		function setup($html = False, $translation = False)
+		public function __construct($html = False, $translation = False)
 		{
 			$this->detection = createObject('phpgwapi.setup_detection');
 			$this->process   = createObject('phpgwapi.setup_process');
@@ -538,7 +538,7 @@
 			// Clean up locations, custom fields and ACL
 			$this->db->query("SELECT app_id FROM phpgw_applications WHERE app_name = '{$appname}'");
 			$this->db->next_record();
-			$app_id = $this->db->f('app_id');
+			$app_id = (int)$this->db->f('app_id');
 
 			$this->db->query("SELECT location_id FROM phpgw_locations WHERE app_id = {$app_id}");
 
@@ -651,8 +651,8 @@
 				echo'<br>Input values: '
 					. 'A="'.$a.'", B="'.$b.'"';
 			}
-			$newa = ereg_replace('pre','.',$a);
-			$newb = ereg_replace('pre','.',$b);
+			$newa = str_replace('pre','.',$a);
+			$newb = str_replace('pre','.',$b);
 			$testa = explode('.',$newa);
 			if(@$testa[1] == '')
 			{
@@ -740,8 +740,8 @@
 				echo'<br>Input values: '
 					. 'A="'.$a.'", B="'.$b.'"';
 			}
-			$newa = ereg_replace('pre','.',$a);
-			$newb = ereg_replace('pre','.',$b);
+			$newa = str_replace('pre','.',$a);
+			$newb = str_replace('pre','.',$b);
 			$testa = explode('.',$newa);
 			if( !isset($testa[3]) || $testa[3] == '')
 			{
