@@ -7,12 +7,12 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup_html.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: class.setup_html.inc.php 3057 2009-06-13 18:23:12Z sigurd $
 	*/
 
 	/**
 	* Setup html
-	* 
+	*
 	* @package phpgwapi
 	* @subpackage application
 	*/
@@ -34,17 +34,24 @@
 			{
 				$domains = array();
 			}
+
+			$setting = phpgw::get_var('setting', 'string', 'POST');
+			$settings = phpgw::get_var("settings", 'string', 'POST');
+
 			foreach($domains as $k => $v)
 			{
 				if(isset($deletedomain[$k]))
 				{
 					continue;
 				}
-				//$dom = phpgw::get_var("setting_{$k}", 'string', 'POST');
-				$dom = $_POST['settings'][$k];
+				$dom = $settings[$k];
 				$GLOBALS['header_template']->set_var('DB_DOMAIN',$v);
 				foreach($dom as $x => $y)
 				{
+					if( $setting['enable_mcrypt'] == 'True' && ($x == 'db_pass' || $x == 'db_host' || $x == 'db_name' || $x == 'db_user' || $x == 'config_pass'))
+					{
+						$y = $GLOBALS['phpgw']->crypto->encrypt($y);
+					}
 					$GLOBALS['header_template']->set_var(strtoupper($x),$y);
 				}
 				$GLOBALS['header_template']->parse('domains','domain',True);
@@ -52,11 +59,20 @@
 
 			$GLOBALS['header_template']->set_var('domain','');
 
-			$setting = phpgw::get_var('setting', 'string', 'POST');
 			if(!empty($setting) && is_array($setting))
 			{
 				foreach($setting as $k => $v)
 				{
+					if ($setting['enable_mcrypt'] == 'True' && $k == 'HEADER_ADMIN_PASSWORD')
+					{
+						$v = $GLOBALS['phpgw']->crypto->encrypt($v);
+					}
+					
+					if( in_array( $k, array( 'server_root', 'include_root' ) )
+						&& substr(PHP_OS, 0, 3) == 'WIN' )
+					{
+						$v = str_replace( '\\', '/', $v );
+					}
 					$var[strtoupper($k)] = $v;
 				}
 			}
@@ -69,14 +85,14 @@
 			/* hack to get tpl dir */
 			if (is_dir(PHPGW_SERVER_ROOT))
 			{
-				$srv_root = PHPGW_SERVER_ROOT . SEP . "$app_name" . SEP;
+				$srv_root = PHPGW_SERVER_ROOT . "/$app_name/";
 			}
 			else
 			{
 				$srv_root = '';
 			}
 
-			return $srv_root . 'templates' . SEP . 'base';
+			return "{$srv_root}/templates/base";
 		}
 
 		function show_header($title='',$nologoutbutton=False, $logoutfrom='config', $configdomain='')
@@ -156,7 +172,7 @@
 				? $GLOBALS['phpgw_info']['setup']['ConfigLoginMSG'] : '&nbsp;');
 
 			$GLOBALS['setup_tpl']->set_var('HeaderLoginMSG',
-				@$GLOBALS['phpgw_info']['setup']['HeaderLoginMSG'] 
+				@$GLOBALS['phpgw_info']['setup']['HeaderLoginMSG']
 				? $GLOBALS['phpgw_info']['setup']['HeaderLoginMSG'] : '&nbsp;');
 
 			if ($GLOBALS['phpgw_info']['setup']['stage']['header'] == '10')
@@ -220,32 +236,21 @@
 			$GLOBALS['setup_tpl']->pparse('out','T_login_main');
 		}
 
+		/**
+		 * Get a list of available template sets
+		 *
+		 * @internal this doesn't appear to be called from anywhere - and duplicated code from phpgwapi_common
+		 */
 		function get_template_list()
 		{
-			$d = dir(PHPGW_SERVER_ROOT . '/phpgwapi/templates');
-
-			while($entry = $d->read())
-			{
-				if ($entry != 'CVS' && $entry != '.' && $entry != '..')
-				{
-					$list[$entry]['name'] = $entry;
-					$f = PHPGW_SERVER_ROOT . '/phpgwapi/templates/' . $entry . '/details.inc.php';
-					if (file_exists ($f))
-					{
-						include($f);
-						$list[$entry]['title'] = 'Use ' . $GLOBALS['phpgw_info']['template'][$entry]['title'] . 'interface';
-					}
-					else
-					{
-						$list[$entry]['title'] = $entry;
-					}
-				}
-			}
-			$d->close();
-			reset ($list);
-			return $list;
+			return $GLOBALS['phpgw']->common->template_list();
 		}
 
+		/**
+		 * Get a list of available old style themes
+		 *
+		 * @todo FIXME This is broken - themes aren't done this way any more
+		 */
 		function list_themes()
 		{
 			$dh = dir(PHPGW_SERVER_ROOT . '/phpgwapi/themes');
@@ -261,4 +266,3 @@
 			return $list;
 		}
 	}
-?>
