@@ -6,7 +6,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup_process.inc.php 4908 2010-02-24 20:49:33Z sigurd $
+	* @version $Id: class.setup_process.inc.php 7354 2011-06-07 06:06:54Z sigurdne $
 	*/
 
 	/**
@@ -23,14 +23,15 @@
 	* V : Version mismatch at end of upgrade (Not used, proposed only)
 	* M : Missing files at start of upgrade (Not used, proposed only)
 	*/
-	class setup_process
+	class phpgwapi_setup_process
 	{
 		var $oProc;
 		var $tables;
 		var $updateincluded = array();
 		var $translation;
+		protected $global_lock = false;
 
- 		function setup_process()
+ 		function __construct()
 		{
 			$this->translation = createObject('phpgwapi.setup_translation');
 		}
@@ -259,6 +260,15 @@
 			}
 			$GLOBALS['phpgw_setup']->oProc->m_bDeltaOnly = False;
 
+			if ( $GLOBALS['phpgw_setup']->oProc->m_odb->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+			}
+
 			if ( !is_array($setup_info) )
 			{
 				$setup_info = array();
@@ -330,6 +340,11 @@
 				if($DEBUG) { echo '<br>process->current(): Outgoing status: ' . $appname . ',status: '. $setup_info[$key]['status']; }
 			}
 
+			if ( !$this->global_lock )
+			{
+				$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit();
+			}
+
 			/* Done, return current status */
 			return ($setup_info);
 		}
@@ -359,7 +374,22 @@
 //				if( isset($setup_info[$key]['tables'])
 //					&& $setup_info[$key]['tables']
 //					&& file_exists($appdir.'default_records.inc.php'))
-				if( file_exists($appdir.'default_records.inc.php'))
+				$default_found = false;
+
+				$ConfigDomain = phpgw::get_var('ConfigDomain','string', 'COOKIE');
+
+				if( file_exists($appdir.$ConfigDomain.'/default_records.inc.php'))
+				{
+					$default_records = $appdir.$ConfigDomain.'/default_records.inc.php';
+					$default_found = true;
+				}
+				else if( file_exists($appdir.'default_records.inc.php'))
+				{
+					$default_records = $appdir.'default_records.inc.php';
+					$default_found = true;
+				}
+
+				if( $default_found )
 				{
 					if($DEBUG)
 					{
@@ -367,8 +397,10 @@
 					}
 
 					$oProc = &$GLOBALS['phpgw_setup']->oProc;	// to be compatible with old apps
-					require_once $appdir.'default_records.inc.php';
+
+					require_once $default_records;
 				}
+
 				/* $setup_info[$key]['status'] = 'C'; */
 			}
 
@@ -444,6 +476,57 @@
 			return ($setup_info);
 		}
 
+		/**
+		 * process application add credential to admins at install
+		 *
+		 * @param $setup_info	array of application info from setup.inc.php files, etc.
+		 */
+		function add_credential($appname)
+		{
+			$GLOBALS['phpgw']->accounts	= createObject('phpgwapi.accounts');
+			$GLOBALS['phpgw']->acl		= CreateObject('phpgwapi.acl');
+
+			$admins = array();
+			$accounts	= $GLOBALS['phpgw']->acl->get_ids_for_location('run', phpgwapi_acl::READ, 'admin');
+			foreach($accounts as $account_id)
+			{
+				$account = $GLOBALS['phpgw']->accounts->get($account_id);
+				if($account->type == phpgwapi_account::TYPE_GROUP)
+				{
+					$admins[] = $account_id;
+				}
+			}
+
+			$members = array();
+			foreach ($admins as $admin)
+			{
+				if(!$GLOBALS['phpgw']->acl->check('run', phpgwapi_acl::READ, $appname))
+				{
+					$locations = $GLOBALS['phpgw']->locations->get_locations(false, $appname);
+
+					$aclobj =& $GLOBALS['phpgw']->acl;
+					$aclobj->set_account_id($admin, true);
+					// application permissions
+					$aclobj->add($appname, 'run', phpgwapi_acl::READ);
+					foreach ($locations as $location => $info)
+					{
+						$aclobj->add($appname, $location, 31);
+					}
+
+					$aclobj->save_repository();
+					$members = array_merge($members, $GLOBALS['phpgw']->accounts->get_members($admin));
+				}
+			}
+
+			$members = array_unique($members);
+			//Clear the user's menu so it can be regenerated cleanly
+			//FIXME - the cache is not cleared
+			foreach ($members as $account_id)
+			{
+				phpgwapi_cache::user_clear('phpgwapi', 'menu', $account_id);
+			}
+		}
+
 		/**
 		 * process test_data.inc.php in each application/setup dir for developer tests
 		*
@@ -624,7 +707,7 @@
 								$currentver = isset($setup_info[$key]['currentver']) ? $setup_info[$key]['currentver'] : '';
 
 								/* build upgrade function name */
-								$function = $appname . '_upgrade' . ereg_replace("\.", '_', $value);
+								$function = $appname . '_upgrade' . str_replace('.', '_', $value);
 
 								if($DEBUG)
 								{
