@@ -63,20 +63,20 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package phpgwapi
 	* @subpackage application
- 	* @version $Id: class.shm.inc.php 1832 2008-11-15 15:35:58Z sigurd $
+ 	* @version $Id: class.shm.inc.php 7121 2011-03-15 08:53:24Z sigurdne $
 	*/
 
 	//This makes sure there is something set for temp
 	if ( !isset($GLOBALS['phpgw_info']['server']['temp_dir'])  
 			|| !is_dir($GLOBALS['phpgw_info']['server']['temp_dir']) )
 	{
-		if ( substr(PHP_OS, 3) == 'WIN' )
+		if ( substr(PHP_OS,0, 3) == 'WIN' )
 		{
 			$GLOBALS['phpgw_info']['server']['temp_dir'] = 'c:/temp';
 		}
 		else
 		{
-			$GLOBALS['phpgw_info']['server']['temp_dir'] = '/tmp/';
+			$GLOBALS['phpgw_info']['server']['temp_dir'] = '/tmp';
 		}
 	}
 
