@@ -9,7 +9,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.uijsaddressbook.inc.php 1040 2008-05-26 10:27:54Z dave $
+	* @version $Id: class.uijsaddressbook.inc.php 6465 2010-10-10 17:22:31Z sigurdne $
 	* @internal Inherited some code from the addressbook.php file
 	*/
 
@@ -636,7 +636,7 @@
 			//We get it from the category class and ...
 			$this->categoryobject=CreateObject('phpgwapi.categories');
 			$this->categoryobject->app_name = 'addressbook';
-			$this->catlist=ereg_replace( '&nbsp;&lt;' . lang('Global') . '&nbsp;' . lang($this->categoryobject->app_name).'&gt;'
+			$this->catlist=str_replace( '&nbsp;&lt;' . lang('Global') . '&nbsp;' . lang($this->categoryobject->app_name).'&gt;'
 					,'',$this->categoryobject->formated_list('select','all',$this->cat_id,'True'));
 			//			}
 			$this->template->set_var('cats_list',
