@@ -5,7 +5,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage vfs
-	* @version $Id: class.vfs.inc.php 16964 2006-08-16 14:18:45Z skwashd $
+	* @version $Id: class.vfs.inc.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 
 	if ( !isset($GLOBALS['phpgw_info']['server']['file_repository']) 
@@ -17,9 +17,8 @@
 	/**
 	* Include shared vfs class
 	*/
-	include (PHPGW_API_INC . '/class.vfs_shared.inc.php');
+	require_once PHPGW_API_INC . '/class.vfs_shared.inc.php';
 	/**
 	* Include vfs class
 	*/
-	include (PHPGW_API_INC . '/class.vfs_' . $GLOBALS['phpgw_info']['server']['file_repository'] . '.inc.php');
-?>
+	require_once PHPGW_API_INC . "/class.vfs_{$GLOBALS['phpgw_info']['server']['file_repository']}.inc.php";
