@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage vfs
-	* @version $Id: class.vfs_dav.inc.php 2519 2009-03-05 13:32:29Z sigurd $
+	* @version $Id: class.vfs_dav.inc.php 7200 2011-04-08 10:12:03Z sigurdne $
 	*/
 
 	/**
@@ -38,7 +38,7 @@
 	* @package phpgwapi
 	* @subpackage vfs
 	*/
-	class vfs extends vfs_shared
+	class phpgwapi_vfs extends phpgwapi_vfs_shared
 	{
 		/*
 		* That's the history add to the path !
@@ -83,9 +83,9 @@
 		*
 		 */
 
-		function vfs ()
+		function __construct()
 		{
-			$this->vfs_shared();
+			parent::__construct();
 			/*
 			   File/dir attributes, each corresponding to a database field.  Useful for use in loops
 			   If an attribute was added to the table, add it here and possibly add it to
