@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage vfs
-	* @version $Id: class.vfs_shared.inc.php 5187 2010-04-13 08:38:09Z sigurd $
+	* @version $Id: class.vfs_shared.inc.php 7200 2011-04-08 10:12:03Z sigurdne $
 	*/
 
 	/**
@@ -125,7 +125,7 @@
 	* @package phpgwapi
 	* @subpackage vfs
 	*/
-	class vfs_shared
+	class phpgwapi_vfs_shared
 	{
 		/*
 		 * All VFS classes must have some form of 'linked directories'.
@@ -210,10 +210,14 @@
 		 *  * All derived classes should call this function in their
 		 *		constructor ($this->vfs_shared())
 		  */
-		function vfs_shared ()
+		function __construct()
 		{
 			$this->basedir = $GLOBALS['phpgw_info']['server']['files_dir'];
 			$this->working_id = $GLOBALS['phpgw_info']['user']['account_id'];
+			if(empty($this->working_id))
+			{
+				throw new Exception("VFS error! Missing user id!");
+			}
 			$this->working_lid = $GLOBALS['phpgw_info']['user']['account_lid'];
 			$this->now = date ('Y-m-d');
 			/* These are stored in the MIME-type field and should normally 
@@ -581,7 +585,7 @@
 					'nofiles'	=> True
 				)
 			);
-		
+
 			if ($ls_array[0]['mime_type'])
 			{
 				$mime_type = $ls_array[0]['mime_type'];
@@ -591,7 +595,10 @@
 				$mime_type = 'text/plain';
 			}
 		
-			header('Content-type: ' . $mime_type);
+//			header('Content-type: ' . $mime_type);
+			$browser = CreateObject('phpgwapi.browser');
+			$browser->content_header($ls_array[0]['name'],$mime_type,$ls_array[0]['size']);
+
 			echo $this->read (array (
 					'string'	=>  $data['string'],
 					'relatives'	=> $data['relatives']
