@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: functions.inc.php 6048 2010-06-12 15:28:01Z sigurd $
+	* @version $Id: functions.inc.php 7488 2011-08-10 18:26:48Z sigurdne $
 	*/
 
 
@@ -305,7 +305,7 @@ _debug_array($error_line);
 			case E_DEPRECATED:
 			case E_USER_DEPRECATED:
 				$log_args['severity'] = 'DP';
-				$log->deprecated_($log_args);
+				$log->deprecated($log_args);
 				echo '<p class="msg">' . lang('deprecated: %1 in %2 at line %3', $error_msg, $error_file, $error_line) . "</p>\n";
 				echo '<pre>' . phpgw_parse_backtrace($bt) . "</pre>\n";
 				break;
@@ -370,11 +370,11 @@ HTML;
 
 	 /* Load main class */
 	$GLOBALS['phpgw'] = createObject('phpgwapi.phpgw');
-
-	if(get_magic_quotes_runtime())
+	// get_magic_quotes_runtime() is deprecated in php 5.4.0
+	if( version_compare(PHP_VERSION, '5.3.7') <= 0 && get_magic_quotes_runtime())
 	{
-		echo '<center><b>The magic_quotes_runtime has to set to Off in php.ini</b></center>';
-		exit;
+			echo '<center><b>The magic_quotes_runtime has to set to Off in php.ini</b></center>';
+			exit;
 	}
 
 
@@ -397,21 +397,24 @@ HTML;
 	if (isset($_POST['login']))	// on login
 	{
 		$GLOBALS['login'] = $_POST['login'];
-		if (strstr($GLOBALS['login'],'@') === False)
+		if (strstr($GLOBALS['login'],'#') === False)
 		{
-			$GLOBALS['login'] .= '@' . phpgw::get_var('logindomain', 'string', 'POST', $GLOBALS['phpgw_info']['server']['default_domain']);
+			$GLOBALS['login'] .= '#' . phpgw::get_var('logindomain', 'string', 'POST', $GLOBALS['phpgw_info']['server']['default_domain']);
 		}
-		list(,$GLOBALS['phpgw_info']['user']['domain']) = explode('@',$GLOBALS['login']);
+		list(,$GLOBALS['phpgw_info']['user']['domain']) = explode('#',$GLOBALS['login']);
 	}
-	else	// on "normal" pageview
+	else if (phpgw::get_var('domain', 'string', 'REQUEST', false))
 	{
-//		$GLOBALS['phpgw_info']['user']['domain'] = phpgw::get_var('domain', 'string', 'REQUEST', false);
-
+		// on "normal" pageview
 		if(!$GLOBALS['phpgw_info']['user']['domain'] = phpgw::get_var('domain', 'string', 'REQUEST', false))
 		{
 			$GLOBALS['phpgw_info']['user']['domain'] = phpgw::get_var('domain', 'string', 'COOKIE', false);
 		}
 	}
+	else
+	{
+		$GLOBALS['phpgw_info']['user']['domain'] = phpgw::get_var('last_domain', 'string', 'COOKIE', false);
+	}
 
 	if (isset($GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]))
 	{
@@ -454,7 +457,7 @@ HTML;
 	{
 		if(!$GLOBALS['phpgw']->db->query('select count(config_name) from phpgw_config',__LINE__,__FILE__))
 		{
-			$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
+			$setup_dir = str_replace($_SERVER['PHP_SELF'],'index.php','setup/');
 			echo '<center><b>Fatal Error:</b> It appears that you have not created the database tables for '
 			.'phpGroupWare.  Click <a href="' . $setup_dir . '">here</a> to run setup.</center>';
 			exit;
@@ -462,7 +465,7 @@ HTML;
 	}
 	else
 	{
-		$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
+		$setup_dir = str_replace($_SERVER['PHP_SELF'],'index.php','setup/');
 		echo '<center><b>Fatal Error:</b> Unable to connect to database server '
 		.'Click <a href="' . $setup_dir . '">here</a> to run setup.</center>';
 		exit;
@@ -627,7 +630,7 @@ HTML;
 		{
 			if ( isset($_POST['login']) && $_POST['login'] != '')
 			{
-				list($login) = explode("@",$_POST['login']);
+				list($login) = explode("#",$_POST['login']);
 				print_debug('LID',$login,'app');
 				$login_id = $GLOBALS['phpgw']->accounts->name2id($login);
 				print_debug('User ID',$login_id,'app');
@@ -663,6 +666,11 @@ HTML;
 				$cd_array['cd'] = $GLOBALS['phpgw']->session->cd_reason;
 			}
 
+			if(phpgw::get_var('lightbox', 'bool'))
+			{
+//				$cd_array['lightbox'] = true;
+			}
+
 			if(phpgw::get_var('phpgw_return_as', 'string') == 'json')
 			{
 				header('Content-Type: application/json'); 
