@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.sql_mysql.inc.php 17763 2006-12-26 11:37:44Z skwashd $
+	* @version $Id: class.sql_mysql.inc.php 1040 2008-05-26 10:27:54Z dave $
 	* @internal Development of this application was funded by http://www.sogrp.com
 	* @link http://www.sogrp.com/
 	*/
@@ -19,23 +19,18 @@
 	* @package phpgwapi
 	* @subpackage database
 	*/
-	class sql extends sql_
+	class phpgwapi_sql extends phpgwapi_sql_
 	{
-		function sql_()
-		{
-		}
-
-		function concat($elements)
+		public static function concat($elements)
 		{
 			$str =  implode(', ', $elements);
 			return ($str) ? 'concat('.$str.')' : '';
 
 		}
 
-		function concat_null($elements)
+		public static function concat_null($elements)
 		{
-			$str =  implode(', ', sql::safe_null($elements));
+			$str =  implode(', ', self::safe_null($elements));
 			return ($str) ? 'concat('.$str.')' : '';
 		}
 	}
-?>
