@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: create_account.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: create_account.php 1040 2008-05-26 10:27:54Z dave $
 	*/
 	
 	/**
@@ -18,7 +18,7 @@
 	* 
 	*/
 	
- 	include_once('include_login.inc.php');
+ 	require_once 'include_login.inc.php';
  
 	if(!isset($GLOBALS['phpgw_info']['server']['auto_create_acct']) || $GLOBALS['phpgw_info']['server']['auto_create_acct'] != True)
 	{
@@ -166,4 +166,3 @@
 	}
 
 	$uilogin->phpgw_display_login($variables);
-?>
