@@ -8,14 +8,14 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: include_login.inc.php 4616 2010-01-24 17:18:58Z sigurd $
+	* @version $Id: include_login.inc.php 6840 2011-01-25 08:03:38Z sigurdne $
 	*/
-	
+
 	/* 
 	 * Generic include for login.php like pages
 	 */
 	$GLOBALS['phpgw_info'] = array();
-	
+
 	$GLOBALS['phpgw_info']['flags'] = array
 	(
 		'disable_template_class' => true,
@@ -31,6 +31,21 @@
 		exit;
 	}
 
+
+	/**
+	* check for emailaddress as username
+	*/
+	require_once dirname(realpath(__FILE__)) . '/../class.EmailAddressValidator.inc.php';
+
+	$validator = new phpgwapi_EmailAddressValidator();
+	if ( isset($_POST['login']) && $_POST['login'] != '')
+	{
+		if(!$validator->check_email_address($_POST['login']))
+		{
+			$_POST['login'] = str_replace('@', '#', $_POST['login']);
+		}
+	}
+
 	/**
 	* Include phpgroupware header
 	*/
@@ -140,8 +155,8 @@
 					return '&nbsp;';
 			}
 		}
-		
-		
+
+
 		/**
 		* Check languages
 		*/
@@ -158,14 +173,14 @@
 				$GLOBALS['phpgw_info']['server']['lang_ctimes'] = array();
 			}
 			// _debug_array($GLOBALS['phpgw_info']['server']['lang_ctimes']);
-			
+
 			$lang = $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'];
 			$apps = (array)$GLOBALS['phpgw_info']['user']['apps'];
 			$apps['phpgwapi'] = true;	// check the api too
 			foreach ( array_keys($apps) as $app )
 			{
 				$fname = PHPGW_SERVER_ROOT . "/$app/setup/phpgw_$lang.lang";
-				
+
 				if (file_exists($fname))
 				{
 					$ctime = filectime($fname);
@@ -173,7 +188,7 @@
 						isset($GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app]) ? 
 						(int) $GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app] : 0;
 					//echo "checking lang='$lang', app='$app', ctime='$ctime', ltime='$ltime'<br>\n";
-					
+
 					if ($ctime != $ltime)
 					{
 						$this->update_langs();		// update all langs
@@ -198,7 +213,28 @@
 
 		function phpgw_display_login($variables)
 		{
-			
+			// If the lastloginid cookies isn't set, we will default to default_lang - then to english.
+			// Change this if you need.
+
+			$GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] = isset($GLOBALS['phpgw_info']['server']['default_lang']) && $GLOBALS['phpgw_info']['server']['default_lang']? $GLOBALS['phpgw_info']['server']['default_lang'] : 'en';
+			if (isset($_COOKIE['last_loginid']))
+			{
+				$accounts = CreateObject('phpgwapi.accounts');
+				$prefs = CreateObject('phpgwapi.preferences', $accounts->name2id($_COOKIE['last_loginid']));
+
+				if ($prefs->account_id)
+				{
+					$GLOBALS['phpgw_info']['user']['preferences'] = $prefs->read();
+				}
+				#print 'LANG:' . $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] . '<br>';
+				$GLOBALS['phpgw']->translation->set_userlang($GLOBALS['phpgw_info']['user']['preferences']['common']['lang'], $reset = true);
+			}
+
+			if ($selected_lang = phpgw::get_var('lang', 'string', 'GET', ''))
+			{
+				$GLOBALS['phpgw']->translation->set_userlang($selected_lang, $reset = true);
+			}
+
 			$lang = array
 			(
 				'domain'	=> lang('domain'),
@@ -219,9 +255,10 @@
 			{
 				$text = str_repeat('&nbsp;', ($text_len-strlen($text))) . $text;
 			}
-		
+
 			$this->tmpl->set_file(array('login_form'  => 'login.tpl'));
-			$this->tmpl->set_var('charset', lang('charset'));
+
+			$this->tmpl->set_block('login_form', 'message_block', 'message_blocks');
 			$this->tmpl->set_block('login_form', 'domain_option', 'domain_options');
 			$this->tmpl->set_block('login_form', 'domain_select', 'domain_selects');
 			$this->tmpl->set_block('login_form', 'login_additional_info', 'login_additional_infos');
@@ -245,7 +282,7 @@
 			elseif( $GLOBALS['phpgw_info']['server']['show_domain_selectbox'] )
 			{
 				foreach($GLOBALS['phpgw_domain'] as $domain_name => $domain_vars)
-				{	
+				{
 					$this->tmpl->set_var('domain_name', $domain_name);
 
 					if (isset($_COOKIE['last_domain']) && $_COOKIE['last_domain'] == $domain_name)
@@ -275,30 +312,9 @@
 							'domain_from_hosts'	=> ''
 						)
 					);
-				
+
 			}
 
-			if (isset($_COOKIE['last_loginid']))
-			{
-				$accounts = CreateObject('phpgwapi.accounts');
-				$prefs = CreateObject('phpgwapi.preferences', $accounts->name2id($_COOKIE['last_loginid']));
-
-				if (! $prefs->account_id)
-				{
-					$GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] = 'en';
-				}
-				else
-				{
-					$GLOBALS['phpgw_info']['user']['preferences'] = $prefs->read();
-				}
-				#print 'LANG:' . $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] . '<br>';
-			}
-			else
-			{
-				// If the lastloginid cookies isn't set, we will default to english.
-				// Change this if you need.
-				$GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] = 'en';
-			}
 			$GLOBALS['phpgw']->translation->add_app('login');
 			$GLOBALS['phpgw']->translation->add_app('loginscreen');
 			if ( ($login_msg = lang('loginscreen_message') ) != '!loginscreen_message')
@@ -330,7 +346,7 @@
 					unset($_COOKIE['last_domain']);
 				}
 			}
-			
+
 			$last_loginid = isset($_COOKIE['last_loginid']) ? $_COOKIE['last_loginid'] : '';
 			if($GLOBALS['phpgw_info']['server']['show_domain_selectbox'] && $last_loginid !== '')
 			{
@@ -339,7 +355,7 @@
 
 				if ($_COOKIE['last_domain'] != $default_domain && !empty($_COOKIE['last_domain']) && !$GLOBALS['phpgw_info']['server']['show_domain_selectbox'])
 				{
-					$last_loginid .= '@' . $_COOKIE['last_domain'];
+					$last_loginid .= '#' . $_COOKIE['last_domain'];
 				}
 			}
 
@@ -402,17 +418,44 @@
 				$cd = (int) $_GET['cd'];
 			}
 
+			$system_name = isset($GLOBALS['phpgw_info']['server']['system_name']) ? $GLOBALS['phpgw_info']['server']['system_name'] : 'Portico Estate';
 			$this->tmpl->set_var('login_url', $GLOBALS['phpgw_info']['server']['webserver_url'] . '/'.$variables['partial_url'].'?' . http_build_query($extra_vars) );
 			$this->tmpl->set_var('registration_url',$GLOBALS['phpgw_info']['server']['webserver_url'] . '/registration/');
-			$this->tmpl->set_var('system', isset($GLOBALS['phpgw_info']['server']['system_name']) ? $GLOBALS['phpgw_info']['server']['system_name'] : 'phpGroupWare');
+			$this->tmpl->set_var('system', $system_name);
 			$this->tmpl->set_var('version', isset($GLOBALS['phpgw_info']['server']['versions']['system']) ? $GLOBALS['phpgw_info']['server']['versions']['system'] : $GLOBALS['phpgw_info']['server']['versions']['phpgwapi']);
+			$this->tmpl->set_var('instruction', lang('use a valid username and password to gain access to %1', $system_name));
 
 			$this->tmpl->set_var('cd', $this->check_logoutcode($cd) );
 			$this->tmpl->set_var('last_loginid', $last_loginid);
 			if(isset($_REQUEST['skip_remote']) && $_REQUEST['skip_remote'])
 			{
-				$this->tmpl->set_var('skip_remote', true);				
+				$this->tmpl->set_var('skip_remote', true);
 			}
+			if(isset($_REQUEST['lightbox']) && $_REQUEST['lightbox'])
+			{
+				$this->tmpl->set_var('lightbox', true);
+			}
+			if(isset($_REQUEST['hide_lightbox']) && $_REQUEST['hide_lightbox'])
+			{
+				$onload = <<<JS
+					<script language="javascript" type="text/javascript">
+						parent.lightbox_login.hide();
+					</script>
+JS;
+			}
+			else
+			{
+			$onload = <<<JS
+				<script language="javascript" type="text/javascript">
+					window.onload = function()
+					{
+						document.login.login.select();
+						document.login.login.focus();
+					}
+				</script>
+JS;
+			}
+			$this->tmpl->set_var('onload', $onload);
 
 			$this->tmpl->set_var('lang_username', $lang['username']);
 			$this->tmpl->set_var('lang_password', $lang['password']);
@@ -421,7 +464,7 @@
 				$this->tmpl->set_var('lang_login', $variables['lang_login']);
 			}
 
-			$this->tmpl->set_var('lang_testjs', lang('Your browser does not support javascript and/or css, please use a modern standards compliant browser.  If you have disabled either of these features please enable them for this site.') );
+	//		$this->tmpl->set_var('lang_testjs', lang('Your browser does not support javascript and/or css, please use a modern standards compliant browser.  If you have disabled either of these features please enable them for this site.') );
 
 			if(isset($variables['lang_additional_url']) && isset($variables['additional_url']))
 			{
@@ -435,7 +478,7 @@
 								);
 
 			$this->tmpl->set_var('template_set', $GLOBALS['phpgw_info']['login_template_set']);
-			
+
 			if( is_file("{$GLOBALS['phpgw_info']['server']['template_dir']}/css/base.css") )
 			{
 				$base_css = "phpgwapi/templates/{$GLOBALS['phpgw_info']['server']['template_set']}/css/base.css";
@@ -465,6 +508,22 @@
 			}
 			$this->tmpl->set_var('autocomplete', $autocomplete);
 			unset($autocomplete);
+
+			if($cd)
+			{
+				if($cd == 1)
+				{
+					$this->tmpl->set_var('message_class', 'message');
+					$this->tmpl->set_var('message_class_item', 'message message fade');
+				}
+				else
+				{
+					$this->tmpl->set_var('message_class', 'error');
+					$this->tmpl->set_var('message_class_item', 'error message fade');
+				}
+				$this->tmpl->parse('message_blocks', 'message_block');
+			}
+
 			if(!$this->msg_only)
 			{
 				$this->tmpl->parse('loging_blocks', 'loging_block');
