@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: default_records.inc.php 4175 2009-11-22 14:00:45Z sigurd $
+	* @version $Id: default_records.inc.php 6465 2010-10-10 17:22:31Z sigurdne $
 	*/
 
 	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_languages (lang_id, lang_name, available) VALUES ('aa','Afar','No')");
@@ -172,7 +172,16 @@
 	$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_note_type (description) VALUES ('system')");
 
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='email'");
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+//	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+	$comm_type_ids = array();
+	while ($GLOBALS['phpgw_setup']->oProc->next_record())
+	{
+		$comm_type_ids[]=array
+		(
+			'comm_type_id'	=> $GLOBALS['phpgw_setup']->oProc->f('comm_type_id')
+		);
+	}
+
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -187,7 +196,16 @@
 	}
 
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='phone'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+//	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+	$comm_type_ids = array();
+	while ($GLOBALS['phpgw_setup']->oProc->next_record())
+	{
+		$comm_type_ids[]=array
+		(
+			'comm_type_id'	=> $GLOBALS['phpgw_setup']->oProc->f('comm_type_id')
+		);
+	}
+
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -228,7 +246,16 @@
 			.  ")");
 	}
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='fax'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+//	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+	$comm_type_ids = array();
+	while ($GLOBALS['phpgw_setup']->oProc->next_record())
+	{
+		$comm_type_ids[]=array
+		(
+			'comm_type_id'	=> $GLOBALS['phpgw_setup']->oProc->f('comm_type_id')
+		);
+	}
+
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -241,7 +268,16 @@
 			.  ")");
 	}
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='mobile phone'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+//	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+	$comm_type_ids = array();
+	while ($GLOBALS['phpgw_setup']->oProc->next_record())
+	{
+		$comm_type_ids[]=array
+		(
+			'comm_type_id'	=> $GLOBALS['phpgw_setup']->oProc->f('comm_type_id')
+		);
+	}
+
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -254,7 +290,16 @@
 			.  ")");
 	}
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='instant messaging'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+//	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+	$comm_type_ids = array();
+	while ($GLOBALS['phpgw_setup']->oProc->next_record())
+	{
+		$comm_type_ids[]=array
+		(
+			'comm_type_id'	=> $GLOBALS['phpgw_setup']->oProc->f('comm_type_id')
+		);
+	}
+
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
@@ -279,7 +324,16 @@
 			.  ")");				
 	}
 	$GLOBALS['phpgw_setup']->oProc->query("SELECT comm_type_id FROM phpgw_contact_comm_type WHERE type='url'"); 
-	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+//	$comm_type_ids = $GLOBALS['phpgw_setup']->oProc->m_odb->resultSet;
+	$comm_type_ids = array();
+	while ($GLOBALS['phpgw_setup']->oProc->next_record())
+	{
+		$comm_type_ids[]=array
+		(
+			'comm_type_id'	=> $GLOBALS['phpgw_setup']->oProc->f('comm_type_id')
+		);
+	}
+
 	for($i = 0; $i < count($comm_type_ids); $i++)
 	{
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_contact_comm_descr (comm_type_id,descr) VALUES (" 
