@@ -5,14 +5,14 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: setup.inc.php 6221 2010-08-10 12:37:16Z sigurd $
+	* @version $Id: setup.inc.php 7197 2011-04-07 12:17:22Z sigurdne $
 	* @internal $Source$
 	*/
 
 	// Basic information about this app
 	$setup_info['phpgwapi']['name']      = 'phpgwapi';
 	$setup_info['phpgwapi']['title']     = 'phpgwapi';
-	$setup_info['phpgwapi']['version']   = '0.9.17.531';
+	$setup_info['phpgwapi']['version']   = '0.9.17.534';
 	$setup_info['phpgwapi']['versions']['current_header'] = '1.31';
 	$setup_info['phpgwapi']['versions']['system'] = '1.0';
 	$setup_info['phpgwapi']['enable']    = 3;
@@ -71,10 +71,10 @@
 
 	$setup_info['phpgwapi']['hooks'] = array
 	(
-		'menu'  => 'phpgwapi.menu_apps.get_menu'
+		'menu'	=> 'phpgwapi.menu_apps.get_menu',
+		'login'	=> 'phpgwapi.menu.clear'
 	);
 
-
 	// Basic information about this app
 	$setup_info['notifywindow']['name']			= 'notifywindow';
 	$setup_info['notifywindow']['title']		= 'Notify Window';
