@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: tables_current.inc.php 6221 2010-08-10 12:37:16Z sigurd $
+	* @version $Id: tables_current.inc.php 7349 2011-06-06 09:23:43Z sigurdne $
 	* @internal $Source$
 	*/
 
@@ -42,6 +42,8 @@
 				'acl_grantor' => array('type' => 'int', 'precision' => 4, 'nullable' => true, 'default' => '-1'),
 				'acl_type' => array('type' => 'int', 'precision' => 2, 'nullable' => true, 'default' => '0'),
 				'location_id' => array('type' => 'int', 'precision' => 4),
+				'modified_on' => array('type' => 'int','precision' => 4,'nullable' => False),
+				'modified_by' => array('type' => 'int','precision' => 4,'nullable' => False, 'default' => '-1')
 			),
 			'pk' => array(),
 			'ix' => array('location_id','acl_account'),
@@ -86,7 +88,7 @@
 			'pk' => array('delegate_id'),
 			'fk' => array(),
 			'ix' => array(),
-			'uc' => array('account_id','owner_id','location_id','data')
+			'uc' => array()//array('account_id','owner_id','location_id','data') //FIXME - MySQL needs a length on the data-field
 		),
 		'phpgw_preferences' => array(
 			'fd' => array(
@@ -274,7 +276,7 @@
 				'owner_id' => array('type' => 'int','precision' => 4,'nullable' => False),
 				'createdby_id' => array('type' => 'int','precision' => 4,'nullable' => True),
 				'modifiedby_id' => array('type' => 'int','precision' => 4,'nullable' => True),
-				'created' => array('type' => 'date','nullable' => False,'default' => '1970-01-01'),
+				'created' => array('type' => 'date','nullable' => False,'default' => 'current_date'),
 				'modified' => array('type' => 'date','nullable' => True),
 				'size' => array('type' => 'int','precision' => 4,'nullable' => True),
 				'mime_type' => array('type' => 'varchar','precision' => '150','nullable' => True),
@@ -691,6 +693,6 @@
 			'pk' => array('section_id','attrib_id','id'),
 			'fk' => array(),
 			'ix' => array(),
-			'uc' => array('section_id','attrib_id','value')
+			'uc' => array()
 		)
 	);
