@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: navbar.inc.php 2098 2009-01-13 19:14:04Z sigurd $
+	* @version $Id: navbar.inc.php 6465 2010-10-10 17:22:31Z sigurdne $
 	*/
 
 
@@ -45,6 +45,10 @@
 HTML;
 		}
 
+		$app = $GLOBALS['phpgw_info']['flags']['currentapp'];
+		$menu_array = execMethod('phpgwapi.menu.get_local_menu', $app);
+		$var['app_menu'] = phpgwapi_menu::render_horisontal_menu($menu_array);
+
 		$var['applications'] = $applications;
 		$var['logo'] = 'logo.png';
 
