@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package preferences
 	* @subpackage acl
- 	* @version $Id: class.uiadmin_acl.inc.php 17471 2006-10-23 08:41:37Z sigurdne $
+ 	* @version $Id: class.uiadmin_acl.inc.php 1322 2008-06-30 07:15:35Z sigurd $
 	*/
 
 	/**
@@ -61,8 +61,7 @@
 			$this->granting_group	= $this->bo->granting_group;
 			$this->allrows			= $this->bo->allrows;
 
-			// Add top location if used for first time
-			$GLOBALS['phpgw']->acl->verify_location(array($this->acl_app => array('top_grant' =>True)));
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = "admin::{$this->acl_app}::acl";
 		}
 
 		function save_sessiondata()
@@ -267,11 +266,13 @@
 				'select_group_name'				=> 'granting_group',
 				'lang_no_group'					=> lang('No granting group'),
 				'group_list'					=> $this->bo->get_group_list('filter',$this->granting_group,$start=-1,$sort='ASC',$order='account_firstname',$query='',$offset=-1),
+				'lang_enable_inheritance'       => lang('enable inheritance'), 
+                'lang_enable_inheritance_statustext'        => lang('rights are inherited down the hierarchy')
 			);
 
 			$appname			= lang('preferences');
 			$function_msg		= lang('set grants');
-			$owner_name 		= $GLOBALS['phpgw']->accounts->id2name($GLOBALS['phpgw']->accounts->account_id);		// get owner name for title
+			$owner_name 		= $GLOBALS['phpgw']->accounts->id2name($this->account);		// get owner name for title
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('admin') . ' - ' . $this->acl_app . ': ' . $function_msg . ': ' . $owner_name;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list_permission' => $data));
@@ -507,7 +508,9 @@
 				'lang_no_location'				=> lang('No location'),
 				'lang_location_statustext'		=> lang('Select submodule'),
 				'select_name_location'			=> 'module',
-				'location_list'					=> $this->bo->select_location('filter',$this->location,False)
+				'location_list'					=> $this->bo->select_location('filter',$this->location,False),
+				'lang_enable_inheritance'       => lang('enable inheritance'), 
+                'lang_enable_inheritance_statustext'        => lang('rights are inherited down the hierarchy')
 			);
 
 			$appname		= lang('permission');
