@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.boagreement.inc.php 4807 2010-02-12 09:46:39Z sigurd $
+ 	* @version $Id: class.boagreement.inc.php 7495 2011-08-11 12:01:59Z sigurdne $
 	*/
 
 	/**
@@ -44,18 +44,18 @@
 		var $member_id;
 
 		/**
-		* @var object $custom reference to custom fields object
-		*/
+		 * @var object $custom reference to custom fields object
+		 */
 		protected $custom;
 
 		var $public_functions = array
-		(
-			'read'				=> true,
-			'read_single'		=> true,
-			'save'				=> true,
-			'delete'			=> true,
-			'check_perms'		=> true
-		);
+			(
+				'read'				=> true,
+				'read_single'		=> true,
+				'save'				=> true,
+				'delete'			=> true,
+				'check_perms'		=> true
+			);
 
 		function property_boagreement($session=false)
 		{
@@ -69,62 +69,39 @@
 				$this->use_session = true;
 			}
 
-			$start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
-			$query	= phpgw::get_var('query');
-			$sort	= phpgw::get_var('sort');
-			$order	= phpgw::get_var('order');
-			$filter	= phpgw::get_var('filter', 'int');
-			$cat_id	= phpgw::get_var('cat_id', 'int');
+			$start		= phpgw::get_var('start', 'int', 'REQUEST', 0);
+			$query		= phpgw::get_var('query');
+			$sort		= phpgw::get_var('sort');
+			$order		= phpgw::get_var('order');
+			$filter		= phpgw::get_var('filter', 'int');
+			$cat_id		= phpgw::get_var('cat_id', 'int');
 			$vendor_id	= phpgw::get_var('vendor_id', 'int');
 			$allrows	= phpgw::get_var('allrows', 'bool');
-			$role	= phpgw::get_var('role');
+			$role		= phpgw::get_var('role');
 			$member_id	= phpgw::get_var('member_id', 'int');
-
+			$status_id	= phpgw::get_var('status_id');
 
 			$this->role	= $role;
 			$this->so->role	= $role;
 
-			if ($start)
-			{
-				$this->start=$start;
-			}
-			else
-			{
-				$this->start=0;
-			}
+			$this->status_id		= isset($_REQUEST['status_id'])	? $status_id	: $this->status_id;
+			$this->start			= isset($_REQUEST['start']) 	? $start		: $this->start;
+			$this->order			= isset($_REQUEST['order']) 	? $order		: $this->order;
+			$this->sort				= isset($_REQUEST['sort']) 		? $sort			: $this->sort;
+			$this->query			= isset($_REQUEST['query']) 	? $query		: $this->query;
+			$this->vendor_id		= isset($_REQUEST['vendor_id'])	? $vendor_id	: $this->vendor_id;
+			$this->member_id		= isset($_REQUEST['member_id']) ? $member_id	: $this->member_id;
+			$this->cat_id			= isset($_REQUEST['cat_id']) 	? $cat_id		: $this->cat_id;
 
-			if(isset($query))
-			{
-				$this->query = $query;
-			}
 			if(!empty($filter))
 			{
 				$this->filter = $filter;
 			}
-			if(isset($sort))
-			{
-				$this->sort = $sort;
-			}
 
-			$this->order	= isset($order) && $order ? $order : '';
-
-			if(isset($cat_id))
-			{
-				$this->cat_id = $cat_id;
-			}
-
-			if(isset($allrows))
+			if($allrows)
 			{
 				$this->allrows = $allrows;
 			}
-			if(isset($member_id))
-			{
-				$this->member_id = $member_id;
-			}
-			if(isset($vendor_id))
-			{
-				$this->vendor_id = $vendor_id;
-			}
 		}
 
 		function save_sessiondata($data)
@@ -139,7 +116,7 @@
 		{
 			$data = $GLOBALS['phpgw']->session->appsession('session_data','agreement');
 
-			//_debug_array($data);
+//			_debug_array($data);die();
 
 			$this->start	= $data['start'];
 			$this->query	= $data['query'];
@@ -149,7 +126,7 @@
 			$this->cat_id	= $data['cat_id'];
 			$this->vendor_id= $data['vendor_id'];
 			$this->member_id= $data['member_id'];
-			$this->allrows	= $data['allrows'];
+			$this->status_id= $data['status_id'];
 		}
 
 		function check_perms($has, $needed)
@@ -161,12 +138,12 @@
 		{
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('select_vendor'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('filter_vendor'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('select_vendor'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('filter_vendor'));
+				break;
 			}
 
 			$input_list= $this->so->select_vendor_list();
@@ -177,35 +154,37 @@
 
 		function read()
 		{
-			$agreement = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
-											'vendor_id'=>$this->vendor_id));
+			$agreements = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
+				'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
+				'vendor_id'=>$this->vendor_id, 'status_id'=>$this->status_id));
 			$this->total_records = $this->so->total_records;
 
 			$this->uicols	= $this->so->uicols;
 
-			for ($i=0; $i<count($agreement); $i++)
+			foreach ($agreements as &$agreement)
 			{
-				if($agreement[$i]['start_date'])
+				if($agreement['start_date'])
 				{
-					$agreement[$i]['start_date']  = $GLOBALS['phpgw']->common->show_date($agreement[$i]['start_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
+					$agreement['start_date']  = $GLOBALS['phpgw']->common->show_date($agreement['start_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 				}
-				if($agreement[$i]['end_date'])
+				if($agreement['termination_date'])
 				{
-					$agreement[$i]['end_date']  = $GLOBALS['phpgw']->common->show_date($agreement[$i]['end_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
+					$agreement['termination_date']  = $GLOBALS['phpgw']->common->show_date($agreement['termination_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 				}
 
-				$agreement[$i]['status']  = lang($agreement[$i]['status']);
-
+				if($agreement['end_date'])
+				{
+					$agreement['end_date']  = $GLOBALS['phpgw']->common->show_date($agreement['end_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
+				}
 			}
-			return $agreement;
+			return $agreements;
 		}
 
 		function read_details($id)
 		{
 			$list = $this->so->read_details(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
-											'agreement_id'=>$id));
+				'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
+				'agreement_id'=>$id));
 			$this->total_records = $this->so->total_records;
 
 			$this->uicols	= $this->so->uicols;
@@ -265,8 +244,8 @@
 			$vfs->override_acl = 1;
 
 			$values['files'] = $vfs->ls (array(
-			     'string' => "/property/agreement/{$data['agreement_id']}",
-			     'relatives' => array(RELATIVE_NONE)));
+				'string' => "/property/agreement/{$data['agreement_id']}",
+				'relatives' => array(RELATIVE_NONE)));
 
 			$vfs->override_acl = 0;
 
@@ -290,13 +269,13 @@
 		}
 
 		/**
-		* Arrange attributes within groups
-		*
-		* @param string  $location    the name of the location of the attribute
-		* @param array   $attributes  the array of the attributes to be grouped
-		*
-		* @return array the grouped attributes
-		*/
+		 * Arrange attributes within groups
+		 *
+		 * @param string  $location    the name of the location of the attribute
+		 * @param array   $attributes  the array of the attributes to be grouped
+		 *
+		 * @return array the grouped attributes
+		 */
 
 		public function get_attribute_groups($location, $attributes = array())
 		{
@@ -315,7 +294,7 @@
 			}
 
 			if ($action=='edit')
-//			if ($values['agreement_id'])
+				//			if ($values['agreement_id'])
 			{
 				if ($values['agreement_id'] != 0)
 				{
@@ -331,7 +310,7 @@
 
 		function save_item($values,$values_attribute='')
 		{
-//_debug_array($values);
+			//_debug_array($values);
 			$values['m_cost']	= str_replace(",",".",$values['m_cost']);
 			$values['w_cost']	= str_replace(",",".",$values['w_cost']);
 			$values['total_cost']		= $values['m_cost'] + $values['w_cost'];
@@ -390,7 +369,7 @@
 
 		function request_next_id()
 		{
-				return $this->so->request_next_id();
+			return $this->so->request_next_id();
 		}
 
 		function get_agreement_group_list($selected='')
@@ -415,12 +394,12 @@
 		{
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('status_select'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('status_filter'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('status_select'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('status_filter'));
+				break;
 			}
 
 			$status_entries= $this->so->select_status_list();
@@ -433,4 +412,3 @@
 			return $this->so->get_activity_descr($id);
 		}
 	}
-
