@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.boevent.inc.php 5125 2010-04-05 19:02:16Z sigurd $
+ 	* @version $Id: class.boevent.inc.php 6718 2011-01-03 09:29:44Z sigurdne $
 	*/
 
 	/*
@@ -32,27 +32,27 @@
 	 */
 	phpgw::import_class('phpgwapi.datetime');
 
-if ( !extension_loaded('mcal') )
-{
-	define('MCAL_RECUR_NONE',0);
-	define('MCAL_RECUR_DAILY',1);
-	define('MCAL_RECUR_WEEKLY',2);
-	define('MCAL_RECUR_MONTHLY_MDAY',3);
-	define('MCAL_RECUR_MONTHLY_WDAY',4);
-	define('MCAL_RECUR_YEARLY',5);
+	if ( !extension_loaded('mcal') )
+	{
+		define('MCAL_RECUR_NONE',0);
+		define('MCAL_RECUR_DAILY',1);
+		define('MCAL_RECUR_WEEKLY',2);
+		define('MCAL_RECUR_MONTHLY_MDAY',3);
+		define('MCAL_RECUR_MONTHLY_WDAY',4);
+		define('MCAL_RECUR_YEARLY',5);
 	
-	define('MCAL_M_SUNDAY',1);
-	define('MCAL_M_MONDAY',2);
-	define('MCAL_M_TUESDAY',4);
-	define('MCAL_M_WEDNESDAY',8);
-	define('MCAL_M_THURSDAY',16);
-	define('MCAL_M_FRIDAY',32);
-	define('MCAL_M_SATURDAY',64);
+		define('MCAL_M_SUNDAY',1);
+		define('MCAL_M_MONDAY',2);
+		define('MCAL_M_TUESDAY',4);
+		define('MCAL_M_WEDNESDAY',8);
+		define('MCAL_M_THURSDAY',16);
+		define('MCAL_M_FRIDAY',32);
+		define('MCAL_M_SATURDAY',64);
 	
-	define('MCAL_M_WEEKDAYS',62);
-	define('MCAL_M_WEEKEND',65);
-	define('MCAL_M_ALLDAYS',127);
-}
+		define('MCAL_M_WEEKDAYS',62);
+		define('MCAL_M_WEEKEND',65);
+		define('MCAL_M_ALLDAYS',127);
+	}
 
 	/**
 	 * Description
@@ -70,22 +70,21 @@ if ( !extension_loaded('mcal') )
 		var $location_info = array();
 		var $cached_events;
 		protected $event_functions = array
-		(
-			'send_sms'	=> 'send SMS'
-		);
+			(
+				'send_sms'	=> 'send SMS'
+			);
 
 		var $public_functions = array
-		(
-			'event_schedule_data'		=> true,
-			'event_schedule_week_data'	=> true
-		);
+			(
+				'event_schedule_data'		=> true,
+				'event_schedule_week_data'	=> true
+			);
+
 
-	
 		function __construct($session=false)
 		{
 			$this->so 			= CreateObject('property.soevent');
 			$this->custom 		= CreateObject('property.custom_fields');//& $this->so->custom;
-	//		$this->bocommon 	= CreateObject('property.bocommon');
 			$this->sbox 		= CreateObject('phpgwapi.sbox');
 			$this->asyncservice = CreateObject('phpgwapi.asyncservice');
 
@@ -130,7 +129,7 @@ if ( !extension_loaded('mcal') )
 		{
 			$data = $GLOBALS['phpgw']->session->appsession('session_data','category');
 
-	//		_debug_array($data);
+			//		_debug_array($data);
 
 			$this->start		= $data['start'];
 			$this->query		= $data['query'];
@@ -146,7 +145,7 @@ if ( !extension_loaded('mcal') )
 		public function read($dry_run='')
 		{
 			$values = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'allrows'=>$this->allrows, 'location_id' => $this->location_id, 'user_id' => $this->user_id, 'dry_run'=>$dry_run));
+				'allrows'=>$this->allrows, 'location_id' => $this->location_id, 'user_id' => $this->user_id, 'dry_run'=>$dry_run));
 
 			static $locations = array();
 			static $urls = array();
@@ -159,7 +158,7 @@ if ( !extension_loaded('mcal') )
 
 				if($locations[$entry['location_id']])
 				{
-					 $location = $locations[$entry['location_id']];
+					$location = $locations[$entry['location_id']];
 				}
 				else
 				{
@@ -198,15 +197,15 @@ if ( !extension_loaded('mcal') )
 				if($values['rpt_day'])
 				{
 					$rpt_day = array
-					(
-						1		=> 'Sunday',
-						2		=> 'Monday',
-						4		=> 'Tuesday',
-						8		=> 'Wednesday',
-						16		=> 'Thursday',
-						32		=> 'Friday',
-						64		=> 'Saturday'
-					);
+						(
+							1		=> 'Sunday',
+							2		=> 'Monday',
+							4		=> 'Tuesday',
+							8		=> 'Wednesday',
+							16		=> 'Thursday',
+							32		=> 'Friday',
+							64		=> 'Saturday'
+						);
 
 					foreach ($rpt_day as $mask => $name)
 					{
@@ -224,7 +223,7 @@ if ( !extension_loaded('mcal') )
 				$values['next'] = $GLOBALS['phpgw']->common->show_date($job[$job_id]['next'],$dateformat);
 			}
 
-	//		$this->find_scedules($criteria);
+//			$this->find_scedules($criteria);
 
 			return $values;
 		}
@@ -248,20 +247,20 @@ if ( !extension_loaded('mcal') )
 				$receipt = $this->so->add($data);
 			}
 
-			$action_object		= CreateObject('property.socategory');
+			$action_object		= CreateObject('property.sogeneric');
 			$action_object->get_location_info('event_action',false);
 			$action	= $action_object->read_single(array('id'=> $data['action']),$values = array());
 
 			$rpt_day = array
-			(
-				1		=> 0, //'Sunday',
-				2		=> 1, //'Monday',
-				4		=> 2, //'Tuesday',
-				8		=> 3, //'Wednesday',
-				16		=> 4, //'Thursday',
-				32		=> 5, //'Friday',
-				64		=> 6  //'Saturday'
-			);
+				(
+					1		=> 0, //'Sunday',
+					2		=> 1, //'Monday',
+					4		=> 2, //'Tuesday',
+					8		=> 3, //'Wednesday',
+					16		=> 4, //'Thursday',
+					32		=> 5, //'Friday',
+					64		=> 6  //'Saturday'
+				);
 
 			$repeat_day = array();
 			if ($data['repeat_day'])
@@ -285,73 +284,73 @@ if ( !extension_loaded('mcal') )
 				$dow = $rpt_day[$data['repeat_day'][0]];
 				switch($data['repeat_type'])
 				{
-					case '0':
-						$times = $data['start_date'];
-						break;
-					case '1': //'Daily'
-						if($data['repeat_interval'])
-						{
-							$times = array('day' => "*/{$data['repeat_interval']}");
-						}
-						else
-						{
-							$times = array('day' => "*/1");
-						}
-						break;
-					case '2': //'Weekly'
-						if($data['repeat_interval'])
-						{
-							$day = $data['repeat_interval'] * 7;
-							$times = array('day' => "*/{$day}");
-						}
-						else
-						{
-							$times = array('day' => "*/7");
-						}
-						if ($data['repeat_day'])
-						{
-							$times['dow'] = $repeat_day;
-						}
-						break;
-					case '3': //'Monthly (by day)'
-						if( !isset($data['repeat_day']) || !is_array($data['repeat_day']) )
-						{
-							$dow = 1;
-						}
-						
-						if($data['repeat_interval'])
-						{
-							$times = array('month' => "*/{$data['repeat_interval']}", 'dow' => $dow);
-						}
-						else
-						{
-							$times = array('month' => "*/1", 'dow' => $dow);
-						}
-						break;
-					case '4': //'Monthly (by date)'
-						if($data['repeat_interval'])
-						{
-							$times = array('month' => "*/{$data['repeat_interval']}", 'day' => 1);
-						}
-						else
-						{
-							$times = array('day' => 1);
-						}
-						break;
-					case '5': //'Yearly'
-						$month = date(n, $data['start_date']);
-						if($data['repeat_interval'])
-						{
-							$times = array('year' => "*/{$data['repeat_interval']}", 'month' => $month);
-						}
-						else
-						{
-							$times = array('month' => $month);
-						}
-						break;
-					default:
-						$times = $data['start_date'];
-						break;
+				case '0':
+					$times = $data['start_date'];
+					break;
+				case '1': //'Daily'
+					if($data['repeat_interval'])
+					{
+						$times = array('day' => "*/{$data['repeat_interval']}");
+					}
+					else
+					{
+						$times = array('day' => "*/1");
+					}
+					break;
+				case '2': //'Weekly'
+					if($data['repeat_interval'])
+					{
+						$day = $data['repeat_interval'] * 7;
+						$times = array('day' => "*/{$day}");
+					}
+					else
+					{
+						$times = array('day' => "*/7");
+					}
+					if ($data['repeat_day'])
+					{
+						$times['dow'] = $repeat_day;
+					}
+					break;
+				case '3': //'Monthly (by day)'
+					if( !isset($data['repeat_day']) || !is_array($data['repeat_day']) )
+					{
+						$dow = 1;
+					}
+
+					if($data['repeat_interval'])
+					{
+						$times = array('month' => "*/{$data['repeat_interval']}", 'dow' => $dow);
+					}
+					else
+					{
+						$times = array('month' => "*/1", 'dow' => $dow);
+					}
+					break;
+				case '4': //'Monthly (by date)'
+					if($data['repeat_interval'])
+					{
+						$times = array('month' => "*/{$data['repeat_interval']}", 'day' => 1);
+					}
+					else
+					{
+						$times = array('day' => 1);
+					}
+					break;
+				case '5': //'Yearly'
+					$month = date(n, $data['start_date']);
+					if($data['repeat_interval'])
+					{
+						$times = array('year' => "*/{$data['repeat_interval']}", 'month' => $month);
+					}
+					else
+					{
+						$times = array('month' => $month);
+					}
+					break;
+				default:
+					$times = $data['start_date'];
+					break;
 				}
 			}
 
@@ -360,14 +359,14 @@ if ( !extension_loaded('mcal') )
 			$account_id = execMethod('property.soresponsible.get_responsible_user_id', $data['responsible']);
 
 			$timer_data = array
-			(
-				'start'		=> $data['start_date'],
-				'enabled'	=> true,
-				'owner'		=> $account_id,
-				'enabled'	=> !! $data['enabled'],
-				'action'	=> $action['action']
-			);
-				
+				(
+					'start'		=> $data['start_date'],
+					'enabled'	=> true,
+					'owner'		=> $account_id,
+					'enabled'	=> !! $data['enabled'],
+					'action'	=> $action['action']
+				);
+
 			if($data['end_date'])
 			{
 				$timer_data['end'] = $data['end_date'];
@@ -388,24 +387,19 @@ if ( !extension_loaded('mcal') )
 			$this->asyncservice->cancel_timer($id);
 			$this->asyncservice->set_timer($times, $id, 'property.boevent.action', $timer_data, $account_id);
 
-
-
-//
-
 			$event = $this->so->read_single($receipt['id']);
 
 			$criteria = array
-			(
-				'start_date'		=> $event['start_date'],
-				'end_date'			=> $event['end_date'],
-				'location_id'		=> $event['location_id'],
-				'location_item_id'	=> $event['location_item_id']
-			);
+				(
+					'start_date'		=> $event['start_date'],
+					'end_date'			=> $event['end_date'],
+					'location_id'		=> $event['location_id'],
+					'location_item_id'	=> $event['location_item_id']
+				);
 
 			$this->find_scedules($criteria);
 			$schedule =  $this->cached_events;
 			$this->so->create_schedule(array('event_id' => $receipt['id'], 'schedule' => $schedule));
-//
 
 			return $receipt;
 		}
@@ -450,14 +444,14 @@ if ( !extension_loaded('mcal') )
 		public function get_rpt_type_list($selected='')
 		{
 			$rpt_type = array
-			(
-				0	=> 'None',
-				1	=> 'Daily',
-				2	=> 'Weekly',
-				3	=> 'Monthly (by date)',
-				4	=> 'Monthly (by day)',
-				5	=> 'Yearly'
-			);
+				(
+					0	=> 'None',
+					1	=> 'Daily',
+					2	=> 'Weekly',
+					3	=> 'Monthly (by date)',
+					4	=> 'Monthly (by day)',
+					5	=> 'Yearly'
+				);
 
 
 			return $this->sbox->getArrayItem('values[repeat_type]', $selected, $rpt_type);
@@ -466,15 +460,15 @@ if ( !extension_loaded('mcal') )
 		public function get_rpt_day_list($selected=array())
 		{
 			$rpt_day = array
-			(
-				1		=> 'Sunday',
-				2		=> 'Monday',
-				4		=> 'Tuesday',
-				8		=> 'Wednesday',
-				16		=> 'Thursday',
-				32		=> 'Friday',
-				64		=> 'Saturday'
-			);
+				(
+					1		=> 'Sunday',
+					2		=> 'Monday',
+					4		=> 'Tuesday',
+					8		=> 'Wednesday',
+					16		=> 'Thursday',
+					32		=> 'Friday',
+					64		=> 'Saturday'
+				);
 
 			$title = lang('(for weekly)');
 			$i = 0; $boxes = '';
@@ -489,11 +483,11 @@ if ( !extension_loaded('mcal') )
 		public function get_responsible($selected = '')
 		{
 			$responsible = CreateObject('property.soresponsible');
-			
+
 			$location = phpgw::get_var('location');
 			$values = $responsible->read_type(array('start' => 0, 'query' =>'', 'sort' => '',
-												'order' => '', 'location' => $location, 'allrows'=>true,
-												'filter' => ''));
+				'order' => '', 'location' => $location, 'allrows'=>true,
+				'filter' => ''));
 
 			$list = array(0 => lang('none'));
 			foreach($values as $entry)
@@ -506,39 +500,39 @@ if ( !extension_loaded('mcal') )
 
 		public function get_action($selected = '')
 		{
-/*			$action_object					= CreateObject('property.socategory');
+/*			$action_object					= CreateObject('property.sogeneric');
 			$action_object->get_location_info('event_action',false);
 			$values					= $action_object->read(array('allrows'=> true));
-*/
+ */
 			$list = array(0 => lang('none'));
 /*
 			foreach($values as $entry)
 			{
 				$list[$entry['id']] = $entry['name'];
 			}
-*/
+ */
 			$list = array_merge($list,$this->event_functions);
 
 			return $this->sbox->getArrayItem('values[action]', $selected, $list, true);
 		}
-		
+
 		protected function send_sms()
 		{
 			$data = array
-			(
-				'p_num_text'	=> 'xxxxxxxx',//number
-				'message'		=> 'dette er en melding'
-			);
+				(
+					'p_num_text'	=> 'xxxxxxxx',//number
+					'message'		=> 'dette er en melding'
+				);
 
 			execMethod('sms.bosms.send_sms', $data);
 		}
 
 		/**
-		* Find recurring events
-		*
-		* @param array $date the date array to convert, must contain keys 'start_date', 'end_date', 'appname', 'location'
-		* @return array events
-		*/
+		 * Find recurring events
+		 *
+		 * @param array $date the date array to convert, must contain keys 'start_date', 'end_date', 'appname', 'location'
+		 * @return array events
+		 */
 
 		function find_scedules($params)
 		{			
@@ -562,7 +556,7 @@ if ( !extension_loaded('mcal') )
 
 			if(!isset($params['location_item_id']) || !$params['location_item_id'])
 			{
-					throw new Exception("property_boevent::find_scedules - Missing location_item_id in input");
+				throw new Exception("property_boevent::find_scedules - Missing location_item_id in input");
 			}
 			$location_item_id = $params['location_item_id'];
 
@@ -587,7 +581,7 @@ if ( !extension_loaded('mcal') )
 					echo '<!-- owner_id in ('.implode($owner_id,',').') -->'."\n";
 				}
 			}
-			
+
 			if(!$eyear && !$emonth && !$eday)
 			{
 				$edate = mktime(23,59,59,$smonth + 1,$sday + 1,$syear);
@@ -616,7 +610,7 @@ if ( !extension_loaded('mcal') )
 				}
 				$edate = mktime(23,59,59,$emonth,$eday,$eyear);
 			}
-			
+
 			if($this->debug)
 			{
 				echo '<!-- Start Date : '.sprintf("%04d%02d%02d",$syear,$smonth,$sday).' -->'."\n";
@@ -624,23 +618,23 @@ if ( !extension_loaded('mcal') )
 			}
 
 			$find_criteria = array
-			(
-				'syear'				=> $syear,
-				'smonth'			=> $smonth,
-				'sday'				=> $sday,
-				'eyear'				=> $eyear,
-				'emonth'			=> $emonth,
-				'eday'				=> $eday,
-				'tz_offset'			=> 0,
-				'extra'				=> '',
-				'owner_id'			=> $owner_id,
-				'location_id'		=> $location_id,
-				'location_item_id'	=> $location_item_id
-			);
+				(
+					'syear'				=> $syear,
+					'smonth'			=> $smonth,
+					'sday'				=> $sday,
+					'eyear'				=> $eyear,
+					'emonth'			=> $emonth,
+					'eday'				=> $eday,
+					'tz_offset'			=> 0,
+					'extra'				=> '',
+					'owner_id'			=> $owner_id,
+					'location_id'		=> $location_id,
+					'location_item_id'	=> $location_item_id
+				);
 
 			$cached_event_ids			= $this->so->list_events($find_criteria);
 			$cached_event_ids_repeating	= $this->so->list_repeated_events($find_criteria);
-//_debug_array($cached_event_ids_repeating);die();
+			//_debug_array($cached_event_ids_repeating);die();
 			unset($find_criteria);
 
 			if($this->debug)
@@ -650,7 +644,7 @@ if ( !extension_loaded('mcal') )
 			}
 
 			$this->cached_events = array();
-			
+
 			if(!$cached_event_ids && !$cached_event_ids_repeating)
 			{
 				return;
@@ -696,7 +690,7 @@ if ( !extension_loaded('mcal') )
 			$this->repeating_events = array();
 			if($cached_event_ids_repeating)
 			{
-//_debug_array($cached_event_ids_repeating);die();
+				//_debug_array($cached_event_ids_repeating);die();
 				$i = 0;
 				foreach($cached_event_ids_repeating as $cached_event_id)
 				{
@@ -736,7 +730,7 @@ if ( !extension_loaded('mcal') )
 					$retval[$j] = $this->cached_events[$j];
 				}
 			}
-//_debug_array($this->cached_events);die();
+			//_debug_array($this->cached_events);die();
 			return $retval;
 //			return $this->cached_events;
 		}
@@ -789,7 +783,7 @@ if ( !extension_loaded('mcal') )
 					{
 						$event_recur_time = mktime(0,0,0,1,1,2030);
 					}
-*/
+ */
 					$end_recur_date = date('Ymd',$event_recur_time);
 					$full_event_date = date('Ymd',$event_beg_day);
 
@@ -816,110 +810,110 @@ if ( !extension_loaded('mcal') )
 						$type = $rep_events['repeat_type'];
 						switch($type)
 						{
-							case MCAL_RECUR_DAILY:
-								if($this->debug)
-								{
-									echo '<!-- check_repeating_events - MCAL_RECUR_DAILY - '.$id.' -->'."\n";
-								}
-//								if ($freq == 1 && $rep_events['recur_enddate']['month'] != 0 && $rep_events['recur_enddate']['mday'] != 0 && $rep_events['recur_enddate']['year'] != 0 && $search_date_full <= $end_recur_date)
-								if ($freq == 1 && $rep_events['end_date'] && $search_date_full <= $end_recur_date)
-								{
-									$this->sort_event($rep_events,$search_date_full);
-								}
-								elseif (floor(($search_beg_day - $event_beg_day)/86400) % $freq)
-								{
-									continue;
-								}
-								else
-								{
-									$this->sort_event($rep_events,$search_date_full);
-								}
+						case MCAL_RECUR_DAILY:
+							if($this->debug)
+							{
+								echo '<!-- check_repeating_events - MCAL_RECUR_DAILY - '.$id.' -->'."\n";
+							}
+							//if ($freq == 1 && $rep_events['recur_enddate']['month'] != 0 && $rep_events['recur_enddate']['mday'] != 0 && $rep_events['recur_enddate']['year'] != 0 && $search_date_full <= $end_recur_date)
+							if ($freq == 1 && $rep_events['end_date'] && $search_date_full <= $end_recur_date)
+							{
+								$this->sort_event($rep_events,$search_date_full);
+							}
+							elseif (floor(($search_beg_day - $event_beg_day)/86400) % $freq)
+							{
+								continue;
+							}
+							else
+							{
+								$this->sort_event($rep_events,$search_date_full);
+							}
 							break;
-							case MCAL_RECUR_WEEKLY:
-								$test = (($search_beg_day - $event_beg_day)/604800)/$freq;
+						case MCAL_RECUR_WEEKLY:
+							$test = (($search_beg_day - $event_beg_day)/604800)/$freq;
+							$test_subtract = floor($test);
+
+							//if (floor(($search_beg_day - $event_beg_day)/604800) % $freq)
+							if(!$rep_events['rpt_day'])
+							{
+								if(!($test - $test_subtract))
+								{
+									$this->sort_event($rep_events,$search_date_full);
+								}
+							}
+							else
+							{
+								$test = ($search_date_week - $event_beg_week)/$freq;
 								$test_subtract = floor($test);
-
-								//if (floor(($search_beg_day - $event_beg_day)/604800) % $freq)
-								if(!$rep_events['rpt_day'])
-								{
-									if(!($test - $test_subtract))
-									{
-										$this->sort_event($rep_events,$search_date_full);
-									}
-								}
-								else
-								{
-									$test = ($search_date_week - $event_beg_week)/$freq;
-									$test_subtract = floor($test);
-									if(($test - $test_subtract))
-									{
-										continue;
-									}
-
-									$check = 0;
-									switch($search_date_dow)
-									{
-										case 0:
-											$check = MCAL_M_SUNDAY;
-											break;
-										case 1:
-											$check = MCAL_M_MONDAY;
-											break;
-										case 2:
-											$check = MCAL_M_TUESDAY;
-											break;
-										case 3:
-											$check = MCAL_M_WEDNESDAY;
-											break;
-										case 4:
-											$check = MCAL_M_THURSDAY;
-											break;
-										case 5:
-											$check = MCAL_M_FRIDAY;
-											break;
-										case 6:
-											$check = MCAL_M_SATURDAY;
-											break;
-									}
-
-									if ($rep_events['rpt_day'] & $check)
-									{
-										$this->sort_event($rep_events,$search_date_full);
-									}
-								}
-								break;
-							case MCAL_RECUR_MONTHLY_WDAY:
-								if ((($search_date_year - $rep_events['start']['year']) * 12 + $search_date_month - $rep_events['start']['month']) % $freq)
+								if(($test - $test_subtract))
 								{
 									continue;
 								}
-	  
-								if ((phpgwapi_datetime::day_of_week($rep_events['start']['year'],$rep_events['start']['month'],$rep_events['start']['mday']) == phpgwapi_datetime::day_of_week($search_date_year,$search_date_month,$search_date_day)) &&
-									(ceil($rep_events['start']['mday']/7) == ceil($search_date_day/7)))
+
+								$check = 0;
+								switch($search_date_dow)
+								{
+								case 0:
+									$check = MCAL_M_SUNDAY;
+									break;
+								case 1:
+									$check = MCAL_M_MONDAY;
+									break;
+								case 2:
+									$check = MCAL_M_TUESDAY;
+									break;
+								case 3:
+									$check = MCAL_M_WEDNESDAY;
+									break;
+								case 4:
+									$check = MCAL_M_THURSDAY;
+									break;
+								case 5:
+									$check = MCAL_M_FRIDAY;
+									break;
+								case 6:
+									$check = MCAL_M_SATURDAY;
+									break;
+								}
+
+								if ($rep_events['rpt_day'] & $check)
 								{
 									$this->sort_event($rep_events,$search_date_full);
 								}
-								break;
-							case MCAL_RECUR_MONTHLY_MDAY:
-								if ((($search_date_year - $rep_events['start']['year']) * 12 + $search_date_month - $rep_events['start']['month']) % $freq)
-								{
-									continue;
-								}
-								if ($search_date_day == $rep_events['start']['mday'])
-								{
-									$this->sort_event($rep_events,$search_date_full);
-								}
-								break;
-							case MCAL_RECUR_YEARLY:
-								if (($search_date_year - $rep_events['start']['year']) % $freq)
-								{
-									continue;
-								}
-								if (date('dm',$datetime) == date('dm',$event_beg_day))
-								{
-									$this->sort_event($rep_events,$search_date_full);
-								}
-								break;
+							}
+							break;
+						case MCAL_RECUR_MONTHLY_WDAY:
+							if ((($search_date_year - $rep_events['start']['year']) * 12 + $search_date_month - $rep_events['start']['month']) % $freq)
+							{
+								continue;
+							}
+
+							if ((phpgwapi_datetime::day_of_week($rep_events['start']['year'],$rep_events['start']['month'],$rep_events['start']['mday']) == phpgwapi_datetime::day_of_week($search_date_year,$search_date_month,$search_date_day)) &&
+								(ceil($rep_events['start']['mday']/7) == ceil($search_date_day/7)))
+							{
+								$this->sort_event($rep_events,$search_date_full);
+							}
+							break;
+						case MCAL_RECUR_MONTHLY_MDAY:
+							if ((($search_date_year - $rep_events['start']['year']) * 12 + $search_date_month - $rep_events['start']['month']) % $freq)
+							{
+								continue;
+							}
+							if ($search_date_day == $rep_events['start']['mday'])
+							{
+								$this->sort_event($rep_events,$search_date_full);
+							}
+							break;
+						case MCAL_RECUR_YEARLY:
+							if (($search_date_year - $rep_events['start']['year']) % $freq)
+							{
+								continue;
+							}
+							if (date('dm',$datetime) == date('dm',$event_beg_day))
+							{
+								$this->sort_event($rep_events,$search_date_full);
+							}
+							break;
 						}
 					}
 				}
@@ -936,7 +930,7 @@ if ( !extension_loaded('mcal') )
 
 			if(isset($event['repeat_exception']))
 			{
-//				$event_time = mktime($event['start']['hour'],$event['start']['min'],0,intval(substr($date,4,2)),intval(substr($date,6,2)),intval(substr($date,0,4))) - phpgwapi_datetime::user_timezone();
+				//$event_time = mktime($event['start']['hour'],$event['start']['min'],0,intval(substr($date,4,2)),intval(substr($date,6,2)),intval(substr($date,0,4))) - phpgwapi_datetime::user_timezone();
 				$event_time = mktime($event['start']['hour'],$event['start']['min'],0,intval(substr($date,4,2)),intval(substr($date,6,2)),intval(substr($date,0,4)));
 				while($inserted == false && list($key,$exception_time) = each($event['repeat_exception']))
 				{
@@ -946,10 +940,10 @@ if ( !extension_loaded('mcal') )
 					}
 					if($exception_time == $event_time)
 					{
-//_debug_array(date('Y-m-d',$event_time));die();
-//						_debug_array($event);
-//						_debug_array($this->cached_events);die();
-//						$inserted = true;
+						//_debug_array(date('Y-m-d',$event_time));die();
+						//						_debug_array($event);
+						//						_debug_array($this->cached_events);die();
+						//						$inserted = true;
 						$event['exception'] = true;
 
 /*
@@ -960,13 +954,13 @@ if ( !extension_loaded('mcal') )
 							die();
 							}
 						}
-*/
+ */
 					}
 				}
 			}
 			if(isset($this->cached_events[$date]) && $this->cached_events[$date] && $inserted == false)
 			{
-				
+
 				if($this->debug)
 				{
 					echo '<!-- Cached Events found for '.$date.' -->'."\n";
@@ -979,7 +973,7 @@ if ( !extension_loaded('mcal') )
 				{
 					echo '<!-- Date : '.$date.' Count : '.count($this->cached_events[$date]).' -->'."\n";
 				}
-				
+
 				for($i=0;$i<count($this->cached_events[$date]);$i++)
 				{
 					$events = $this->cached_events[$date][$i];
@@ -1002,7 +996,7 @@ if ( !extension_loaded('mcal') )
 					}
 					if(date('Hi',mktime($event['start']['hour'],$event['start']['min'],$event['start']['sec'],$month,$day,$year)) < date('Hi',mktime($this->cached_events[$date][$i]['start']['hour'],$this->cached_events[$date][$i]['start']['min'],$this->cached_events[$date][$i]['start']['sec'],$month,$day,$year)))
 					{
-		//				for($j=count($this->cached_events[$date]);$j>=$i;$j--)
+						//				for($j=count($this->cached_events[$date]);$j>=$i;$j--)
 						for($j=count($this->cached_events[$date]);$j>=($i+1);$j--)
 						{
 							$this->cached_events[$date][$j] = $this->cached_events[$date][$j-1];
@@ -1041,14 +1035,14 @@ if ( !extension_loaded('mcal') )
 			$prev_date->modify('-1 week');
 			$next_date->modify('+1 week');
 			$resource = $this->read_single($id);
-            if ($search)
-            {
-                $resource['buildings_link'] = $GLOBALS['phpgw']->link('/index.php', array('menuaction' => $search, "type" => "building"));
-            }
-            else
-            {
-                $resource['buildings_link'] = $GLOBALS['phpgw']->link('/index.php', array('menuaction' => $buildingmodule . '.index'));
-            }
+			if ($search)
+			{
+				$resource['buildings_link'] = $GLOBALS['phpgw']->link('/index.php', array('menuaction' => $search, "type" => "building"));
+			}
+			else
+			{
+				$resource['buildings_link'] = $GLOBALS['phpgw']->link('/index.php', array('menuaction' => $buildingmodule . '.index'));
+			}
 
 			$resource['building_link'] = $GLOBALS['phpgw']->link('/index.php', array('menuaction' => $buildingmodule . '.show', 'id' => $resource['building_id']));
 			$resource['resource_link'] = $GLOBALS['phpgw']->link('/index.php', array('menuaction' => $resourcemodule . '.show', 'id' => $resource['id']));
@@ -1067,29 +1061,29 @@ if ( !extension_loaded('mcal') )
 
 
 		/**
-		* Find recurring events for a week
-		*
-		* @return array schedule
-		*/
+		 * Find recurring events for a week
+		 *
+		 * @return array schedule
+		 */
 
 		public function event_schedule_week_data()
 		{
-//		    $date = new DateTime(phpgw::get_var('date')); Use this one when moving to php 5.3
+			//		    $date = new DateTime(phpgw::get_var('date')); Use this one when moving to php 5.3
 
 			$datetime = CreateObject('phpgwapi.datetime');
 			$date = $datetime->convertDate(phpgw::get_var('date'), 'Y-m-d', $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 			$datetime_start = $datetime->date_to_timestamp($date);
-	    
+
 			$id = phpgw::get_var('resource_id', 'int');
-	
+
 			$event = $this->so->read_single($id);
 			$criteria = array
-			(
-				'start_date'		=> $datetime_start,
-				'end_date'			=> $datetime_start + (86400 * 6),
-				'location_id'		=> $event['location_id'],
-				'location_item_id'	=> $event['location_item_id']
-			);
+				(
+					'start_date'		=> $datetime_start,
+					'end_date'			=> $datetime_start + (86400 * 6),
+					'location_id'		=> $event['location_id'],
+					'location_item_id'	=> $event['location_item_id']
+				);
 
 			$this->find_scedules($criteria);
 			$schedules =  $this->cached_events;
@@ -1108,13 +1102,13 @@ if ( !extension_loaded('mcal') )
 			for($i = 0; $i < $total_records; $i++)
 			{
 				$values[$i] = array
-				(
-					'resource'			=> 'descr',
-					'resource_id'		=> 11,
-					'time'				=> $i+1,
-					'_from'				=> '16:30',
-					'_to'				=> '17:00'
-				);
+					(
+						'resource'			=> 'descr',
+						'resource_id'		=> 11,
+						'time'				=> $i+1,
+						'_from'				=> '16:30',
+						'_to'				=> '17:00'
+					);
 
 				foreach($schedules as $_date => $set)
 				{
@@ -1122,47 +1116,47 @@ if ( !extension_loaded('mcal') )
 					$date = new DateTime($__date);
 					$day_of_week = $date->format('D');
 					$values[$i][$day_of_week] = array
-					(
-						'exception' => $set[$i]['exception'],
-						'lang_exception' => $lang_exception,
-						'type' => 'event',
-						'name' => $set[$i]['descr'],
-						'link' => $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'booking.uievent.show', 'location_id' => $set[$i]['location_id'], 'location_item_id' => $set[$i]['location_item_id']))
-					);
+						(
+							'exception' => $set[$i]['exception'],
+							'lang_exception' => $lang_exception,
+							'type' => 'event',
+							'name' => $set[$i]['descr'],
+							'link' => $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'booking.uievent.show', 'location_id' => $set[$i]['location_id'], 'location_item_id' => $set[$i]['location_item_id']))
+						);
 				}
 			}
 
 			$data = array
-			(
-				'ResultSet' => array(
-					"totalResultsAvailable" => $total_records, 
-					"Result" => $values
-				)
-			);
-//_debug_array($data);die();
+				(
+					'ResultSet' => array(
+						"totalResultsAvailable" => $total_records, 
+						"Result" => $values
+					)
+				);
+			//_debug_array($data);die();
 			return $data;
 
 		}
 
 		/**
-		* Find recurring events for a period defined by the event
-		*
-		* @return array schedule
-		*/
+		 * Find recurring events for a period defined by the event
+		 *
+		 * @return array schedule
+		 */
 
 		public function event_schedule_data()
 		{
 			$id = phpgw::get_var('id', 'int');
-	
+
 			$event = $this->so->read_single($id);
 
 			$criteria = array
-			(
-				'start_date'		=> $event['start_date'],
-				'end_date'			=> $event['end_date'],
-				'location_id'		=> $event['location_id'],
-				'location_item_id'	=> $event['location_item_id']
-			);
+				(
+					'start_date'		=> $event['start_date'],
+					'end_date'			=> $event['end_date'],
+					'location_id'		=> $event['location_id'],
+					'location_item_id'	=> $event['location_item_id']
+				);
 
 			$this->find_scedules($criteria);
 			$schedules =  $this->cached_events;
@@ -1181,29 +1175,29 @@ if ( !extension_loaded('mcal') )
 				foreach($set as $entry)
 				{
 					$values[] = array
-					(
-						'time'				=> $i,
-						'date'				=> array
 						(
-							'exception' => $entry['exception'],
-							'lang_exception' => $lang_exception,
-							'type' => 'event',
-							'name' => $date,
-							'link' => $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'booking.uievent.show', 'location_id' => $entry['location_id'], 'location_item_id' => $entry['location_item_id']))
-						)
-					);
+							'time'				=> $i,
+							'date'				=> array
+							(
+								'exception' => $entry['exception'],
+								'lang_exception' => $lang_exception,
+								'type' => 'event',
+								'name' => $date,
+								'link' => $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'booking.uievent.show', 'location_id' => $entry['location_id'], 'location_item_id' => $entry['location_item_id']))
+							)
+						);
 
 					$i++;
 				}
 			}
 
 			$data = array
-			(
-				'ResultSet' => array(
-					"totalResultsAvailable" => $total_records, 
-					"Result" => $values
-				)
-			);
+				(
+					'ResultSet' => array(
+						"totalResultsAvailable" => $total_records, 
+						"Result" => $values
+					)
+				);
 
 			return $data;
 		}
@@ -1212,7 +1206,7 @@ if ( !extension_loaded('mcal') )
 		{
 			if(!isset($data['event_id']) || !$data['event_id'])
 			{
-					throw new Exception("property_boevent::set_exceptions - Missing event_id info in input");
+				throw new Exception("property_boevent::set_exceptions - Missing event_id info in input");
 			}
 			$this->so->set_exceptions($data);
 		}
