@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage eco
- 	* @version $Id: class.boinvoice.inc.php 6179 2010-07-05 06:52:20Z sigurd $
+ 	* @version $Id: class.boinvoice.inc.php 7379 2011-06-14 11:51:29Z sigurdne $
 	*/
 
 	/**
@@ -34,9 +34,12 @@
 
 	class property_boinvoice
 	{
+		public $total_records = 0;
+		public $sum_amount = 0;
+
 		function property_boinvoice($session=false)
 		{
-			$this->so		= CreateObject('property.soinvoice',true);
+			$this->so			= CreateObject('property.soinvoice',true);
 			$this->bocommon		= CreateObject('property.bocommon');
 			$this->account_id	= $GLOBALS['phpgw_info']['user']['account_id'];
 
@@ -84,7 +87,7 @@
 		{
 			$data = $GLOBALS['phpgw']->session->appsession('session_data','invoice');
 
-//	_debug_array($data);
+			//	_debug_array($data);
 
 			$this->start			= isset($data['start'])?$data['start']:'';
 			$this->query			= isset($data['query'])?$data['query']:'';
@@ -103,23 +106,55 @@
 		{
 			$start_date	= $this->bocommon->date_to_timestamp($start_date);
 			$end_date	= $this->bocommon->date_to_timestamp($end_date);
-			
+
 			$invoice = $this->so->read_invoice(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'user_lid' => $this->user_lid,'cat_id' => $this->cat_id, 'paid' => $paid,
-											'start_date'=>$start_date,'end_date'=>$end_date,'vendor_id'=>$vendor_id,
-											'loc1'=>$loc1,'workorder_id'=>$workorder_id,'allrows'=>$this->allrows,
-											'voucher_id'=>$voucher_id,'b_account_class' =>$this->b_account_class,
-											'district_id' => $this->district_id));
+				'user_lid' => $this->user_lid,'cat_id' => $this->cat_id, 'paid' => $paid,
+				'start_date'=>$start_date,'end_date'=>$end_date,'vendor_id'=>$vendor_id,
+				'loc1'=>$loc1,'workorder_id'=>$workorder_id,'allrows'=>$this->allrows,
+				'voucher_id'=>$voucher_id,'b_account_class' =>$this->b_account_class,
+				'district_id' => $this->district_id));
+
+			$soXport    = CreateObject('property.soXport');
+			$soworkorder = CreateObject('property.soworkorder');
+			$sos_agreement = CreateObject('property.sos_agreement');
+			foreach ( $invoice as & $entry )
+			{
+				if( $entry['order_id'] )
+				{
+					if($order_type = $soXport->check_order($entry['order_id']))
+					{
+						if($order_type == 'workorder')
+						{
+							$workorder	= $soworkorder->read_single($entry['order_id']);
+
+							if($workorder['vendor_id'] && ($workorder['vendor_id'] != $entry['vendor_id']))
+							{
+								$entry['vendor']		=  $this->get_vendor_name($workorder['vendor_id']) . ' => ' . $entry['vendor'];
+							}
+						}
+
+						if($order_type == 's_agreement')
+						{
+							$s_agreement = $sos_agreement->read_single($entry['order_id']);
+
+							if($s_agreement['vendor_id'] && ($s_agreement['vendor_id'] != $entry['vendor_id']))
+							{
+								$entry['vendor']		= $this->get_vendor_name($s_agreement['vendor_id']) . ' => ' . $entry['vendor'];
+							}
+						}
+					}
+				}
+			}
 
 			$this->total_records = $this->so->total_records;
-
+			$this->sum_amount = $this->so->sum_amount;
 			return $invoice;
 		}
 
 		function read_invoice_sub($voucher_id='',$paid='')
 		{
 			$invoice = $this->so->read_invoice_sub(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'user_lid' => $this->user_lid,'cat_id' => $this->cat_id,'voucher_id'=>$voucher_id,'paid' => $paid));
+				'user_lid' => $this->user_lid,'cat_id' => $this->cat_id,'voucher_id'=>$voucher_id,'paid' => $paid));
 			$this->total_records = $this->so->total_records;
 			return $invoice;
 		}
@@ -140,10 +175,10 @@
 			$end_date	= $this->bocommon->date_to_timestamp($end_date);
 
 			$invoice = $this->so->read_consume(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'user_lid' => $this->user_lid,'cat_id' => $this->cat_id,
-											'start_date'=>$start_date,'end_date'=>$end_date,'vendor_id'=>$vendor_id,
-											'loc1'=>$loc1,'workorder_id'=>$workorder_id,'b_account_class' =>$b_account_class,
-											'district_id' => $district_id, 'b_account' => $this->b_account ));
+				'user_lid' => $this->user_lid,'cat_id' => $this->cat_id,
+				'start_date'=>$start_date,'end_date'=>$end_date,'vendor_id'=>$vendor_id,
+				'loc1'=>$loc1,'workorder_id'=>$workorder_id,'b_account_class' =>$b_account_class,
+				'district_id' => $district_id, 'b_account' => $this->b_account ));
 
 			$this->total_records = $this->so->total_records;
 
@@ -162,6 +197,11 @@
 			return $this->so->update_invoice_sub($values);
 		}
 
+		function update_single_line($values)
+		{
+			return $this->so->update_single_line($values);
+		}
+
 		function select_account_class($selected='')
 		{
 			$b_account_class_list= $this->so->select_account_class();
@@ -195,10 +235,10 @@
 				}
 
 				$tax_code_list[] = array
-				(
-					'id'			=> $code['id'],
-					'selected'		=> $sel_code
-				);
+					(
+						'id'			=> $code['id'],
+						'selected'		=> $sel_code
+					);
 			}
 
 			for ($i=0;$i<count($tax_code_list);$i++)
@@ -240,18 +280,17 @@
 			$arts=$this->so->get_lisfm_ecoart();
 			return $this->bocommon->select_list($selected,$arts);
 		}
-	//----------
 
 		function select_category($format='',$selected='')
 		{
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('cat_select'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('cat_filter'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('cat_select'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('cat_filter'));
+				break;
 			}
 
 			$categories= $this->so->get_type_list();
@@ -269,12 +308,12 @@
 
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('user_lid_select'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('user_lid_filter'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('user_lid_select'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('user_lid_filter'));
+				break;
 			}
 			$users=$this->bocommon->get_user_list_right(array(32, 64, 128),$selected,'.invoice',$extra,$default);
 			return $users;
@@ -286,14 +325,12 @@
 			return $this->bocommon->select_list($selected,$types);
 		}
 
-	//----------
 		function select_dimb_list($selected='')
 		{
 			$dimbs=$this->so->select_dimb_list();
 			return $this->bocommon->select_list($selected,$dimbs);
 		}
 
-	//-------------------
 		function select_dimd_list($selected='')
 		{
 			$dimds=$this->so->select_dimd_list();
@@ -352,23 +389,23 @@
 			$values['kildeid'] 			= 1;
 			$values['kidnr'] 			= $values['kid_nr'];
 			$values['typeid'] 			= $values['type'];
-//_debug_array($values);die();
+			//_debug_array($values);die();
 			if($values['order_id'] && $order_type = $this->soXport->check_order($values['order_id']))
 			{
 				if($order_type=='workorder')
 				{
-					$soworkorder = CreateObject('property.soworkorder');
-					$soproject = CreateObject('property.soproject');
-					$workorder	= $soworkorder->read_single($values['order_id']);
-					$project	= $soproject->read_single($workorder['project_id']);
+					$soworkorder	= CreateObject('property.soworkorder');
+					$soproject		= CreateObject('property.soproject');
+					$workorder		= $soworkorder->read_single($values['order_id']);
+					$project		= $soproject->read_single($workorder['project_id']);
 
-					$values['spvend_code']	= $workorder['vendor_id'];
+					$values['spvend_code']		= $workorder['vendor_id'];
 					$values['spbudact_code']	= $workorder['b_account_id'];
-					$values['location_code']	=$project['location_code'];
-					$values['dima']				=str_replace('-','',$project['location_code']);
+					$values['location_code']	= $project['location_code'];
+					$values['dima']				= str_replace('-','',$project['location_code']);
 					$values['vendor_name']		= $this->get_vendor_name($workorder['vendor_id']);
 					$values['pmwrkord_code']	= $values['order_id'];
-					$values['project_id']			= $workorder['project_id'];
+					$values['project_id']		= $workorder['project_id'];
 					if(!$values['dimb'])
 					{
 						$values['dimb']			= $workorder['ecodimb'];
@@ -461,21 +498,21 @@
 
 		function get_vendor_name($vendor_id='')
 		{
-			$contacts	= CreateObject('property.soactor');
-			$contacts->role='vendor';
+			$contacts	= CreateObject('property.sogeneric');
+			$contacts->get_location_info('vendor',false);
 
 			$criteria = array
-			(
-				'attributes' => array
 				(
-					array
+					'attributes' => array
 					(
-						'column_name' => 'org_name'
+						array
+						(
+							'column_name' => 'org_name'
+						)
 					)
-				)
-			);
+				);
 
-			$vendor_data	= $contacts->read_single($vendor_id, $criteria);
+			$vendor_data	= $contacts->read_single(array('id' => $vendor_id), $criteria);
 
 			if(is_array($vendor_data))
 			{
@@ -541,5 +578,48 @@
 			}
 			return $values;
 		}
-	}
 
+		public function get_single_line($id)
+		{
+			$line = $this->so->get_single_line($id);
+
+			$soXport    = CreateObject('property.soXport');
+			$soworkorder = CreateObject('property.soworkorder');
+			$sos_agreement = CreateObject('property.sos_agreement');
+			if( $line['order_id'] )
+			{
+				if($order_type = $soXport->check_order($line['order_id']))
+				{
+					if($order_type == 'workorder')
+					{
+						$workorder	= $soworkorder->read_single($line['order_id']);
+						if($workorder['vendor_id'] && ($workorder['vendor_id'] != $line['vendor_id']))
+						{
+							$line['vendor']		=  $this->get_vendor_name($workorder['vendor_id']) . ' => ' . $this->get_vendor_name($line['vendor_id']);
+						}
+					}
+					if($order_type == 's_agreement')
+					{
+						$s_agreement = $sos_agreement->read_single(array('s_agreement_id'=>$line['order_id']));
+						if($s_agreement['vendor_id'] && ($s_agreement['vendor_id'] != $line['vendor_id']))
+						{
+							$line['vendor']		= $this->get_vendor_name($s_agreement['vendor_id']) . ' => ' . $this->get_vendor_name($line['vendor_id']);
+						}
+					}
+					$line['order_type'] = $order_type;
+				}
+			}
+
+			if(!isset($line['vendor']))
+			{
+				$line['vendor']	= $this->get_vendor_name($line['vendor_id']);
+			}
+			return $line;
+		}
+
+		function check_role()
+		{
+			return $this->so->check_role();
+		}
+
+	}
