@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage location
- 	* @version $Id: class.bolocation.inc.php 6124 2010-06-21 08:38:33Z sigurd $
+ 	* @version $Id: class.bolocation.inc.php 7387 2011-06-16 10:30:40Z sigurdne $
 	*/
 
 	/**
@@ -47,37 +47,18 @@
 		var $total_records;
 
 		/**
-		* @var object $custom reference to custom fields object
-		*/
+		 * @var object $custom reference to custom fields object
+		 */
 		protected $custom;
 
 		var $public_functions = array
-		(
-			'read'		=> true,
-			'read_single'	=> true,
-			'save'		=> true,
-			'delete'	=> true,
-			'check_perms'	=> true
-		);
-
-		var $soap_functions = array(
-			'list' => array(
-				'in'  => array('int','int','struct','string','int'),
-				'out' => array('array')
-			),
-			'read' => array(
-				'in'  => array('int','struct'),
-				'out' => array('array')
-			),
-			'save' => array(
-				'in'  => array('int','struct'),
-				'out' => array()
-			),
-			'delete' => array(
-				'in'  => array('int','struct'),
-				'out' => array()
-			)
-		);
+			(
+				'read'		=> true,
+				'read_single'	=> true,
+				'save'		=> true,
+				'delete'	=> true,
+				'check_perms'	=> true
+			);
 
 		function property_bolocation($session=false)
 		{
@@ -108,11 +89,16 @@
 			$allrows				= phpgw::get_var('allrows', 'bool');
 			$location_code			= phpgw::get_var('location_code');
 
+			if($location_code && !$type_id)
+			{
+				$type_id = count(explode('-',$location_code));
+			}
+
 			$this->start			= $start ? $start : 0;
-			$this->query			= isset($query) ? $query : $this->query;
+			$this->query			= isset($query) && $query ? $query : '';
 			$this->filter			= isset($filter) && $filter ? $filter : '';
-			$this->sort				= isset($sort) && $sort ? $sort : '';
-			$this->order			= isset($order) && $order ? $order : '';
+			$this->sort				= isset($sort) && $sort ? $sort : $this->sort;
+			$this->order			= isset($order) && $order ? $order : $this->order;
 			$this->cat_id			= isset($cat_id) && $cat_id ? $cat_id : '';
 			$this->part_of_town_id	= isset($part_of_town_id) && $part_of_town_id ? $part_of_town_id : '';
 			$this->district_id		= isset($district_id) && $district_id ? $district_id : '';
@@ -121,7 +107,7 @@
 			$this->allrows			= isset($allrows) && $allrows ? $allrows : '';
 			$this->acl_location		= '.location.' . $this->type_id;
 			$this->location_code	= isset($location_code) && $location_code ? $location_code : '';
-			
+
 			if(isset($_REQUEST['query']) && !$query && !isset($_REQUEST['block_query']))
 			{
 				$this->location_code = '';
@@ -140,7 +126,7 @@
 			$self = parse_url(phpgw::get_var('QUERY_STRING', 'string', 'SERVER') );
 			parse_str($self['path'],$self_out);
 
-			if(isset($referer_out['menuaction']) && isset($self_out['menuaction']) && $referer_out['menuaction'] == $self_out['menuaction'])
+//			if(isset($referer_out['menuaction']) && isset($self_out['menuaction']) && $referer_out['menuaction'] == $self_out['menuaction'])
 			{
 				$data = $GLOBALS['phpgw']->session->appsession('session_data','location');
 			}
@@ -175,7 +161,7 @@
 			$this->district_id		= isset($data['district_id'])?$data['district_id']:'';
 			$this->status			= isset($data['status'])?$data['status']:'';
 			$this->type_id			= isset($data['type_id'])?$data['type_id']:'';
-		//	$this->allrows			= $data['allrows'];
+			//	$this->allrows			= $data['allrows'];
 		}
 
 		function save_sessiondata($data)
@@ -202,12 +188,12 @@
 		{
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('status_select'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('status_filter'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('status_select'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('status_filter'));
+				break;
 			}
 
 			$list= $this->so->select_status_list($this->type_id);
@@ -216,7 +202,7 @@
 
 		function read_entity_to_link($location_code)
 		{
-				return $this->so->read_entity_to_link($location_code);
+			return $this->so->read_entity_to_link($location_code);
 		}
 
 		function get_owner_list($format='',$selected='')
@@ -224,12 +210,12 @@
 
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('owner_select'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('owner_filter'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('owner_select'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('owner_filter'));
+				break;
 			}
 
 			$owners = $this->so->get_owner_list();
@@ -242,12 +228,12 @@
 
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('owner_select'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('owner_filter'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('owner_select'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('owner_filter'));
+				break;
 			}
 
 			$owners = $this->so->get_owner_type_list();
@@ -270,32 +256,33 @@
 			{
 				switch($data['lookup_type'])
 				{
-					case 'form':
-						$GLOBALS['phpgw']->xslttpl->add_file(array('location_form'));
-						break;
-					case 'view':
-						$GLOBALS['phpgw']->xslttpl->add_file(array('location_view'));
-						break;
+				case 'form':
+					$GLOBALS['phpgw']->xslttpl->add_file(array('location_form'));
+					break;
+				case 'view':
+					$GLOBALS['phpgw']->xslttpl->add_file(array('location_view'));
+					break;
 				}
 			}
 
 			$filter_location	= isset($data['filter_location']) ? $data['filter_location'] : '';
 			$block_query 		= !!$filter_location;
 			$location_link		= "menuaction:'property.uilocation.index',lookup:1";
+			$lookup_functions 	= array();
 
 			$config = $this->soadmin_location->read_config('');
 
 			$this->config	= $config;
-//_debug_array($config);
+			//_debug_array($config);
 			$location_types	= $this->soadmin_location->select_location_type();
 			$this->location_types	= $location_types;
 
-			if($data['type_id']<0)
+			if(!$data['type_id'] === 0 || $data['type_id'] < 0)
 			{
 				$data['type_id'] = count($location_types);
 			}
-//_debug_array($data);die();
-//_debug_array($location_types);
+			//_debug_array($data);die();
+			//_debug_array($location_types);
 			$fm_location_cols = array();
 			for ($i=1;$i<($data['type_id']+1);$i++)
 			{
@@ -308,7 +295,7 @@
 			}
 			unset($fm_location_cols_temp);
 
-//_debug_array($fm_location_cols);
+			//_debug_array($fm_location_cols);
 
 			for ($i=0;$i<$data['type_id'];$i++)
 			{
@@ -318,57 +305,48 @@
 				$insert_record['location'][]						= $location['location'][$i]['input_name'];
 				$location['location'][$i]['size']					= 5;
 				$location['location'][$i]['name']					= $location_types[($i)]['name'];
-				$location['location'][$i]['value']					= (isset($data['values']['loc' . ($i+1)])?$data['values']['loc' . ($i+1)]:'');
+				$location['location'][$i]['value']					= isset($data['values']['loc' . ($i+1)]) ? $data['values']['loc' . ($i+1)] : '';
 				$location['location'][$i]['statustext']				= lang('click this link to select') . ' ' . $location_types[($i)]['name'];
 
-				if($i==0)
-				{
-					$location['location'][$i]['extra'][0]['input_name']		= 'loc' . ($i+1).'_name';
-					$input_name[]							= $location['location'][$i]['extra'][0]['input_name'];
-					$location['location'][$i]['extra'][0]['input_type']		= 'text';
-					$location['location'][$i]['extra'][0]['size']			= 30;
-					$location['location'][$i]['extra'][0]['lookup_function_call']	= 'lookup_loc' . ($i+1) . '()';
-					$location['location'][$i]['extra'][0]['value']			= (isset($data['values']['loc' . ($i+1).'_name'])?$data['values']['loc' . ($i+1).'_name']:'');
-				}
-				else
-				{
-					$location['location'][$i]['extra'][0]['input_name']		= 'loc' . ($i+1).'_name';
-					$input_name[]							= $location['location'][$i]['extra'][0]['input_name'];
-					$location['location'][$i]['extra'][0]['input_type']		= 'text';
-					$location['location'][$i]['extra'][0]['size']			= 30;
-					$location['location'][$i]['extra'][0]['lookup_function_call']	= 'lookup_loc' . ($i+1) . '()';
-					$location['location'][$i]['extra'][0]['value']			= (isset($data['values']['loc' . ($i+1).'_name'])?$data['values']['loc' . ($i+1).'_name']:'');
-				}
+				$location['location'][$i]['extra'][0]['input_name']		= 'loc' . ($i+1).'_name';
+				$input_name[]							= $location['location'][$i]['extra'][0]['input_name'];
+				$location['location'][$i]['extra'][0]['input_type']		= 'text';
+				$location['location'][$i]['extra'][0]['size']			= 30;
+				$location['location'][$i]['extra'][0]['lookup_function_call']	= 'lookup_loc' . ($i+1) . '()';
+				$location['location'][$i]['extra'][0]['value']			=  isset($data['values']['loc' . ($i+1).'_name']) ? $data['values']['loc' . ($i+1).'_name'] : '';
 
 				$location['location'][$i]['lookup_function_call']			= 'lookup_loc' . ($i+1) . '()';
 				$location['location'][$i]['readonly']					= true;
-				
+
 				if(!isset($data['block_parent']) || $data['block_parent'] < ($i+1))
 				{
 					$location['location'][$i]['lookup_link']				= true;
 					$lookup_functions[] = array
-					(
-						'name' 						=> 'lookup_loc' . ($i+1) . '()',
-						'filter_level'				=> $i,
-						'link'						=>  $location_link .',type_id:' . ($i+1) . ',lookup_name:' . $i,
-						'action' 					=> 'Window1=window.open(strURL,"Search","width=1000,height=700,toolbar=no,scrollbars=yes,resizable=yes");'
-					);
+						(
+							'name' 						=> 'lookup_loc' . ($i+1) . '()',
+							'filter_level'				=> $i,
+							'link'						=> $location_link .',type_id:' . ($i+1) . ',lookup_name:' . $i,
+							'action' 					=> 'Window1=window.open(strURL,"Search","left=50,top=100,width=1000,height=700,toolbar=no,scrollbars=yes,resizable=yes");'
+						);
 				}
-
-				if(isset($data['no_link']) && $data['no_link']>=($i+3))
+//_debug_array($data['no_link']);
+				if(isset($data['no_link']) && $data['no_link'] && $data['no_link']>=($i+3))
 				{
-					$location['location'][$i]['lookup_link']			= false;
-					$lookup_functions[$i]['link'] 					= $location_link .',type_id:' . ($data['no_link']-1) . ',lookup_name:' . ($data['no_link']-2);
-					$lookup_functions[$i]['action'] 				= 'Window1=window.open(strURL,"Search","width=1000,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
-					$location['location'][$i]['statustext']				= lang('click this link to select') . ' ' . $location_types[($data['no_link']-2)]['name'];
+					$location['location'][$i]['lookup_link']						= false;
+					$location['location'][$i]['lookup_function_call']				= '';
+					$location['location'][$i]['extra'][0]['lookup_function_call']	= '';
+					$location['location'][$i]['lookup_link']						= false;
+					$lookup_functions[$i]['link'] 									= $location_link .',type_id:' . ($data['no_link']-1) . ',lookup_name:' . ($data['no_link']-2);
+					$lookup_functions[$i]['action'] 								= 'Window1=window.open(strURL,"Search","left=50,top=100,width=1000,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+					$location['location'][$i]['statustext']							= lang('click this link to select') . ' ' . $location_types[($data['no_link']-2)]['name'];
 				}
 
 				if(isset($data['query_link']) && $i < ($data['type_id']-1))
 				{
-						for ($j=1;$j<$i+2;$j++)
-						{
-							$temp_location[]= $data['values']['loc' . ($j)];
-						}
+					for ($j=1;$j<$i+2;$j++)
+					{
+						$temp_location[]= $data['values']['loc' . ($j)];
+					}
 
 					$data['link_data']['query_location']				= implode('-',$temp_location);
 					$location['location'][$i]['query_link']				= $GLOBALS['phpgw']->link('/index.php',$data['link_data']);
@@ -378,24 +356,36 @@
 				$m=$i;
 			}
 
-//_debug_array($fm_location_cols);
-//_debug_array($data);
-
 			$location_cols_count =count($fm_location_cols);
 			for ($j=0;$j<$location_cols_count;$j++)
 			{
-				if((isset($fm_location_cols[$j]['location_type']) && $fm_location_cols[$j]['location_type'] <= $data['type_id']) && $fm_location_cols[$j]['lookup_form'])
+				$_lookup_link = true;
+				if(isset($data['no_link']) && $data['no_link'])
+				{
+					$_lookup_link = false;
+					if( $data['no_link'] < ($fm_location_cols[$j]['location_type']+2))
+					{
+						$_lookup_link = true;
+					}
+				}
+
+				if( $fm_location_cols[$j]['lookup_form'] && $fm_location_cols[$j]['location_type'] == $data['type_id'] )
 				{
 					$location['location'][$i]['input_type']				= 'text';
 					$location['location'][$i]['input_name']				= $fm_location_cols[$j]['column_name'];
 					$input_name[]										= $location['location'][$i]['input_name'];
 					$location['location'][$i]['size']					= 5;
-					$location['location'][$i]['lookup_function_call']	= 'lookup_loc' . $fm_location_cols[$j]['location_type'] . '()';
-					$location['location'][$i]['lookup_link']			= true;
+					$location['location'][$i]['lookup_function_call']	= $_lookup_link ? "lookup_loc{$fm_location_cols[$j]['location_type']}()" : '';
+					$location['location'][$i]['lookup_link']			= $_lookup_link;
 					$location['location'][$i]['readonly']				= true;
 					$location['location'][$i]['name']					= $fm_location_cols[$j]['input_text'];
 					$location['location'][$i]['value']					= isset($data['values'][$fm_location_cols[$j]['column_name']]) ? $data['values'][$fm_location_cols[$j]['column_name']] : '';
 					$location['location'][$i]['statustext']				= lang('click this link to select') . ' ' . $location_types[($fm_location_cols[$j]['location_type']-1)]['name'];
+					$insert_record['additional_info'][]					= array
+					(
+						'input_name'	=> $location['location'][$i]['input_name'],
+						'input_text'	=> $fm_location_cols[$j]['input_text']
+					);
 					$i++;
 
 				}
@@ -404,14 +394,23 @@
 			$config_count =count($config);
 			for ($j=0;$j<$config_count;$j++)
 			{
+				$_lookup_link = true;
+				if(isset($data['no_link']) && $data['no_link'])
+				{
+					$_lookup_link = false;
+					if( $data['no_link'] < ($config[$j]['location_type']+2))
+					{
+						$_lookup_link = true;
+					}
+				}
 				if($config[$j]['location_type'] <= $data['type_id'] && $config[$j]['lookup_form'] )
 				{
-					if($config[$j]['column_name']=='street_id' && $location_types[($data['type_id']-1)]['list_address']==1):
+					if($config[$j]['column_name']=='street_id' && $location_types[($data['type_id']-1)]['list_address']==1)
 					{
 						$location['location'][$i]['input_name']				= $config[$j]['column_name'];
 						$input_name[]										= 'street_id';
-						$location['location'][$i]['lookup_link']			= true;
-						$location['location'][$i]['lookup_function_call']	= 'lookup_loc' . $config[$j]['location_type'] . '()';
+						$location['location'][$i]['lookup_link']			= $_lookup_link;
+						$location['location'][$i]['lookup_function_call']	= $_lookup_link ? "lookup_loc{$config[$j]['location_type']}()" : '';
 						$location['location'][$i]['name']					= lang('address');
 						$location['location'][$i]['input_type']				= 'hidden';
 						$location['location'][$i]['value']					= (isset($data['values'][$config[$j]['column_name']])?$data['values'][$config[$j]['column_name']]:'');
@@ -421,7 +420,7 @@
 						$location['location'][$i]['extra'][0]['readonly']	= true;
 						$input_name[]										= $location['location'][$i]['extra'][0]['input_name'];
 						$location['location'][$i]['extra'][0]['size']		= 30;
-						$location['location'][$i]['extra'][0]['lookup_function_call']	= 'lookup_loc' . $config[$j]['location_type'] . '()';
+						$location['location'][$i]['extra'][0]['lookup_function_call']	= $_lookup_link ? "lookup_loc{$config[$j]['location_type']}()" : '';
 						$location['location'][$i]['extra'][0]['value']		= (isset($data['values']['street_name'])?$data['values']['street_name']:'');
 
 						$location['location'][$i]['extra'][1]['input_type']	= 'text';
@@ -429,22 +428,22 @@
 						$location['location'][$i]['extra'][1]['readonly']	= true;
 						$input_name[]										= $location['location'][$i]['extra'][1]['input_name'];
 						$location['location'][$i]['extra'][1]['size']		= 6;
-						$location['location'][$i]['extra'][1]['lookup_function_call']	= 'lookup_loc' . $config[$j]['location_type'] . '()';
+						$location['location'][$i]['extra'][1]['lookup_function_call']	= $_lookup_link ? "lookup_loc{$config[$j]['location_type']}()" : '';
 						$location['location'][$i]['extra'][1]['value']		= (isset($data['values']['street_number'])?$data['values']['street_number']:'');
 						$i++;
 					}
-					elseif($config[$j]['column_name']=='tenant_id' && $data['tenant']):
+					else if($config[$j]['column_name']=='tenant_id' && $data['tenant'])
 					{
 						$m++;
 						$lookup_functions[] = array
-						(
-							'name' 						=> 'lookup_loc' . ($m+1) . '()',
-							'filter_level'				=> $m,
-							'link'						=> $location_link .',lookup_tenant:1,type_id:' . $config[$j]['location_type'] . ',lookup_name:' . $i,
-							'action' 					=> 'Window1=window.open(strURL,"Search","width=1600,height=700,toolbar=no,scrollbars=yes,resizable=yes");'
-						);
+							(
+								'name' 						=> 'lookup_loc' . ($m+1) . '()',
+								'filter_level'				=> $m,
+								'link'						=> $location_link .',lookup_tenant:1,type_id:' . $config[$j]['location_type'] . ',lookup_name:' . $i,
+								'action' 					=> 'Window1=window.open(strURL,"Search","left=50,top=100,width=1600,height=700,toolbar=no,scrollbars=yes,resizable=yes");'
+							);
 
-						$location['location'][$i]['lookup_link']			= true;
+						$location['location'][$i]['lookup_link']			= $_lookup_link;
 						$location['location'][$i]['name']					= lang('Tenant');
 						$location['location'][$i]['input_type']				= 'hidden';
 						$location['location'][$i]['input_name']				= 'tenant_id';
@@ -483,7 +482,7 @@
 						$location['location'][$i]['statustext']				= lang('contact phone');
 						$i++;
 					}
-					elseif($config[$j]['column_name']!='tenant_id' && $config[$j]['column_name']!='street_id'):
+					else if($config[$j]['column_name']!='tenant_id' && $config[$j]['column_name']!='street_id')
 					{
 						$location['location'][$i]['input_name']				= $config[$j]['column_name'];
 						$input_name[]										= $location['location'][$i]['input_name'];
@@ -491,14 +490,33 @@
 						$location['location'][$i]['size']					= 5;
 						$location['location'][$i]['value']					= $data['location']['value'][$config[$j]['column_name']];
 						$location['location'][$i]['lookup_function_call']	= 'lookup_loc' . $fm_location_cols[$j]['location_type'] . '()';
-						$location['location'][$i]['lookup_link']			= true;
+						$location['location'][$i]['lookup_link']			= $_lookup_link;
 						$location['location'][$i]['name']					= $config[$j]['descr'];
 						$location['location'][$i]['value']					= $data['values'][$config[$j]['column_name']];
 						$location['location'][$i]['statustext']				= lang('click this link to select') . ' ' .$location_types[($fm_location_cols[$j]['location_type']-1)]['name'];
 						$location['location'][$i]['input_type']				= 'text';
 						$i++;
 					}
-					endif;
+				}
+			}
+
+			if(!isset($data['lookup_entity']) || !$data['lookup_entity'])
+			{
+				if(is_array($data['entity_data']))
+				{
+					$soadmin_entity 			= CreateObject('property.soadmin_entity');
+					$soadmin_entity->type		= 'entity';
+					$soadmin_entity->type_app	= 'property';
+
+					foreach($data['entity_data'] as $_entity_id => $_entity_info)				
+					{
+						$entity_lookup = $soadmin_entity->read_single($_entity_id);
+						$data['lookup_entity'][] = array
+						(
+							'id'		=> $_entity_id,
+							'name'		=> $entity_lookup['name']
+						);
+					}
 				}
 			}
 
@@ -508,12 +526,13 @@
 				{
 					$m++;
 
+					$p_cat_id = isset($data['entity_data'][$entity['id']]['p_cat_id']) ? $data['entity_data'][$entity['id']]['p_cat_id'] : '';
 					$lookup_functions[] = array
-					(
-						'name'		=> 'lookup_entity_' . $entity['id'] .'()',
-						'link'		=> "menuaction:'property.uilookup.entity',location_type:{$data['type_id']},entity_id:{$entity['id']},location_code:'{$filter_location}',block_query:'{$block_query}'",
-						'action'	=> 'Window1=window.open(strURL,"Search","width=1200,height=700,toolbar=no,scrollbars=yes,resizable=yes");'
-					);
+						(
+							'name'		=> 'lookup_entity_' . $entity['id'] .'()',
+							'link'		=> "menuaction:'property.uilookup.entity',location_type:{$data['type_id']},entity_id:{$entity['id']},cat_id:'{$p_cat_id}',location_code:'{$filter_location}',block_query:'{$block_query}'",
+							'action'	=> 'Window1=window.open(strURL,"Search","left=50,top=100,width=1200,height=700,toolbar=no,scrollbars=yes,resizable=yes");'
+						);
 
 					$location['location'][$i]['input_type']						= 'text';
 					$location['location'][$i]['input_name']						= 'entity_num_' . $entity['id'];
@@ -565,7 +584,7 @@
 				}
 			}
 
-//_debug_array($location['location']);
+			//_debug_array($location['location']);
 			if(isset($input_name))
 			{
 				$GLOBALS['phpgw']->session->appsession('lookup_fields','property',$input_name);
@@ -574,7 +593,7 @@
 			{
 				$GLOBALS['phpgw']->session->appsession('insert_record','property',$insert_record);
 			}
-//			$GLOBALS['phpgw']->session->appsession('input_name','property',$input_name);
+			//			$GLOBALS['phpgw']->session->appsession('input_name','property',$input_name);
 
 
 			if(isset($lookup_functions) && is_array($lookup_functions))
@@ -597,38 +616,46 @@
 					{
 						$lookup_functions[$j]['link'] .= ",location_code:'{$filter_location}',block_query:'{$block_query}'";
 					}
-					
-					$location['lookup_functions'] .= "\t".'function ' . $lookup_functions[$j]['name'] ."\n";
-					$location['lookup_functions'] .= "\t".'{'."\n";
+
+					$location['lookup_functions'] .= <<<JS
+
+						function {$lookup_functions[$j]['name']}
+						{
+JS;
 					if($filter_level)
 					{
-						$location['lookup_functions'] .= "
-						var block = '';
-						var filter = '';
-						var filter_level = {$filter_level};
-						if (filter_level) 
-						{
-							for(i=1;i<=filter_level;i++)
+						$location['lookup_functions'] .= <<<JS
+
+							var block = '';
+							var filter = '';
+							var filter_level = {$filter_level};
+							if (filter_level) 
 							{
-								if(eval('document.form.loc'+i+'.value'))
+								for(i=1;i<=filter_level;i++)
 								{
-									block = true;
-									if(!filter)
+									if(eval('document.form.loc'+i+'.value'))
 									{
-										filter = eval('document.form.loc'+i+'.value');
-									}
-									else
-									{
-										filter = filter  + '-' + eval('document.form.loc'+i+'.value');									
+										block = true;
+										if(!filter)
+										{
+											filter = eval('document.form.loc'+i+'.value');
+										}
+										else
+										{
+											filter = filter  + '-' + eval('document.form.loc'+i+'.value');									
+										}
 									}
 								}
 							}
-						}";
+JS;
 					}
-					$location['lookup_functions'] .= "\t\tvar oArgs = {" . $lookup_functions[$j]['link'] ."};" . "\n";
-					$location['lookup_functions'] .= "\t\tvar strURL = phpGWLink('index.php', oArgs);\n";
-					$location['lookup_functions'] .= "\t\t".$lookup_functions[$j]['action'] ."\n";
-					$location['lookup_functions'] .= "\t".'}'."\n";
+					$location['lookup_functions'] .= <<<JS
+
+							var oArgs = {{$lookup_functions[$j]['link']}};
+							var strURL = phpGWLink('index.php', oArgs);
+							{$lookup_functions[$j]['action']}
+						}
+JS;
 				}
 			}
 
@@ -645,19 +672,46 @@
 			}
 		}
 
-		function read($data='')
+		function read($data = array())
 		{
-			$location = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'filter' => $this->filter,'cat_id' => $this->cat_id,'type_id' => $data['type_id'],
-											'lookup_tenant'=>$data['lookup_tenant'],'lookup'=>$data['lookup'],
-											'district_id'=>$this->district_id,'allrows'=>$data['allrows'],
-											'status'=>$this->status,'part_of_town_id'=>$this->part_of_town_id,'dry_run'=>$data['dry_run'],
-											'location_code' => $this->location_code));
+			$locations = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
+				'filter' => $this->filter,'cat_id' => $this->cat_id,'type_id' => $data['type_id'],
+				'lookup_tenant'=>$data['lookup_tenant'],'lookup'=>$data['lookup'],
+				'district_id'=>$this->district_id,'allrows'=>$data['allrows'],
+				'status'=>$this->status,'part_of_town_id'=>$this->part_of_town_id,'dry_run'=>$data['dry_run'],
+				'location_code' => $this->location_code, 'filter_role_on_contact' => $data['filter_role_on_contact'], 'role_id' => $data['role_id']));
 
 			$this->total_records = $this->so->total_records;
 			$this->uicols = $this->so->uicols;
 
-			return $location;
+			return $locations;
+		}
+
+		function get_responsible($data = array())
+		{
+			$soresponsible		= CreateObject('property.soresponsible');
+			$contacts = createObject('phpgwapi.contacts');
+
+			if($data['user_id'] < 0 && $data['role_id'])
+			{
+				$account = $GLOBALS['phpgw']->accounts->get(abs($data['user_id']));
+				$contact_id = $account->person_id;
+
+				$data['filter_role_on_contact'] = $contact_id;
+			}
+
+			$locations = $this->read($data);
+			foreach ($locations as & $location)
+			{
+				$responsible_item = $soresponsible->get_active_responsible_at_location($location['location_code'], $data['role_id']);
+				$location['responsible_item'] = $responsible_item['id'];
+				$location['responsible_contact'] = $contacts->get_name_of_person_id($responsible_item['contact_id']);
+				$location['responsible_contact_id'] = $responsible_item['contact_id'];
+			}
+
+			//_debug_array($locations);
+
+			return $locations;
 		}
 
 		function read_single($data='',$extra=array())
@@ -672,7 +726,7 @@
 				$location_code = $data;
 			}
 
-			$location_array = split('-',$location_code);
+			$location_array = explode('-',$location_code);
 			$type_id= count($location_array);
 
 			if (!$type_id)
@@ -690,7 +744,7 @@
 			{
 				$values = $this->so->read_single($location_code);
 			}
-			
+
 
 			if( isset($extra['tenant_id']) && $extra['tenant_id']!='lookup')
 			{
@@ -754,13 +808,13 @@
 		}
 
 		/**
-		* Arrange attributes within groups
-		*
-		* @param string  $location    the name of the location of the attribute
-		* @param array   $attributes  the array of the attributes to be grouped
-		*
-		* @return array the grouped attributes
-		*/
+		 * Arrange attributes within groups
+		 *
+		 * @param string  $location    the name of the location of the attribute
+		 * @param array   $attributes  the array of the attributes to be grouped
+		 *
+		 * @return array the grouped attributes
+		 */
 
 		public function get_attribute_groups($location, $attributes = array())
 		{
@@ -794,11 +848,11 @@
 			}
 
 			$criteria = array
-			(
-				'appname'	=> 'property',
-				'location'	=> ".location.{$type_id}",
-				'allrows'	=> true
-			);
+				(
+					'appname'	=> 'property',
+					'location'	=> ".location.{$type_id}",
+					'allrows'	=> true
+				);
 
 			$custom_functions = $GLOBALS['phpgw']->custom_functions->find($criteria);
 
@@ -844,7 +898,7 @@
 		function read_summary($data=array())
 		{
 			$summary = $this->so->read_summary(array('filter' => $this->filter,'type_id' => isset($data['type_id'])?$data['type_id']:'',
-								'district_id'=>$this->district_id,'part_of_town_id'=>$this->part_of_town_id));
+				'district_id'=>$this->district_id,'part_of_town_id'=>$this->part_of_town_id));
 			$this->uicols = $this->so->uicols;
 			return $summary;
 
