@@ -24,13 +24,14 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.boproject.inc.php 6294 2010-09-01 10:41:59Z sigurd $
+ 	* @version $Id: class.boproject.inc.php 7112 2011-03-11 12:46:45Z sigurdne $
 	*/
 
 	/**
 	 * Description
 	 * @package property
 	 */
+	phpgw::import_class('phpgwapi.datetime');
 
 	class property_boproject
 	{
@@ -42,13 +43,13 @@
 		var $cat_id;
 
 		var $public_functions = array
-		(
-			'read'				=> true,
-			'read_single'		=> true,
-			'save'				=> true,
-			'delete'			=> true,
-			'check_perms'		=> true
-		);
+			(
+				'read'				=> true,
+				'read_single'		=> true,
+				'save'				=> true,
+				'delete'			=> true,
+				'check_perms'		=> true
+			);
 
 		function property_boproject($session=false)
 		{
@@ -65,29 +66,60 @@
 				$this->use_session = true;
 			}
 
-			$start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
-			$query	= phpgw::get_var('query');
-			$sort	= phpgw::get_var('sort');
-			$order	= phpgw::get_var('order');
-			$filter	= phpgw::get_var('filter', 'int');
-			$cat_id	= phpgw::get_var('cat_id', 'int');
-			$status_id	= phpgw::get_var('status_id');
-			$user_id	= phpgw::get_var('user_id', 'int');
-			$wo_hour_cat_id	= phpgw::get_var('wo_hour_cat_id', 'int');
-			$district_id	= phpgw::get_var('district_id', 'int');
-			$criteria_id	= phpgw::get_var('criteria_id', 'int');
+			$start					= phpgw::get_var('start', 'int', 'REQUEST', 0);
+			$query					= phpgw::get_var('query');
+			$sort					= phpgw::get_var('sort');
+			$order					= phpgw::get_var('order');
+			$filter					= phpgw::get_var('filter', 'int');
+			$cat_id					= phpgw::get_var('cat_id', 'int');
+			$status_id				= phpgw::get_var('status_id');
+			$user_id				= phpgw::get_var('user_id', 'int');
+			$wo_hour_cat_id			= phpgw::get_var('wo_hour_cat_id', 'int');
+			$district_id			= phpgw::get_var('district_id', 'int');
+			$criteria_id			= phpgw::get_var('criteria_id', 'int');
 
 			$this->start			= $start ? $start : 0;
-			$this->query			= isset($query) ? $query : $this->query;
-			$this->sort				= isset($sort) && $sort ? $sort : '';
-			$this->order			= isset($order) && $order ? $order : '';
-			$this->filter			= isset($filter) && $filter ? $filter : '';
-			$this->cat_id			= isset($cat_id) && $cat_id ? $cat_id : '';
-			$this->status_id		= isset($status_id) && $status_id ? $status_id : '';
-			$this->user_id			= isset($user_id) && $user_id ? $user_id : '';
-			$this->wo_hour_cat_id	= isset($wo_hour_cat_id) && $wo_hour_cat_id ? $wo_hour_cat_id : '';
-			$this->district_id		= isset($district_id) && $district_id ? $district_id : '';
-			$this->criteria_id		= isset($criteria_id) && $criteria_id ? $criteria_id : '';
+
+			if(isset($_POST['query']) || isset($_GET['query']))
+			{
+				$this->query = $query;
+			}
+			if(isset($_POST['sort']) || isset($_GET['sort']))
+			{
+				$this->sort = $sort;
+			}
+			if(isset($_POST['order']) || isset($_GET['order']))
+			{
+				$this->order = $order;
+			}
+			if(isset($_POST['filter']) || isset($_GET['filter']))
+			{
+				$this->filter = $filter;
+			}
+			if(isset($_POST['cat_id']) || isset($_GET['cat_id']))
+			{
+				$this->cat_id = $cat_id;
+			}
+			if(isset($_POST['status_id']) || isset($_GET['status_id']))
+			{
+				$this->status_id = $status_id;
+			}
+			if(isset($_POST['user_id']) || isset($_GET['user_id']))
+			{
+				$this->user_id = $user_id;
+			}
+			if(isset($_POST['wo_hour_cat_id']) || isset($_GET['wo_hour_cat_id']))
+			{
+				$this->wo_hour_cat_id = $wo_hour_cat_id;
+			}
+			if(isset($_POST['district_id']) || isset($_GET['district_id']))
+			{
+				$this->district_id = $district_id;
+			}
+			if(isset($_POST['criteria_id']) || isset($_GET['criteria_id']))
+			{
+				$this->criteria_id = $criteria_id;
+			}
 		}
 
 		function save_sessiondata($data)
@@ -115,33 +147,71 @@
 			$this->criteria_id		= isset($data['criteria_id'])?$data['criteria_id']:'';
 		}
 
-		function column_list($selected = array(),$type_id='',$allrows='')
+		function column_list($selected = array())
 		{
 			if(!$selected)
 			{
 				$selected = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns']) ? $GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns'] : '';
 			}
-			$filter = array('list' => ''); // translates to "list IS NULL"
+			$columns	= $this->get_column_list();
+			return $this->bocommon->select_multi_list($selected,$columns);
+		}
+
+		function get_column_list()
+		{
 			$columns = array();
-			$columns[] = array
-			(
-				'id' => 'billable_hours',
-				'name'=> lang('billable hours')
-			);
-			$column_list=$this->bocommon->select_multi_list($selected,$columns);
-			return $column_list;
+			$columns['planned_cost'] = array
+				(
+					'id'		=> 'planned_cost',
+					'name'		=> lang('planned cost'),
+					'sortable'	=> false,
+					'formatter'	=> 'myFormatCount2',
+					'classname'	=> 'rightClasss'
+				);
+			$columns['ecodimb'] = array
+				(
+					'id'		=> 'ecodimb',
+					'name'		=> lang('accounting dim b'),
+					'sortable'	=> true
+				);
+			$columns['entry_date'] = array
+				(
+					'id'		=> 'entry_date',
+					'name'		=> lang('entry date'),
+					'sortable'	=> true
+				);
+			$columns['start_date'] = array
+				(
+					'id'		=> 'start_date',
+					'name'		=> lang('start date'),
+					'sortable'	=> true
+				);
+			$columns['end_date'] = array
+				(
+					'id'		=> 'end_date',
+					'name'		=> lang('end date'),
+					'sortable'	=> true
+				);
+			$columns['billable_hours'] = array
+				(
+					'id'		=> 'billable_hours',
+					'name'		=> lang('billable hours'),
+					'sortable'	=> true
+				);
+
+			return $columns;
 		}
 
 		function select_status_list($format='',$selected='')
 		{
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('status_select'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('status_filter'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('status_select'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('status_filter'));
+				break;
 			}
 
 			$status_entries= $this->so->select_status_list();
@@ -184,7 +254,7 @@
 					unset($branch_list[$i]['selected']);
 				}
 			}
-		*/
+		 */
 
 			return $branch_list;
 		}
@@ -192,38 +262,49 @@
 		function get_criteria_list($selected='')
 		{
 			$criteria = array
-			(
-				array
 				(
-					'id'	=> '1',
-					'name'	=> lang('project group')
-				),
-				array
-				(
-					'id'	=> '2',
-					'name'	=> lang('project id')
-				),
-				array
-				(
-					'id'	=> '3',
-					'name'	=> lang('address')
-				),
-				array
-				(
-					'id'	=> '4',
-					'name'	=> lang('location code')
-				),
-				array
-				(
-					'id'	=> '5',
-					'name'	=> lang('title')
-				),
-				array
-				(
-					'id'	=> '6',
-					'name'	=> lang('module')
-				),
-			);
+					array
+					(
+						'id'	=> '1',
+						'name'	=> lang('project group')
+					),
+					array
+					(
+						'id'	=> '2',
+						'name'	=> lang('project id')
+					),
+					array
+					(
+						'id'	=> '3',
+						'name'	=> lang('address')
+					),
+					array
+					(
+						'id'	=> '4',
+						'name'	=> lang('location code')
+					),
+					array
+					(
+						'id'	=> '5',
+						'name'	=> lang('title')
+					),
+					array
+					(
+						'id'	=> '6',
+						'name'	=> lang('module')
+					),
+					array
+					(
+						'id'	=> '7',
+						'name'	=> lang('accounting dim b')
+					),
+					array
+					(
+						'id'	=> '8',
+						'name'	=> lang('budget account group')
+					)
+				);
+
 			return $this->bocommon->select_list($selected,$criteria);
 		}
 
@@ -232,53 +313,69 @@
 		{
 			$criteria = array();
 			$criteria[1] = array
-			(
-				'field'		=> 'project_group',
-				'type'		=> 'int',
-				'matchtype' => 'exact',
-				'front' => '',
-				'back' => ''
-			);
+				(
+					'field'		=> 'project_group',
+					'type'		=> 'int',
+					'matchtype' => 'exact',
+					'front' => '',
+					'back' => ''
+				);
 			$criteria[2] = array
-			(
-				'field'		=> 'fm_project.id',
-				'type'		=> 'int',
-				'matchtype' => 'exact',
-				'front' => '',
-				'back' => ''
-			);
+				(
+					'field'		=> 'fm_project.id',
+					'type'		=> 'int',
+					'matchtype' => 'exact',
+					'front' => '',
+					'back' => ''
+				);
 			$criteria[3] = array
-			(
-				'field'	=> 'fm_project.address',
-				'type'	=> 'varchar',
-				'matchtype' => 'like',
-				'front' => "'%",
-				'back' => "%'",
-			);
+				(
+					'field'	=> 'fm_project.address',
+					'type'	=> 'varchar',
+					'matchtype' => 'like',
+					'front' => "'%",
+					'back' => "%'",
+				);
 			$criteria[4] = array
-			(
-				'field'	=> 'fm_project.location_code',
-				'type'	=> 'varchar',
-				'matchtype' => 'like',
-				'front' => "'",
-				'back' => "%'"
-			);
+				(
+					'field'	=> 'fm_project.location_code',
+					'type'	=> 'varchar',
+					'matchtype' => 'like',
+					'front' => "'",
+					'back' => "%'"
+				);
 			$criteria[5] = array
-			(
-				'field'	=> 'fm_project.name',
-				'type'	=> 'varchar',
-				'matchtype' => 'like',
-				'front' => "'%",
-				'back' => "%'"
-			);
+				(
+					'field'	=> 'fm_project.name',
+					'type'	=> 'varchar',
+					'matchtype' => 'like',
+					'front' => "'%",
+					'back' => "%'"
+				);
 			$criteria[6] = array
-			(
-				'field'	=> 'fm_project.p_num',
-				'type'	=> 'varchar',
-				'matchtype' => 'exact',
-				'front' => "'",
-				'back' => "'"
-			);
+				(
+					'field'	=> 'fm_project.p_num',
+					'type'	=> 'varchar',
+					'matchtype' => 'exact',
+					'front' => "'",
+					'back' => "'"
+				);
+			$criteria[7] = array
+				(
+					'field'	=> 'fm_project.ecodimb',
+					'type'	=> 'int',
+					'matchtype' => 'exact',
+					'front' => '',
+					'back' => ''
+				);
+			$criteria[8] = array
+				(
+					'field'	=> 'fm_project.account_group',
+					'type'	=> 'int',
+					'matchtype' => 'exact',
+					'front' => '',
+					'back' => ''
+				);
 
 			if($id)
 			{
@@ -304,14 +401,32 @@
 			$end_date	= $this->bocommon->date_to_timestamp($data['end_date']);
 
 			$project = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'filter' => $this->filter,'cat_id' => $this->cat_id,'status_id' => $this->status_id,'wo_hour_cat_id' => $this->wo_hour_cat_id,
-											'start_date'=>$start_date,'end_date'=>$end_date,'allrows'=>isset($data['allrows']) ? $data['allrows'] : '','dry_run' => $data['dry_run'],
-											'district_id' => $this->district_id, 'criteria' => $this->get_criteria($this->criteria_id)));
+				'filter' => $this->filter,'cat_id' => $this->cat_id,'status_id' => $this->status_id,'wo_hour_cat_id' => $this->wo_hour_cat_id,
+				'start_date'=>$start_date,'end_date'=>$end_date,'allrows'=>isset($data['allrows']) ? $data['allrows'] : '','dry_run' => $data['dry_run'],
+				'district_id' => $this->district_id, 'criteria' => $this->get_criteria($this->criteria_id)));
 			$this->total_records = $this->so->total_records;
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
 			$this->uicols	= $this->so->uicols;
+
+			$custom_cols = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns'] : array();
+			$column_list = $this->get_column_list();
+
+			foreach ($custom_cols as $col_id)
+			{
+				$this->uicols['input_type'][]	= 'text';
+				$this->uicols['name'][]			= $col_id;
+				$this->uicols['descr'][]		= $column_list[$col_id]['name'];
+				$this->uicols['statustext'][]	= $column_list[$col_id]['name'];
+				$this->uicols['exchange'][]		= false;
+				$this->uicols['align'][] 		= '';
+				$this->uicols['datatype'][]		= false;
+				$this->uicols['sortable'][]		= $column_list[$col_id]['sortable'];
+				$this->uicols['formatter'][]	= $column_list[$col_id]['formatter'];
+				$this->uicols['classname'][]	= $column_list[$col_id]['classname'];
+			}
+
 			if(!isset($data['skip_origin']) || !$data['skip_origin'])
 			{
 				$this->uicols['input_type'][]	= 'text';
@@ -323,40 +438,29 @@
 				$this->uicols['datatype'][]		= 'link';
 			}
 
-			$custom_cols = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns'] : array();
-
-			foreach ($custom_cols as $col)
-			{
-				$this->uicols['input_type'][]	= 'text';
-				$this->uicols['name'][]			= $col;
-				$this->uicols['descr'][]		= lang(str_replace('_', ' ', $col));
-				$this->uicols['statustext'][]	= $col;
-				$this->uicols['exchange'][]		= false;
-				$this->uicols['align'][] 		= '';
-				$this->uicols['datatype'][]		= false;
-			}
-
 			$cols_extra		= $this->so->cols_extra;
 
 			foreach ($project as & $entry)
 			{
+				$entry['entry_date'] = $GLOBALS['phpgw']->common->show_date($entry['entry_date'],$dateformat);
 				$entry['start_date'] = $GLOBALS['phpgw']->common->show_date($entry['start_date'],$dateformat);
+				$entry['end_date'] = $GLOBALS['phpgw']->common->show_date($entry['end_date'],$dateformat);
 				if(!isset($data['skip_origin']) || !$data['skip_origin'])
 				{
 					$origin = $this->interlink->get_relation('property', '.project', $entry['project_id'], 'origin');
 					if(isset($origin[0]['location']) && $origin[0]['location'] == '.ticket')
 					{
 						$entry['ticket'] = array
-										(
-											'url' 			=> $GLOBALS['phpgw']->link('/index.php', array
-																(
-																	'menuaction'	=> 'property.uitts.view',
-																	'id'			=> $origin[0]['data'][0]['id']
-																)
-															),
-											'text'			=> $origin[0]['data'][0]['id'],
-											'statustext'	=> $origin[0]['data'][0]['statustext'],											
-										);
+							(
+								'url' 			=> $GLOBALS['phpgw']->link('/index.php', array
+								(
+									'menuaction'	=> 'property.uitts.view',
+									'id'			=> $origin[0]['data'][0]['id']
+								)
+							),
+							'text'			=> $origin[0]['data'][0]['id'],
+							'statustext'	=> $origin[0]['data'][0]['statustext'],											
+						);
 					}
 				}
 			}
@@ -365,8 +469,8 @@
 
 		function read_single($project_id = 0, $values = array(), $view = false)
 		{
-			$contacts		= CreateObject('property.soactor');
-			$contacts->role='vendor';
+			$contacts	= CreateObject('property.sogeneric');
+			$contacts->get_location_info('vendor',false);
 
 			$config				= CreateObject('phpgwapi.config','property');
 			$config->read();
@@ -402,7 +506,9 @@
 				$sum_workorder_calculation= $sum_workorder_calculation+$workorder_data[$i]['calculation'];
 				$sum_workorder_actual_cost= $sum_workorder_actual_cost+$workorder_data[$i]['act_mtrl_cost']+$workorder_data[$i]['act_vendor_cost'];
 
+				$values['workorder_budget'][$i]['title']=$workorder_data[$i]['title'];
 				$values['workorder_budget'][$i]['workorder_id']=$workorder_data[$i]['workorder_id'];
+				$values['workorder_budget'][$i]['contract_sum']=number_format($workorder_data[$i]['contract_sum'], 2, ',', '');
 				$values['workorder_budget'][$i]['budget']=number_format($workorder_data[$i]['budget'], 2, ',', '');
 				$values['workorder_budget'][$i]['calculation']=number_format($workorder_data[$i]['calculation']*$tax, 2, ',', '');
 				$values['workorder_budget'][$i]['charge_tenant'] = $workorder_data[$i]['charge_tenant'];
@@ -414,7 +520,7 @@
 				{
 					$vendor['attributes'] = $this->custom->find('property','.vendor', 0, '', 'ASC', 'attrib_sort', true, true);
 
-					$vendor	= $contacts->read_single($workorder_data[$i]['vendor_id'], $vendor);
+					$vendor	= $contacts->read_single(array('id' => $workorder_data[$i]['vendor_id']), $vendor);
 					foreach($vendor['attributes'] as $attribute)
 					{
 						if($attribute['name']=='org_name')
@@ -468,7 +574,7 @@
 			$values['origin'] = $this->interlink->get_relation('property', '.project', $project_id, 'origin');
 			$values['target'] = $this->interlink->get_relation('property', '.project', $project_id, 'target');
 
-//_debug_array($values);
+			//_debug_array($values);
 			return $values;
 		}
 
@@ -500,7 +606,7 @@
 				unset($project['location_data']['first_name']);
 			}
 
-//_debug_array($project);
+			//_debug_array($project);
 			return $project;
 		}
 
@@ -518,29 +624,69 @@
 
 				switch ($value['status'])
 				{
-					case 'B': $type = lang('Budget'); break;
-					case 'BR': $type = lang('reserve'); break;
-					case 'R': $type = lang('Re-opened'); break;
-					case 'RM': $type = lang('remark'); break;
-					case 'X': $type = lang('Closed');    break;
-					case 'O': $type = lang('Opened');    break;
-					case 'A': $type = lang('Re-assigned'); break;
-					case 'P': $type = lang('Priority changed'); break;
-					case 'CO': $type = lang('Initial Coordinator'); break;
-					case 'C': $type = lang('Coordinator changed'); break;
-					case 'TO': $type = lang('Initial Category'); break;
-					case 'T': $type = lang('Category changed'); break;
-					case 'SO': $type = lang('Initial Status'); break;
-					case 'S': $type = lang('Status changed'); break;
-					case 'SC': $type = lang('Status confirmed'); break;
-					case 'AP': $type = lang('Ask for approval'); break;
-					case 'ON': $type = lang('Owner notified'); break;
-					default: break;
+				case 'B':
+					$type = lang('Budget');
+					break;
+				case 'BR':
+					$type = lang('reserve');
+					break;
+				case 'R':
+					$type = lang('Re-opened');
+					break;
+				case 'RM':
+					$type = lang('remark');
+					break;
+				case 'X':
+					$type = lang('Closed');
+					break;
+				case 'O':
+					$type = lang('Opened');
+					break;
+				case 'A':
+					$type = lang('Re-assigned');
+					break;
+				case 'P':
+					$type = lang('Priority changed');
+					break;
+				case 'CO':
+					$type = lang('Initial Coordinator');
+					break;
+				case 'C':
+					$type = lang('Coordinator changed');
+					break;
+				case 'TO':
+					$type = lang('Initial Category');
+					break;
+				case 'T':
+					$type = lang('Category changed');
+					break;
+				case 'SO':
+					$type = lang('Initial Status');
+					break;
+				case 'S':
+					$type = lang('Status changed');
+					break;
+				case 'SC':
+					$type = lang('Status confirmed');
+					break;
+				case 'AP':
+					$type = lang('Ask for approval');
+					break;
+				case 'ON':
+					$type = lang('Owner notified');
+					break;
+				default:
+					break;
 				}
 
-				if($value['new_value']=='O'){$value['new_value']=lang('Opened');}
-				if($value['new_value']=='X'){$value['new_value']=lang('Closed');}
-
+				if($value['new_value']=='O')
+				{
+					$value['new_value']=lang('Opened');
+				}
+				if($value['new_value']=='X')
+				{
+					$value['new_value']=lang('Closed');
+				}
 
 				$record_history[$i]['value_action']	= $type?$type:'';
 				unset($type);
@@ -616,7 +762,7 @@
 		function save($project,$action='',$values_attribute = array())
 		{
 
-//_debug_array($project);
+			//_debug_array($project);
 			while (is_array($project['location']) && list(,$value) = each($project['location']))
 			{
 				if($value)
@@ -627,11 +773,8 @@
 
 			$project['location_code']=implode("-", $location);
 
-			$start_date	= $this->bocommon->date_array($project['start_date']);
-			$end_date	= $this->bocommon->date_array($project['end_date']);
-
-			$project['start_date']	= mktime (2,0,0,$start_date['month'],$start_date['day'],$start_date['year']);
-			$project['end_date']	= $end_date ? mktime (2,0,0,$end_date['month'],$end_date['day'],$end_date['year']) : '';
+			$project['start_date']	=  phpgwapi_datetime::date_to_timestamp($project['start_date']);
+			$project['end_date']	=  phpgwapi_datetime::date_to_timestamp($project['end_date']);
 
 			if(is_array($values_attribute))
 			{
@@ -640,7 +783,7 @@
 
 			if ($action=='edit')
 			{
-					$receipt = $this->so->edit($project, $values_attribute);
+				$receipt = $this->so->edit($project, $values_attribute);
 			}
 			else
 			{
@@ -661,4 +804,3 @@
 		}
 
 	}
-
