@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.bos_agreement.inc.php 5148 2010-04-08 13:42:11Z sigurd $
+ 	* @version $Id: class.bos_agreement.inc.php 7498 2011-08-12 08:52:29Z sigurdne $
 	*/
 
 	/**
@@ -45,24 +45,24 @@
 		var $uicols = array();
 
 		/**
-		* @var object $custom reference to custom fields object
-		*/
+		 * @var object $custom reference to custom fields object
+		 */
 		public $custom;
 
 		var $public_functions = array
-		(
-			'read'				=> true,
-			'read_single'		=> true,
-			'save'				=> true,
-			'delete'			=> true,
-			'check_perms'		=> true
-		);
+			(
+				'read'				=> true,
+				'read_single'		=> true,
+				'save'				=> true,
+				'delete'			=> true,
+				'check_perms'		=> true
+			);
 
 		function property_bos_agreement($session=false)
 		{
-			$this->so			= CreateObject('property.sos_agreement');
-			$this->bocommon		= CreateObject('property.bocommon');
-			$this->custom 		= createObject('property.custom_fields');
+			$this->so					= CreateObject('property.sos_agreement');
+			$this->bocommon				= CreateObject('property.bocommon');
+			$this->custom 				= createObject('property.custom_fields');
 			$this->cats					= CreateObject('phpgwapi.categories', -1,  'property', '.vendor');
 			$this->cats->supress_info	= true;
 
@@ -72,30 +72,34 @@
 				$this->use_session = true;
 			}
 
-			$start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
-			$query	= phpgw::get_var('query');
-			$sort	= phpgw::get_var('sort');
-			$order	= phpgw::get_var('order');
-			$filter	= phpgw::get_var('filter', 'int');
-			$cat_id	= phpgw::get_var('cat_id', 'int');
-			$vendor_id	= phpgw::get_var('vendor_id', 'int');
-			$allrows	= phpgw::get_var('allrows', 'bool');
-			$role	= phpgw::get_var('role');
-			$member_id	= phpgw::get_var('member_id', 'int');
+			$start				= phpgw::get_var('start', 'int', 'REQUEST', 0);
+			$query				= phpgw::get_var('query');
+			$sort				= phpgw::get_var('sort');
+			$order				= phpgw::get_var('order');
+			$filter				= phpgw::get_var('filter', 'int');
+			$cat_id				= phpgw::get_var('cat_id', 'int');
+			$vendor_id			= phpgw::get_var('vendor_id', 'int');
+			$allrows			= phpgw::get_var('allrows', 'bool');
+			$role				= phpgw::get_var('role');
+			$member_id			= phpgw::get_var('member_id', 'int');
+			$status_id	= phpgw::get_var('status_id', 'int');
 
+			$this->p_num		= phpgw::get_var('p_num');
 
-			$this->role	= $role;
-			$this->so->role	= $role;
+			$this->role			= $role;
+			$this->so->role		= $role;
 
-			$this->start			= $start ? $start : 0;
-			$this->query			= isset($query) ? $query : $this->query;
-			$this->sort				= isset($sort) && $sort ? $sort : '';
-			$this->order			= isset($order) && $order ? $order : '';
-			$this->filter			= isset($filter) && $filter ? $filter : '';
-			$this->cat_id			= isset($cat_id) && $cat_id ? $cat_id : '';
-			$this->member_id		= isset($member_id) && $member_id ? $member_id : '';
-			$this->vendor_id		= isset($vendor_id) && $vendor_id ? $vendor_id : '';
-			$this->allrows			= isset($allrows) && $allrows ? $allrows : '';
+			$this->status_id		= isset($_REQUEST['status_id'])	? $status_id	: $this->status_id;
+			$this->start			= isset($_REQUEST['start']) 	? $start		: $this->start;
+			$this->order			= isset($_REQUEST['order']) 	? $order		: $this->order;
+			$this->sort				= isset($_REQUEST['sort']) 		? $sort			: $this->sort;
+			$this->query			= isset($_REQUEST['query']) 	? $query		: $this->query;
+			$this->vendor_id		= isset($_REQUEST['vendor_id'])	? $vendor_id	: $this->vendor_id;
+			$this->member_id		= isset($_REQUEST['member_id']) ? $member_id	: $this->member_id;
+			$this->cat_id			= isset($_REQUEST['cat_id']) 	? $cat_id		: $this->cat_id;
+
+			$this->filter			= $filter ? $filter : '';
+			$this->allrows			= $allrows ? $allrows : '';
 		}
 
 		function save_sessiondata($data)
@@ -120,7 +124,7 @@
 			$this->cat_id	= isset($data['cat_id']) ? $data['cat_id'] : '';
 			$this->vendor_id= isset($data['vendor_id']) ? $data['vendor_id'] : '';
 			$this->member_id= isset($data['member_id']) ? $data['member_id'] : '';
-			$this->allrows	= isset($data['allrows']) ? $data['allrows'] : '';
+			$this->status_id= $data['status_id'];
 		}
 
 		function check_perms($has, $needed)
@@ -132,12 +136,12 @@
 		{
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('select_vendor'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('filter_vendor'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('select_vendor'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('filter_vendor'));
+				break;
 			}
 
 			$input_list= $this->so->select_vendor_list();
@@ -146,34 +150,61 @@
 			return $vendor_list;
 		}
 
+		//FIXME
+		function select_status_list($format='',$selected='')
+		{
+			$status_list = array();
+			$attrib_data = $this->custom->find('property', '.s_agreement', 0, '', 'ASC', 'attrib_sort', true, true);
+			foreach ( $attrib_data as $attrib )
+			{
+				if($attrib['datatype'] == 'LB' && $attrib['column_name'] == 'status')
+				{
+					foreach($attrib['choice'] as $choice)
+					{
+						$status_list[]  = array
+						(
+							'id' 	=> $choice['id'],
+							'name'	=> htmlspecialchars($choice['value'], ENT_QUOTES, 'UTF-8'),
+						);
+					}
+				}
+			}
+			return $status_list;
+		}
+
 		function read()
 		{
-			$s_agreement = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
-											'vendor_id'=>$this->vendor_id));
+			$s_agreements = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
+				'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
+				'vendor_id'=>$this->vendor_id, 'p_num' => $this->p_num, 'status_id'=>$this->status_id));
 			$this->total_records = $this->so->total_records;
 
 			$this->uicols	= $this->so->uicols;
 
-			for ($i=0; $i<count($s_agreement); $i++)
+			foreach ($s_agreements as &$s_agreement)
 			{
-				if($s_agreement[$i]['start_date'])
+				if($s_agreement['start_date'])
 				{
-					$s_agreement[$i]['start_date']  = $GLOBALS['phpgw']->common->show_date($s_agreement[$i]['start_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
+					$s_agreement['start_date']  = $GLOBALS['phpgw']->common->show_date($s_agreement['start_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 				}
-				if($s_agreement[$i]['end_date'])
+				if($s_agreement['termination_date'])
 				{
-					$s_agreement[$i]['end_date']  = $GLOBALS['phpgw']->common->show_date($s_agreement[$i]['end_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
+					$s_agreement['termination_date']  = $GLOBALS['phpgw']->common->show_date($s_agreement['termination_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
+				}
+
+				if($s_agreement['end_date'])
+				{
+					$s_agreement['end_date']  = $GLOBALS['phpgw']->common->show_date($s_agreement['end_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 				}
 			}
-			return $s_agreement;
+			return $s_agreements;
 		}
 
 		function read_details($id)
 		{
 			$list = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
-											's_agreement_id'=>$id,'detail'=>true));
+				'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
+				's_agreement_id'=>$id,'detail'=>true));
 			$this->total_records = $this->so->total_records;
 
 			$this->uicols	= $this->so->uicols;
@@ -233,8 +264,8 @@
 			$vfs->override_acl = 1;
 
 			$values['files'] = $vfs->ls (array(
-			     'string' => "/property/service_agreement/{$data['s_agreement_id']}",
-			     'relatives' => array(RELATIVE_NONE)));
+				'string' => "/property/service_agreement/{$data['s_agreement_id']}",
+				'relatives' => array(RELATIVE_NONE)));
 
 			$vfs->override_acl = 0;
 
@@ -256,7 +287,7 @@
 			}
 			$values = $this->custom->prepare($values, 'property', '.s_agreement.detail');
 
-//_debug_array($item);
+			//_debug_array($item);
 
 			if($values['location_code'])
 			{
@@ -279,13 +310,13 @@
 		}
 
 		/**
-		* Arrange attributes within groups
-		*
-		* @param string  $location    the name of the location of the attribute
-		* @param array   $attributes  the array of the attributes to be grouped
-		*
-		* @return array the grouped attributes
-		*/
+		 * Arrange attributes within groups
+		 *
+		 * @param string  $location    the name of the location of the attribute
+		 * @param array   $attributes  the array of the attributes to be grouped
+		 *
+		 * @return array the grouped attributes
+		 */
 
 		public function get_attribute_groups($location, $attributes = array())
 		{
@@ -305,7 +336,6 @@
 			}
 
 			if ($action=='edit')
-//			if ($values['s_agreement_id'])
 			{
 				if ($values['s_agreement_id'] != 0)
 				{
@@ -368,11 +398,11 @@
 			}
 
 			$values = array(
-			'extra' 			=> $import_data,
-			's_agreement_id' 	=> $id,
-			'location_code'		=> $import_data['location_code'],
-			'location_name'		=> $import_data['address'],
-			'cost'				=> $import_data['cost']
+				'extra' 			=> $import_data,
+				's_agreement_id' 	=> $id,
+				'location_code'		=> $import_data['location_code'],
+				'location_name'		=> $import_data['address'],
+				'cost'				=> $import_data['cost']
 			);
 			unset($values['extra']['location_code']);
 			unset($values['extra']['address']);
@@ -419,16 +449,16 @@
 
 		function request_next_id()
 		{
-				return $this->so->request_next_id();
+			return $this->so->request_next_id();
 		}
 
 		function read_attrib_history($data)
 		{
-		//	_debug_array($data);
+			//	_debug_array($data);
 			$historylog = CreateObject('property.historylog','s_agreement');
 			$history_values = $historylog->return_array(array(),array('SO'),'history_timestamp','ASC',$data['id'],$data['attrib_id'],$data['item_id']);
 			$this->total_records = count($history_values);
-		//	_debug_array($history_values);
+			//	_debug_array($history_values);
 			return $history_values;
 		}
 
@@ -448,9 +478,9 @@
 			{
 				$list = array();
 			}
-			$year = date('Y');
-			$limit = $year + 4;
-			
+			$year	= date('Y');
+			$limit	= $year + 4;
+
 			while ($year < $limit)
 			{
 				$list[] =  $year;
@@ -459,15 +489,15 @@
 
 			$list = array_unique($list);
 			sort($list);
-			
+
 			$values;
 			foreach($list as $entry)
 			{
 				$values[] = array
-				(
-					'id'	=> $entry,
-					'name'	=> $entry
-				);
+					(
+						'id'	=> $entry,
+						'name'	=> $entry
+					);
 			}
 			return $values;
 		}
