@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.botts.inc.php 6378 2010-09-22 09:01:32Z sigurd $
+ 	* @version $Id: class.botts.inc.php 7227 2011-04-15 11:51:34Z sigurdne $
 	*/
 
 	/**
@@ -49,32 +49,16 @@
 		var $user_id;
 		var $part_of_town_id;
 		var $district_id;
-		var $total_records;
+		public $total_records	= 0;
+		public $sum_budget		= 0;
+		public $sum_actual_cost	= 0;
 
 		var $public_functions = array
 		(
 			'read'			=> true,
-			'read_single'		=> true,
+			'read_single'	=> true,
 			'save'			=> true,
-		);
-
-		var $soap_functions = array(
-			'list' => array(
-				'in'  => array('int','int','struct','string','int'),
-				'out' => array('array')
-			),
-			'read' => array(
-				'in'  => array('int','struct'),
-				'out' => array('array')
-			),
-			'save' => array(
-				'in'  => array('int','struct'),
-				'out' => array()
-			),
-			'delete' => array(
-				'in'  => array('int','struct'),
-				'out' => array()
-			)
+			'addfiles'		=> true,
 		);
 
 		function property_botts($session=false)
@@ -109,9 +93,17 @@
 			$start_date				= phpgw::get_var('start_date', 'string');
 			$end_date				= phpgw::get_var('end_date', 'string');
 			$location_code			= phpgw::get_var('location_code');
-			
+			$vendor_id				= phpgw::get_var('vendor_id', 'int');
+			$ecodimb				= phpgw::get_var('ecodimb', 'int');
+			$b_account				= phpgw::get_var('b_account', 'string');
+			$building_part			= phpgw::get_var('building_part', 'string');
+			$branch_id				= phpgw::get_var('branch_id', 'int');
+			$order_dim1				= phpgw::get_var('order_dim1', 'int');
 
-			$this->start			= $start 							? $start 			: 0;
+
+//			$this->start			= $start 							? $start 			: 0;
+
+			$this->start			= isset($_REQUEST['start']) 		? $start			: $this->start;
 			$this->query			= isset($_REQUEST['query']) 		? $query			: $this->query;
 			$this->sort				= isset($_REQUEST['sort']) 			? $sort				: $this->sort;
 			$this->order			= isset($_REQUEST['order']) 		? $order			: $this->order;
@@ -124,8 +116,13 @@
 			$this->start_date		= isset($_REQUEST['start_date']) 	? $start_date		: $this->start_date;
 			$this->end_date			= isset($_REQUEST['end_date'])		? $end_date			: $this->end_date;
 			$this->location_code	= isset($location_code) && $location_code ? $location_code : '';
-
+			$this->vendor_id		= isset($_REQUEST['vendor_id']) 	? $vendor_id		: $this->vendor_id;
 			$this->p_num			= phpgw::get_var('p_num');
+			$this->ecodimb			= isset($_REQUEST['ecodimb']) 		? $ecodimb			: $this->ecodimb;
+			$this->b_account		= isset($_REQUEST['b_account']) 	? $b_account		: $this->b_account;
+			$this->building_part	= isset($_REQUEST['building_part']) ? $building_part	: $this->building_part;
+			$this->branch_id		= isset($_REQUEST['branch_id']) 	? $branch_id		: $this->branch_id;
+			$this->order_dim1		= isset($_REQUEST['order_dim1']) 	? $order_dim1		: $this->order_dim1;
 		}
 
 
@@ -141,17 +138,19 @@
 		{
 			$data = $GLOBALS['phpgw']->session->appsession('session_data','fm_tts');
 
-			$this->start		= isset($data['start'])?$data['start']:'';
-			$this->query		= isset($data['query'])?$data['query']:'';
-			$this->user_id		= isset($data['user_id'])?$data['user_id']:'';
-			$this->sort			= isset($data['sort'])?$data['sort']:'';
-			$this->order		= isset($data['order'])?$data['order']:'';
-			$this->status_id	= isset($data['status_id'])?$data['status_id']:'';
-			$this->cat_id		= isset($data['cat_id'])?$data['cat_id']:'';
-			$this->district_id	= isset($data['district_id'])?$data['district_id']:'';
-			$this->allrows		= isset($data['allrows'])?$data['allrows']:'';
-			$this->start_date	= isset($data['start_date'])?$data['start_date']:'';
-			$this->end_date		= isset($data['end_date'])?$data['end_date']:'';
+			$this->start			= isset($data['start'])?$data['start']:'';
+			$this->query			= isset($data['query'])?$data['query']:'';
+			$this->user_id			= isset($data['user_id'])?$data['user_id']:'';
+			$this->sort				= isset($data['sort'])?$data['sort']:'';
+			$this->order			= isset($data['order'])?$data['order']:'';
+			$this->status_id		= isset($data['status_id'])?$data['status_id']:'';
+			$this->cat_id			= isset($data['cat_id'])?$data['cat_id']:'';
+			$this->district_id		= isset($data['district_id'])?$data['district_id']:'';
+			$this->part_of_town_id	= isset($data['part_of_town_id'])?$data['part_of_town_id']:'';
+			$this->allrows			= isset($data['allrows'])?$data['allrows']:'';
+			$this->start_date		= isset($data['start_date'])?$data['start_date']:'';
+			$this->end_date			= isset($data['end_date'])?$data['end_date']:'';
+			$this->vendor_id		= isset($data['vendor_id'])?$data['vendor_id']:'';
 		}
 
 		function column_list($selected = array(),$type_id='',$allrows='')
@@ -162,16 +161,22 @@
 			}
 			$filter = array('list' => ''); // translates to "list IS NULL"
 			$columns = array();
+
 			$columns[] = array
-			(
-				'id' => 'billable_hours',
-				'name'=> lang('billable hours')
-			);
+				(
+					'id' => 'vendor',
+					'name'=> lang('vendor')
+				);
 			$columns[] = array
-			(
-				'id' => 'district',
-				'name'=> lang('district')
-			);
+				(
+					'id' => 'billable_hours',
+					'name'=> lang('billable hours')
+				);
+			$columns[] = array
+				(
+					'id' => 'district',
+					'name'=> lang('district')
+				);
 			$column_list=$this->bocommon->select_multi_list($selected,$columns);
 			return $column_list;
 		}
@@ -186,12 +191,12 @@
 
 			switch($format)
 			{
-				case 'select':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('filter_select'));
-					break;
-				case 'filter':
-					$GLOBALS['phpgw']->xslttpl->add_file(array('filter_filter'));
-					break;
+			case 'select':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('filter_select'));
+				break;
+			case 'filter':
+				$GLOBALS['phpgw']->xslttpl->add_file(array('filter_filter'));
+				break;
 			}
 
 			$_filters[0]['id']='all';
@@ -228,10 +233,10 @@
 			foreach($custom_status as $custom)
 			{
 				$status[$i] = array
-				(
-					'id'			=> "C{$custom['id']}",
-					'name'			=> $custom['name']
-				);
+					(
+						'id'			=> "C{$custom['id']}",
+						'name'			=> $custom['name']
+					);
 				$i++;
 			}
 
@@ -243,7 +248,7 @@
 			$status_text = array(
 				'R' => lang('Re-opened'),
 				'X' => lang('Closed'),
-				'O' => lang('Opened'),
+				'O' => isset($this->config->config_data['tts_lang_open']) && $this->config->config_data['tts_lang_open'] ? $this->config->config_data['tts_lang_open'] : lang('Open'),
 				'A' => lang('Re-assigned'),
 				'G' => lang('Re-assigned group'),
 				'P' => lang('Priority changed'),
@@ -253,7 +258,8 @@
 				'H' => lang('Billing hours'),
 				'F' => lang('finnish date'),
 				'SC' => lang('Status changed'),
-				'M' => lang('Sendt by email to'),
+				'M' => lang('Sent by email to'),
+				'MS' => lang('Sent by sms'),
 				'AC'=> lang('actual cost changed'),
 			);
 
@@ -278,7 +284,7 @@
 			}
 
 			$priority_comment[$prioritylevels]=' - '.lang('Lowest');
-//			$priority_comment[2]=' - '.lang('Medium');
+			//			$priority_comment[2]=' - '.lang('Medium');
 			$priority_comment[1]=' - '.lang('Highest');
 
 			$priorities = array();
@@ -310,22 +316,29 @@
 			static $category_name = array();
 			static $account = array();
 			static $vendor_cache = array();
-			
+
 			$interlink 	= CreateObject('property.interlink');
 			$start_date	= $this->bocommon->date_to_timestamp($start_date);
 			$end_date	= $this->bocommon->date_to_timestamp($end_date);
 
 			$tickets = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'status_id' => $this->status_id,'cat_id' => $this->cat_id,'district_id' => $this->district_id,
-											'start_date'=>$start_date,'end_date'=>$end_date,
-											'allrows'=>$this->allrows,'user_id' => $this->user_id,'external'=>$external, 'dry_run' => $dry_run,
-											'location_code' => $this->location_code, 'p_num' => $this->p_num));
+				'status_id' => $this->status_id,'cat_id' => $this->cat_id,'district_id' => $this->district_id,
+				'part_of_town_id' => $this->part_of_town_id, 'start_date'=>$start_date,'end_date'=>$end_date,
+				'allrows'=>$this->allrows,'user_id' => $this->user_id,'external'=>$external, 'dry_run' => $dry_run,
+				'location_code' => $this->location_code, 'p_num' => $this->p_num, 'vendor_id' => $this->vendor_id,
+				'ecodimb' => $this->ecodimb, 'b_account' => $this->b_account, 'building_part' => $this->building_part,
+				'branch_id' => $this->branch_id ,'order_dim1' => $this->order_dim1));
+
 			$this->total_records = $this->so->total_records;
+			$this->sum_budget = $this->so->sum_budget;
+			$this->sum_actual_cost = $this->so->sum_actual_cost;
+
 			if(!$external)
 			{
 				$entity	= $this->get_origin_entity_type();
-				$contacts	= CreateObject('property.soactor');
-				$contacts->role='vendor';
+				$contacts	= CreateObject('property.sogeneric');
+				$contacts->get_location_info('vendor',false);
+
 				$custom 		= createObject('property.custom_fields');
 				$vendor_data['attributes'] = $custom->find('property','.vendor', 0, '', 'ASC', 'attrib_sort', true, true);
 			}
@@ -380,7 +393,7 @@
 					}
 					else
 					{
-						 $ticket['assignedto'] = $account[$ticket['group_id']];
+						$ticket['assignedto'] = $account[$ticket['group_id']];
 					}
 				}
 
@@ -422,7 +435,7 @@
 					}
 					else
 					{
-						$vendor_data	= $contacts->read_single($ticket['vendor_id'],$vendor_data);
+						$vendor_data	= $contacts->read_single(array('id' => $ticket['vendor_id']),$vendor_data);
 						if($vendor_data)
 						{
 							foreach($vendor_data['attributes'] as $attribute)
@@ -438,7 +451,6 @@
 					}
 				}
 			}
-
 			return $tickets;
 		}
 
@@ -454,7 +466,7 @@
 			$interlink 	= CreateObject('property.interlink');
 			$ticket['origin'] = $interlink->get_relation('property', '.ticket', $id, 'origin');
 			$ticket['target'] = $interlink->get_relation('property', '.ticket', $id, 'target');
-//_debug_array($ticket);
+			//_debug_array($ticket);
 			if(isset($ticket['finnish_date2']) && $ticket['finnish_date2'])
 			{
 				$ticket['finnish_date']=$ticket['finnish_date2'];
@@ -470,7 +482,7 @@
 				$solocation 	= CreateObject('property.solocation');
 				$ticket['location_data'] = $solocation->read_single($ticket['location_code']);
 			}
-//_debug_array($ticket['location_data']);
+			//_debug_array($ticket['location_data']);
 			if($ticket['p_num'])
 			{
 				$soadmin_entity	= CreateObject('property.soadmin_entity');
@@ -525,8 +537,8 @@
 			$vfs->override_acl = 1;
 
 			$ticket['files'] = $vfs->ls (array(
-			     'string' => "/property/fmticket/{$id}",
-			     'relatives' => array(RELATIVE_NONE)));
+				'string' => "/property/fmticket/{$id}",
+				'relatives' => array(RELATIVE_NONE)));
 
 			$vfs->override_acl = 0;
 
@@ -552,13 +564,13 @@
 			foreach ($history_array as $value)
 			{
 				$additional_notes[] = array
-				(
-					'value_id'		=> $value['id'],
-					'value_count'	=> $i,
-					'value_date'	=> $GLOBALS['phpgw']->common->show_date($value['datetime']),
-					'value_user'	=> $value['owner'],
-					'value_note'	=> stripslashes($value['new_value']),
-					'value_publish'	=> $value['publish'],
+					(
+						'value_id'		=> $value['id'],
+						'value_count'	=> $i,
+						'value_date'	=> $GLOBALS['phpgw']->common->show_date($value['datetime']),
+						'value_user'	=> $value['owner'],
+						'value_note'	=> stripslashes($value['new_value']),
+						'value_publish'	=> $value['publish'],
 					);
 				$i++;
 			}
@@ -574,93 +586,92 @@
 			$record_history = array();
 			$i=0;
 
-			if (is_array($history_array))
+			foreach ($history_array as $value)
 			{
-				foreach ($history_array as $value)
-				{
-					$record_history[$i]['value_date']	= $GLOBALS['phpgw']->common->show_date($value['datetime']);
-					$record_history[$i]['value_user']	= $value['owner'];
+				$record_history[$i]['value_date']	= $GLOBALS['phpgw']->common->show_date($value['datetime']);
+				$record_history[$i]['value_user']	= $value['owner'];
 
+				switch ($value['status'])
+				{
+				case 'R': $type = lang('Re-opened'); break;
+				case 'X': $type = lang('Closed');    break;
+				case 'O': $type = lang('Opened');    break;
+				case 'A': $type = lang('Re-assigned'); break;
+				case 'G': $type = lang('Re-assigned group'); break;
+				case 'P': $type = lang('Priority changed'); break;
+				case 'T': $type = lang('Category changed'); break;
+				case 'S': $type = lang('Subject changed'); break;
+				case 'H': $type = lang('Billable hours changed'); break;
+				case 'B': $type = lang('Budget changed'); break;
+//				case 'B': $type = lang('Billable rate changed'); break;
+				case 'F': $type = lang('finnish date changed'); break;
+				case 'IF': $type = lang('Initial finnish date'); break;
+				case 'L': $type = lang('Location changed'); break;
+				case 'AC': $type = lang('actual cost changed'); break;
+				case 'M':
+					$type = lang('Sent by email to');
+					$this->order_sent_adress = $value['new_value']; // in case we want to resend the order as an reminder
+					break;
+				case 'MS':
+					$type = lang('Sent by sms');
+					break;
+				default:
+					// nothing
+				}
+
+		//		if ( $value['status'] == 'X' || $value['status'] == 'R' || (strlen($value['status']) == 2 && substr($value['new_value'], 0, 1) == 'C') ) // if custom status
+				if ( $value['status'] == 'X' || $value['status'] == 'R' || preg_match('/^C/i', $value['status']) || ( $value['status'] == 'R' && preg_match('/^C/i', $value['new_value']))) // if custom status
+				{
 					switch ($value['status'])
 					{
-						case 'R': $type = lang('Re-opened'); break;
-						case 'X': $type = lang('Closed');    break;
-						case 'O': $type = lang('Opened');    break;
-						case 'A': $type = lang('Re-assigned'); break;
-						case 'G': $type = lang('Re-assigned group'); break;
-						case 'P': $type = lang('Priority changed'); break;
-						case 'T': $type = lang('Category changed'); break;
-						case 'S': $type = lang('Subject changed'); break;
-						case 'H': $type = lang('Billable hours changed'); break;
-						case 'B': $type = lang('Budget changed'); break;
-	//					case 'B': $type = lang('Billable rate changed'); break;
-						case 'F': $type = lang('finnish date changed'); break;
-						case 'IF': $type = lang('Initial finnish date'); break;
-						case 'L': $type = lang('Location changed'); break;
-						case 'AC': $type = lang('actual cost changed'); break;
-						case 'M':
-							$type = lang('Sendt by email to');
-							$this->order_sent_adress = $value['new_value']; // in case we want to resend the order as an reminder
-							break;
-						default: break;
+					case 'R': 
+						$type = lang('Re-opened');
+						break;
+					case 'X':
+						$type = lang('Closed');
+						break;
+					default:
+						$type = lang('Status changed');
 					}
+					$value['new_value'] = $status_text[$value['new_value']];
+					$value['old_value'] = $status_text[$value['old_value']];
+				}
 
-					if ( $value['status'] == 'X' || $value['status'] == 'R' || (strlen($value['status']) == 2 && substr($value['new_value'], 0, 1) == 'C') ) // if custom status
+				$record_history[$i]['value_action']	= $type?$type:'';
+				unset($type);
+				if ($value['status'] == 'A' || $value['status'] == 'G')
+				{
+					if ((int)$value['new_value']>0)
 					{
-						switch ($value['status'])
-						{
-							case 'R': 
-								$type = lang('Re-opened');
-								break;
-							case 'X':
-								$type = lang('Closed');
-								break;
-							default:
-								$type = lang('Status changed')
-								;break;
-						}
-						
-						$value['new_value'] = $status_text[$value['new_value']];
-						$value['old_value'] = $status_text[$value['old_value']];
-					}
-
-					$record_history[$i]['value_action']	= $type?$type:'';
-					unset($type);
-					if ($value['status'] == 'A' || $value['status'] == 'G')
-					{
-						if ((int)$value['new_value']>0)
-						{
-							$record_history[$i]['value_new_value']	= $GLOBALS['phpgw']->accounts->id2name($value['new_value']);
-							$record_history[$i]['value_old_value'] = $value['old_value'] ? $GLOBALS['phpgw']->accounts->id2name($value['old_value']) : '';
-						}
-						else
-						{
-							$record_history[$i]['value_new_value']	= lang('None');
-							$record_history[$i]['value_old_value']	= lang('None');
-						}
-					}
-					else if ($value['status'] == 'T')
-					{
-						$record_history[$i]['value_new_value']	= $this->get_category_name($value['new_value']);
-						$record_history[$i]['value_old_value']	= $this->get_category_name($value['old_value']);
-					}
-					else if (($value['status'] == 'F') || ($value['status'] =='IF'))
-					{
-						$record_history[$i]['value_new_value']	= $GLOBALS['phpgw']->common->show_date($value['new_value'],$this->dateformat);
-					}
-					else if ($value['status'] != 'O' && $value['new_value'])
-					{
-						$record_history[$i]['value_new_value']	= $value['new_value'];
-						$record_history[$i]['value_old_value']	= $value['old_value'];
+						$record_history[$i]['value_new_value']	= $GLOBALS['phpgw']->accounts->id2name($value['new_value']);
+						$record_history[$i]['value_old_value'] = $value['old_value'] ? $GLOBALS['phpgw']->accounts->id2name($value['old_value']) : '';
 					}
 					else
 					{
-						$record_history[$i]['value_new_value']	= '';
-
+						$record_history[$i]['value_new_value']	= lang('None');
+						$record_history[$i]['value_old_value']	= lang('None');
 					}
-
-					$i++;
 				}
+				else if ($value['status'] == 'T')
+				{
+					$record_history[$i]['value_new_value']	= $this->get_category_name($value['new_value']);
+					$record_history[$i]['value_old_value']	= $this->get_category_name($value['old_value']);
+				}
+				else if (($value['status'] == 'F') || ($value['status'] =='IF'))
+				{
+					$record_history[$i]['value_new_value']	= $GLOBALS['phpgw']->common->show_date($value['new_value'],$this->dateformat);
+				}
+				else if ($value['status'] != 'O' && $value['new_value'])
+				{
+					$record_history[$i]['value_new_value']	= $value['new_value'];
+					$record_history[$i]['value_old_value']	= $value['old_value'];
+				}
+				else
+				{
+					$record_history[$i]['value_new_value']	= '';
+				}
+
+				$i++;
 			}
 
 			return $record_history;
@@ -688,18 +699,18 @@
 
 			if ( (isset($ticket['send_mail']) && $ticket['send_mail']) 
 				|| (isset($this->config->config_data['mailnotification'])
-					&& $this->config->config_data['mailnotification'])
-				)
+				&& $this->config->config_data['mailnotification'])
+			)
 			{
 				$receipt_mail = $this->mail_ticket($receipt['id'],false,$receipt,$ticket['location_code']);
 			}
 
 			$criteria = array
-			(
-				'appname'	=> 'property',
-				'location'	=> $this->acl_location,
-				'allrows'	=> true
-			);
+				(
+					'appname'	=> 'property',
+					'location'	=> $this->acl_location,
+					'allrows'	=> true
+				);
 
 			$custom_functions = $GLOBALS['phpgw']->custom_functions->find($criteria);
 
@@ -741,10 +752,10 @@
 				for ($i=1; $i<$type_id+1; $i++)
 				{
 					$address_element[] = array
-					(
-						'text' => $location_types[($i-1)]['name'],
-						'value'=> $location_data["loc{$i}"] . '  ' . $location_data["loc{$i}_name"]
-					);
+						(
+							'text' => $location_types[($i-1)]['name'],
+							'value'=> $location_data["loc{$i}"] . '  ' . $location_data["loc{$i}_name"]
+						);
 				}
 
 				$fm_location_cols = $custom->find('property','.location.' . $type_id, 0, '', 'ASC', 'attrib_sort', true, true);
@@ -754,17 +765,17 @@
 					if($location_entry['lookup_form'])
 					{
 						$address_element[] = array
-						(
-							'text' => $location_entry['input_text'],
-							'value'=> $location_data[$location_entry['column_name']]
-						);
+							(
+								'text' => $location_entry['input_text'],
+								'value'=> $location_data[$location_entry['column_name']]
+							);
 					}
 					$i++;
 				}
 			}
 			return $address_element;
 		}
-		
+
 		function mail_ticket($id, $fields_updated, $receipt = array(),$location_code='', $get_message = false)
 		{
 			$this->send			= CreateObject('phpgwapi.send');
@@ -795,13 +806,13 @@
 
 			$from_address=$prefs_user['email'];
 
-	//-----------from--------
+			//-----------from--------
 
 			$current_prefs_user = $this->bocommon->create_preferences('property',$GLOBALS['phpgw_info']['user']['account_id']);
 			$current_user_address = "{$GLOBALS['phpgw_info']['user']['fullname']}<{$current_prefs_user['email']}>";
 
-	//-----------from--------
-		// build body
+			//-----------from--------
+			// build body
 			$body  = '';
 			$body .= '<a href ="http://' . $GLOBALS['phpgw_info']['server']['hostname'] . $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uitts.view', 'id' => $id)).'">' . lang('Ticket').' #' .$id .'</a>'."\n";
 			$body .= lang('Date Opened').': '.$entry_date."\n";
@@ -839,8 +850,8 @@
 			$body .= stripslashes(strip_tags($ticket['details']))."\n\n";
 
 			/**************************************************************\
-			* Display additional notes                                     *
-			\**************************************************************/
+			 * Display additional notes                                     *
+			 \**************************************************************/
 			if($fields_updated)
 			{
 				$i=1;
@@ -857,8 +868,8 @@
 				$subject.= "-" .$i;
 			}
 			/**************************************************************\
-			* Display record history                                       *
-			\**************************************************************/
+			 * Display record history                                       *
+			 \**************************************************************/
 
 			if($timestampclosed)
 			{
@@ -885,9 +896,7 @@
 
 			$GLOBALS['phpgw']->preferences->set_account_id($ticket['user_id'], true);
 			if( (isset($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'])
-					&& ($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'] == 1 
-				//	&& $GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'] != 2
-					)
+					&& ($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'] == 1)
 				)
 				|| ($this->config->config_data['ownernotification'] && $ticket['user_id']))
 			{
@@ -897,12 +906,10 @@
 
 			$GLOBALS['phpgw']->preferences->set_account_id($ticket['assignedto'], true);
 			if( (isset($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'])
-					&& ($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'] == 1
-			//		&& $GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'] != 2
-					)
-				)
-					|| ($this->config->config_data['assignednotification'] && $ticket['assignedto'])
+					&& ($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'] == 1)
 				)
+				|| ($this->config->config_data['assignednotification'] && $ticket['assignedto'])
+			)
 			{
 				// add assigned to recipients
 				$members[$ticket['assignedto']] = $GLOBALS['phpgw']->accounts->id2name($ticket['assignedto']);
@@ -920,19 +927,19 @@
 				{
 					if ($validator->check_email_address($prefs['email']))
 					{
-			            // Email address is technically valid
+						// Email address is technically valid
 						// avoid problems with the delimiter in the send class
-			            if(strpos($account_name,','))
-			            {
-			            	$_account_name = explode(',', $account_name);
-			            	$account_name = ltrim($_account_name[1]) . ' ' . $_account_name[0];
-			            }
-			            
+						if(strpos($account_name,','))
+						{
+							$_account_name = explode(',', $account_name);
+							$account_name = ltrim($_account_name[1]) . ' ' . $_account_name[0];
+						}
+
 						$toarray[] = "{$account_name}<{$prefs['email']}>";
 					}
 					else
 					{
-						$receipt['error'][] = array('msg'=> lang('Your message could not be sent!'));
+//						$receipt['error'][] = array('msg'=> lang('Your message could not be sent!'));
 						$receipt['error'][] = array('msg'=>lang('This user has not defined an email address !') . ' : ' . $account_name);
 					}
 				}
@@ -960,6 +967,7 @@
 				}
 			}
 
+/*
 			if (!$rc && ($this->config->config_data['groupnotification'] || $this->config->config_data['ownernotification'] || $this->config->config_data['groupnotification']))
 			{
 				$receipt['error'][] = array('msg'=> lang('Your message could not be sent by mail!'));
@@ -975,8 +983,8 @@
 				$receipt['error'][] = array('msg'=> 'err_msg: '. htmlspecialchars($this->send->err['msg']));
 				$receipt['error'][] = array('msg'=> 'err_desc: '. $this->send->err['desc']);
 			}
-
-//_debug_array($receipt);
+*/
+			//_debug_array($receipt);
 			return $receipt;
 		}
 
@@ -986,10 +994,10 @@
 		}
 
 		/**
-		* Get a list of user(admin)-configured status
-		*
-		* @return array with list of custom status
-		*/
+		 * Get a list of user(admin)-configured status
+		 *
+		 * @return array with list of custom status
+		 */
 
 		public function get_custom_status()
 		{
@@ -1003,10 +1011,178 @@
 			return $receipt;
 		}
 
-		public function update_ticket($data, $id)
+		public function update_ticket($data, $id,$receipt = array())
 		{
-			$receipt 	= $this->so->update_ticket($data, $id);
+			$receipt = $this->so->update_ticket($data, $id, $receipt);
 			$this->fields_updated = $this->so->fields_updated;		
 			return $receipt;
 		}
+
+		public function get_vendors($selected)
+		{
+			$vendors = $this->so->get_vendors();
+			foreach ($vendors as &$vendor)
+			{
+				if($vendor['id'] == $selected)
+				{
+					$vendor['selected'] = 1;
+					break;
+				}
+			}
+
+			$default_value = array
+			(
+				'id'	=> '',
+				'name'	=> lang('vendor')
+			);
+			array_unshift($vendors,$default_value);
+			return $vendors;
+		}
+		public function get_ecodimb($selected)
+		{
+			$values = $this->so->get_ecodimb();
+			foreach ($values as &$value)
+			{
+				if($value['id'] == $selected)
+				{
+					$value['selected'] = 1;
+					break;
+				}
+			}
+
+			$default_value = array
+			(
+				'id'	=> '',
+				'name'	=> lang('dimb')
+			);
+			array_unshift($values,$default_value);
+			return $values;
+		}
+		public function get_b_account($selected)
+		{
+			$values = $this->so->get_b_account();
+			foreach ($values as &$value)
+			{
+				if($value['id'] == $selected)
+				{
+					$value['selected'] = 1;
+					break;
+				}
+			}
+
+			$default_value = array
+			(
+				'id'	=> '',
+				'name'	=> lang('budget account')
+			);
+			array_unshift($values,$default_value);
+			return $values;
+		}
+		public function get_building_part($selected)
+		{
+			$values = $this->so->get_building_part();
+			foreach ($values as &$value)
+			{
+				if($value['id'] == $selected)
+				{
+					$value['selected'] = 1;
+					break;
+				}
+			}
+
+			$default_value = array
+			(
+				'id'	=> '',
+				'name'	=> lang('building part')
+			);
+			array_unshift($values,$default_value);
+			return $values;
+		}
+		public function get_branch($selected)
+		{
+			$values = $this->so->get_branch();
+			foreach ($values as &$value)
+			{
+				if($value['id'] == $selected)
+				{
+					$value['selected'] = 1;
+					break;
+				}
+			}
+
+			$default_value = array
+			(
+				'id'	=> '',
+				'name'	=> lang('branch')
+			);
+			array_unshift($values,$default_value);
+			return $values;
+		}
+		public function get_order_dim1($selected)
+		{
+			$values = $this->so->get_order_dim1();
+			foreach ($values as &$value)
+			{
+				if($value['id'] == $selected)
+				{
+					$value['selected'] = 1;
+					break;
+				}
+			}
+
+			$default_value = array
+			(
+				'id'	=> '',
+				'name'	=> lang('order_dim1')
+			);
+			array_unshift($values,$default_value);
+			return $values;
+		}
+
+		public function addfiles()
+		{
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = false;
+			$GLOBALS['phpgw_info']['flags']['noframework'] = true;
+			$GLOBALS['phpgw_info']['flags']['nofooter'] = true;
+
+			$acl 			= & $GLOBALS['phpgw']->acl;
+			$acl_add 		= $acl->check('.ticket', PHPGW_ACL_ADD, 'property');
+			$acl_edit 		= $acl->check('.ticket', PHPGW_ACL_EDIT, 'property');
+			$id				= phpgw::get_var('id', 'int');
+			$check			= phpgw::get_var('check', 'bool');
+			$fileuploader	= CreateObject('property.fileuploader');
+
+			if(!$acl_add && !$acl_edit)
+			{
+				$GLOBALS['phpgw']->common->phpgw_exit();
+			}
+
+			if(!$id)
+			{
+				$GLOBALS['phpgw']->common->phpgw_exit();
+			}
+
+			$test = false;
+			if ($test)
+			{
+				if (!empty($_FILES))
+				{
+					$tempFile = $_FILES['Filedata']['tmp_name'];
+					$targetPath = "{$GLOBALS['phpgw_info']['server']['temp_dir']}/";
+					$targetFile =  str_replace('//','/',$targetPath) . $_FILES['Filedata']['name'];
+					move_uploaded_file($tempFile,$targetFile);
+					echo str_replace($GLOBALS['phpgw_info']['server']['temp_dir'],'',$targetFile);
+				}
+				$GLOBALS['phpgw']->common->phpgw_exit();
+			}
+	
+			if($check)
+			{
+				$fileuploader->check("fmticket/{$id}");
+			}
+			else
+			{
+				$fileuploader->upload("fmticket/{$id}");
+			}
+		}
 	}
