@@ -9,7 +9,7 @@
 	 * @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	 * @package phpgroupware
 	 * @subpackage phpgwapi
-	 * @version $Id: class.custom_fields.inc.php 6317 2010-09-08 10:58:04Z sigurd $
+	 * @version $Id: class.custom_fields.inc.php 6972 2011-02-11 09:03:26Z sigurdne $
 	 */
 
 	/*
@@ -66,18 +66,19 @@
 		public function prepare($values, $appname, $location, $view_only='')
 		{
 			$contacts		= CreateObject('phpgwapi.contacts');
-			$vendor 		= CreateObject('property.soactor');
-			$vendor->role	= 'vendor';
+			$vendor			= CreateObject('property.sogeneric');
+			$vendor->get_location_info('vendor',false);
+
 			$location_id	= $GLOBALS['phpgw']->locations->get_id($appname, $location);
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
 			$input_type_array = array
-			(
-				'R'		=> 'radio',
-				'CH'	=> 'checkbox',
-				'LB'	=> 'listbox'
-			);
+				(
+					'R'		=> 'radio',
+					'CH'	=> 'checkbox',
+					'LB'	=> 'listbox'
+				);
 
 			$m = 0;
 			$i = 0;
@@ -119,7 +120,7 @@
 					$lookup_link					= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.addressbook', 'column'=> $attributes['name']));
 
 					$lookup_functions[$m]['name']	= 'lookup_'. $attributes['name'] .'()';
-					$lookup_functions[$m]['action']	= 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+					$lookup_functions[$m]['action']	= 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","left=50,top=100,width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
 
 					$clear_functions[$m]['name']	= "clear_{$attributes['name']}()";
 					$confirm_msg = lang('delete') . '?';
@@ -140,7 +141,7 @@ JS;
 						$attributes['org_name']		= $contact_data[0]['org_name'];
 
 						$comms = $contacts->get_comm_contact_data($attributes['value'], $fields_comms='', $simple=false);
-						
+
 						$comm_data = array();
 						if(is_array($comms))
 						{
@@ -161,14 +162,14 @@ JS;
 					$lookup_link					= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.organisation', 'column'=> $attributes['name']));
 
 					$lookup_functions[$m]['name']	= 'lookup_'. $attributes['name'] .'()';
-					$lookup_functions[$m]['action']	= 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+					$lookup_functions[$m]['action']	= 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","left=50,top=100,width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
 					$m++;
 				}
 				else if($attributes['datatype'] == 'VENDOR')
 				{
 					if($attributes['value'])
 					{
-						$vendor_data	= $vendor->read_single($attributes['value'],array('attributes' => array(0 => array('column_name' => 'org_name'))));
+						$vendor_data	= $vendor->read_single(array('id' => $attributes['value']),array('attributes' => array(0 => array('column_name' => 'org_name'))));
 
 						for ($n=0;$n<count($vendor_data['attributes']);$n++)
 						{
@@ -184,7 +185,7 @@ JS;
 					$lookup_link					= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.vendor', 'column'=> $attributes['name']));
 
 					$lookup_functions[$m]['name']	= 'lookup_'. $attributes['name'] .'()';
-					$lookup_functions[$m]['action']	= 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+					$lookup_functions[$m]['action']	= 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","left=50,top=100,width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
 					$m++;
 				}
 				else if($attributes['datatype'] == 'user')
@@ -198,7 +199,7 @@ JS;
 					$lookup_link					= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->_appname.'.uilookup.phpgw_user', 'column'=> $attributes['name']));
 
 					$lookup_functions[$m]['name']	= 'lookup_'. $attributes['name'] .'()';
-					$lookup_functions[$m]['action']	= 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
+					$lookup_functions[$m]['action']	= 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","left=50,top=100,width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
 					$m++;
 				}
 				else if($attributes['datatype'] == 'R' || $attributes['datatype'] == 'CH' || $attributes['datatype'] == 'LB')
@@ -207,7 +208,8 @@ JS;
 
 					if($attributes['datatype'] == 'CH')
 					{
-						$attributes['value'] = unserialize($attributes['value']);
+//						$attributes['value'] = unserialize($attributes['value']);
+						$attributes['value'] = explode(',', trim($attributes['value'], ','));
 
 						if (isset($attributes['choice']) AND is_array($attributes['choice']))
 						{
@@ -277,8 +279,8 @@ JS;
 					$lookup_functions[$m]['name']	= 'lookup_'. $attributes['name'] .'()';
 
 					$lookup_functions[$m]['action'] = "var oArgs = {menuaction:'{$this->_appname}.uievent.edit',"
-									."location:'{$location}',"
-									."attrib_id:'{$attributes['id']}'";
+						."location:'{$location}',"
+						."attrib_id:'{$attributes['id']}'";
 					$lookup_functions[$m]['action'] .=	isset($attributes['item_id']) && $attributes['item_id'] ? ",item_id:{$attributes['item_id']}" : '';		
 					$lookup_functions[$m]['action'] .=	isset($attributes['value']) && $attributes['value'] ? ",id:{$attributes['value']}" : '';		
 					$lookup_functions[$m]['action'] .= "};\n";
@@ -287,7 +289,7 @@ JS;
 					$lookup_functions[$m]['action'] .= "oArgs['id'] = document.form.{$attributes['name']}.value;";
 					$lookup_functions[$m]['action'] .= "}\n";
 					$lookup_functions[$m]['action'] .= "var strURL = phpGWLink('index.php', oArgs);\n";
-					$lookup_functions[$m]['action']	.= 'Window1=window.open(strURL,"Search","width=800,height=500,toolbar=no,scrollbars=yes,resizable=yes");';
+					$lookup_functions[$m]['action']	.= 'Window1=window.open(strURL,"Search","left=50,top=100,width=800,height=500,toolbar=no,scrollbars=yes,resizable=yes");';
 					$m++;
 				}
 				else if (isset($entity['attributes'][$i]) && $entity['attributes'][$i]['datatype']!='I' && $entity['attributes'][$i]['value'])
@@ -375,7 +377,7 @@ JS;
 							if($entry['value'] != $old_value)
 							{
 								$data['history_set'][$entry['attrib_id']] = array
-								('
+									('
 									value'	=> $entry['value'],
 									'date'	=> phpgwapi_datetime::date_to_timestamp($entry['date'])
 								);
@@ -383,7 +385,7 @@ JS;
 						}
 						else
 						{
-								$data['history_set'][$entry['attrib_id']] = $entry['value'];
+							$data['history_set'][$entry['attrib_id']] = $entry['value'];
 						}
 					}
 				}
@@ -397,7 +399,7 @@ JS;
 			$attribute_table = 'phpgw_cust_attribute';
 			$attribute_filter = " location_id = {$location_id}";
 			$contacts = CreateObject('phpgwapi.contacts');
-//_debug_array($values);
+			//_debug_array($values);
 			$location = array();
 			$ret = array();
 			$j=0;
@@ -407,7 +409,7 @@ JS;
 				{
 					if($field == 'location_code')
 					{
-						$location = split('-',$data['value']);
+						$location = explode('-',$data['value']);
 					}
 
 					if(($data['datatype']=='R' || $data['datatype']=='LB') && $data['value'])
@@ -436,7 +438,8 @@ JS;
 					}
 					else if($data['datatype']=='CH' && $data['value'])
 					{
-						$ch= unserialize($data['value']);
+					//	$ch= unserialize($data['value']);
+						$ch = explode(',', trim($data['value'], ','));
 						if (isset($ch) AND is_array($ch))
 						{
 							for ($k=0;$k<count($ch);$k++)
@@ -479,15 +482,17 @@ JS;
 
 					if($location)
 					{
-						if(!$location_count)
+						$_location_count = $location_count;
+						if(!$_location_count)
 						{
-							$location_count = count($location);
+							$_location_count = count($location);
 						}
-						for ($m=0;$m < $location_count ; $m++)
+						for ($m=0;$m < $_location_count ; $m++)
 						{
 							$ret[$j]['loc' . ($m+1)] = $location[$m];
 							$ret[$j]['query_location']['loc' . ($m+1)]=implode('-', array_slice($location, 0, ($m + 1)));
 						}
+						$_location_count = 0;
 					}
 				}
 				$j++;
