@@ -7,7 +7,7 @@
 	 * @copyright Copyright (C) 2007,2008 Free Software Foundation, Inc. http://www.fsf.org/
 	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	 * @package property
-	 * @version $Id: class.hook_helper.inc.php 5822 2010-05-27 12:21:50Z sigurd $
+	 * @version $Id: class.hook_helper.inc.php 7026 2011-02-21 07:59:06Z sigurdne $
 	 */
 
 	/*
@@ -41,7 +41,7 @@
 		public function clear_userlist()
 		{
 			$cleared = ExecMethod('property.bocommon.reset_fm_cache_userlist');
-			$receipt['message'][] = array('msg' => lang('%1 userlists cleared from cache',$cleared));
-			phpgwapi_cache::session_set('phpgwapi', 'phpgw_messages', $receipt);
+			$message =lang('%1 userlists cleared from cache',$cleared);
+			phpgwapi_cache::message_set($message, 'message');
 		}
 	}
