@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.soagreement.inc.php 4807 2010-02-12 09:46:39Z sigurd $
+ 	* @version $Id: class.soagreement.inc.php 7495 2011-08-11 12:01:59Z sigurdne $
 	*/
 
 	/**
@@ -45,7 +45,7 @@
 			$this->join			= $this->bocommon->join;
 			$this->left_join	= $this->bocommon->left_join;
 			$this->like			= $this->bocommon->like;
-//			$this->role		= 'agreement';
+			//			$this->role		= 'agreement';
 		}
 
 		function select_vendor_list()
@@ -65,20 +65,18 @@
 
 		function read($data)
 		{
-			if(is_array($data))
-			{
-				$start			= (isset($data['start'])?$data['start']:0);
-				$filter			= (isset($data['filter'])?$data['filter']:'none');
-				$query 			= (isset($data['query'])?$data['query']:'');
-				$sort 			= (isset($data['sort'])?$data['sort']:'DESC');
-				$order			= (isset($data['order'])?$data['order']:'');
-				$cat_id			= (isset($data['cat_id'])?$data['cat_id']:'');
-				$vendor_id		= (isset($data['vendor_id'])?$data['vendor_id']:'');
-				$allrows		= (isset($data['allrows'])?$data['allrows']:'');
-				$member_id		= (isset($data['member_id'])?$data['member_id']:0);
-				$agreement_id	= (isset($data['agreement_id'])?$data['agreement_id']:'');
-				$status 		= (isset($data['status'])?$data['status']:'');
-			}
+//_debug_array($data);die();
+			$start			= isset($data['start']) && $data['start'] ? (int)$data['start'] : 0;
+			$filter			= isset($data['filter']) && $data['filter'] ? $data['filter'] : 'none';
+			$query 			= isset($data['query']) ? $data['query'] : '';
+			$sort 			= isset($data['sort']) && $data['sort'] ? $data['sort'] : 'DESC';
+			$order			= isset($data['order']) ? $data['order'] : '';
+			$cat_id			= isset($data['cat_id']) ? (int) $data['cat_id'] : '';
+			$vendor_id		= isset($data['vendor_id']) ? (int)$data['vendor_id']:'';
+			$allrows		= isset($data['allrows']) ? $data['allrows']:'';
+			$member_id		= isset($data['member_id']) ? (int)$data['member_id']:0;
+			$agreement_id	= isset($data['agreement_id'])? (int) $data['agreement_id']:'';
+			$status_id 		= isset($data['status_id']) ? $data['status_id'] : '';
 
 			$filtermethod = '';
 			$querymethod = '';
@@ -91,10 +89,11 @@
 			$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.agreement'); 
 			$attribute_filter = " location_id = {$location_id}";
 			$paranthesis ='(';
-			$joinmethod = " $this->join $category_table ON ( $entity_table.category =$category_table.id)";
-			$joinmethod .= " $this->join  fm_vendor ON ( $entity_table.vendor_id =fm_vendor.id ))";
+			$joinmethod = " {$this->join} {$category_table} ON ( {$entity_table}.category = {$category_table}.id)";
+			$joinmethod .= " {$this->join}  fm_vendor ON ( {$entity_table}.vendor_id =fm_vendor.id )";
+			$joinmethod .= " {$this->join} fm_agreement_status ON ( {$entity_table}.status = fm_agreement_status.id))";
 
-			$cols = $entity_table . ".*,$category_table.descr as category, org_name";
+			$cols = "{$entity_table}.*,{$category_table}.descr as category, org_name, fm_agreement_status.descr as status";
 
 			$cols_return[] 				= 'id';
 			$uicols['input_type'][]		= 'text';
@@ -131,6 +130,13 @@
 			$uicols['statustext'][]		= lang('start date');
 			$uicols['datatype'][]		= 'D';
 
+			$cols_return[] 				= 'termination_date';
+			$uicols['input_type'][]		= 'text';
+			$uicols['name'][]			= 'termination_date';
+			$uicols['descr'][]			= lang('termination date');
+			$uicols['statustext'][]		= lang('termination date');
+			$uicols['datatype'][]		= 'D';
+
 			$cols_return[] 				= 'end_date';
 			$uicols['input_type'][]		= 'text';
 			$uicols['name'][]			= 'end_date';
@@ -147,24 +153,25 @@
 
 			if ($order)
 			{
-				if ($order=='id')
+				switch ($order)
 				{
-					$ordermethod = " order by $entity_table.$order $sort";
-				}
-				else
-				{
-					$ordermethod = " order by $order $sort";
+					case 'id':
+					case 'status':
+						$ordermethod = " ORDER BY {$entity_table}.{$order} {$sort}";
+						break;
+					case 'category':
+						$ordermethod = " ORDER BY {$category_table}.descr {$sort}";					
+						break;
+					default:
+						$ordermethod = " ORDER BY {$order} {$sort}";
 				}
 			}
 			else
 			{
-				$ordermethod = " order by $entity_table.id DESC";
+				$ordermethod = " ORDER BY {$entity_table}.id DESC";
 			}
-
-
-			$from = " FROM $paranthesis $entity_table ";
-
-			$sql = "SELECT $cols $from $joinmethod";
+//_debug_array($ordermethod);
+			$sql = "SELECT {$cols} FROM {$paranthesis} {$entity_table} {$joinmethod}";
 
 			$i	= count($uicols['name']);
 
@@ -217,7 +224,7 @@
 				$filtermethod = " $where $entity_table.user_id=$filter ";
 				$where= 'AND';
 			}
-*/
+ */
 
 			if ($agreement_id)
 			{
@@ -244,9 +251,9 @@
 				$where= 'AND';
 			}
 
-			if ($status)
+			if ($status_id)
 			{
-				$filtermethod .= " $where $entity_table.status='$status' ";
+				$filtermethod .= " {$where} {$entity_table}.status='{$status_id}' ";
 				$where= 'AND';
 			}
 
@@ -257,7 +264,7 @@
 
 				$querymethod[]= "fm_branch.descr {$this->like} '%{$query}%'";
 				$querymethod[]= "{$entity_table}.name {$this->like} '%{$query}%'";
-				
+
 				$this->db->query("SELECT * FROM $attribute_table WHERE search='1' AND $attribute_filter ");
 
 				while ($this->db->next_record())
@@ -294,7 +301,7 @@
 
 			$j=0;
 			$n=count($cols_return);
-//_debug_array($cols_return);
+			//_debug_array($cols_return);
 
 			$contacts		= CreateObject('phpgwapi.contacts');
 			$agreement_list = array();
@@ -336,8 +343,8 @@
 						}
 						else if($cols_return_extra[$i]['datatype']=='CH' && $value)
 						{
-							$ch= unserialize($value);
-
+//							$ch= unserialize($value);
+							$ch = explode(',', trim($data['value'], ','));
 							if (isset($ch) AND is_array($ch))
 							{
 								for ($k=0;$k<count($ch);$k++)
@@ -373,24 +380,22 @@
 				}
 				$j++;
 			}
-//_debug_array($agreement_list);
+			//_debug_array($agreement_list);
 			return $agreement_list;
 		}
 
 		function read_details($data)
 		{
-			if(is_array($data))
-			{
-				$start			= (isset($data['start'])?$data['start']:0);
-				$filter			= (isset($data['filter'])?$data['filter']:'none');
-				$query 			= (isset($data['query'])?$data['query']:'');
-				$sort 			= (isset($data['sort'])?$data['sort']:'DESC');
-				$order			= (isset($data['order'])?$data['order']:'');
-				$cat_id			= (isset($data['cat_id'])?$data['cat_id']:'');
-				$allrows		= (isset($data['allrows'])?$data['allrows']:'');
-				$agreement_id	= (isset($data['agreement_id'])?$data['agreement_id']:'');
-			}
-$allrows = true; // return all..
+				$start			= isset($data['start']) && $data['start'] ? $data['start']:0;
+				$filter			= isset($data['filter']) && $data['filter'] ? $data['filter']:'none';
+				$query 			= isset($data['query']) ? $data['query'] : '';
+				$sort 			= isset($data['sort']) && $data['sort'] ? $data['sort']:'DESC';
+				$order			= isset($data['order']) ? $data['order'] : '';
+				$cat_id			= isset($data['cat_id']) ? $data['cat_id'] : '';
+				$allrows		= isset($data['allrows']) ? $data['allrows'] : '';
+				$agreement_id	= isset($data['agreement_id']) ? $data['agreement_id'] : '';
+
+			$allrows = true; // return all..
 
 			$entity_table = 'fm_activity_price_index';
 
@@ -445,17 +450,31 @@ $allrows = true; // return all..
 
 			if ($order)
 			{
-				$ordermethod = " order by $entity_table.$order $sort";
+				switch($order)
+				{
+					case 'index_date':
+					case 'activity_id':
+					case 'index_count':
+					case 'total_cost':
+					case 'w_cost':
+					case 'm_cost':
+					case 'num':
+					case 'descr':
+					case 'unit':
+					case 'm_cost':
+						$ordermethod = "ORDER BY {$entity_table}.{$order} {$sort}";
+						break;
+					default:
+						$ordermethod = '';
+				}
+				
 			}
 			else
 			{
-				$ordermethod = " order by $entity_table.activity_id DESC";
+				$ordermethod = "ORDER BY {$entity_table}.activity_id DESC";
 			}
 
-
-			$from = " FROM $paranthesis $entity_table ";
-
-			$sql = "SELECT $cols $from $joinmethod";
+			$sql = "SELECT {$cols} FROM {$paranthesis} {$entity_table} {$joinmethod}";
 
 			$this->uicols	= $uicols;
 
@@ -470,7 +489,7 @@ $allrows = true; // return all..
 			}
 
 			$sql .= " $filtermethod";
-//echo $sql;
+			//echo $sql;
 
 			$this->db2->query($sql,__LINE__,__FILE__);
 			$this->total_records = $this->db2->num_rows();
@@ -488,22 +507,22 @@ $allrows = true; // return all..
 			while ($this->db->next_record())
 			{
 				$details[] = array
-				(
-					'agreement_id'		=> $this->db->f('agreement_id'),
-					'activity_id'		=> $this->db->f('activity_id'),
-					'id'				=> $this->db->f('id'),
-					'num'				=> $this->db->f('num'),
-					'descr'				=> $this->db->f('descr'),
-					'unit'				=> $this->db->f('unit'),
-					'm_cost'			=> $this->db->f('m_cost'),
-					'w_cost'			=> $this->db->f('w_cost'),
-					'total_cost'		=> $this->db->f('total_cost'),
-					'this_index'		=> $this->db->f('this_index'),
-					'index_count'		=> $this->db->f('index_count'),
-					'index_date'		=> $GLOBALS['phpgw']->common->show_date($this->db->f('index_date'),$dateformat)
-				);
+					(
+						'agreement_id'		=> $this->db->f('agreement_id'),
+						'activity_id'		=> $this->db->f('activity_id'),
+						'id'				=> $this->db->f('id'),
+						'num'				=> $this->db->f('num'),
+						'descr'				=> htmlspecialchars_decode($this->db->f('descr',true)),
+						'unit'				=> $this->db->f('unit'),
+						'm_cost'			=> $this->db->f('m_cost'),
+						'w_cost'			=> $this->db->f('w_cost'),
+						'total_cost'		=> $this->db->f('total_cost'),
+						'this_index'		=> $this->db->f('this_index'),
+						'index_count'		=> $this->db->f('index_count'),
+						'index_date'		=> $GLOBALS['phpgw']->common->show_date($this->db->f('index_date'),$dateformat)
+					);
 			}
-//html_print_r($details);
+			//html_print_r($details);
 			return $details;
 		}
 
@@ -520,47 +539,47 @@ $allrows = true; // return all..
 			$cols = "fm_activity_price_index.m_cost,fm_activity_price_index.w_cost,fm_activity_price_index.total_cost,"
 				. " fm_activity_price_index.index_count,fm_activity_price_index.index_date,fm_activity_price_index.activity_id,fm_activity_price_index.this_index";
 
-			$cols_return[] 			= 'activity_id';
+			$cols_return[] 				= 'activity_id';
 			$uicols['input_type'][]		= 'text';
 			$uicols['name'][]			= 'activity_id';
 			$uicols['descr'][]			= lang('activity ID');
 			$uicols['statustext'][]		= lang('activity ID');
 
-			$cols_return[] 			= 'id';
+			$cols_return[] 				= 'id';
 			$uicols['input_type'][]		= 'hidden';
 			$uicols['name'][]			= 'id';
 			$uicols['descr'][]			= false;
 			$uicols['statustext'][]		= false;
 
-			$cols_return[] 			= 'm_cost';
+			$cols_return[] 				= 'm_cost';
 			$uicols['input_type'][]		= 'text';
 			$uicols['name'][]			= 'm_cost';
 			$uicols['descr'][]			= lang('m_cost');
 			$uicols['statustext'][]		= lang('m_cost');
-			$cols_return[] 			= 'w_cost';
+			$cols_return[] 				= 'w_cost';
 			$uicols['input_type'][]		= 'text';
 			$uicols['name'][]			= 'w_cost';
 			$uicols['descr'][]			= lang('w_cost');
 			$uicols['statustext'][]		= lang('w_cost');
-			$cols_return[] 			= 'total_cost';
+			$cols_return[] 				= 'total_cost';
 			$uicols['input_type'][]		= 'text';
 			$uicols['name'][]			= 'total_cost';
 			$uicols['descr'][]			= lang('total cost');
 			$uicols['statustext'][]		= lang('total cost');
 
-			$cols_return[] 			= 'this_index';
+			$cols_return[] 				= 'this_index';
 			$uicols['input_type'][]		= 'text';
 			$uicols['name'][]			= 'this_index';
 			$uicols['descr'][]			= lang('index');
 			$uicols['statustext'][]		= lang('index');
 
-			$cols_return[] 			= 'index_count';
+			$cols_return[] 				= 'index_count';
 			$uicols['input_type'][]		= 'text';
 			$uicols['name'][]			= 'index_count';
 			$uicols['descr'][]			= lang('index_count');
 			$uicols['statustext'][]		= lang('index_count');
 
-			$cols_return[] 			= 'index_date';
+			$cols_return[] 				= 'index_date';
 			$uicols['input_type'][]		= 'text';
 			$uicols['name'][]			= 'index_date';
 			$uicols['descr'][]			= lang('date');
@@ -586,7 +605,7 @@ $allrows = true; // return all..
 
 
 			$sql .= " $filtermethod";
-//echo $sql;
+			//echo $sql;
 
 			$this->db2->query($sql,__LINE__,__FILE__);
 			$this->total_records = $this->db2->num_rows();
@@ -601,7 +620,7 @@ $allrows = true; // return all..
 
 			$j=0;
 			$n=count($cols_return);
-//_debug_array($cols_return);
+			//_debug_array($cols_return);
 			while ($this->db->next_record())
 			{
 				for ($i=0;$i<$n;$i++)
@@ -611,7 +630,7 @@ $allrows = true; // return all..
 				}
 				$j++;
 			}
-//_debug_array($agreement_list);
+			//_debug_array($agreement_list);
 			return $agreement_list;
 		}
 
@@ -682,7 +701,7 @@ $allrows = true; // return all..
 
 		function add($agreement,$values_attribute='')
 		{
-//_debug_array($agreement);
+			//_debug_array($agreement);
 			$table = 'fm_agreement';
 			$agreement['name'] = $this->db->db_addslashes($agreement['name']);
 			$agreement['descr'] = $this->db->db_addslashes($agreement['descr']);
@@ -754,7 +773,7 @@ $allrows = true; // return all..
 
 		function add_item($values,$values_attribute='')
 		{
-//_debug_array($values);
+			//_debug_array($values);
 
 			$this->db->transaction_begin();
 
@@ -788,8 +807,8 @@ $allrows = true; // return all..
 
 		function edit($values,$values_attribute='')
 		{
-//_debug_array($values);
-//_debug_array($values_attribute);
+			//_debug_array($values);
+			//_debug_array($values_attribute);
 			$table = 'fm_agreement';
 
 			$values['name'] = $this->db->db_addslashes($values['name']);
@@ -835,7 +854,7 @@ $allrows = true; // return all..
 			}
 
 			$this->db->query("UPDATE $table set entry_date='" . time() . "', category='"
-							. $values['cat_id'] . "', start_date=" . intval($values['start_date']) . ", end_date=" . intval($values['end_date']) . ", termination_date=" . intval($values['termination_date']) . "$value_set WHERE id=" . intval($values['agreement_id']));
+				. $values['cat_id'] . "', start_date=" . intval($values['start_date']) . ", end_date=" . intval($values['end_date']) . ", termination_date=" . intval($values['termination_date']) . "$value_set WHERE id=" . intval($values['agreement_id']));
 
 			$this->db->query("UPDATE fm_activity_price_index set index_date=" . intval($values['start_date']) . " WHERE index_count=1 AND agreement_id= " . intval($values['agreement_id']));
 
@@ -846,7 +865,7 @@ $allrows = true; // return all..
 
 		function edit_item($values)
 		{
-//_debug_array($values);
+			//_debug_array($values);
 
 			$value_set['m_cost']		= $values['m_cost'];
 			$value_set['w_cost']		= $values['w_cost'];
@@ -869,7 +888,7 @@ $allrows = true; // return all..
 
 		function update($values)
 		{
-//_debug_array($values);
+			//_debug_array($values);
 			$values['new_index']=$this->floatval($values['new_index']);
 			$this->db->transaction_begin();
 
@@ -953,29 +972,29 @@ $allrows = true; // return all..
 		{
 			switch($table)
 			{
-				case 'fm_agreement':
-					$fd=array(
-						'group_id' => array('type' => 'int','precision' => '4','nullable' => false),
-						'id' => array('type' => 'int','precision' => '4','nullable' => false),
-						'vendor_id' => array('type' => 'int','precision' => '4','nullable' => false),
-						'name' => array('type' => 'varchar','precision' => '100','nullable' => false),
-						'descr' => array('type' => 'text','nullable' => true),
-						'status' => array('type' => 'varchar','precision' => '10','nullable' => true),
-						'entry_date' => array('type' => 'int','precision' => '4','nullable' => true),
-						'start_date' => array('type' => 'int','precision' => '4','nullable' => true),
-						'end_date' => array('type' => 'int','precision' => '4','nullable' => true),
-						'termination_date' => array('type' => 'int','precision' => '4','nullable' => true),
-						'category' => array('type' => 'int','precision' => '4','nullable' => true),
-						'user_id' => array('type' => 'int','precision' => '4','nullable' => true)
-						);
-					break;
-				case 'fm_agreement_detail':
+			case 'fm_agreement':
+				$fd=array(
+					'group_id' => array('type' => 'int','precision' => '4','nullable' => false),
+					'id' => array('type' => 'int','precision' => '4','nullable' => false),
+					'vendor_id' => array('type' => 'int','precision' => '4','nullable' => false),
+					'name' => array('type' => 'varchar','precision' => '100','nullable' => false),
+					'descr' => array('type' => 'text','nullable' => true),
+					'status' => array('type' => 'varchar','precision' => '10','nullable' => true),
+					'entry_date' => array('type' => 'int','precision' => '4','nullable' => true),
+					'start_date' => array('type' => 'int','precision' => '4','nullable' => true),
+					'end_date' => array('type' => 'int','precision' => '4','nullable' => true),
+					'termination_date' => array('type' => 'int','precision' => '4','nullable' => true),
+					'category' => array('type' => 'int','precision' => '4','nullable' => true),
+					'user_id' => array('type' => 'int','precision' => '4','nullable' => true)
+				);
+				break;
+			case 'fm_agreement_detail':
 
 
-					break;
-				default:
-					return;
-					break;
+				break;
+			default:
+				return;
+				break;
 			}
 
 			return $fd;
@@ -1023,12 +1042,12 @@ $allrows = true; // return all..
 					}
 
 					$fd[$metadata[$i]['name']] = array(
-					 	'type' => $this->bocommon->translate_datatype_insert(stripslashes($this->db->f('datatype'))),
-					 	'precision' => $precision,
-					 	'nullable' => stripslashes($this->db->f('nullable')),
-					 	'default' => stripslashes($this->db->f('default_value')),
-					 	'scale' => $this->db->f('scale')
-					 		);
+						'type' => $this->bocommon->translate_datatype_insert(stripslashes($this->db->f('datatype'))),
+						'precision' => $precision,
+						'nullable' => stripslashes($this->db->f('nullable')),
+						'default' => stripslashes($this->db->f('default_value')),
+						'scale' => $this->db->f('scale')
+					);
 					unset($precision);
 				}
 			}
@@ -1036,8 +1055,8 @@ $allrows = true; // return all..
 			$table_def = array(
 				$table =>	array(
 					'fd' => $fd
-					)
-				);
+				)
+			);
 
 			$table_def[$table]['pk'] = $pk;
 			$table_def[$table]['fk'] = array();
@@ -1061,10 +1080,10 @@ $allrows = true; // return all..
 			while ($this->db->next_record())
 			{
 				$agreement_group_list[]=array
-				(
-					'id'	=> $this->db->f('id'),
-					'name'	=> $GLOBALS['phpgw']->strip_html($this->db->f('descr')).' [ '. $GLOBALS['phpgw']->strip_html($this->db->f('status')).' ] '
-				);
+					(
+						'id'	=> $this->db->f('id'),
+						'name'	=> $GLOBALS['phpgw']->strip_html($this->db->f('descr')).' [ '. $GLOBALS['phpgw']->strip_html($this->db->f('status')).' ] '
+					);
 			}
 			return $agreement_group_list;
 		}
@@ -1094,14 +1113,14 @@ $allrows = true; // return all..
 			while ($this->db->next_record())
 			{
 				$activity_list[$this->db->f('id')]=array
-				(
-					'id'		=> $this->db->f('id'),
-					'num'		=> $this->db->f('num'),
-					'base_descr'	=> $this->db->f('base_descr'),
-					'descr'		=> $this->db->f('descr'),
-					'unit'		=> $this->db->f('unit'),
-					'ns3420'	=> $this->db->f('ns3420'),
-				);
+					(
+						'id'		=> $this->db->f('id'),
+						'num'		=> $this->db->f('num'),
+						'base_descr'	=> $this->db->f('base_descr'),
+						'descr'		=> $this->db->f('descr'),
+						'unit'		=> $this->db->f('unit'),
+						'ns3420'	=> $this->db->f('ns3420'),
+					);
 			}
 
 			$sql="SELECT activity_id FROM fm_activity_price_index WHERE agreement_id = $agreement_id";
@@ -1135,53 +1154,53 @@ $allrows = true; // return all..
 				if(!$date)
 				{
 					throw new Exception("missing start date for agreement {$agreement_id}");
-//					return $receipt['error'][] = array('msg'=>lang('missing start date for agreement %1',$agreement_id));
+					//					return $receipt['error'][] = array('msg'=>lang('missing start date for agreement %1',$agreement_id));
 				}
-				
+
 				$sql = 'INSERT INTO fm_activity_price_index (agreement_id, activity_id, index_count, current_index, index_date, entry_date, user_id)'
-							. ' VALUES(?, ?, ?, ?, ?, ?, ?)';
+					. ' VALUES(?, ?, ?, ?, ?, ?, ?)';
 				$valueset=array();
 
 				foreach($values['select'] as $activity_id)
 				{
 					$valueset[] = array
-					(
-						1	=> array
 						(
-							'value'	=> $agreement_id,
-							'type'	=> PDO::PARAM_INT
-						),
-						2	=> array
-						(
-							'value'	=> $activity_id,
-							'type'	=>	PDO::PARAM_INT
-						),
-						3	=> array
-						(
-							'value'	=> -1,
-							'type'	=> PDO::PARAM_INT
-						),
-						4	=> array
-						(
-							'value'	=> 1,
-							'type'	=>	PDO::PARAM_INT
-						),
-						5	=> array
-						(
-							'value'	=> $date,
-							'type'	=> PDO::PARAM_INT
-						),
-						6	=> array
-						(
-							'value'	=> time(),
-							'type'	=> PDO::PARAM_INT
-						),
-						7	=> array
-						(
-							'value'	=> $this->account,
-							'type'	=> PDO::PARAM_INT
-						)
-					);
+							1	=> array
+							(
+								'value'	=> $agreement_id,
+								'type'	=> PDO::PARAM_INT
+							),
+							2	=> array
+							(
+								'value'	=> $activity_id,
+								'type'	=>	PDO::PARAM_INT
+							),
+							3	=> array
+							(
+								'value'	=> -1,
+								'type'	=> PDO::PARAM_INT
+							),
+							4	=> array
+							(
+								'value'	=> 1,
+								'type'	=>	PDO::PARAM_INT
+							),
+							5	=> array
+							(
+								'value'	=> $date,
+								'type'	=> PDO::PARAM_INT
+							),
+							6	=> array
+							(
+								'value'	=> time(),
+								'type'	=> PDO::PARAM_INT
+							),
+							7	=> array
+							(
+								'value'	=> $this->account,
+								'type'	=> PDO::PARAM_INT
+							)
+						);
 				}
 
 				$this->db->insert($sql, $valueset, __LINE__, __FILE__);
@@ -1202,10 +1221,10 @@ $allrows = true; // return all..
 			while ($this->db->next_record())
 			{
 				$status[] = array
-				(
-					'id'	=> $this->db->f('id'),
-					'name'	=> $this->db->f('descr',true)
-				);
+					(
+						'id'	=> $this->db->f('id'),
+						'name'	=> $this->db->f('descr',true)
+					);
 			}
 			return $status;
 		}
