@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage document
- 	* @version $Id: class.sodocument.inc.php 6350 2010-09-18 16:44:28Z sigurd $
+ 	* @version $Id: class.sodocument.inc.php 7098 2011-03-09 08:14:06Z sigurdne $
 	*/
 
 	/**
@@ -46,9 +46,9 @@
 			$this->cats					= CreateObject('phpgwapi.categories', -1, 'property', '.document');
 			$this->cats->supress_info	= true;
 
-			$this->db           	= & $GLOBALS['phpgw']->db;
-			$this->join				= & $this->db->join;
-			$this->like				= & $this->db->like;
+			$this->db           		= & $GLOBALS['phpgw']->db;
+			$this->join					= & $this->db->join;
+			$this->like					= & $this->db->like;
 		}
 
 
@@ -60,10 +60,10 @@
 			while ($this->db->next_record())
 			{
 				$status[] = array
-				(
-					'id'	=> $this->db->f('id'),
-					'name'	=> $this->db->f('descr',true)
-				);
+					(
+						'id'	=> $this->db->f('id'),
+						'name'	=> $this->db->f('descr',true)
+					);
 			}
 			return $status;
 		}
@@ -76,10 +76,10 @@
 			while ($this->db->next_record())
 			{
 				$branch[] = array
-				(
-					'id'	=> $this->db->f('id'),
-					'name'	=> $this->db->f('descr',true)
-				);
+					(
+						'id'	=> $this->db->f('id'),
+						'name'	=> $this->db->f('descr',true)
+					);
 			}
 			return $branch;
 		}
@@ -95,7 +95,7 @@
 				$order		= isset($data['order'])?$data['order']:'';
 				$cat_id		= isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id']:0;
 				$entity_id	= isset($data['entity_id'])?$data['entity_id']:'';
-				$doc_type		= isset($data['doc_type']) && $data['doc_type'] ? $data['doc_type']: 0;
+				$doc_type	= isset($data['doc_type']) && $data['doc_type'] ? $data['doc_type']: 0;
 			}
 
 			$doc_types = $this->get_sub_doc_types($doc_type);
@@ -142,16 +142,16 @@
 
 
 				$sql	= $this->bocommon->generate_sql(array('entity_table'=> $document_table,
-															'cols'			=> $cols,
-															'cols_return'	=> $cols_return,
-															'uicols'		=> $uicols,
-															'joinmethod'	=> $joinmethod,
-															'paranthesis'	=> $paranthesis,
-															'query'			=> $query,
-															'force_location'=> true,
-															'no_address'	=> true,
-															'uicol_address'=> true
-															));
+					'cols'			=> $cols,
+					'cols_return'	=> $cols_return,
+					'uicols'		=> $uicols,
+					'joinmethod'	=> $joinmethod,
+					'paranthesis'	=> $paranthesis,
+					'query'			=> $query,
+					'force_location'=> true,
+					'no_address'	=> true,
+					'uicol_address'=> true
+				));
 
 				$this->bocommon->fm_cache('sql_document_' . $entity_id,$sql);
 
@@ -235,7 +235,7 @@
 
 			$sql .= " $filtermethod $querymethod $groupmethod";
 
-//echo $sql;
+			//echo $sql;
 
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->total_records = $this->db->num_rows();
@@ -251,7 +251,7 @@
 				}
 
 				$location_code=	$this->db->f('location_code');
-				$location = split('-',$location_code);
+				$location = explode('-',$location_code);
 				for ($m=0;$m<count($location);$m++)
 				{
 					$document_list[$j]['loc' . ($m+1)] = $location[$m];
@@ -262,7 +262,7 @@
 			}
 
 
-//_debug_array($document_list);
+			//_debug_array($document_list);
 			return $document_list;
 		}
 
@@ -282,6 +282,11 @@
 				$location_code	= isset($data['location_code'])?$data['location_code']:'';
 			}
 
+			if( !$location_code )
+			{
+				return array();
+			}
+
 			$doc_types = $this->get_sub_doc_types($doc_type);
 
 			if ($order)
@@ -322,12 +327,12 @@
 			{
 				$query = $this->db->db_addslashes($query);
 				$querymethod = " $where (fm_document.title $this->like '%$query%' OR fm_document.document_name"
-				. " $this->like '%$query%')";
+					. " $this->like '%$query%')";
 			}
 
 			$sql = "SELECT fm_document.*, phpgw_categories.cat_name as category FROM fm_document"
-			. " $this->join phpgw_categories on fm_document.category = phpgw_categories.cat_id"
-			. " $filtermethod $querymethod";
+				. " $this->join phpgw_categories on fm_document.category = phpgw_categories.cat_id"
+				. " $filtermethod $querymethod";
 
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->total_records = $this->db->num_rows();
@@ -345,14 +350,14 @@
 			while ($this->db->next_record())
 			{
 				$document_list[] = array
-				(
-					'document_id'		=> $this->db->f('id'),
-					'document_name'		=> $this->db->f('document_name', true),
-					'link'				=> $this->db->f('link', true),
-					'title'				=> $this->db->f('title', true),
-					'doc_type'			=> $this->db->f('category'),
-					'user_id'			=> $this->db->f('coordinator'),
-					'document_date'		=> $this->db->f('document_date')
+					(
+						'document_id'		=> $this->db->f('id'),
+						'document_name'		=> $this->db->f('document_name', true),
+						'link'				=> $this->db->f('link', true),
+						'title'				=> $this->db->f('title', true),
+						'doc_type'			=> $this->db->f('category'),
+						'user_id'			=> $this->db->f('coordinator'),
+						'document_date'		=> $this->db->f('document_date')
 					);
 			}
 
@@ -388,8 +393,8 @@
 				$document['p_cat_id']			= $this->db->f('p_cat_id');
 			}
 
-//_debug_array($document);
-				return $document;
+			//_debug_array($document);
+			return $document;
 		}
 
 		function add($document)
@@ -431,12 +436,11 @@
 			}
 
 			$document['descr'] = $this->db->db_addslashes($document['descr']);
-			$document['name'] = $this->db->db_addslashes($document['name']);
 			$document['title'] = $this->db->db_addslashes($document['title']);
-//_debug_array($document);
+			//_debug_array($document);
 
 			$values= array(
-				$document['document_name'],
+				$this->db->db_addslashes($document['document_name']),
 				$document['link'],
 				$document['title'],
 				'public',
@@ -483,19 +487,21 @@
 		function edit($document)
 		{
 			$receipt = array();
-			while (is_array($document['location']) && list($input_name,$value) = each($document['location']))
+			$value_set=array();
+			if (isset($document['location']) && is_array($document['location']))
 			{
-				$vals[]	= "$input_name = '$value'";
+				foreach($document['location'] as $input_name => $value)
+				{
+					$value_set[$input_name]	= $value;
+				}
 			}
 
-			while (is_array($document['extra']) && list($input_name,$value) = each($document['extra']))
+			if (isset($document['extra']) && is_array($document['extra']))
 			{
-				$vals[]	= "$input_name = '$value'";
-			}
-
-			if($vals)
-			{
-				$vals	= "," . implode(",",$vals);
+				foreach($document['extra'] as $input_name => $value)
+				{
+					$value_set[$input_name]	= $value;
+				}
 			}
 
 			if($document['street_name'])
@@ -556,8 +562,8 @@
 
 			if($old_link !=$document['link'] )
 			{
-					$this->historylog->add('L',$document['document_id'],$document['link'],$old_link);
-					$alter_link=true;
+				$this->historylog->add('L',$document['document_id'],$document['link'],$old_link);
+				$alter_link=true;
 			}
 
 
@@ -583,33 +589,27 @@
 				}
 
 				$receipt= $this->delete_file($file);
-			*/
+			 */
 			}
 
 			if($document['link'])
 			{
-				unset($document['document_name']);
+				$document['document_name'] = '';
 			}
 
-			$document['descr'] = $this->db->db_addslashes($document['descr']);
-			$document['name'] = $this->db->db_addslashes($document['name']);
-			$document['title'] = $this->db->db_addslashes($document['title']);
-
-			$value_set=array(
-				'document_name'	=>$document['document_name'],
-				'link'			=>$document['link'],
-				'title'			=>$document['title'],
-				'branch_id'		=>$document['branch_id'],
-				'status'		=>$document['status'],
-				'category'		=>$document['doc_type'],
-				'document_date'	=>$document['document_date'],
-				'coordinator'	=>$document['coordinator'],
-				'descr'			=>$document['descr'],
-				'version'		=>$document['version'],
-				'location_code'	=>$document['location_code'],
-				'vendor_id'		=>$document['vendor_id'],
-				'address'		=>$address
-				);
+			$value_set['document_name']	= $this->db->db_addslashes($document['document_name']);
+			$value_set['link']			= $document['link'];
+			$value_set['title']			= $this->db->db_addslashes($document['title']);
+			$value_set['branch_id']		= $document['branch_id'];
+			$value_set['status']		= $document['status'];
+			$value_set['category']		= $document['doc_type'];
+			$value_set['document_date']	= $document['document_date'];
+			$value_set['coordinator']	= $document['coordinator'];
+			$value_set['descr']			= $this->db->db_addslashes($document['descr']);
+			$value_set['version']		= $document['version'];
+			$value_set['location_code']	= $document['location_code'];
+			$value_set['vendor_id']		= $document['vendor_id'];
+			$value_set['address']		= $address;
 
 			$value_set	= $this->db->validate_update($value_set);
 
@@ -651,10 +651,38 @@
 		 * @return array parent and children
 		 */
 
-		function get_files_at_location($location_code)
+		function get_files_at_location($data)
 		{
+			$location_code = isset($data['location_code']) ? $data['location_code'] : '';
+			$entity_id = (int)$data['entity_id'];
+			$cat_id = (int)$data['cat_id'];
+			$num = $data['num'];
+
+			if( !$location_code )
+			{
+				if( !$entity_id  || !$cat_id || !$num)
+				{
+					throw new Exception("property_soentity::read_entity_to_link - Missing entity information info in input");
+				}
+			}
+			else if( !$entity_id  || !$cat_id || !$num)
+			{
+				if( !$location_code)
+				{
+					throw new Exception("property_soentity::read_entity_to_link - Missing entity information info in input");
+				}
+			}
+
+			$acl_add = $GLOBALS['phpgw']->acl->check('.document', PHPGW_ACL_ADD, 'property');
 			$documents = array();
-			$sql = "SELECT count(*) as hits FROM fm_document WHERE location_code $this->like '$location_code%'";
+			if($location_code)
+			{
+				$sql = "SELECT count(*) as hits FROM fm_document WHERE location_code {$this->like} '$location_code%' AND p_num IS NULL";
+			}
+			else
+			{
+				$sql = "SELECT count(*) as hits FROM fm_document WHERE p_entity_id = {$entity_id} AND p_cat_id = {$cat_id} AND p_num = '{$num}'";
+			}
 			$this->db->query($sql,__LINE__,__FILE__);
 			if($this->db->next_record())
 			{
@@ -664,25 +692,39 @@
 				$y = 0; //level
 				$cache_x_at_y[$y] = $x;
 				$documents[$x] = array
-				(
-					'link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'property.uidocument.list_doc','location_code'=> $location_code)),
-					'text'		=> lang('documents') . ' [' . $hits . ']:',
-					'descr'		=> lang('Documentation'),
-					'level'		=> 0
-				);
+					(
+						'link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'property.uidocument.list_doc','location_code'=> $location_code,
+															'entity_id' => $entity_id,
+															'cat_id'	=> $cat_id,
+															'p_num'		=> $num)),
+						'text'		=> lang('documents') . ' [' . $hits . ']:',
+						'descr'		=> lang('Documentation'),
+						'level'		=> 0
+					);
 			}
 			else
 			{
-				return $documents;
+//				return $documents;
 			}
 
 			$categories = $this->cats->return_sorted_array(0, false);
 
+			$location_filter = 'WHERE 1=1';
+
+			if($location_code)
+			{
+				$location_filter = "WHERE location_code {$this->like} '{$location_code}%' AND p_num IS NULL";
+			}
+			else
+			{
+				$location_filter = "WHERE p_entity_id = {$entity_id} AND p_cat_id = {$cat_id} AND p_num = '{$num}'";
+			}
+
 			foreach ($categories as $category)
 			{
 				$doc_types = $this->get_sub_doc_types($category['id']);
 
-				$sql = "SELECT count(*) as hits FROM fm_document WHERE location_code $this->like '$location_code%' AND category IN (". implode(',', $doc_types) . ')';
+				$sql = "SELECT count(*) as hits FROM fm_document {$location_filter} AND category IN (". implode(',', $doc_types) . ')';
 				$this->db->query($sql,__LINE__,__FILE__);
 				$this->db->next_record();
 				$hits = (int) $this->db->f('hits');
@@ -702,25 +744,71 @@
 				}
 				$y = $level;
 
+				$map = '$documents'; 
+				for ($i = 0; $i < $level ; $i++)
+				{
+
+					$map .= '[' . $cache_x_at_y[$i] ."]['children']"; 
+				}
+
+				$map .= '[]'; 
+
+				eval($map . ' =array('
+					.	"'link'	=> '" . $GLOBALS['phpgw']->link('/index.php',array('menuaction'	=> 'property.uidocument.list_doc',
+																				'location_code'	=> $location_code,
+																				'doc_type'		=> $category['id'],
+																				'entity_id' 	=> $entity_id,
+																				'cat_id'		=> $cat_id,
+																				'p_num'			=> $num)) . "',\n"
+					.	"'text'			=> '" . $category['name'] . ' [' . $hits . ']' . "',\n"
+					.	"'descr'		=> '" . lang('Documentation') . "',\n"
+					.	"'level'		=> "  . ($category['level']+1) . "\n"
+					. ');');
+
+				$cache_x_at_y[$y] = $x;
+
+//--add node
+
+				if($acl_add && count($doc_types) == 1) // node
+				{
+					$level = $level+1;
+					if($level == $y)
+					{
+						$x++;
+					}
+					else if($level < $y )
+					{
+						$x = $cache_x_at_y[$level]+1;
+					}
+					else if($level > $y )
+					{
+						$x = 0;
+					}
+					$y = $level;
+	
 					$map = '$documents'; 
 					for ($i = 0; $i < $level ; $i++)
 					{
-
 						$map .= '[' . $cache_x_at_y[$i] ."]['children']"; 
 					}
 
 					$map .= '[]'; 
 
 					eval($map . ' =array('
-					.	"'link'	=> '" . $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'property.uidocument.list_doc','location_code'=> $location_code, 'doc_type'=> $category['id'])) . "',\n"
-					.	"'text'			=> '" . $category['name'] . ' [' . $hits . ']' . "',\n"
-					.	"'descr'		=> '" . lang('Documentation') . "',\n"
-					.	"'level'		=> "  . ($category['level']+1) . "\n"
-					 . ');');
+						.	"'link'	=> '" . $GLOBALS['phpgw']->link('/index.php',array('menuaction'	=> 'property.uidocument.edit',
+																				'location_code'	=> $location_code,
+																				'doc_type'		=> $category['id'],
+																				'p_entity_id' 	=> $entity_id,
+																				'p_cat_id'		=> $cat_id,
+																				'p_num'			=> $num)) . "',\n"
+						.	"'text'			=> '" . lang('add') . "',\n"
+						.	"'descr'		=> '" . lang('Add Document') . "',\n"
+						.	"'level'		=> "  . $y . "\n"
+						. ');');
 
-				$cache_x_at_y[$y] = $x;
+					$cache_x_at_y[$y] = $x;
+				}
 			}
-
 			return $documents;
 		}
 
@@ -728,17 +816,17 @@
 		{
 			$receipt = array();
 			if($this->vfs->file_exists(array(
-					'string' => $file,
-					'relatives' => Array(RELATIVE_NONE)
-				)))
+				'string' => $file,
+				'relatives' => Array(RELATIVE_NONE)
+			)))
 			{
 				$this->vfs->override_acl = 1;
 
 				if(!$this->vfs->rm (array(
 					'string' => $file,
-				     'relatives' => array(
-				          RELATIVE_NONE
-				     )
+					'relatives' => array(
+						RELATIVE_NONE
+					)
 				)))
 				{
 					$receipt['error'][]=array('msg'=>lang('failed to delete file') . ' :'. $file);
@@ -790,22 +878,22 @@
 
 
 		/**
-		* used for retrive a child-node from a hierarchy
-		*
-		* @param string $dirname current path
-		* @param integer $level is increased when we go deeper into the tree,
-		* @param integer $maks_level is how deep we want to go
-		* @param integer $filter_level search for filter at a predefined level
-		* @param string $filter
-		* @param string $menuaction is used to make an url to the item
-		* @return array $child Children
-		*/
+		 * used for retrive a child-node from a hierarchy
+		 *
+		 * @param string $dirname current path
+		 * @param integer $level is increased when we go deeper into the tree,
+		 * @param integer $maks_level is how deep we want to go
+		 * @param integer $filter_level search for filter at a predefined level
+		 * @param string $filter
+		 * @param string $menuaction is used to make an url to the item
+		 * @return array $child Children
+		 */
 
 		protected function get_children($dirname, $level, $maks_level = 0, $filter_level=1, $filter = 'hei', $menuaction)
 		{
 			// prevent path traversal
 			if ( preg_match('/\./', $dirname) 
-			 || !is_dir($dirname) )
+				|| !is_dir($dirname) )
 			{
 				return array();
 			}
@@ -818,18 +906,18 @@
 				{
 					if ( ($file->isDot() || !$file->isReadable())
 						|| ($level == $filter_level && !preg_match("/{$filter}/i", $file->getFilename()))
-						)
- 					{
+					)
+					{
 						continue;
 					}
 					$children[] =array
-					(
-						'link'			=> $GLOBALS['phpgw']->link('/home.php'),
-						'text'			=> $file->getFilename(),
-						'is_dir'		=> $file->isDir(),
-						'path'			=> $file->getPathname(),
-						'level'			=> $level,
-					);
+						(
+							'link'			=> $GLOBALS['phpgw']->link('/home.php'),
+							'text'			=> $file->getFilename(),
+							'is_dir'		=> $file->isDir(),
+							'path'			=> $file->getPathname(),
+							'level'			=> $level,
+						);
 				}
 			}
 
@@ -847,22 +935,22 @@
 		}
 
 		/**
-		* used for retrive a filetree from a given start point
-		*
-		* @param string $dirname Start point
-		* @param integer $maks_level is how deep we want to go
-		* @param integer $filter_level search for filter at a predefined level
-		* @param string $filter
-		* @param string $menuaction is used to make an url to the item
-		* @return array $child Children
-		*/
+		 * used for retrive a filetree from a given start point
+		 *
+		 * @param string $dirname Start point
+		 * @param integer $maks_level is how deep we want to go
+		 * @param integer $filter_level search for filter at a predefined level
+		 * @param string $filter
+		 * @param string $menuaction is used to make an url to the item
+		 * @return array $child Children
+		 */
 
 		public function read_file_tree($dirname = '', $maks_level = 2, $filter_level, $filter, $menuaction = '')
 		{
 			$dirname = $dirname ? $dirname : $GLOBALS['phpgw_info']['server']['temp_dir'];
 			// prevent path traversal
 			if ( preg_match('/\./', $dirname) 
-			 || !is_dir($dirname) )
+				|| !is_dir($dirname) )
 			{
 				return array();
 			}
@@ -875,18 +963,18 @@
 				{
 					if ( $file->isDot()
 						|| !$file->isReadable()
-						)
- 					{
+					)
+					{
 						continue;
 					}
 					$file_list[] =array
-					(
-						'link'			=> $GLOBALS['phpgw']->link('/home.php'),
-						'text'			=> $file->getFilename(),
-						'is_dir'		=> $file->isDir(),
-						'path'			=> $file->getPathname(),
-						'level'			=> 0,
-					);
+						(
+							'link'			=> $GLOBALS['phpgw']->link('/home.php'),
+							'text'			=> $file->getFilename(),
+							'is_dir'		=> $file->isDir(),
+							'path'			=> $file->getPathname(),
+							'level'			=> 0,
+						);
 				}
 			}
 
