@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage entity
- 	* @version $Id: class.soentity.inc.php 5807 2010-05-26 10:16:29Z sigurd $
+ 	* @version $Id: class.soentity.inc.php 7434 2011-06-27 13:36:06Z sigurdne $
 	*/
 
 	/**
@@ -44,10 +44,10 @@
 
 
 		protected $type_app = array
-		(
-			'entity'	=> 'property',
-			'catch'		=> 'catch'
-		);
+			(
+				'entity'	=> 'property',
+				'catch'		=> 'catch'
+			);
 
 		function __construct($entity_id='',$cat_id='')
 		{
@@ -77,11 +77,11 @@
 			$location_id = $GLOBALS['phpgw']->locations->get_id($this->type_app[$this->type], ".{$this->type}.{$entity_id}.{$cat_id}");
 
 			$sql= "SELECT phpgw_cust_choice.id, phpgw_cust_choice.value FROM phpgw_cust_attribute"
-			. " $this->join phpgw_cust_choice ON"
-			. " phpgw_cust_attribute.location_id= phpgw_cust_choice.location_id AND"
-			. " phpgw_cust_attribute.id= phpgw_cust_choice.attrib_id"
-			. " WHERE phpgw_cust_attribute.column_name='status'"
-			. " AND phpgw_cust_choice.location_id={$location_id} ORDER BY phpgw_cust_choice.id";
+				. " $this->join phpgw_cust_choice ON"
+				. " phpgw_cust_attribute.location_id= phpgw_cust_choice.location_id AND"
+				. " phpgw_cust_attribute.id= phpgw_cust_choice.attrib_id"
+				. " WHERE phpgw_cust_attribute.column_name='status'"
+				. " AND phpgw_cust_choice.location_id={$location_id} ORDER BY phpgw_cust_choice.id";
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
@@ -89,10 +89,10 @@
 			while ($this->db->next_record())
 			{
 				$status[] = array
-				(
-					'id'	=> $this->db->f('id'),
-					'name'	=> stripslashes($this->db->f('value'))
-				);
+					(
+						'id'	=> $this->db->f('id'),
+						'name'	=> stripslashes($this->db->f('value'))
+					);
 			}
 			return $status;
 		}
@@ -118,6 +118,9 @@
 			$this->type		= isset($data['type']) && $data['type'] ? $data['type'] : $this->type;
 			$location_code	= isset($data['location_code']) ? $data['location_code'] : '';
 			$criteria_id	= isset($data['criteria_id']) ? $data['criteria_id'] : '';
+			$attrib_filter	= $data['attrib_filter'] ? $data['attrib_filter'] : array();
+			$p_num			= isset($data['p_num']) ? $data['p_num'] : '';
+			$custom_condition= isset($data['custom_condition']) ? $data['custom_condition'] : '';
 
 			if(!$entity_id || !$cat_id)
 			{
@@ -160,6 +163,10 @@
 				$uicols['statustext'][]		= 'dummy';
 				$uicols['align'][] 			= '';
 				$uicols['datatype'][]		= '';
+				$uicols['sortable'][]		= true;
+				$uicols['exchange'][]		= false;
+				$uicols['formatter'][]		= '';
+				$uicols['classname'][]		= '';
 
 				$cols_return[] 				= 'num';
 				$uicols['input_type'][]		= 'text';
@@ -168,6 +175,10 @@
 				$uicols['statustext'][]		= lang('ID');
 				$uicols['align'][] 			= '';
 				$uicols['datatype'][]		= '';
+				$uicols['sortable'][]		= true;
+				$uicols['exchange'][]		= false;
+				$uicols['formatter'][]		= '';
+				$uicols['classname'][]		= '';
 
 				$cols_return[] 				= 'id';
 				$uicols['input_type'][]		= 'hidden';
@@ -176,6 +187,10 @@
 				$uicols['statustext'][]		= false;
 				$uicols['align'][] 			= '';
 				$uicols['datatype'][]		= '';
+				$uicols['sortable'][]		= false;
+				$uicols['exchange'][]		= false;
+				$uicols['formatter'][]		= '';
+				$uicols['classname'][]		= '';
 
 				if($lookup)
 				{
@@ -187,29 +202,27 @@
 					$uicols['statustext'][]		= 'dummy';
 					$uicols['align'][] 			= '';
 					$uicols['datatype'][]		= '';
+					$uicols['sortable'][]		= false;
+					$uicols['exchange'][]		= false;
+					$uicols['formatter'][]		= '';
+					$uicols['classname'][]		= '';
 				}
 
 				$cols .= ", {$entity_table}.user_id";
 				$cols_return[] 				= 'user_id';
-				$uicols['input_type'][]		= 'text';
-				$uicols['name'][]			= 'user_id';
-				$uicols['descr'][]			= lang('User');
-				$uicols['statustext'][]		= lang('User');
-				$uicols['align'][] 			= '';
-				$uicols['datatype'][]		= 'user';
 
 				$cols_return_extra[]= array
-								(
-									'name'		=> 'user_id',
-									'datatype'	=> 'user'
-								);
+				(
+					'name'		=> 'user_id',
+					'datatype'	=> 'user'
+				);
 
 				// Don't work with LDAP - where phpgw_accounts is empty
-	//			$joinmethod = " $this->join phpgw_accounts ON ($entity_table.user_id = phpgw_accounts.account_id))";
-	//			$paranthesis ='(';
+				//			$joinmethod = " $this->join phpgw_accounts ON ($entity_table.user_id = phpgw_accounts.account_id))";
+				//			$paranthesis ='(';
 
 				$sql = $this->bocommon->generate_sql(array('entity_table'=>$entity_table,'cols_return'=>$cols_return,'cols'=>$cols,
-								'uicols'=>$uicols,'joinmethod'=>$joinmethod,'paranthesis'=>$paranthesis,'query'=>$query,'lookup'=>$lookup,'location_level'=>$category['location_level']));
+					'uicols'=>$uicols,'joinmethod'=>$joinmethod,'paranthesis'=>$paranthesis,'query'=>$query,'lookup'=>$lookup,'location_level'=>$category['location_level']));
 
 				$this->bocommon->fm_cache("sql_{$this->type}_{$entity_id}_{$cat_id}_{$lookup}", $sql);
 				$this->bocommon->fm_cache("uicols_{$this->type}_{$entity_id}_{$cat_id}_{$lookup}", $this->bocommon->uicols);
@@ -234,13 +247,22 @@
 
 			if ($cat_id > 0)
 			{
-//-------------------
+				//-------------------
 
-				$user_columns = isset($GLOBALS['phpgw_info']['user']['preferences'][$this->type_app[$this->type]]['entity_columns_'.$entity_id.'_'.$cat_id])?$GLOBALS['phpgw_info']['user']['preferences'][$this->type_app[$this->type]]['entity_columns_'.$entity_id.'_'.$cat_id]:'';
+				$user_columns = isset($GLOBALS['phpgw_info']['user']['preferences'][$this->type_app[$this->type]]['entity_columns_'.$entity_id.'_'.$cat_id])?$GLOBALS['phpgw_info']['user']['preferences'][$this->type_app[$this->type]]['entity_columns_'.$entity_id.'_'.$cat_id]:array();
+				
+				$_user_columns = array();
+				foreach ($user_columns as $user_column_id)
+				{
+					if(ctype_digit($user_column_id))
+					{
+						$_user_columns[] = $user_column_id;
+					}
+				}
 				$user_column_filter = '';
 				if (isset($user_columns) AND is_array($user_columns) AND $user_columns[0])
 				{
-					$user_column_filter = " OR ($attribute_filter AND id IN (" . implode(',',$user_columns) .'))';
+					$user_column_filter = " OR ($attribute_filter AND id IN (" . implode(',',$_user_columns) .'))';
 				}
 
 				$this->db->query("SELECT * FROM $attribute_table WHERE list=1 AND $attribute_filter $user_column_filter ORDER BY group_id, attrib_sort ASC");
@@ -253,14 +275,19 @@
 					$uicols['descr'][]			= $this->db->f('input_text');
 					$uicols['statustext'][]		= $this->db->f('statustext');
 					$uicols['datatype'][$i]		= $this->db->f('datatype');
+					$uicols['sortable'][$i]		= true;
+					$uicols['exchange'][$i]		= false;
+					$uicols['formatter'][$i]	= '';
+					$uicols['classname'][$i]	= '';
+
 					$uicols['cols_return_extra'][$i] = array
-					(
-						'name'	=> $this->db->f('column_name'),
-						'datatype'	=> $this->db->f('datatype'),
-						'attrib_id'	=> $this->db->f('id')					
-					);
-					
-					
+						(
+							'name'	=> $this->db->f('column_name'),
+							'datatype'	=> $this->db->f('datatype'),
+							'attrib_id'	=> $this->db->f('id')					
+						);
+
+
 					$cols_return_extra[]= array(
 						'name'	=> $this->db->f('column_name'),
 						'datatype'	=> $this->db->f('datatype'),
@@ -275,11 +302,16 @@
 				$uicols['descr'][]			= lang('entry date');
 				$uicols['statustext'][]		= lang('entry date' );
 				$uicols['datatype'][]		= 'timestamp';
+				$uicols['sortable'][]		= true;
+				$uicols['exchange'][]		= false;
+				$uicols['formatter'][]	= '';
+				$uicols['classname'][]	= '';
+
 				$uicols['cols_return_extra'][$i] = array
-				(
-					'name'		=> 'entry_date',
-					'datatype'	=> 'timestamp',
-				);
+					(
+						'name'		=> 'entry_date',
+						'datatype'	=> 'timestamp',
+					);
 
 
 				$cols_return_extra[]= array(
@@ -293,11 +325,7 @@
 			}
 
 			$this->uicols	= $uicols;
-//_debug_array($cols_return_extra);
-			if($dry_run)
-			{
-				return array();
-			}
+			//_debug_array($cols_return_extra);
 
 			if ($order)
 			{
@@ -306,6 +334,9 @@
 					case 'user_id':
 		//				$ordermethod = " ORDER BY phpgw_accounts.account_lastname {$sort}";  // Don't work with LDAP. 
 						break;
+					case 'loc1_name':
+						$ordermethod = " ORDER BY fm_location1.loc1_name {$sort}";  // Don't work with LDAP. 
+						break;
 					default:
 						$ordermethod = " ORDER BY $entity_table.$order $sort";	
 				}
@@ -318,9 +349,10 @@
 			$where= 'WHERE';
 			$filtermethod = '';
 
-			$GLOBALS['phpgw']->config->read();
-			if(isset($GLOBALS['phpgw']->config->config_data['acl_at_location'])
-				&& $GLOBALS['phpgw']->config->config_data['acl_at_location']
+			$_config	= CreateObject('phpgwapi.config','property');
+			$_config->read();
+			if(isset($_config->config_data['acl_at_location'])
+				&& $_config->config_data['acl_at_location']
 				&& $category['location_level'] > 0)
 			{
 				$access_location = $this->bocommon->get_location_list(PHPGW_ACL_READ);
@@ -328,6 +360,8 @@
 				$where= 'AND';
 			}
 
+			unset($_config);
+
 			if ($filter=='all')
 			{
 				if (is_array($grants))
@@ -354,7 +388,7 @@
 				$where= 'AND';
 			}
 
-			if ($district_id > 0)
+			if ($district_id > 0 && $category['location_level'])
 			{
 				$filtermethod .= " $where  fm_part_of_town.district_id='$district_id' ";
 				$where = 'AND';
@@ -372,6 +406,24 @@
 				$where= 'AND';			
 			}
 
+			if ($attrib_filter)
+			{
+				$filtermethod .= " $where " . implode(' AND ', $attrib_filter);
+				$where= 'AND';			
+			}
+
+			if ($custom_condition)
+			{
+				$filtermethod .= " {$where} {$custom_condition}";
+				$where= 'AND';			
+			}
+
+			if ($p_num)
+			{
+				$filtermethod .= " $where $entity_table.p_num='$p_num'";
+				$where= 'AND';
+			}
+
 			$_querymethod = array();
 			$__querymethod = array();
 			$_joinmethod_datatype = array();
@@ -395,7 +447,7 @@
 					{
 						$__querymethod = array("{$entity_table}.id = -1"); // block query waiting for criteria
 					}
-//_debug_array($__querymethod);					
+					//_debug_array($__querymethod);					
 
 					$this->db->query("SELECT * FROM $attribute_table WHERE $attribute_filter AND search='1'");
 
@@ -405,25 +457,32 @@
 						{
 							case 'V':
 							case 'email':
-							case 'CH':
+							case 'T':
 								if(!$criteria_id)
 								{
 									$_querymethod[]= "$entity_table." . $this->db->f('column_name') . " {$this->like} '%{$query}%'";
 									$__querymethod = array(); // remove block
 								}
 								break;
+							case 'CH':
+								if(!$criteria_id)
+								{
+									$_querymethod[]= "$entity_table." . $this->db->f('column_name') . " {$this->like} '%,{$query},%'";
+									$__querymethod = array(); // remove block
+								}
+								break;
 							case 'R':
 							case 'LB':
 								if(!$criteria_id)
 								{
 									$_joinmethod_datatype[] = "{$this->join} phpgw_cust_choice ON ({$entity_table}." . $this->db->f('column_name') . " = phpgw_cust_choice.id"
-									." AND phpgw_cust_choice.location_id =" . (int)$this->db->f('location_id')
-									." AND phpgw_cust_choice.attrib_id =" . (int)$this->db->f('id') .')';
-
+										." AND phpgw_cust_choice.location_id =" . (int)$this->db->f('location_id')
+										." AND phpgw_cust_choice.attrib_id =" . (int)$this->db->f('id') .')';
+	
 									$_querymethod[]= "(phpgw_cust_choice.location_id =" . (int)$this->db->f('location_id')
-									." AND phpgw_cust_choice.attrib_id =" . (int)$this->db->f('id')
-									." AND phpgw_cust_choice.value {$this->like} '%{$query}%')";
-
+										." AND phpgw_cust_choice.attrib_id =" . (int)$this->db->f('id')
+										." AND phpgw_cust_choice.value {$this->like} '%{$query}%')";
+	
 									$__querymethod = array(); // remove block
 								}
 								break;
@@ -470,9 +529,9 @@
 			{
 				$sql .= $_joinmethod;
 			}
-			
+
 			$querymethod = '';
-			
+
 			$_querymethod = array_merge($__querymethod, $_querymethod);
 			if ($_querymethod)
 			{
@@ -487,6 +546,11 @@
 			$this->db->next_record();
 			$this->total_records = $this->db->f('cnt');
 
+			if($dry_run)
+			{
+				return array();
+			}
+
 			if(!$allrows)
 			{
 				$this->db->limit_query($sql . $ordermethod,$start,__LINE__,__FILE__);
@@ -504,32 +568,32 @@
 				foreach($cols_return as $key => $field)
 				{
 					$dataset[$j][$field] = array
-					(
-						'value'		=> $this->db->f($field),
-						'datatype'	=> $uicols['datatype'][$key],
-						'attrib_id'	=> $uicols['cols_return_extra'][$key]['attrib_id']
-					);
+						(
+							'value'		=> $this->db->f($field),
+							'datatype'	=> $uicols['datatype'][$key],
+							'attrib_id'	=> $uicols['cols_return_extra'][$key]['attrib_id']
+						);
 				}
 				if($lookup)
 				{
 					$dataset[$j]["entity_cat_name_{$entity_id}"] = array
-					(
-						'value'		=> $category['name'],
-						'datatype'	=> false,
-						'attrib_id'	=> false
-					);
+						(
+							'value'		=> $category['name'],
+							'datatype'	=> false,
+							'attrib_id'	=> false
+						);
 					$dataset[$j]["entity_id_{$entity_id}"] = array
-					(
-						'value'		=> $entity_id,
-						'datatype'	=> false,
-						'attrib_id'	=> false
-					);
+						(
+							'value'		=> $entity_id,
+							'datatype'	=> false,
+							'attrib_id'	=> false
+						);
 					$dataset[$j]["cat_id_{$entity_id}"] = array
-					(
-						'value'		=> $cat_id,
-						'datatype'	=> false,
-						'attrib_id'	=> false
-					);
+						(
+							'value'		=> $cat_id,
+							'datatype'	=> false,
+							'attrib_id'	=> false
+						);
 				}
 				$j++;				
 			}
@@ -541,35 +605,45 @@
 
 		function read_single($data,$values = array())
 		{
-			$entity_id =$data['entity_id'];
-			$cat_id =$data['cat_id'];
-			$id =$data['id'];
+			$entity_id	= isset($data['entity_id']) && $data['entity_id'] ? (int)$data['entity_id'] : $this->entity_id;
+			$cat_id		= isset($data['cat_id']) && $data['cat_id'] ? (int)$data['cat_id'] : $this->cat_id;
+			$id			= (int)$data['id'];
+			$num		= isset($data['num']) && $data['num'] ? $data['num'] : '';
 			$table = "fm_{$this->type}_{$entity_id}_{$cat_id}";
 
-				$this->db->query("SELECT * FROM $table WHERE id =$id");
+			if($num)
+			{
+				$filtermethod = "WHERE num = '{$num}'";
+			}
+			else
+			{
+				$filtermethod = "WHERE id = {$id}";
+			}
+			
+			$this->db->query("SELECT * FROM {$table} {$filtermethod}");
 
-				if($this->db->next_record())
+			if($this->db->next_record())
+			{
+				$values['id']				= $id;
+				$values['num']				= $this->db->f('num');
+				$values['p_num']			= $this->db->f('p_num');
+				$values['p_entity_id']		= $this->db->f('p_entity_id');
+				$values['p_cat_id']			= $this->db->f('p_cat_id');
+				$values['location_code']	= $this->db->f('location_code');
+				$values['tenant_id']		= $this->db->f('tenant_id');
+				$values['contact_phone']	= $this->db->f('contact_phone');
+				$values['status']			= $this->db->f('status');
+				$values['user_id']			= $this->db->f('user_id');
+				$values['entry_date']		= $this->db->f('entry_date');
+
+				if ( isset($values['attributes']) && is_array($values['attributes']) )
 				{
-					$values['id']				= $id;
-					$values['num']				= $this->db->f('num');
-					$values['p_num']			= $this->db->f('p_num');
-					$values['p_entity_id']		= $this->db->f('p_entity_id');
-					$values['p_cat_id']			= $this->db->f('p_cat_id');
-					$values['location_code']	= $this->db->f('location_code');
-					$values['tenant_id']		= $this->db->f('tenant_id');
-					$values['contact_phone']	= $this->db->f('contact_phone');
-					$values['status']			= $this->db->f('status');
-					$values['user_id']			= $this->db->f('user_id');
-					$values['entry_date']		= $this->db->f('entry_date');
-
-					if ( isset($values['attributes']) && is_array($values['attributes']) )
+					foreach ( $values['attributes'] as &$attr )
 					{
-						foreach ( $values['attributes'] as &$attr )
-						{
-							$attr['value'] 	= $this->db->f($attr['column_name']);
-						}
+						$attr['value'] 	= $this->db->f($attr['column_name']);
 					}
 				}
+			}
 
 			return	$values;
 		}
@@ -646,7 +720,7 @@
 				$cols[] = 'location_code';
 				$vals[] = $values['location_code'];			
 			}
-			
+
 			if(isset($values['location']) && is_array($values['location']))
 			{
 				foreach ($values['location'] as $input_name => $value)
@@ -721,14 +795,14 @@
 				if($values['origin'][0]['data'][0]['id'])
 				{
 					$interlink_data = array
-					(
-						'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $values['origin'][0]['location']),
-						'location1_item_id' => $values['origin'][0]['data'][0]['id'],
-						'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', ".{$this->type}.{$entity_id}.{$cat_id}"),
-						'location2_item_id' => $values['id'],
-						'account_id'		=> $this->account
-					);
-					
+						(
+							'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $values['origin'][0]['location']),
+							'location1_item_id' => $values['origin'][0]['data'][0]['id'],
+							'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', ".{$this->type}.{$entity_id}.{$cat_id}"),
+							'location2_item_id' => $values['id'],
+							'account_id'		=> $this->account
+						);
+
 					$interlink 	= CreateObject('property.interlink');
 					$interlink->add($interlink_data,$this->db);
 				}
@@ -775,7 +849,7 @@
 
 			if (isset($values['location_code']) && $values['location_code'])
 			{
-					$value_set['location_code'] = $values['location_code'];
+				$value_set['location_code'] = $values['location_code'];
 			}
 
 			$admin_location	= CreateObject('property.soadmin_location');
@@ -840,19 +914,27 @@
 
 					if($entry['history'] == 1)
 					{
-						$this->db->query("select " . $entry['name'] . " from $table WHERE id=" . $values['id'],__LINE__,__FILE__);
+						$this->db->query("SELECT {$entry['name']} FROM {$table} WHERE id = '{$values['id']}'",__LINE__,__FILE__);
 						$this->db->next_record();
-						$old_value = $this->db->f($entry['name']);
+						$old_value = $this->db->f($entry['name'],true);
+
+						if($entry['datatype'] == 'D')
+						{
+							$old_value = date(phpgwapi_db::date_format(), strtotime($old_value));
+						}
+
 						if($entry['value'] != $old_value)
 						{
-							$history_set[$entry['attrib_id']] = array('value' => $entry['value'],
-												'date'  => $this->bocommon->date_to_timestamp($entry['date']));
+							$history_set[$entry['attrib_id']] = array
+							(
+								'value' => $entry['value'],
+								'date'  => $this->bocommon->date_to_timestamp($entry['date'])
+							);
 						}
 					}
 				}
 			}
 
-//_debug_array($history_set);
 			$value_set	= $this->db->validate_update($value_set);
 
 			$this->db->transaction_begin();
@@ -916,7 +998,7 @@
 
 			$cat_id = (int)$data['cat_id'];
 			$entity_id = (int)$data['entity_id'];
-			$id = (int)$data['id'];
+			$id = $data['id'];
 
 			$entity = array();
 
@@ -934,12 +1016,12 @@
 				while ($this->db->next_record())
 				{
 					$category[] = array
-					(
-						'entity_id'	=> $this->db->f('entity_id'),
-						'cat_id'	=> $this->db->f('id'),
-						'name'		=> $this->db->f('name'),
-						'descr'		=> $this->db->f('descr')
-					);
+						(
+							'entity_id'	=> $this->db->f('entity_id'),
+							'cat_id'	=> $this->db->f('id'),
+							'name'		=> $this->db->f('name'),
+							'descr'		=> $this->db->f('descr')
+						);
 				}
 
 				foreach($category as $entry)
@@ -948,25 +1030,25 @@
 					{
 						continue;
 					}
-					
+
 					$sql = "SELECT count(*) as hits FROM fm_{$type}_{$entry['entity_id']}_{$entry['cat_id']} WHERE p_entity_id = {$entity_id} AND p_cat_id = {$cat_id} AND p_num = '{$id}'";
 					$this->db->query($sql,__LINE__,__FILE__);
 					$this->db->next_record();
 					if($this->db->f('hits'))
 					{
 						$entity['related'][] = array
-						(
-							'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array
-															(
-																'menuaction'	=> "property.ui{$type}.index",
-																'entity_id'		=> $entry['entity_id'],
-																'cat_id'		=> $entry['cat_id'],
-																'p_entity_id'	=> $entity_id,
-																'p_cat_id' 		=> $cat_id,
-																'p_num' 		=> $id,
-																'type'			=> $type
-															)
-														),
+							(
+								'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array
+								(
+									'menuaction'	=> "property.uientity.index",
+									'entity_id'		=> $entry['entity_id'],
+									'cat_id'		=> $entry['cat_id'],
+									'p_entity_id'	=> $entity_id,
+									'p_cat_id' 		=> $cat_id,
+									'p_num' 		=> $id,
+									'type'			=> $type
+								)
+							),
 							'name'			=> $entry['name'] . ' [' . $this->db->f('hits') . ']',
 							'descr'			=> $entry['descr']
 						);
@@ -981,15 +1063,15 @@
 			{
 				$hits = $this->db->f('hits');
 				$entity['related'][] = array
-				(
-					'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitts.index',
-														//	'p_entity_id'	=> $entity_id,
-														//	'p_cat_id' 		=> $cat_id,
-															'p_num' 		=> $id,
-															'query'=> "entity.{$entry['entity_id']}.{$entry['cat_id']}.{$id}")),
-					'name'		=> lang('Helpdesk') . " [{$hits}]",
-					'descr'		=> lang('Helpdesk')
-				);
+					(
+						'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitts.index',
+					//	'p_entity_id'	=> $entity_id,
+					//	'p_cat_id' 		=> $cat_id,
+						'p_num' 		=> $id,
+						'query'=> "entity.{$entity_id}.{$cat_id}.{$id}")),
+						'name'		=> lang('Helpdesk') . " [{$hits}]",
+						'descr'		=> lang('Helpdesk')
+					);
 			}
 
 			$sql = "SELECT count(*) as hits FROM fm_request WHERE p_entity_id = {$entity_id} AND p_cat_id = {$cat_id} AND p_num = '{$id}'";
@@ -999,15 +1081,15 @@
 			{
 				$hits = $this->db->f('hits');
 				$entity['related'][] = array
-				(
-					'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'property.uirequest.index',
-													//		'p_entity_id'	=> $entity_id,
-													//		'p_cat_id' 		=> $cat_id,
-															'p_num' 		=> $id,
-															'query'=> "entity.{$entry['entity_id']}.{$entry['cat_id']}.{$id}")),
-					'name'		=> lang('request') . " [{$hits}]",
-					'descr'		=> lang('request')
-				);
+					(
+						'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'property.uirequest.index',
+					//	'p_entity_id'	=> $entity_id,
+					//	'p_cat_id' 		=> $cat_id,
+						'p_num' 		=> $id,
+						'query'=> "entity.{$entity_id}.{$cat_id}.{$id}")),
+						'name'		=> lang('request') . " [{$hits}]",
+						'descr'		=> lang('request')
+					);
 			}
 
 			$sql = "SELECT count(*) as hits FROM fm_project WHERE p_entity_id = {$entity_id} AND p_cat_id = {$cat_id} AND p_num = '{$id}'";
@@ -1017,13 +1099,29 @@
 			{
 				$hits = $this->db->f('hits');
 				$entity['related'][] = array
-				(
-					'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'property.uiproject.index',
-															'query'=> "entity.{$entry['entity_id']}.{$entry['cat_id']}.{$id}",
-															'criteria_id' => 6)), //FIXME: criteria 6 is for entities should be altered to locations
-					'name'		=> lang('project') . " [{$hits}]",
-					'descr'		=> lang('project')
-				);
+					(
+						'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'property.uiproject.index',
+						'query'=> "entity.{$entity_id}.{$cat_id}.{$id}",
+						'criteria_id' => 6)), //FIXME: criteria 6 is for entities should be altered to locations
+						'name'		=> lang('project') . " [{$hits}]",
+						'descr'		=> lang('project')
+					);
+			}
+
+			$sql = "SELECT count(*) as hits FROM fm_s_agreement {$this->join} fm_s_agreement_detail ON fm_s_agreement.id = fm_s_agreement_detail.agreement_id WHERE p_entity_id = {$entity_id} AND p_cat_id = {$cat_id} AND p_num = '{$id}'";
+			$this->db->query($sql,__LINE__,__FILE__);
+			$this->db->next_record();
+			if($this->db->f('hits'))
+			{
+				$hits = $this->db->f('hits');
+				$entity['related'][] = array
+					(
+						'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'property.uis_agreement.index',
+																'query'	=> "entity.{$entity_id}.{$cat_id}.{$id}",
+																'p_num' => $id)),
+						'name'			=> lang('service agreement') . " [{$hits}]",
+						'descr'			=> lang('service agreement')
+					);
 			}
 
 			return $entity;
