@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage location
- 	* @version $Id: class.sogab.inc.php 4709 2010-02-02 15:18:50Z sigurd $
+ 	* @version $Id: class.sogab.inc.php 6975 2011-02-11 14:37:21Z sigurdne $
 	*/
 
 	/**
@@ -71,9 +71,11 @@
 				$check_payments	= isset($data['check_payments']) ? $data['check_payments'] : '';
 			}
 
+
+
 			if ($order)
 			{
-				$ordermethod = " order by fm_gab_location.$order $sort";
+				$ordermethod = " order by fm_gab_location.{$order} {$sort}";
 			}
 			else
 			{
@@ -85,39 +87,52 @@
 
 			if ($cat_id > 0)
 			{
-				$filtermethod .= " $where fm_gab_location.category='$cat_id' ";
+				$filtermethod .= " {$where} fm_gab_location.category='{$cat_id}' ";
 				$where = 'AND';
 			}
 
 			if ($address)
 			{
-				$filtermethod .= " $where fm_gab_location.address $this->like '%$address%' ";
+				$filtermethod .= " {$where} fm_gab_location.address {$this->like} '%{$address}%' ";
 				$where = 'AND';
 			}
 			if ($location_code)
 			{
-				$filtermethod .= " $where fm_gab_location.location_code $this->like '$location_code%' ";
+				$location_code = explode('-',$location_code);
+				$i = 1;		
+				foreach($location_code as $_loc)
+				{
+					$loc[] = $_loc;
+					if($i == $this->gab_insert_level)
+					{
+						break;
+					}
+					$i++;
+				}
+				$location_code = implode('-', $loc);
+
+				$filtermethod .= " {$where} fm_gab_location.location_code {$this->like} '{$location_code}%' ";
 				$where = 'AND';
 			}
 
 			if ($gaards_nr)
 			{
-				$filtermethod .= " $where SUBSTRING(gab_id,5,5) $this->like '%$gaards_nr' ";
+				$filtermethod .= " {$where} SUBSTRING(gab_id,5,5) {$this->like} '%$gaards_nr' ";
 				$where = 'AND';
 			}
 			if ($bruksnr)
 			{
-				$filtermethod .= " $where SUBSTRING(gab_id,10,4) $this->like '%$bruksnr' ";
+				$filtermethod .= " {$where} SUBSTRING(gab_id,10,4) {$this->like} '%$bruksnr' ";
 				$where = 'AND';
 			}
 			if ($feste_nr)
 			{
-				$filtermethod .= " $where SUBSTRING(gab_id,14,4) $this->like '%$feste_nr' ";
+				$filtermethod .= " {$where} SUBSTRING(gab_id,14,4) {$this->like} '%$feste_nr' ";
 				$where = 'AND';
 			}
 			if ($seksjons_nr)
 			{
-				$filtermethod .= " $where SUBSTRING(gab_id,18,3) $this->like '%$seksjons_nr' ";
+				$filtermethod .= " {$where} SUBSTRING(gab_id,18,3) {{$this->like}} '%$seksjons_nr' ";
 				$where = 'AND';
 			}
 
@@ -142,19 +157,19 @@
 
 			if($check_payments)
 			{
-//				$sql = "SELECT gab_id,count(gab_id) as hits, address ,fm_gab_location.loc1 as location_code, fm_gab_location.owner as owner FROM fm_gab_location $joinmethod $filtermethod GROUP BY gab_id,fm_gab_location.loc1,address,owner ";
-//				$sql = "SELECT DISTINCT gab_id, fm_gab_location.loc1 as location_code, fm_gab_location.owner as owner FROM fm_gab_location $joinmethod $filtermethod GROUP BY gab_id,fm_gab_location.loc1,address,owner ";
-//				$sql = "SELECT gab_id, fm_gab_location.loc1 as location_code, fm_gab_location.owner as owner FROM fm_gab_location $joinmethod $filtermethod GROUP BY gab_id,fm_gab_location.loc1,address,owner ";
+				//				$sql = "SELECT gab_id,count(gab_id) as hits, address ,fm_gab_location.loc1 as location_code, fm_gab_location.owner as owner FROM fm_gab_location $joinmethod $filtermethod GROUP BY gab_id,fm_gab_location.loc1,address,owner ";
+				//				$sql = "SELECT DISTINCT gab_id, fm_gab_location.loc1 as location_code, fm_gab_location.owner as owner FROM fm_gab_location $joinmethod $filtermethod GROUP BY gab_id,fm_gab_location.loc1,address,owner ";
+				//				$sql = "SELECT gab_id, fm_gab_location.loc1 as location_code, fm_gab_location.owner as owner FROM fm_gab_location $joinmethod $filtermethod GROUP BY gab_id,fm_gab_location.loc1,address,owner ";
 
 				$spvend_code = 9901;
 				$spbudact_code = '11954111';
 				switch($GLOBALS['phpgw_info']['server']['db_type'])
 				{
-					case 'postgres':
-						$due_date 		= "to_char(forfallsdato,'MM/YYYY') as due_date";
-						break;
-					default:
-						$due_date 		= "to_char(forfallsdato,'MM/YYYY') as due_date";
+				case 'postgres':
+					$due_date 		= "to_char(forfallsdato,'MM/YYYY') as due_date";
+					break;
+				default:
+					$due_date 		= "to_char(forfallsdato,'MM/YYYY') as due_date";
 				}
 
 				$sql = "SELECT sum(belop) as paid, count(fm_ecobilagoverf.loc1) as hits, {$due_date}, fm_ecobilagoverf.loc1, owner"
@@ -186,13 +201,13 @@
 				while ($this->db->next_record())
 				{
 					$gab_list[] = array
-					(
-						'gab_id'		=> $this->db->f('gab_id'),
-						'location_code'	=> $this->db->f('location_code'),
-						'address'		=> $this->db->f('address',true),
-						'hits'			=> $this->db->f('hits'),
-						'owner'			=> $this->db->f('owner')
-					);
+						(
+							'gab_id'		=> $this->db->f('gab_id'),
+							'location_code'	=> $this->db->f('location_code'),
+							'address'		=> $this->db->f('address',true),
+							'hits'			=> $this->db->f('hits'),
+							'owner'			=> $this->db->f('owner')
+						);
 				}
 			}
 			else
@@ -211,15 +226,15 @@
 				while ($this->db->next_record())
 				{
 					$gross_list[] = array
-					(
-						'gab_id'		=> '00000000000000000000',//$this->db->f('gab_id'),
-						'location_code'	=> $this->db->f('loc1'),
-						'address'		=> $this->db->f('address',true),
-						'hits'			=> $this->db->f('hits'),
-						'owner'			=> $this->db->f('owner'),
-						'paid'			=> $this->db->f('paid'),
-						'due_date'		=> $this->db->f('due_date'),
-					);
+						(
+							'gab_id'		=> '00000000000000000000',//$this->db->f('gab_id'),
+							'location_code'	=> $this->db->f('loc1'),
+							'address'		=> $this->db->f('address',true),
+							'hits'			=> $this->db->f('hits'),
+							'owner'			=> $this->db->f('owner'),
+							'paid'			=> $this->db->f('paid'),
+							'due_date'		=> $this->db->f('due_date'),
+						);
 					$dates[$this->db->f('due_date')] = true;
 				}
 
@@ -232,13 +247,13 @@
 					if(!isset($location_buffer[$entry['location_code']]))
 					{
 						$gab_list[$i] = array
-						(
-							'location_code'	=> $entry['location_code'],
-							'gab_id'		=> $entry['gab_id'],
-							'address'		=> $entry['address'],
-							'hits'			=> $entry['hits'],
-							'owner'			=> $entry['owner']
-						);
+							(
+								'location_code'	=> $entry['location_code'],
+								'gab_id'		=> $entry['gab_id'],
+								'address'		=> $entry['address'],
+								'hits'			=> $entry['hits'],
+								'owner'			=> $entry['owner']
+							);
 						$location_buffer[$entry['location_code']] = true;
 						$j = $i;
 						$i++;
@@ -274,7 +289,7 @@
 					}
 
 				}
-*/
+ */
 				$this->payment_date=$payment_date;
 			}
 
@@ -311,7 +326,7 @@
 			$cols_return[] = 'address';
 
 			$sql	= $this->bocommon->generate_sql(array('entity_table'=>$entity_table,'cols'=>$cols,'cols_return'=>$cols_return,
-							'uicols'=>$uicols,'joinmethod'=>$joinmethod,'paranthesis'=>$paranthesis,'query'=>$query));
+				'uicols'=>$uicols,'joinmethod'=>$joinmethod,'paranthesis'=>$paranthesis,'query'=>$query));
 
 
 			if ($order)
@@ -331,24 +346,24 @@
 			}
 
 			$sql .= " $filtermethod ";
-//echo $sql;
+			//echo $sql;
 			$this->uicols		= $this->bocommon->uicols;
 
-			$this->uicols['input_type'][]		= 'text';
+			$this->uicols['input_type'][]	= 'text';
 			$this->uicols['name'][]			= 'owner';
 			$this->uicols['descr'][]		= lang('owner');
-			$this->uicols['statustext'][]		= lang('owner');
-			$this->uicols['input_type'][]		= 'text';
+			$this->uicols['statustext'][]	= lang('owner');
+			$this->uicols['input_type'][]	= 'text';
 			$this->uicols['name'][]			= 'location_code';
 			$this->uicols['descr'][]		= 'location code';
 			$this->uicols['statustext'][]	= 'location code';
-			$this->uicols['input_type'][]		= 'text';
+			$this->uicols['input_type'][]	= 'text';
 			$this->uicols['name'][]			= 'address';
 			$this->uicols['descr'][]		= lang('address');
 			$this->uicols['statustext'][]	= lang('address');
 
 			$cols_return		= $this->bocommon->cols_return;
-			$type_id		= $this->bocommon->type_id;
+			$type_id			= $this->bocommon->type_id;
 			$this->cols_extra	= $this->bocommon->cols_extra;
 
 
@@ -373,7 +388,7 @@
 				}
 
 				$location_code=	$this->db->f('location_code');
-				$location = split('-',$location_code);
+				$location = explode('-',$location_code);
 				for ($m=0;$m<count($location);$m++)
 				{
 					$gab_list[$j]['loc' . ($m+1)] = $location[$m];
@@ -398,8 +413,8 @@
 				$gab['owner']			= $this->db->f('owner');
 			}
 
-//_debug_array($gab);
-				return $gab;
+			//_debug_array($gab);
+			return $gab;
 		}
 
 		function exist_gab_location($gab_id='',$location_code='')
@@ -420,7 +435,7 @@
 			$location = explode('-', $gab['location_code']);
 			$next_type	= count($location)+1;
 
-//_debug_array($gab);
+			//_debug_array($gab);
 
 			$where= 'WHERE';
 			for ($i=0;$i<count($location);$i++)
@@ -451,18 +466,18 @@
 					if(!$this->exist_gab_location($gab_id,$this->db->f('location_code')))
 					{
 						$gab_insert[] = array('location_code'	=> $this->db->f('location_code'),
-												'gab_id'		=> $gab_id,
-												'location_name'	=> $this->db->f('location_name'),
-												'remark'		=> $gab['remark'],
-												'owner'			=> $gab['owner']);
+							'gab_id'		=> $gab_id,
+							'location_name'	=> $this->db->f('location_name'),
+							'remark'		=> $gab['remark'],
+							'owner'			=> $gab['owner']);
 					}
 					else
 					{
 						$gab_update[] = array('location_code'	=> $this->db->f('location_code'),
-												'gab_id'		=> $gab_id,
-												'location_name'	=> $this->db->f('location_name'),
-												'remark'		=> $gab['remark'],
-												'owner'			=> $gab['owner']);
+							'gab_id'		=> $gab_id,
+							'location_name'	=> $this->db->f('location_name'),
+							'remark'		=> $gab['remark'],
+							'owner'			=> $gab['owner']);
 					}
 				}
 			}
@@ -471,12 +486,12 @@
 				if(count($location)==$this->gab_insert_level)
 				{
 					$gab_insert[] = array('location_code'=> $gab['location_code'],
-										'gab_id'	=> $gab_id,
-										'street_name'	=> $gab['street_name'],
-										'street_number'	=> $gab['street_number'],
-										'location_name'	=> $gab['location_name'],
-										'remark'	=> $gab['remark'],
-										'owner'			=> $gab['owner']);
+						'gab_id'	=> $gab_id,
+						'street_name'	=> $gab['street_name'],
+						'street_number'	=> $gab['street_number'],
+						'location_name'	=> $gab['location_name'],
+						'remark'	=> $gab['remark'],
+						'owner'			=> $gab['owner']);
 				}
 			}
 
@@ -545,7 +560,7 @@
 					. $this->account. "','"
 					. $address . "' $vals )",__LINE__,__FILE__);
 
-					$receipt['message'][] = array('msg'=>lang('at location %1',$gab_insert[$i]['location_code']));
+				$receipt['message'][] = array('msg'=>lang('at location %1',$gab_insert[$i]['location_code']));
 
 				unset($location);
 				unset($col);
@@ -573,7 +588,7 @@
 					user_id			='" . $this->account
 					. "' WHERE location_code = '" . $gab_update[$i]['location_code'] ."' AND gab_id= '" . $gab_update[$i]['gab_id'] . "'",__LINE__,__FILE__);
 
-					$receipt['message'][] = array('msg'=>lang('at location %1',$gab_update[$i]['location_code']));
+				$receipt['message'][] = array('msg'=>lang('at location %1',$gab_update[$i]['location_code']));
 			}
 
 			return $receipt;
@@ -583,7 +598,7 @@
 		{
 			$location = explode('-', $gab['location_code']);
 
-//_debug_array($gab);
+			//_debug_array($gab);
 
 			if(!$gab['owner'])
 			{
