@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage eco
- 	* @version $Id: class.soinvoice.inc.php 6275 2010-08-26 18:00:32Z sigurd $
+ 	* @version $Id: class.soinvoice.inc.php 7070 2011-03-04 13:31:32Z sigurdne $
 	*/
 
 	/**
@@ -34,8 +34,9 @@
 
 	class property_soinvoice
 	{
-		var $total_records = 0;
-		var $role = array();
+		public $total_records = 0;
+		public $sum_amount = 0;
+		public $role = array();
 		protected $invoice_approval = 2;
 
 		function __construct()
@@ -55,15 +56,15 @@
 		{
 
 			$valid_order = array
-			(
-				'bilagsnr'			=> true,
-				'spvend_code'		=> true,
-				'fakturadato'		=> true,
-				'oppsynsigndato'	=> true,
-				'saksigndato'		=> true,
-				'budsjettsigndato'	=> true,
-				'periode'			=> true
-			);
+				(
+					'bilagsnr'			=> true,
+					'spvend_code'		=> true,
+					'fakturadato'		=> true,
+					'oppsynsigndato'	=> true,
+					'saksigndato'		=> true,
+					'budsjettsigndato'	=> true,
+					'periode'			=> true
+				);
 
 			$start			= isset($data['start']) && $data['start'] ? $data['start'] : 0;
 			$query 			= isset($data['query'])?$data['query']:'';
@@ -85,8 +86,8 @@
 			$join_tables	= '';
 			$filtermethod	= '';
 			$querymethod	= '';
-//_debug_array($data);
-			
+			//_debug_array($data);
+
 			$this->db->query("SELECT * FROM fm_ecoart");
 			$art_list = array();
 			while ($this->db->next_record())
@@ -105,16 +106,15 @@
 
 			$where= 'WHERE';
 
-			if ($user_lid=='none' || !$user_lid):
+			if ($user_lid=='none' || !$user_lid)
 			{
-				return;
+				return array();
 			}
-			elseif ($user_lid!='all'):
+			else if ($user_lid!='all')
 			{
 				$filtermethod = " WHERE ( oppsynsmannid= '$user_lid' or saksbehandlerid= '$user_lid' or budsjettansvarligid= '$user_lid')";
 				$where= 'AND';
 			}
-			endif;
 
 			if ($cat_id > 0)
 			{
@@ -126,7 +126,7 @@
 			{
 				$filtermethod .= " $where  district_id='$district_id' ";
 				$join_tables = " $this->join fm_location1 ON fm_ecobilagoverf.loc1 = fm_location1.loc1"
-						. " $this->join fm_part_of_town ON (fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id)";
+					. " $this->join fm_part_of_town ON (fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id)";
 				$where= 'AND';
 			}
 
@@ -140,19 +140,6 @@
 				$filtermethod .= " $where  dima $this->like '%$loc1%' ";
 				$where= 'AND';
 			}
-			if ($workorder_id)
-			{
-				$filtermethod .= " $where  pmwrkord_code ='$workorder_id' ";
-				$where= 'AND';
-			}
-
-
-			if ($voucher_id)
-			{
-				$filtermethod .= " $where  bilagsnr = " . (int)$voucher_id;
-				$where= 'AND';
-			}
-
 
 			if ($paid)
 			{
@@ -165,12 +152,13 @@
 					$join_tables .= " $this->join fm_b_account ON fm_ecobilagoverf.spbudact_code = fm_b_account.id";
 				}
 
-				if (!$workorder_id && !$voucher_id  && $start_date)
+				if (!$workorder_id && !$voucher_id)
 				{
 					$start_periode = date('Ym',$start_date);
 					$end_periode = date('Ym',$end_date);
 
 					$filtermethod .= " $where (periode >='$start_periode' AND periode <= '$end_periode')";
+					$where= 'AND';
 				}
 			}
 			else
@@ -178,7 +166,20 @@
 				$table ='fm_ecobilag';
 			}
 
-			if($query)
+			$no_q = false;
+			if ($voucher_id)
+			{
+				$filtermethod = " WHERE bilagsnr = " . (int)$voucher_id;
+				$no_q = true;
+			}
+
+			if ($workorder_id)
+			{
+				$filtermethod = " WHERE pmwrkord_code ='$workorder_id' ";
+				$no_q = true;
+			}
+
+			if($query && !$no_q)
 			{
 				$query = (int) $query;
 				$querymethod = " $where ( spvend_code = {$query} OR bilagsnr = {$query})";
@@ -190,6 +191,12 @@
 			$this->db->query($sql2,__LINE__,__FILE__);
 			$this->total_records = $this->db->num_rows();
 
+			$sql3 = "SELECT sum(belop) as sum_amount FROM  $table $join_tables $filtermethod $querymethod";
+			$this->db->query($sql3,__LINE__,__FILE__);
+			$this->db->next_record();
+			$this->sum_amount		= $this->db->f('sum_amount');
+
+
 			if(!$allrows)
 			{
 				$this->db->limit_query($sql . $ordermethod,$start,__LINE__,__FILE__);
@@ -203,14 +210,15 @@
 			while ($this->db->next_record())
 			{
 				$temp[] = array
-				(
-					'voucher_id'		=> $this->db->f('bilagsnr'),
-					'invoice_count'		=> $this->db->f('invoice_count'),
-					'amount'		=> $this->db->f('belop')
+					(
+						'voucher_id'		=> $this->db->f('bilagsnr'),
+						'invoice_count'		=> $this->db->f('invoice_count'),
+						'amount'		=> $this->db->f('belop')
 					);
 			}
 
-			$invoice = array();
+			$invoice	= array();
+
 			if ($temp)
 			{
 				$role= $this->check_role();
@@ -219,13 +227,13 @@
 				{
 					$voucher_id = $invoice_temp['voucher_id'];
 
-					$sql = "SELECT spvend_code,oppsynsmannid,saksbehandlerid,budsjettansvarligid,"
-					. " utbetalingid,oppsynsigndato,saksigndato,budsjettsigndato,utbetalingsigndato,fakturadato,org_name,"
-					. " forfallsdato,periode,artid,kidnr,kreditnota "
-					. " from $table $this->join fm_vendor ON fm_vendor.id = $table.spvend_code WHERE bilagsnr = $voucher_id "
-					. " group by bilagsnr,spvend_code,oppsynsmannid,saksbehandlerid,budsjettansvarligid,"
-					. " utbetalingid,oppsynsigndato,saksigndato,budsjettsigndato,utbetalingsigndato,fakturadato,org_name,"
-					. " forfallsdato,periode,artid,kidnr,kreditnota ";
+					$sql = "SELECT pmwrkord_code,spvend_code,oppsynsmannid,saksbehandlerid,budsjettansvarligid,"
+						. " utbetalingid,oppsynsigndato,saksigndato,budsjettsigndato,utbetalingsigndato,fakturadato,org_name,"
+						. " forfallsdato,periode,artid,kidnr,kreditnota,currency "
+						. " FROM {$table} {$this->join} fm_vendor ON fm_vendor.id = {$table}.spvend_code WHERE bilagsnr = {$voucher_id} "
+						. " GROUP BY bilagsnr,pmwrkord_code,spvend_code,oppsynsmannid,saksbehandlerid,budsjettansvarligid,"
+						. " utbetalingid,oppsynsigndato,saksigndato,budsjettsigndato,utbetalingsigndato,fakturadato,org_name,"
+						. " forfallsdato,periode,artid,kidnr,kreditnota,currency";
 
 					$this->db->query($sql,__LINE__,__FILE__);
 
@@ -253,7 +261,7 @@
 
 					if($this->db->f('budsjettansvarligid') && $this->db->f('budsjettsigndato'))
 					{
-							$invoice[$i]['budget_date']=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($this->db->f('budsjettsigndato')));
+						$invoice[$i]['budget_date']=date($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],strtotime($this->db->f('budsjettsigndato')));
 					}
 					else
 					{
@@ -278,7 +286,6 @@
 					$invoice[$i]['is_janitor']				= $role['is_janitor'];
 					$invoice[$i]['is_supervisor']			= $role['is_supervisor'];
 					$invoice[$i]['is_budget_responsible']	= $role['is_budget_responsible'];
-					$invoice[$i]['is_janitor']				= $role['is_janitor'];
 					$invoice[$i]['is_transfer']				= $role['is_transfer'];
 					$invoice[$i]['janitor']					= $this->db->f('oppsynsmannid');
 					$invoice[$i]['supervisor']				= $this->db->f('saksbehandlerid');
@@ -290,30 +297,31 @@
 					$invoice[$i]['type']					= $art_list[$this->db->f('artid')];
 					$invoice[$i]['kidnr']					= $this->db->f('kidnr');
 					$invoice[$i]['kreditnota']				= $this->db->f('kreditnota');
+					$invoice[$i]['currency']				= $this->db->f('currency');
+					$invoice[$i]['order_id']				= $this->db->f('pmwrkord_code');
 					$invoice[$i]['amount']					= $invoice_temp['amount'];
 					$invoice[$i]['num_days']				= intval(($timestamp_payment_date-$timestamp_voucher_date)/(24*3600));
 					$invoice[$i]['timestamp_voucher_date']	= $timestamp_voucher_date;
 
-					if($invoice[$i]['current_user']==$invoice[$i]['janitor'] && $invoice[$i]['jan_date']):
+					if($invoice[$i]['current_user']==$invoice[$i]['janitor'] && $invoice[$i]['jan_date'])
 					{
 						$invoice[$i]['sign_orig']='sign_janitor';
 					}
-					elseif($invoice[$i]['current_user']==$invoice[$i]['supervisor'] && $invoice[$i]['super_date']):
+					else if($invoice[$i]['current_user']==$invoice[$i]['supervisor'] && $invoice[$i]['super_date'])
 					{
 						$invoice[$i]['sign_orig']='sign_supervisor';
 					}
-					elseif($invoice[$i]['current_user']==$invoice[$i]['budget_responsible'] && $invoice[$i]['budget_date']):
+					else if($invoice[$i]['current_user']==$invoice[$i]['budget_responsible'] && $invoice[$i]['budget_date'])
 					{
 						$invoice[$i]['sign_orig']='sign_budget_responsible';
 					}
-					endif;
 
 					$i++;
 
 				}
 			}
-//_debug_array($invoice);
-//_debug_array($invoice_temp);
+			//_debug_array($invoice);
+			//_debug_array($invoice_temp);
 
 			return $invoice;
 
@@ -322,15 +330,14 @@
 
 		function read_invoice_sub($data)
 		{
-			if(is_array($data))
-			{
-				$start		= isset($data['start']) && $data['start'] ? $data['start'] : 0;
-				$filter		= isset($data['filter']) ? $data['filter'] : 'none';
-				$sort		= isset($data['sort']) ? $data['sort'] : 'DESC';
-				$order		= isset($data['order']) ? $data['order'] : '';
-				$voucher_id	= isset($data['voucher_id']) && $data['voucher_id'] ? $data['voucher_id'] : 0;
-				$paid		= isset($data['paid']) ? $data['paid'] : '';
-			}
+			$start		= isset($data['start']) && $data['start'] ? (int)$data['start'] : 0;
+			$filter		= isset($data['filter']) ? $data['filter'] : 'none';
+			$sort		= isset($data['sort']) ? $data['sort'] : 'DESC';
+			$order		= isset($data['order']) ? $data['order'] : '';
+			$voucher_id	= isset($data['voucher_id']) && $data['voucher_id'] ? (int)$data['voucher_id'] : 0;
+			$paid		= isset($data['paid']) ? $data['paid'] : '';
+			$project_id	= isset($data['project_id']) && $data['project_id'] ? (int)$data['project_id'] : 0;
+			$order_id 	= isset($data['order_id']) && $data['order_id'] ? $data['order_id'] : 0 ;//might be bigint
 
 			if ($paid)
 			{
@@ -351,15 +358,32 @@
 				$ordermethod = ' order by id DESC';
 			}
 
+			$filtermethod = '';
+			$where = 'WHERE';
+
 			if ($voucher_id)
 			{
-				$filtermethod = " WHERE ( bilagsnr= '$voucher_id')";
+				$filtermethod .= " {$where} bilagsnr= '$voucher_id'";
+				$where = 'AND';
 			}
 
-			$sql = "SELECT $table.*,fm_workorder.status,fm_workorder.charge_tenant,org_name,fm_workorder.claim_issued, fm_workorder.paid_percent, project_group FROM $table"
-			. " $this->left_join fm_workorder ON fm_workorder.id = $table.pmwrkord_code"
-			. " $this->left_join fm_project ON fm_workorder.project_id = fm_project.id"
-			. " $this->join fm_vendor ON $table.spvend_code = fm_vendor.id $filtermethod";
+			if ($order_id)
+			{
+				$filtermethod .= " {$where} pmwrkord_code= '{$order_id}'";
+				$where = 'AND';
+			}
+
+			if ($project_id)
+			{
+				$filtermethod .= " {$where} fm_project.id = '{$project_id}'";
+				$where = 'AND';
+			}
+
+			$sql = "SELECT $table.*,fm_workorder.status,fm_workorder.charge_tenant,org_name,"
+				. "fm_workorder.claim_issued, fm_workorder.paid_percent FROM $table"
+				. " $this->left_join fm_workorder ON fm_workorder.id = $table.pmwrkord_code"
+				. " $this->left_join fm_project ON fm_workorder.project_id = fm_project.id"
+				. " $this->join fm_vendor ON $table.spvend_code = fm_vendor.id $filtermethod";
 
 			$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
 			$this->total_records = $this->db->num_rows();
@@ -371,29 +395,33 @@
 			while ($this->db->next_record())
 			{
 				$invoice[] = array
-				(
-					'counter'				=> $i,
-					'claim_issued'			=> $this->db->f('claim_issued'),
-					'project_id'			=> $this->db->f('project_id'),
-					'workorder_id'			=> $this->db->f('pmwrkord_code'),
-					'status'				=> $this->db->f('status'),
-					'closed'				=> $this->db->f('status') == $closed,
-					'voucher_id'			=> $voucher_id,
-					'id'					=> $this->db->f('id'),
-					'invoice_id'			=> $this->db->f('fakturanr'),
-					'budget_account'		=> $this->db->f('spbudact_code'),
-					'dima'					=> $this->db->f('dima'),
-					'dimb'					=> $this->db->f('dimb'),
-					'dimd'					=> $this->db->f('dimd'),
-					'remark' 				=> !!$this->db->f('merknad'),
-					'tax_code'				=> $this->db->f('mvakode'),
-					'amount'				=> $this->db->f('belop'),
-					'charge_tenant'			=> $this->db->f('charge_tenant'),
-					'vendor'				=> $this->db->f('org_name'),
-					'paid_percent'			=> $this->db->f('paid_percent'),
-					'project_group'			=> $this->db->f('project_group'),
-					'external_ref'			=> $this->db->f('external_ref')
-				);
+					(
+						'counter'				=> $i,
+						'claim_issued'			=> $this->db->f('claim_issued'),
+				//		'project_id'			=> $this->db->f('project_id'),
+						'workorder_id'			=> $this->db->f('pmwrkord_code'),
+						'status'				=> $this->db->f('status'),
+						'closed'				=> $this->db->f('status') == $closed,
+						'voucher_id'			=> $this->db->f('bilagsnr'),
+						'id'					=> $this->db->f('id'),
+						'invoice_id'			=> $this->db->f('fakturanr'),
+						'budget_account'		=> $this->db->f('spbudact_code'),
+						'dima'					=> $this->db->f('dima'),
+						'dimb'					=> $this->db->f('dimb'),
+						'dimd'					=> $this->db->f('dimd'),
+						'remark' 				=> !!$this->db->f('merknad'),
+						'tax_code'				=> $this->db->f('mvakode'),
+						'amount'				=> $this->db->f('belop'),
+						'charge_tenant'			=> $this->db->f('charge_tenant'),
+						'vendor'				=> $this->db->f('org_name'),
+						'paid_percent'			=> $this->db->f('paid_percent'),
+						'project_group'			=> $this->db->f('project_id'),
+						'external_ref'			=> $this->db->f('external_ref'),
+						'currency'				=> $this->db->f('currency'),
+						'budget_responsible'	=> $this->db->f('budsjettansvarligid'),
+						'budsjettsigndato'		=> $this->db->f('budsjettsigndato'),
+						'transfer_time'			=> $this->db->f('overftid'),
+					);
 
 				$i++;
 			}
@@ -411,12 +439,12 @@
 				$query 			= isset($data['query'])?$data['query']:'';
 				$sort 			= isset($data['sort'])?$data['sort']:'DESC';
 				$order 			= isset($data['order'])?$data['order']:'';
-				$cat_id 		= isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id']:0;
+				$cat_id 		= isset($data['cat_id']) && $data['cat_id'] ? (int)$data['cat_id']:0;
 				$start_date 	= isset($data['start_date']) && $data['start_date'] ? $data['start_date'] : 0;
 				$end_date 		= isset($data['end_date']) && $data['end_date'] ? $data['end_date'] : time();
-				$vendor_id 		= isset($data['vendor_id'])?$data['vendor_id']:'';
+				$vendor_id 		= isset($data['vendor_id'])?(int)$data['vendor_id']:0;
 				$loc1 			= isset($data['loc1'])?$data['loc1']:'';
-				$district_id 	= isset($data['district_id'])?$data['district_id']:'';
+				$district_id 	= isset($data['district_id'])?(int)$data['district_id']:0;
 				$workorder_id 	= isset($data['workorder_id']) && $data['workorder_id'] ? $data['workorder_id']:0;
 				$b_account_class = isset($data['b_account_class'])?$data['b_account_class']:'';
 				$b_account		= isset($data['b_account']) ? $data['b_account'] : '';
@@ -466,7 +494,7 @@
 
 			if ($workorder_id)
 			{
-				$filtermethod.= " $where pmwrkord_code = $workorder_id";
+				$filtermethod.= " $where pmwrkord_code = '{$workorder_id}'";
 				$where= 'AND';
 			}
 
@@ -484,10 +512,10 @@
 				. " FROM  fm_ecobilagoverf $this->join fm_location1 ON (fm_ecobilagoverf.loc1 = fm_location1.loc1) "
 				. " $this->join fm_part_of_town ON (fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id) "
 				. " $this->join fm_b_account ON (fm_ecobilagoverf.spbudact_code = fm_b_account.id) "
-		        	. " WHERE (periode >='$start_periode' AND periode <= '$end_periode' $filtermethod )"
-		        	. " GROUP BY district_id,periode $group_account_class"
-		        	. " ORDER BY periode";
-//echo $sql;
+				. " WHERE (periode >='$start_periode' AND periode <= '$end_periode' $filtermethod )"
+				. " GROUP BY district_id,periode $group_account_class"
+				. " ORDER BY periode";
+			//echo $sql;
 
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->total_records = $this->db->num_rows();
@@ -497,12 +525,12 @@
 			while ($this->db->next_record())
 			{
 				$consume[] = array
-				(
-					'consume'		=> round($this->db->f('consume')),
-					'period'		=> $this->db->f('periode'),
-					'district_id'	=> $this->db->f('district_id'),
-					'account_class'	=> $b_account_class ? $b_account_class : $this->db->f('b_account_class')
-				);	
+					(
+						'consume'		=> round($this->db->f('consume')),
+						'period'		=> $this->db->f('periode'),
+						'district_id'	=> $this->db->f('district_id'),
+						'account_class'	=> $b_account_class ? $b_account_class : $this->db->f('b_account_class')
+					);	
 			}
 
 			return $consume;
@@ -552,12 +580,12 @@
 
 			while($entry=each($values['counter']))
 			{
-					$local_error='';
+				$local_error='';
 
-					$n=$entry[0];
+				$n=$entry[0];
 
 
-//_debug_array($entry);
+				//_debug_array($entry);
 
 				if ($values['budget_account'][$n])
 				{
@@ -573,8 +601,8 @@
 				}
 				else
 				{
-						$receipt['error'][] = array('msg'=>lang('Budget account is missing:'));
-						$local_error= true;
+					$receipt['error'][] = array('msg'=>lang('Budget account is missing:'));
+					$local_error= true;
 				}
 
 				if(!$values['dimd'][$n])
@@ -618,7 +646,7 @@
 						$local_error= true;
 					}
 
-				//	$dima_field="dima="."'" . $values['dima'][$n] . "'";
+					//	$dima_field="dima="."'" . $values['dima'][$n] . "'";
 					$dima_field="dima="."'" . $values['dima'][$n] . "',loc1=" . "'" . substr($values['dima'][$n],0,4) . "'";
 
 					$kostra_field="kostra_id="."'" . $GLOBALS['phpgw']->db->f('kostra_id') . "'";
@@ -668,7 +696,7 @@
 					$this->db->next_record();
 					switch ( $this->db->f('type') )
 					{
-						case 'workorder':
+					case 'workorder':
 						$historylog_workorder->add($entry,$id,$status_code[$entry]);
 						$GLOBALS['phpgw']->db->query("UPDATE fm_workorder set status=" . "'$status_code[$entry]'" . "where id=$id");
 						$receipt['message'][] = array('msg'=>lang('Workorder %1 is %2',$id, $status_code[$entry]));
@@ -683,26 +711,132 @@
 				{
 					$paid_percent = (int) $paid_percent;
 					$GLOBALS['phpgw']->db->query("UPDATE fm_workorder set paid_percent={$paid_percent} WHERE id= $workorder_id");				
-	
+
 					$this->db->query("SELECT type FROM fm_orders WHERE id={$workorder_id}",__LINE__,__FILE__);
 					$this->db->next_record();
 					switch ( $this->db->f('type') )
 					{
-						case 'workorder':
-							$this->db->query("SELECT project_id FROM fm_workorder WHERE id={$workorder_id}",__LINE__,__FILE__);
-							$this->db->next_record();
-							$project_id = $this->db->f('project_id');
-							$workorder->update_planned_cost($project_id);
-							break;
+					case 'workorder':
+						$this->db->query("SELECT project_id FROM fm_workorder WHERE id={$workorder_id}",__LINE__,__FILE__);
+						$this->db->next_record();
+						$project_id = $this->db->f('project_id');
+						$workorder->update_planned_cost($project_id);
+						break;
 					}
 				}
 			}
-			
+
 			$GLOBALS['phpgw']->db->transaction_commit();
 
 			return $receipt;
 		}
 
+		function update_single_line($values)
+		{
+			$table ='fm_ecobilag';
+			$id = (int)$values['id'];
+
+			$this->db->transaction_begin();
+
+			// Approval applies to all lines within voucher
+			if( $values['approve'] != $values['sign_orig'] )
+			{
+				switch ( $values['sign_orig'] )
+				{
+					case 'is_janitor':
+						$value_set['oppsynsigndato'] = null;
+						break;
+					case 'is_supervisor':
+						$value_set['saksigndato'] = null;
+						break;
+					case 'is_budget_responsible':
+						$value_set['budsjettsigndato'] = null;
+						break;
+				}
+ 
+				switch ( $values['approve'] )
+				{
+					case 'is_janitor':
+						$value_set['oppsynsigndato'] = date( $this->db->datetime_format() );
+						$value_set['oppsynsmannid'] = $values['my_initials'];
+						break;
+					case 'is_supervisor':
+						$value_set['saksigndato'] = date( $this->db->datetime_format() );
+						$value_set['saksbehandlerid'] = $values['my_initials'];
+						break;
+					case 'is_budget_responsible':
+						$value_set['budsjettsigndato'] = date( $this->db->datetime_format() );
+						$value_set['budsjettansvarligid'] = $values['my_initials'];
+						break;
+				}
+
+				$sql ="SELECT bilagsnr FROM {$table} WHERE id= {$id}";
+				$this->db->query($sql,__LINE__,__FILE__);
+				$this->db->next_record();
+				$bilagsnr = (int)$this->db->f('bilagsnr');
+				$value_set	= $this->db->validate_update($value_set);
+				$this->db->query("UPDATE {$table} SET $value_set WHERE bilagsnr= {$bilagsnr}" ,__LINE__,__FILE__);
+			}
+
+			$value_set = array
+			(
+				'project_id'	=> $values['project_group'] ? $values['project_group'] : '',
+				'pmwrkord_code'	=> $values['order_id'],
+				'process_log'	=> $this->db->db_addslashes($values['process_log']),
+				'process_code'	=> $values['process_code'],
+			);
+
+			$value_set	= $this->db->validate_update($value_set);
+
+			$this->db->query("UPDATE {$table} SET $value_set WHERE id= {$id}" ,__LINE__,__FILE__);
+
+			if(isset($values['split_line']) && $values['split_amount'] && isset($values['split_amount']) && $values['split_amount'])
+			{
+				$metadata = $this->db->metadata($table);
+				$sql ="SELECT * FROM {$table} WHERE id= {$id}";
+				$this->db->query($sql,__LINE__,__FILE__);
+				$this->db->next_record();
+
+				$value_set = array();
+
+				foreach($metadata as $_field)
+				{
+					if($_field->name != 'id')
+					{
+						$value_set[$_field->name] = $this->db->f($_field->name,true);
+					}
+				}
+
+				$this->db->query( "INSERT INTO {$table} (" . implode( ',', array_keys($value_set) ) . ')'
+					. ' VALUES (' . $this->db->validate_insert( array_values($value_set) ) . ')',__LINE__,__FILE__);
+
+				$new_id = $this->db->get_last_insert_id($table,'id');
+
+				$this->db->query("SELECT belop FROM {$table} WHERE id={$id}",__LINE__,__FILE__);
+				$this->db->next_record();
+				$amount = $this->db->f('belop');
+				$new_amount = $amount - $values['split_amount'];
+
+				$value_set= array
+				(
+					'belop'			=> $new_amount,
+					'godkjentbelop' => $new_amount,
+				);
+				$value_set	= $this->db->validate_update($value_set);
+				$this->db->query("UPDATE {$table} SET $value_set WHERE id= {$id}" ,__LINE__,__FILE__);
+
+				$value_set= array
+				(
+					'belop'			=> $values['split_amount'],
+					'godkjentbelop' => $values['split_amount'],
+				);
+				$value_set	= $this->db->validate_update($value_set);
+				$this->db->query("UPDATE {$table} SET $value_set WHERE id= {$new_id}" ,__LINE__,__FILE__);
+			}
+
+			$this->db->transaction_commit();
+		}
+
 		function read_remark($id='',$paid='')
 		{
 			if ($paid)
@@ -724,12 +858,12 @@
 		{
 			if(!isset($this->role) || !$this->role)
 			{
-				$this->role=array(
+				$this->role = array(
 					'is_janitor' 				=> $this->acl->check('.invoice', 32, 'property'),
 					'is_supervisor' 			=> $this->acl->check('.invoice', 64, 'property'),
 					'is_budget_responsible' 	=> $this->acl->check('.invoice', 128, 'property'),
 					'is_transfer' 				=> $this->acl->check('.invoice', 16, 'property')
-					);
+				);
 			}
 			return $this->role;
 		}
@@ -743,7 +877,7 @@
 			$check_count=array(
 				'dima_count' 				=> $this->db->f('dima_count'),
 				'spbudact_code_count' 		=> $this->db->f('spbudact_code_count')
-				);
+			);
 
 			$this->db->query("select count(kostra_id) as kostra_count  from fm_ecobilag where bilagsnr ='$voucher_id' and kostra_id > 0");
 			$this->db->next_record();
@@ -823,7 +957,7 @@
 			return $art_list;
 		}
 
-	//----------
+		//----------
 
 		function get_type_list()
 		{
@@ -839,7 +973,7 @@
 			return $category;
 		}
 
-	//----------
+		//----------
 		function select_dimb_list()
 		{
 			$this->db->query("SELECT * FROM fm_ecodimb order by id asc ");
@@ -854,7 +988,7 @@
 			return $dimb_list;
 		}
 
-	//-------------------
+		//-------------------
 		function select_dimd_list()
 		{
 			$this->db->query("SELECT * FROM fm_ecodimd order by id asc ");
@@ -868,7 +1002,7 @@
 			}
 			return $dimd_list;
 		}
-	//---------------------
+		//---------------------
 
 		function select_tax_code_list()
 		{
@@ -905,47 +1039,72 @@
 			$this->db->query("DELETE FROM fm_ecobilag WHERE bilagsnr ='" . $bilagsnr  ."'",__LINE__,__FILE__);
 		}
 
-		function read_single_voucher($bilagsnr)
+		function read_single_voucher($bilagsnr = 0, $id = 0)
 		{
-			$sql = "SELECT * from fm_ecobilag WHERE bilagsnr ='$bilagsnr'";
+			$bilagsnr =(int)$bilagsnr;
+			$id = (int)$id;
+			if($bilagsnr)
+			{
+				$sql = "SELECT * from fm_ecobilag WHERE bilagsnr ='$bilagsnr'";
+			}
+			else if ($id)
+			{
+				$sql = "SELECT * from fm_ecobilag WHERE id ='$id'";
+			}
+			else
+			{
+				return array();
+			}			
+
 			$this->db->query($sql,__LINE__,__FILE__);
 
 			$values = array();
 			while ($this->db->next_record())
 			{
-				$values[] = Array(
-
-				'location_code'		=> $this->db->f('id'),
-				'art'			=> $this->db->f('artid'),
-				'type'			=> $this->db->f('typeid'),
-				'dim_a'			=> $this->db->f('dima'),
-				'dim_b'			=> $this->db->f('dimb'),
-				'dim_d'			=> $this->db->f('dimd'),
-				'tax'			=> $this->db->f('mvakode'),
-				'invoice_id'		=> $this->db->f('fakturanr'),
-				'kid_nr'		=> $this->db->f('kidnr'),
-				'vendor_id'		=> $this->db->f('spvend_code'),
-				'janitor'		=> $this->db->f('oppsynsmannid'),
-				'supervisor'		=> $this->db->f('saksbehandlerid'),
-				'budget_responsible'	=> $this->db->f('budsjettansvarligid'),
-				'invoice_date' 		=> $this->db->f('fakturadato'),
-				'project_id'		=> $this->db->f('project_id'),
-				'payment_date' 		=> $this->db->f('forfallsdato'),
-				'merknad'		=> $this->db->f('merknad'),
-				'b_account_id'		=> $this->db->f('spbudact_code'),
-				'amount'		=> $this->db->f('belop'),
-				'order'			=> $this->db->f('pmwrkord_code'),
-				'kostra_id'		=> $this->db->f('kostra_id'),
-				);
+				$values[] = array
+					(
+						'id'					=> $this->db->f('id'),
+						'art'					=> $this->db->f('artid'),
+						'type'					=> $this->db->f('typeid'),
+						'dim_a'					=> $this->db->f('dima'),
+						'dim_b'					=> $this->db->f('dimb'),
+						'dim_d'					=> $this->db->f('dimd'),
+						'tax'					=> $this->db->f('mvakode'),
+						'invoice_id'			=> $this->db->f('fakturanr'),
+						'kid_nr'				=> $this->db->f('kidnr'),
+						'vendor_id'				=> $this->db->f('spvend_code'),
+						'janitor'				=> $this->db->f('oppsynsmannid'),
+						'supervisor'			=> $this->db->f('saksbehandlerid'),
+						'budget_responsible'	=> $this->db->f('budsjettansvarligid'),
+						'invoice_date' 			=> $this->db->f('fakturadato'),
+						'project_id'			=> $this->db->f('project_id'),
+						'project_group'			=> $this->db->f('project_id'),
+						'payment_date' 			=> $this->db->f('forfallsdato'),
+						'merknad'				=> $this->db->f('merknad'),
+						'b_account_id'			=> $this->db->f('spbudact_code'),
+						'amount'				=> $this->db->f('belop'),
+						'order'					=> $this->db->f('pmwrkord_code'),
+						'order_id'				=> $this->db->f('pmwrkord_code'),
+						'kostra_id'				=> $this->db->f('kostra_id'),
+						'currency'				=> $this->db->f('currency'),
+						'process_code'			=> $this->db->f('process_code'),
+						'process_log'			=> $this->db->f('process_log',true),
+						'oppsynsigndato'		=> $this->db->f('oppsynsigndato'),
+						'saksigndato'			=> $this->db->f('saksigndato'),
+						'budsjettsigndato'		=> $this->db->f('budsjettsigndato'),
+					);
 			}
-//_debug_array($values);
+
+
+
+			//_debug_array($values);
 			return $values;
 		}
 
 		function update_invoice($values)
 		{
 
-//_debug_array($values);
+			//_debug_array($values);
 			$receipt = array();
 			foreach($values['counter'] as $n)
 			{
@@ -956,11 +1115,11 @@
 					$voucher_id=$values['voucher_id'][$n];
 
 					$check_value=array('voucher_id'=>$voucher_id,
-							'sign_orig'		=> $values['sign_orig'][$n],
-							'sign'			=> isset($values['sign'][$n])?$values['sign'][$n]:'',
-							'transfer'		=> isset($values['transfer'][$n])?$values['transfer'][$n]:'',
-							'kreditnota'	=> isset($values['kreditnota'][$n])?$values['kreditnota'][$n]:'',
-							'num_days'		=> $values['num_days'][$n]);
+						'sign_orig'		=> $values['sign_orig'][$n],
+						'sign'			=> isset($values['sign'][$n])?$values['sign'][$n]:'',
+						'transfer'		=> isset($values['transfer'][$n])?$values['transfer'][$n]:'',
+						'kreditnota'	=> isset($values['kreditnota'][$n])?$values['kreditnota'][$n]:'',
+						'num_days'		=> $values['num_days'][$n]);
 
 					if($this->check_for_updates($check_value))
 					{
@@ -1000,91 +1159,114 @@
 						$wait_for_kreditnota='';
 						$user_lid	=$GLOBALS['phpgw_info']['user']['account_lid'];
 
-						if (($values['sign'][$n]=='sign_none') && ($values['sign_orig'][$n]=='sign_janitor')):
+						if (($values['sign'][$n]=='sign_none') && ($values['sign_orig'][$n]=='sign_janitor'))
+						{
 							$blank_date = 'oppsynsigndato= NULL';
 							$sign_field='';
 							$sign_id='';
 							$sign_date_field='';
 							$sign_date='';
 							$kommma='';
-						elseif (($values['sign'][$n]=='sign_none') && ($values['sign_orig'][$n]=='sign_supervisor')):
+						}
+						else if (($values['sign'][$n]=='sign_none') && ($values['sign_orig'][$n]=='sign_supervisor'))
+						{
 							$blank_date = 'saksigndato= NULL';
 							$sign_field='';
 							$sign_id='';
 							$sign_date_field='';
 							$sign_date='';
 							$kommma='';
-						elseif (($values['sign'][$n]=='sign_none') && ($values['sign_orig'][$n]=='sign_budget_responsible')):
+						}
+						else if (($values['sign'][$n]=='sign_none') && ($values['sign_orig'][$n]=='sign_budget_responsible'))
+						{
 							$blank_date = 'budsjettsigndato= NULL';
 							$sign_field='';
 							$sign_id='';
 							$sign_date_field='';
 							$sign_date='';
 							$kommma='';
-						elseif ($values['sign'][$n]=='sign_janitor' && !$values['sign_orig'][$n]):
+						}
+						else if ($values['sign'][$n]=='sign_janitor' && !$values['sign_orig'][$n])
+						{
 							$blank_date = '';
 							$sign_field = 'oppsynsmannid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'oppsynsigndato=';
 							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
-						elseif ($values['sign'][$n]=='sign_janitor' && $values['sign_orig'][$n]=='sign_supervisor'):
+						}
+						else if ($values['sign'][$n]=='sign_janitor' && $values['sign_orig'][$n]=='sign_supervisor')
+						{
 							$blank_date = 'saksigndato= NULL';
 							$sign_field = 'oppsynsmannid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'oppsynsigndato=';
 							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
-						elseif ($values['sign'][$n]=='sign_janitor' && $values['sign_orig'][$n]=='sign_budget_responsible'):
+						}
+						else if ($values['sign'][$n]=='sign_janitor' && $values['sign_orig'][$n]=='sign_budget_responsible')
+						{
 							$blank_date = 'budsjettsigndato= NULL';
 							$sign_field = 'oppsynsmannid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'oppsynsigndato=';
 							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
-						elseif ($values['sign'][$n]=='sign_supervisor' && !$values['sign_orig'][$n]):
+						}
+						else if ($values['sign'][$n]=='sign_supervisor' && !$values['sign_orig'][$n])
+						{
 							$blank_date = '';
 							$sign_field = 'saksbehandlerid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'saksigndato=';
 							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
-						elseif ($values['sign'][$n]=='sign_supervisor' && $values['sign_orig'][$n]=='sign_janitor'):
+						}
+						else if ($values['sign'][$n]=='sign_supervisor' && $values['sign_orig'][$n]=='sign_janitor')
+						{
 							$blank_date = 'oppsynsigndato= NULL';
 							$sign_field = 'saksbehandlerid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'saksigndato=';
 							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
-						elseif ($values['sign'][$n]=='sign_supervisor' && $values['sign_orig'][$n]=='sign_budget_responsible'):
+						}
+						else if ($values['sign'][$n]=='sign_supervisor' && $values['sign_orig'][$n]=='sign_budget_responsible')
+						{
 							$blank_date = 'budsjettsigndato= NULL';
 							$sign_field = 'saksbehandlerid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'saksigndato=';
 							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
-						elseif ($values['sign'][$n]=='sign_budget_responsible' && $values['sign_orig'][$n]=='sign_janitor'):
+						}
+						else if ($values['sign'][$n]=='sign_budget_responsible' && $values['sign_orig'][$n]=='sign_janitor')
+						{
 							$blank_date = 'oppsynsigndato= NULL';
 							$sign_field = 'budsjettansvarligid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'budsjettsigndato=';
 							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
-						elseif ($values['sign'][$n]=='sign_budget_responsible' && $values['sign_orig'][$n]=='sign_supervisor'):
+						}
+						else if ($values['sign'][$n]=='sign_budget_responsible' && $values['sign_orig'][$n]=='sign_supervisor')
+						{
 							$blank_date = 'saksigndato= NULL';
 							$sign_field = 'budsjettansvarligid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'budsjettsigndato=';
 							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
-						elseif ($values['sign'][$n]=='sign_budget_responsible' && !$values['sign_orig'][$n]):
+						}
+						else if ($values['sign'][$n]=='sign_budget_responsible' && !$values['sign_orig'][$n])
+						{
 							$blank_date = '';
 							$sign_field = 'budsjettansvarligid=';
 							$sign_id = "'$user_lid'";
 							$sign_date_field = 'budsjettsigndato=';
 							$sign_date="'" . date($this->db->datetime_format()) . "'";
 							$kommma=",";
-						endif;
+						}
 
 
 						if($blank_date )
@@ -1185,10 +1367,16 @@
 		function check_claim($voucher_id='')
 		{
 			$sql = "SELECT count(*) as cnt FROM fm_ecobilag $this->left_join fm_workorder on fm_ecobilag.pmwrkord_code = fm_workorder.id "
-			. " WHERE bilagsnr='$voucher_id' AND fm_workorder.charge_tenant=1 AND fm_workorder.claim_issued IS NULL";
+				. " WHERE bilagsnr='$voucher_id' AND fm_workorder.charge_tenant=1 AND fm_workorder.claim_issued IS NULL";
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
 			return $this->db->f('cnt');
 		}
-	}
 
+
+		public function get_single_line($id)
+		{
+			$line = $this->read_single_voucher(0, $id);
+			return $line[0];
+		}
+	}
