@@ -24,9 +24,11 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.soproject.inc.php 6349 2010-09-17 18:25:01Z sigurd $
+ 	* @version $Id: class.soproject.inc.php 7197 2011-04-07 12:17:22Z sigurdne $
 	*/
 
+	phpgw::import_class('phpgwapi.datetime');
+
 	/**
 	 * Description
 	 * @package property
@@ -48,8 +50,8 @@
 			$this->left_join 	= & $this->db->left_join;
 			$this->like			= & $this->db->like;
 
-			$this->acl 		= & $GLOBALS['phpgw']->acl;
-			$this->grants	= $this->acl->get_grants('property','.project');
+			$this->acl 			= & $GLOBALS['phpgw']->acl;
+			$this->grants		= $this->acl->get_grants('property','.project');
 		}
 
 		function select_status_list()
@@ -59,10 +61,10 @@
 			while ($this->db->next_record())
 			{
 				$status[] = array
-				(
-					'id' 	=> $this->db->f('id'),
-					'name'	=> $this->db->f('descr',true)
-				);
+					(
+						'id' 	=> $this->db->f('id'),
+						'name'	=> $this->db->f('descr',true)
+					);
 			}
 			return $status;
 		}
@@ -75,10 +77,10 @@
 			while ($this->db->next_record())
 			{
 				$branch[] = array
-				( 
-					'id' => $this->db->f('id'),
-					'name'	=> $this->db->f('descr',true)
-				);
+					( 
+						'id' => $this->db->f('id'),
+						'name'	=> $this->db->f('descr',true)
+					);
 			}
 			return $branch;
 		}
@@ -90,30 +92,30 @@
 			while ($this->db->next_record())
 			{
 				$location[] = array
-				( 
-					'id' => $this->db->f('id'),
-					'name'	=> $this->db->f('descr',true)
-				);
+					( 
+						'id' => $this->db->f('id'),
+						'name'	=> $this->db->f('descr',true)
+					);
 			}
 			return $location;
 		}
 
 		function read($data)
 		{
-			$start	= isset($data['start']) && $data['start'] ? $data['start'] : 0;
-			$filter	= $data['filter']?(int)$data['filter']:0;
-			$query = (isset($data['query'])?$data['query']:'');
-			$sort = (isset($data['sort'])?$data['sort']:'DESC');
-			$order = (isset($data['order'])?$data['order']:'');
-			$cat_id = (isset($data['cat_id'])?$data['cat_id']:0);
-			$status_id = (isset($data['status_id'])?$data['status_id']:'');
-			$start_date = (isset($data['start_date'])?$data['start_date']:'');
-			$end_date = (isset($data['end_date'])?$data['end_date']:'');
-			$allrows = (isset($data['allrows'])?$data['allrows']:'');
-			$wo_hour_cat_id = (isset($data['wo_hour_cat_id'])?$data['wo_hour_cat_id']:'');
-			$district_id	= (isset($data['district_id'])?$data['district_id']:'');
+			$start			= isset($data['start']) && $data['start'] ? $data['start'] : 0;
+			$filter			= $data['filter']?(int)$data['filter']:0;
+			$query			= isset($data['query'])?$data['query']:'';
+			$sort			= isset($data['sort'])?$data['sort']:'DESC';
+			$order			= isset($data['order'])?$data['order']:'';
+			$cat_id			= isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id'] : 0;
+			$status_id		= isset($data['status_id']) && $data['status_id'] ? $data['status_id'] : 'open';
+			$start_date		= isset($data['start_date']) && $data['start_date'] ? (int)$data['start_date'] : 0;
+			$end_date		= isset($data['end_date']) && $data['end_date'] ? (int)$data['end_date'] : 0;
+			$allrows		= isset($data['allrows'])?$data['allrows']:'';
+			$wo_hour_cat_id = isset($data['wo_hour_cat_id'])?$data['wo_hour_cat_id']:'';
+			$district_id	= isset($data['district_id'])?$data['district_id']:'';
 			$dry_run		= isset($data['dry_run']) ? $data['dry_run'] : '';
-			$criteria	= isset($data['criteria']) && $data['criteria'] ? $data['criteria'] : array();				
+			$criteria		= isset($data['criteria']) && $data['criteria'] ? $data['criteria'] : array();				
 
 			$sql = $this->bocommon->fm_cache('sql_project_' . !!$wo_hour_cat_id);
 
@@ -135,6 +137,7 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= true;
 
 				$cols .= ", project_group";
 				$cols_return[] 				= 'project_group';
@@ -147,6 +150,7 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= 'rightClasss';
+				$uicols['sortable'][]		= true;
 
 				$cols .= ", fm_project_status.descr as status";
 				$cols_return[] 				= 'status';
@@ -159,19 +163,29 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
-				
+				$uicols['sortable'][]		= true;
+
+				$cols.= ",$entity_table.entry_date";
+				$cols_return[] 				= 'entry_date';
 				$cols.= ",$entity_table.start_date";
 				$cols_return[] 				= 'start_date';
+				$cols.= ",$entity_table.end_date";
+				$cols_return[] 				= 'end_date';
+				$cols.= ",$entity_table.ecodimb";
+				$cols_return[] 				= 'ecodimb';
+
+/*
 				$uicols['input_type'][]		= 'text';
-				$uicols['name'][]			= 'start_date';
-				$uicols['descr'][]			= lang('start date');
-				$uicols['statustext'][]		= lang('Project start date');
+				$uicols['name'][]			= 'entry_date';
+				$uicols['descr'][]			= lang('entry date');
+				$uicols['statustext'][]		= lang('Project entry date');
 				$uicols['exchange'][]		= false;
 				$uicols['align'][] 			= '';
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
-
+				$uicols['sortable'][]		= '';
+*/
 				$cols.= ",$entity_table.name as name";
 				$cols_return[] 				= 'name';
 				$uicols['input_type'][]		= 'text';
@@ -183,9 +197,11 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= '';
 
 				$cols.= ",loc1_name";
-				$cols_return[] 				= 'loc1_name';
+//				$cols_return[] 				= 'loc1_name';
+/*
 				$uicols['input_type'][]		= 'hidden';
 				$uicols['name'][]			= 'loc1_name';
 				$uicols['descr'][]			= lang('loc1_name');
@@ -195,7 +211,8 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
-
+				$uicols['sortable'][]		= '';
+*/
 				$cols.= ",account_lid as coordinator";
 				$cols_return[] 				= 'coordinator';
 				$uicols['input_type'][]		= 'text';
@@ -207,6 +224,7 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= '';
 
 				$cols.= ",(fm_project.budget + fm_project.reserve) as budget";
 				$cols_return[] 				= 'budget';
@@ -219,6 +237,7 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= 'myFormatCount2';
 				$uicols['classname'][]		= 'rightClasss';
+				$uicols['sortable'][]		= '';
 
 				$cols .= ',sum(fm_workorder.combined_cost) as combined_cost';
 				$cols_return[] = 'combined_cost';
@@ -231,6 +250,7 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= 'myFormatCount2';
 				$uicols['classname'][]		= 'rightClasss';
+				$uicols['sortable'][]		= '';
 
 				$cols .= ',(sum(fm_workorder.act_mtrl_cost) + sum(fm_workorder.act_vendor_cost)) as actual_cost';
 				$cols_return[] = 'actual_cost';
@@ -243,9 +263,11 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= 'myFormatCount2';
 				$uicols['classname'][]		= 'rightClasss';
+				$uicols['sortable'][]		= '';
 
 				$cols .= ',planned_cost';
 				$cols_return[] = 'planned_cost';
+/*
 				$uicols['input_type'][]		= 'text';
 				$uicols['name'][]			= 'planned_cost';
 				$uicols['descr'][]			= lang('planned cost');
@@ -255,7 +277,8 @@
 				$uicols['datatype'][]		= '';
 				$uicols['formatter'][]		= 'myFormatCount2';
 				$uicols['classname'][]		= 'rightClasss';
-
+				$uicols['sortable'][]		= '';
+*/
 				$cols.= ",$entity_table.user_id";
 
 				$cols .= ',sum(fm_workorder.billable_hours) as billable_hours';
@@ -284,7 +307,7 @@
 				//----- wo_hour_status
 
 				$sql	= $this->bocommon->generate_sql(array('entity_table'=>$entity_table,'cols'=>$cols,'cols_return'=>$cols_return,
-										'uicols'=>$uicols,'joinmethod'=>$joinmethod,'paranthesis'=>$paranthesis,'query'=>$query,'force_location'=>true));
+					'uicols'=>$uicols,'joinmethod'=>$joinmethod,'paranthesis'=>$paranthesis,'query'=>$query,'force_location'=>true));
 
 				$this->bocommon->fm_cache('sql_project_' . !!$wo_hour_cat_id,$sql);
 
@@ -336,16 +359,40 @@
 
 			if ($cat_id > 0)
 			{
-				$filtermethod .= " $where fm_project.category=$cat_id ";
+				$cats	= CreateObject('phpgwapi.categories', -1,  'property', '.project');
+				$cats->supress_info	= true;
+				$cat_list_project	= $cats->return_sorted_array(0, false, '', '', '', false, $cat_id, false);//(0,$limit = false,$query = '',$sort = '',$order = '',$globals = False, $parent_id = $cat_id, $use_acl = false);
+				$cat_filter = array($cat_id);
+				foreach ($cat_list_project as $_category)
+				{
+					$cat_filter[] = $_category['id'];
+				}
+				$filtermethod .= " {$where} fm_project.category IN (" .  implode(',', $cat_filter) .')';
+
 				$where= 'AND';
 			}
 
-			if ($status_id)
+			if ($status_id && $status_id != 'all')
 			{
-				$filtermethod .= " $where fm_project.status='$status_id' ";
+
+				if($status_id == 'open')
+				{
+					$_status_filter = array();
+					$this->db->query("SELECT * FROM fm_project_status WHERE closed IS NULL");
+					while($this->db->next_record())
+					{
+						$_status_filter[] = $this->db->f('id');
+					}
+					$filtermethod .= " $where fm_project.status IN ('" . implode("','", $_status_filter) . "')"; 
+				}
+				else
+				{
+					$filtermethod .= " $where fm_project.status='$status_id' ";
+				}
 				$where= 'AND';
 			}
 
+
 			if($wo_hour_cat_id)
 			{
 				$filtermethod .= " $where fm_wo_hours_category.id=$wo_hour_cat_id ";
@@ -358,8 +405,8 @@
 				$where= 'AND';
 			}
 
-			$group_method = ' GROUP BY fm_project_status.descr,loc1_name,fm_project.location_code,fm_project.id,fm_project.start_date,'
-				. 'fm_project.name,phpgw_accounts.account_lid,fm_project.user_id,fm_project.address,'
+			$group_method = ' GROUP BY fm_project_status.descr,loc1_name,fm_project.location_code,fm_project.id,fm_project.entry_date,fm_project.start_date,fm_project.end_date,'
+				. 'fm_project.name,fm_project.ecodimb,phpgw_accounts.account_lid,fm_project.user_id,fm_project.address,'
 				. 'fm_project.budget,fm_project.reserve,planned_cost,project_group';
 
 
@@ -384,10 +431,13 @@
 
 			if ($start_date)
 			{
+				$end_date	= $end_date + 3600 * 16 + phpgwapi_datetime::user_timezone();
+				$start_date	= $start_date - 3600 * 8 + phpgwapi_datetime::user_timezone();
+
 				$filtermethod .= " $where fm_project.start_date >= $start_date AND fm_project.start_date <= $end_date ";
 				$where= 'AND';
 			}
-//_debug_array($criteria);
+			//_debug_array($criteria);
 			$querymethod = '';
 			if($query)
 			{
@@ -407,11 +457,11 @@
 				{
 
 					$matchtypes = array
-					(
-						'exact' => '=',
-						'like'	=> $this->like						
-					);
-					
+						(
+							'exact' => '=',
+							'like'	=> $this->like						
+						);
+
 					if(count($criteria) > 1)
 					{
 						$_querymethod = array();
@@ -452,10 +502,10 @@
 
 			$sql .= " $filtermethod $querymethod";
 
-//echo substr($sql,strripos($sql,'from'));
+			//echo substr($sql,strripos($sql,'from'));
 			if($GLOBALS['phpgw_info']['server']['db_type']=='postgres')
 			{
-				$sql2 = 'SELECT count(*) as cnt FROM (SELECT fm_project.id ' . substr($sql,strripos($sql,'from'))  . ' GROUP BY fm_project.id) as cnt';
+				$sql2 = 'SELECT count(*) as cnt FROM (SELECT DISTINCT fm_project.id ' . substr($sql,strripos($sql,'from'))  . ') as cnt';
 				$this->db->query($sql2,__LINE__,__FILE__);
 				$this->db->next_record();
 				$this->total_records = $this->db->f('cnt');
@@ -466,7 +516,7 @@
 				$this->db->query($sql2,__LINE__,__FILE__);
 				$this->total_records = $this->db->num_rows();
 			}
-//_debug_array($sql2);
+			//_debug_array($sql2);
 			$project_list = array();
 			$sql .= " $group_method";
 			if(!$allrows)
@@ -498,7 +548,7 @@
 					$project_list[$j]['grants'] = (int)$this->grants[$this->db->f('user_id')];
 				}
 				$location_code=	$this->db->f('location_code');
-				$location = split('-',$location_code);
+				$location = explode('-',$location_code);
 				$n=count($location);
 				for ($m=0;$m<$n;$m++)
 				{
@@ -525,41 +575,40 @@
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
-
 			if ($this->db->next_record())
 			{
 				$project = array
-				(
-					'project_id'			=> $this->db->f('id'),
-					'title'					=> $this->db->f('title'),
-					'name'					=> $this->db->f('name'),
-					'location_code'			=> $this->db->f('location_code'),
-					'key_fetch'				=> $this->db->f('key_fetch'),
-					'key_deliver'			=> $this->db->f('key_deliver'),
-					'other_branch'			=> $this->db->f('other_branch'),
-					'key_responsible'		=> $this->db->f('key_responsible'),
-					'descr'					=> $this->db->f('descr', true),
-					'status'				=> $this->db->f('status'),
-					'budget'				=> (int)$this->db->f('budget'),
-					'planned_cost'			=> (int)$this->db->f('planned_cost'),
-					'reserve'				=> (int)$this->db->f('reserve'),
-					'tenant_id'				=> $this->db->f('tenant_id'),
-					'user_id'				=> $this->db->f('user_id'),
-					'coordinator'			=> $this->db->f('coordinator'),
-					'access'				=> $this->db->f('access'),
-					'start_date'			=> $this->db->f('start_date'),
-					'end_date'				=> $this->db->f('end_date'),
-					'cat_id'				=> $this->db->f('category'),
-					'grants' 				=> (int)$this->grants[$this->db->f('user_id')],
-					'p_num'					=> $this->db->f('p_num'),
-					'p_entity_id'			=> $this->db->f('p_entity_id'),
-					'p_cat_id'				=> $this->db->f('p_cat_id'),
-					'contact_phone'			=> $this->db->f('contact_phone'),
-					'project_group'			=> $this->db->f('project_group'),
-					'ecodimb'				=> $this->db->f('ecodimb'),
-					'b_account_id'			=> $this->db->f('account_group'),
-					'contact_id'			=> $this->db->f('contact_id'),
-				);
+					(
+						'project_id'			=> $this->db->f('id'),
+						'title'					=> $this->db->f('title'),
+						'name'					=> $this->db->f('name'),
+						'location_code'			=> $this->db->f('location_code'),
+						'key_fetch'				=> $this->db->f('key_fetch'),
+						'key_deliver'			=> $this->db->f('key_deliver'),
+						'other_branch'			=> $this->db->f('other_branch'),
+						'key_responsible'		=> $this->db->f('key_responsible'),
+						'descr'					=> $this->db->f('descr', true),
+						'status'				=> $this->db->f('status'),
+						'budget'				=> (int)$this->db->f('budget'),
+						'planned_cost'			=> (int)$this->db->f('planned_cost'),
+						'reserve'				=> (int)$this->db->f('reserve'),
+						'tenant_id'				=> $this->db->f('tenant_id'),
+						'user_id'				=> $this->db->f('user_id'),
+						'coordinator'			=> $this->db->f('coordinator'),
+						'access'				=> $this->db->f('access'),
+						'start_date'			=> $this->db->f('start_date'),
+						'end_date'				=> $this->db->f('end_date'),
+						'cat_id'				=> $this->db->f('category'),
+						'grants' 				=> (int)$this->grants[$this->db->f('user_id')],
+						'p_num'					=> $this->db->f('p_num'),
+						'p_entity_id'			=> $this->db->f('p_entity_id'),
+						'p_cat_id'				=> $this->db->f('p_cat_id'),
+						'contact_phone'			=> $this->db->f('contact_phone'),
+						'project_group'			=> $this->db->f('project_group'),
+						'ecodimb'				=> $this->db->f('ecodimb'),
+						'b_account_id'			=> $this->db->f('account_group'),
+						'contact_id'			=> $this->db->f('contact_id'),
+					);
 
 				if ( isset($values['attributes']) && is_array($values['attributes']) )
 				{
@@ -570,11 +619,10 @@
 					}
 				}
 
-
 				$location_code = $this->db->f('location_code');
 				$project['power_meter']		= $this->get_power_meter($location_code);
 			}
-//_debug_array($project);
+			//_debug_array($project);
 			return $project;
 		}
 
@@ -596,13 +644,14 @@
 		{
 			$project_id = (int) $project_id;
 			$budget = array();
-			$this->db->query("SELECT act_mtrl_cost, act_vendor_cost, budget, fm_workorder.id as workorder_id,"
-			." vendor_id, calculation,rig_addition,addition,deviation,charge_tenant,fm_workorder_status.descr as status, fm_workorder.account_id as b_account_id"
-			." FROM fm_workorder $this->join fm_workorder_status ON fm_workorder.status = fm_workorder_status.id WHERE project_id={$project_id}");
+			$this->db->query("SELECT fm_workorder.title, act_mtrl_cost, act_vendor_cost, budget, fm_workorder.id as workorder_id,contract_sum,"
+				." vendor_id, calculation,rig_addition,addition,deviation,charge_tenant,fm_workorder_status.descr as status, fm_workorder.account_id as b_account_id"
+				." FROM fm_workorder $this->join fm_workorder_status ON fm_workorder.status = fm_workorder_status.id WHERE project_id={$project_id}");
 			while ($this->db->next_record())
 			{
 				$budget[] = array(
 					'workorder_id'		=> $this->db->f('workorder_id'),
+					'title'				=> $this->db->f('title',true),
 					'budget'			=> (int)$this->db->f('budget'),
 					'deviation'			=> $this->db->f('deviation'),
 					'calculation'		=> $this->db->f('calculation'),
@@ -612,7 +661,8 @@
 					'charge_tenant'		=> $this->db->f('charge_tenant'),
 					'status'			=> $this->db->f('status'),
 					'b_account_id'		=> $this->db->f('b_account_id'),
-					);
+					'contract_sum'		=> (int)$this->db->f('contract_sum'),
+				);
 			}
 			return $budget;
 		}
@@ -701,31 +751,31 @@
 			$this->db->transaction_begin();
 			$id = $this->next_project_id();
 			$values= array
-			(
-				$id,
-				$project['project_group'],
-				$project['name'],
-				'public',
-				$project['cat_id'],
-				time(),
-				$project['start_date'],
-				$project['end_date'],
-				$project['coordinator'],
-				$project['status'],
-				$project['descr'],
-				(int) $project['budget'],
-				(int) $project['reserve'],
-				$project['location_code'],
-				$address,
-				$project['key_deliver'],
-				$project['key_fetch'],
-				$project['other_branch'],
-				$project['key_responsible'],
-				$this->account,
-				$project['ecodimb'],
-				$project['b_account_id'],
-				$project['contact_id']
-			);
+				(
+					$id,
+					$project['project_group'],
+					$project['name'],
+					'public',
+					$project['cat_id'],
+					time(),
+					$project['start_date'],
+					$project['end_date'],
+					$project['coordinator'],
+					$project['status'],
+					$project['descr'],
+					(int) $project['budget'],
+					(int) $project['reserve'],
+					$project['location_code'],
+					$address,
+					$project['key_deliver'],
+					$project['key_fetch'],
+					$project['other_branch'],
+					$project['key_responsible'],
+					$this->account,
+					$project['ecodimb'],
+					$project['b_account_id'],
+					$project['contact_id']
+				);
 
 			$values	= $this->bocommon->validate_db_insert($values);
 
@@ -756,14 +806,14 @@
 				if($project['origin'][0]['data'][0]['id'])
 				{					
 					$interlink_data = array
-					(
-						'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $project['origin'][0]['location']),
-						'location1_item_id' => $project['origin'][0]['data'][0]['id'],
-						'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project'),			
-						'location2_item_id' => $id,
-						'account_id'		=> $this->account
-					);
-					
+						(
+							'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $project['origin'][0]['location']),
+							'location1_item_id' => $project['origin'][0]['data'][0]['id'],
+							'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project'),			
+							'location2_item_id' => $id,
+							'account_id'		=> $this->account
+						);
+
 					$this->interlink->add($interlink_data,$this->db);
 				}
 			}
@@ -785,7 +835,7 @@
 			{
 				$receipt['error'][] = array('msg'=>lang('the project has not been saved'));
 			}
-			
+
 			$receipt['id'] = $id;
 			return $receipt;
 		}
@@ -804,13 +854,11 @@
 			{
 				foreach($location as $location_entry)
 				{
-
 					$cols[] = 'loc' . $i;
 					$vals[] = $location_entry;
 
 					$i++;
 				}
-
 			}
 
 			if($cols)
@@ -819,7 +867,6 @@
 				$vals	= ",'" . implode("','", $vals) . "'";
 			}
 
-
 			$this->db->query("SELECT count(*) as cnt FROM $meter_table where location_code='$location_code' and category=1",__LINE__,__FILE__);
 
 			$this->db->next_record();
@@ -897,9 +944,9 @@
 				'ecodimb'			=> $project['ecodimb'],
 				'account_group'		=> $project['b_account_id'],
 				'contact_id'		=> $project['contact_id']
-				);
+			);
 
-			$data_attribute = $this->custom->prepare_for_db('fm_project', $values_attribute, $data['id']);
+			$data_attribute = $this->custom->prepare_for_db('fm_project', $values_attribute, $project['id']);
 
 			if(isset($data_attribute['value_set']))
 			{
@@ -939,7 +986,7 @@
 			{
 				$this->update_power_meter($project['power_meter'],$project['location_code'],$address);
 			}
-	// -----------------which branch is represented
+			// -----------------which branch is represented
 			$this->db->query("DELETE FROM fm_projectbranch WHERE project_id={$project['id']}",__LINE__,__FILE__);
 
 			if (count($project['branch']) != 0)
@@ -981,21 +1028,21 @@
 					$close_pending_action = true;
 
 					$action_params = array
-					(
-						'appname'			=> 'property',
-						'location'			=> '.project',
-						'id'				=> (int)$project['id'],
-						'responsible'		=> $this->account,
-						'responsible_type'  => 'user',
-						'action'			=> 'approval',
-						'remark'			=> '',
-						'deadline'			=> ''
-					);
+						(
+							'appname'			=> 'property',
+							'location'			=> '.project',
+							'id'				=> (int)$project['id'],
+							'responsible'		=> $this->account,
+							'responsible_type'  => 'user',
+							'action'			=> 'approval',
+							'remark'			=> '',
+							'deadline'			=> ''
+						);
 
 					execMethod('property.sopending_action.close_pending_action', $action_params);
 					unset($action_params);
 				}
- 
+
 				if ($workorders)
 				{
 					$historylog_workorder	= CreateObject('property.historylog','workorder');
@@ -1036,16 +1083,16 @@
 				if($close_pending_action)
 				{
 					$action_params = array
-					(
-						'appname'			=> 'property',
-						'location'			=> '.project.workorder',
-						'id'				=> 0,
-						'responsible'		=> $this->account,
-						'responsible_type'  => 'user',
-						'action'			=> 'approval',
-						'remark'			=> '',
-						'deadline'			=> ''
-					);
+						(
+							'appname'			=> 'property',
+							'location'			=> '.project.workorder',
+							'id'				=> 0,
+							'responsible'		=> $this->account,
+							'responsible_type'  => 'user',
+							'action'			=> 'approval',
+							'remark'			=> '',
+							'deadline'			=> ''
+						);
 
 
 					foreach($workorders as $workorder_id)
@@ -1091,8 +1138,8 @@
 				$historylog->add('RM',$project['id'],$project['remark']);
 			}
 
- 			execMethod('property.soworkorder.update_planned_cost', $project['id']);
- 			
+			execMethod('property.soworkorder.update_planned_cost', $project['id']);
+
 			$receipt['id'] = $project['id'];
 			$receipt['message'][] = array('msg'=>lang('project %1 has been edited', $project['id']));
 
@@ -1167,14 +1214,14 @@
 				if(!$project_id)
 				{
 					$interlink_data = array
-					(
-						'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project.request'),
-						'location1_item_id' => $add_request['request_id'][$i],
-						'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project'),			
-						'location2_item_id' => $id,
-						'account_id'		=> $this->account
-					);
-					
+						(
+							'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project.request'),
+							'location1_item_id' => $add_request['request_id'][$i],
+							'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project'),			
+							'location2_item_id' => $id,
+							'account_id'		=> $this->account
+						);
+
 					$this->interlink->add($interlink_data);
 
 					$this->db->query("UPDATE fm_request SET project_id='$id' where id='". $add_request['request_id'][$i] . "'",__LINE__,__FILE__);
