@@ -9,7 +9,7 @@
 	* @package phpgroupware
 	* @subpackage property
 	* @category core
- 	* @version $Id: class.soresponsible.inc.php 4709 2010-02-02 15:18:50Z sigurd $
+ 	* @version $Id: class.soresponsible.inc.php 7189 2011-04-06 10:14:45Z sigurdne $
 	*/
 
 	/*
@@ -44,14 +44,14 @@
 		var $appname = 'property';
 
 		/**
-		* @var the total number of records for a search
-		*/
+		 * @var the total number of records for a search
+		 */
 		public $total_records = 0;
 
 		/**
-		* Constructor
-		*
-		*/
+		 * Constructor
+		 *
+		 */
 
 		function __construct()
 		{
@@ -63,12 +63,12 @@
 		}
 
 		/**
-		* Read type
-		*
-		* @param array $data array that Includes the fields: 'start', 'query', 'sort', 'order', 'allrows', 'filter' and 'location'
-		*
-		* @return array Responsibility types
-		*/
+		 * Read type
+		 *
+		 * @param array $data array that Includes the fields: 'start', 'query', 'sort', 'order', 'allrows', 'filter' and 'location'
+		 *
+		 * @return array Responsibility types
+		 */
 
 		public function read_type($data)
 		{
@@ -81,7 +81,7 @@
 				$allrows	= isset($data['allrows']) ? !!$data['allrows'] : '';
 				$filter		= $data['filter'] ? $data['filter'] : '';
 				$location	= isset($data['location']) ? $data['location'] : '';
-				
+
 			}
 
 			if ($order)
@@ -102,7 +102,7 @@
 				$filtermethod .= " $where cat_id IN (" . implode(',', $filter) . ')';
 				$where = 'AND';
 			}
-*/
+ */
 			if($location)
 			{
 				$filtermethod .= " $where fm_responsibility.location_id =" . $GLOBALS['phpgw']->locations->get_id($this->appname, $location);
@@ -134,28 +134,28 @@
 			while ($this->db->next_record())
 			{
 				$values[] = array
-				(
-					'id'			=> $this->db->f('id'),
-					'name'			=> $this->db->f('name', true),
-					'descr'			=> $this->db->f('descr', true),
-					'active'		=> $this->db->f('active'),
-					'location'		=> $this->db->f('location'),
-					'cat_id'		=> $this->db->f('cat_id'),
-					'created_by'	=> $this->db->f('created_by'),
-					'created_on'	=> $this->db->f('created_on'),
-				);
+					(
+						'id'			=> $this->db->f('id'),
+						'name'			=> $this->db->f('name', true),
+						'descr'			=> $this->db->f('descr', true),
+						'active'		=> $this->db->f('active'),
+						'location'		=> $this->db->f('location'),
+						'cat_id'		=> $this->db->f('cat_id'),
+						'created_by'	=> $this->db->f('created_by'),
+						'created_on'	=> $this->db->f('created_on'),
+					);
 			}
 
 			return $values;
 		}
 
 		/**
-		* Add responsibility type
-		*
-		* @param array $values values to be stored/edited and referencing ID if editing
-		*
-		* @return array $receip with result on the action(failed/success)
-		*/
+		 * Add responsibility type
+		 *
+		 * @param array $values values to be stored/edited and referencing ID if editing
+		 *
+		 * @return array $receip with result on the action(failed/success)
+		 */
 
 		public function add_type($values)
 		{
@@ -164,15 +164,15 @@
 			$values['descr'] = $this->db->db_addslashes($values['descr']);
 
 			$insert_values = array
-			(
-				$values['name'],
-				$values['descr'],
-				$GLOBALS['phpgw']->locations->get_id($this->appname, $values['location']),
-				(int) $values['cat_id'],
-				isset($values['active']) ? !!$values['active'] : '',
-				$this->account,
-				time()
-			);
+				(
+					$values['name'],
+					$values['descr'],
+					$GLOBALS['phpgw']->locations->get_id($this->appname, $values['location']),
+					(int) $values['cat_id'],
+					isset($values['active']) ? !!$values['active'] : '',
+					$this->account,
+					time()
+				);
 
 			$insert_values	= $this->db->validate_insert($insert_values);
 
@@ -195,12 +195,12 @@
 		}
 
 		/**
-		* Edit responsibility type
-		*
-		* @param array $values values to be stored/edited and referencing ID if editing
-		*
-		* @return array $receip with result on the action(failed/success)
-		*/
+		 * Edit responsibility type
+		 *
+		 * @param array $values values to be stored/edited and referencing ID if editing
+		 *
+		 * @return array $receip with result on the action(failed/success)
+		 */
 
 		public function edit_type($values)
 		{
@@ -229,12 +229,12 @@
 		}
 
 		/**
-		* Read single responsibility type
-		*
-		* @param integer $id ID of responsibility type
-		*
-		* @return array Responsibility type
-		*/
+		 * Read single responsibility type
+		 *
+		 * @param integer $id ID of responsibility type
+		 *
+		 * @return array Responsibility type
+		 */
 
 		public function read_single_type($id)
 		{
@@ -246,26 +246,26 @@
 
 			$this->db->next_record();
 			$values = array
-			(
-				'id'			=> $this->db->f('id'),
-				'name'			=> $this->db->f('name', true),
-				'descr'			=> $this->db->f('descr', true),
-				'active'		=> $this->db->f('active'),
-				'cat_id'		=> $this->db->f('cat_id'),
-				'created_by'	=> $this->db->f('created_by'),
-				'created_on'	=> $this->db->f('created_on'),
-			);
+				(
+					'id'			=> $this->db->f('id'),
+					'name'			=> $this->db->f('name', true),
+					'descr'			=> $this->db->f('descr', true),
+					'active'		=> $this->db->f('active'),
+					'cat_id'		=> $this->db->f('cat_id'),
+					'created_by'	=> $this->db->f('created_by'),
+					'created_on'	=> $this->db->f('created_on'),
+				);
 
 			return $values;
 		}
 
 		/**
-		* Delete responsibility type
-		*
-		* @param integer $id ID of responsibility type
-		*
-		* @return void
-		*/
+		 * Delete responsibility type
+		 *
+		 * @param integer $id ID of responsibility type
+		 *
+		 * @return void
+		 */
 
 		function delete_type($id)
 		{
@@ -277,12 +277,12 @@
 
 
 		/**
-		* Read responsibility type contact
-		*
-		* @param array $data array that Includes the fields: 'start', 'query', 'sort', 'order', 'allrows' and 'type_id'
-		*
-		* @return array Responsibility type contacts
-		*/
+		 * Read responsibility type contact
+		 *
+		 * @param array $data array that Includes the fields: 'start', 'query', 'sort', 'order', 'allrows' and 'type_id'
+		 *
+		 * @return array Responsibility type contacts
+		 */
 
 		public function read_contact($data)
 		{
@@ -337,37 +337,37 @@
 			while ($this->db->next_record())
 			{
 				$values[] = array
-				(
-					'id'				=> $this->db->f('id'),
-					'responsibility_id'	=> $this->db->f('responsibility_id'),
-					'contact_id'		=> $this->db->f('contact_id'),
-					'location_code'		=> $this->db->f('location_code'),
-					'priority'			=> $this->db->f('priority'),
-					'active_from'		=> $this->db->f('active_from'),
-					'active_to'			=> $this->db->f('active_to'),
-					'created_on'		=> $this->db->f('created_on'),
-					'created_by'		=> $this->db->f('created_by'),
-					'expired_on'		=> $this->db->f('expired_on'), // historical records
-					'expired_by'		=> $this->db->f('expired_by'),
-					'p_num'				=> $this->db->f('p_num', true),
-					'p_entity_id'		=> $this->db->f('p_entity_id'),
-					'p_cat_id'			=> $this->db->f('p_cat_id'),
-					'ecodimb'			=> $this->db->f('ecodimb'),
-					'remark'			=> $this->db->f('remark', true),
-				);
+					(
+						'id'				=> $this->db->f('id'),
+						'responsibility_id'	=> $this->db->f('responsibility_id'),
+						'contact_id'		=> $this->db->f('contact_id'),
+						'location_code'		=> $this->db->f('location_code'),
+						'priority'			=> $this->db->f('priority'),
+						'active_from'		=> $this->db->f('active_from'),
+						'active_to'			=> $this->db->f('active_to'),
+						'created_on'		=> $this->db->f('created_on'),
+						'created_by'		=> $this->db->f('created_by'),
+						'expired_on'		=> $this->db->f('expired_on'), // historical records
+						'expired_by'		=> $this->db->f('expired_by'),
+						'p_num'				=> $this->db->f('p_num', true),
+						'p_entity_id'		=> $this->db->f('p_entity_id'),
+						'p_cat_id'			=> $this->db->f('p_cat_id'),
+						'ecodimb'			=> $this->db->f('ecodimb'),
+						'remark'			=> $this->db->f('remark', true),
+					);
 			}
 
- 		return $values;
+			return $values;
 		}
 
 
 		/**
-		* Add responsibility contact
-		*
-		* @param array $values values to be stored/edited
-		*
-		* @return array $receip with result on the action(failed/success)
-		*/
+		 * Add responsibility contact
+		 *
+		 * @param array $values values to be stored/edited
+		 *
+		 * @return array $receip with result on the action(failed/success)
+		 */
 
 		public function add_contact($values)
 		{
@@ -375,20 +375,20 @@
 			$values['remark'] = $this->db->db_addslashes($values['remark']);
 
 			$insert_values = array
-			(
-				(int) $values['responsibility_id'],
-				(int) $values['contact_id'],
-				@implode('-', $values['location']),
-				$values['active_from'],
-				$values['active_to'],
-				isset($values['extra']['p_num']) ? $values['extra']['p_num'] : '',
-				isset($values['extra']['p_entity_id']) ? $values['extra']['p_entity_id'] : '',
-				isset($values['extra']['p_cat_id']) ? $values['extra']['p_cat_id'] : '',
-				$values['ecodimb'],
-				$values['remark'],
-				$this->account,
-				time()
-			);
+				(
+					(int) $values['responsibility_id'],
+					(int) $values['contact_id'],
+					@implode('-', $values['location']),
+					(int) $values['active_from'],
+					(int) $values['active_to'],
+					isset($values['extra']['p_num']) ? $values['extra']['p_num'] : '',
+					isset($values['extra']['p_entity_id']) ? $values['extra']['p_entity_id'] : '',
+					isset($values['extra']['p_cat_id']) ? $values['extra']['p_cat_id'] : '',
+					$values['ecodimb'],
+					$values['remark'],
+					$this->account,
+					time()
+				);
 
 			$insert_values	= $this->db->validate_insert($insert_values);
 
@@ -412,12 +412,12 @@
 		}
 
 		/**
-		* Edit responsibility contact
-		*
-		* @param array $values values to be stored/edited
-		*
-		* @return array $receip with result on the action(failed/success)
-		*/
+		 * Edit responsibility contact
+		 *
+		 * @param array $values values to be stored/edited
+		 *
+		 * @return array $receip with result on the action(failed/success)
+		 */
 
 		public function edit_contact($values)
 		{
@@ -426,6 +426,7 @@
 			$orig = $this->read_single_contact($values['id']);
 
 			if(isset($values['location']) &&(@implode('-', $values['location']) != $orig['location_code'])
+				|| $values['contact_id'] != $orig['contact_id']
 				|| $values['active_from'] != $orig['active_from']
 				|| $values['active_to'] != $orig['active_to']
 				|| $values['extra']['p_num'] != $orig['p_num']
@@ -433,7 +434,7 @@
 				|| $values['ecodimb'] != $orig['ecodimb'])
 			{
 				$receipt = $this->add_contact($values);
-				
+
 				if(!isset($receipt['error']))
 				{
 					unset($receipt['message']);
@@ -471,19 +472,19 @@
 
 
 		/**
-		* Read single responsibility contact
-		*
-		* @param integer $id ID of responsibility_contact
-		*
-		* @return array Responsibility contact
-		*/
+		 * Read single responsibility contact
+		 *
+		 * @param integer $id ID of responsibility_contact
+		 *
+		 * @return array Responsibility contact
+		 */
 
 		public function read_single_contact($id)
 		{
 			$sql = "SELECT fm_responsibility_contact.*,  fm_responsibility.name as responsibility_name"
-			. " FROM fm_responsibility_contact"
-			. " $this->join fm_responsibility ON fm_responsibility_contact.responsibility_id = fm_responsibility.id" 
-			. ' WHERE fm_responsibility_contact.id='  . (int) $id;
+				. " FROM fm_responsibility_contact"
+				. " $this->join fm_responsibility ON fm_responsibility_contact.responsibility_id = fm_responsibility.id" 
+				. ' WHERE fm_responsibility_contact.id='  . (int) $id;
 
 			$this->db->query($sql, __LINE__, __FILE__);
 
@@ -491,58 +492,112 @@
 
 			$this->db->next_record();
 			$values = array
-			(
-				'id'				=> $this->db->f('id'),
-				'responsibility_id'	=> $this->db->f('responsibility_id'),
-				'responsibility_name'=> $this->db->f('responsibility_name'),
-				'contact_id'		=> $this->db->f('contact_id'),
-				'location_code'		=> $this->db->f('location_code'),
-				'p_num'				=> $this->db->f('p_num'),
-				'p_entity_id'		=> $this->db->f('p_entity_id'),
-				'p_cat_id'			=> $this->db->f('p_cat_id'),
-				'remark'			=> $this->db->f('remark', true),
-				'active_from'		=> $this->db->f('active_from'),
-				'active_to'			=> $this->db->f('active_to'),
-				'created_by'		=> $this->db->f('created_by'),
-				'created_on'		=> $this->db->f('created_on'),
-				'expired_by'		=> $this->db->f('expired_by'),
-				'expired_on'		=> $this->db->f('expired_on'),
-				'priority'			=> $this->db->f('priority'), // FIXME - evaluate the need for this one
-				'ecodimb'			=> $this->db->f('ecodimb')
-			);
+				(
+					'id'				=> $this->db->f('id'),
+					'responsibility_id'	=> $this->db->f('responsibility_id'),
+					'responsibility_name'=> $this->db->f('responsibility_name'),
+					'contact_id'		=> $this->db->f('contact_id'),
+					'location_code'		=> $this->db->f('location_code'),
+					'p_num'				=> $this->db->f('p_num'),
+					'p_entity_id'		=> $this->db->f('p_entity_id'),
+					'p_cat_id'			=> $this->db->f('p_cat_id'),
+					'remark'			=> $this->db->f('remark', true),
+					'active_from'		=> $this->db->f('active_from'),
+					'active_to'			=> $this->db->f('active_to'),
+					'created_by'		=> $this->db->f('created_by'),
+					'created_on'		=> $this->db->f('created_on'),
+					'expired_by'		=> $this->db->f('expired_by'),
+					'expired_on'		=> $this->db->f('expired_on'),
+					'priority'			=> $this->db->f('priority'), // FIXME - evaluate the need for this one
+					'ecodimb'			=> $this->db->f('ecodimb')
+				);
 
 			return $values;
 		}
 
 		/**
-		* Delete responsibility type contact
-		*
-		* @param integer $id ID of responsibility type
-		*
-		* @return void
-		*/
+		 * Delete responsibility type contact
+		 *
+		 * @param integer $id ID of responsibility type
+		 *
+		 * @return void
+		 */
 
 		function delete_contact($id)
 		{
 			$this->db->query('DELETE FROM fm_responsibility_contact WHERE id='  . (int) $id, __LINE__, __FILE__);
 		}
 
+
 		/**
-		* Get the responsibility for a particular category conserning a given location or item
-		* Locations are checked bottom up at the deepest level - before checkin on it's parent if it is a miss.
-		*
-		* @param array $values containing cat_id, location_code and optional item-information
-		*
-		* @return contact_id
-		*/
+		 * Deactivate a responsibility type contact - leaving the information as history
+		 *
+		 * @param integer $id ID of responsibility type
+		 *
+		 * @return void
+		 */
+
+		function expire_contact($id)
+		{
+			$value_set['expired_by']	= $this->account;
+			$value_set['expired_on']	= time();
+			$value_set	= $this->db->validate_update($value_set);
+			$this->db->transaction_begin();
+			$this->db->query("UPDATE fm_responsibility_contact set $value_set WHERE id = " . (int) $id, __LINE__, __FILE__);
+			$this->db->transaction_commit();
+		}
+
+		/**
+		 * Get the contact and relation id for a particular role at a given location
+		 *
+		 * @param array $location_code location_code
+		 * @param array $role_id  role_id
+		 *
+		 * @return array
+		 */
+
+		public function get_active_responsible_at_location($location_code, $role_id)
+		{
+			$role_id = (int)$role_id;
+			$time = time() +1;
+
+			$sql = "SELECT fm_responsibility_contact.id, contact_id FROM fm_responsibility_contact"
+				. " $this->join fm_responsibility ON fm_responsibility_contact.responsibility_id = fm_responsibility.id"
+				. " $this->join fm_responsibility_role ON fm_responsibility.id = fm_responsibility_role.responsibility_id"
+				. " WHERE fm_responsibility_role.id ={$role_id}"
+				. " AND fm_responsibility_contact.location_code ='{$location_code}'"
+				. " AND active_from < {$time} AND (active_to > {$time} OR active_to = 0) AND expired_on IS NULL";
+
+			$values = array();
+			$this->db->query($sql, __LINE__, __FILE__);
+
+			if($this->db->next_record())
+			{
+				$values = array
+					(
+						'id'			=>  $this->db->f('id'),
+						'contact_id'	=> $this->db->f('contact_id')
+					);
+			}
+			return $values;
+
+		}
+		/**
+		 * Get the responsibility for a particular category conserning a given location or item
+		 * Locations are checked bottom up at the deepest level - before checkin on it's parent if it is a miss.
+		 *
+		 * @param array $values containing cat_id, location_code and optional item-information
+		 *
+		 * @return contact_id
+		 */
 
 		public function get_responsible($values = array())
 		{
 			$location_filter = array();
-	
+
 			$todo = false;
 			$item_filter = '';
-			
+
 			if(isset($values['ecodimb']) && $values['ecodimb'])
 			{
 				$item_filter =   " AND ecodimb = '{$values['ecodimb']}'";
@@ -554,8 +609,8 @@
 				$location_code = implode('-', $values['location']);
 
 				$item_filter =   " AND p_num = '{$values['extra']['p_num']}'"
-								.' AND p_entity_id =' . (int) $values['extra']['p_entity_id']
-								.' AND p_cat_id =' . (int) $values['extra']['p_cat_id'];
+					.' AND p_entity_id =' . (int) $values['extra']['p_entity_id']
+					.' AND p_cat_id =' . (int) $values['extra']['p_cat_id'];
 
 				$location_filter[] = " AND location_code = '{$location_code}'";
 				$ordermethod = '';
@@ -586,10 +641,10 @@
 			}
 
 			$sql = "SELECT contact_id FROM fm_responsibility_contact"
-			 . " $this->join fm_responsibility ON fm_responsibility_contact.responsibility_id = fm_responsibility.id"
-			 . ' WHERE cat_id =' . (int) $values['cat_id']
-			 . ' AND active = 1 AND active_from < ' . time() . ' AND (active_to > ' . time() . ' OR active_to = 0) AND expired_on IS NULL'
- 			 . " {$item_filter}";
+				. " $this->join fm_responsibility ON fm_responsibility_contact.responsibility_id = fm_responsibility.id"
+				. ' WHERE cat_id =' . (int) $values['cat_id']
+				. ' AND active = 1 AND active_from < ' . time() . ' AND (active_to > ' . time() . ' OR active_to = 0) AND expired_on IS NULL'
+				. " {$item_filter}";
 
 			foreach ($location_filter as $filter_at_location)
 			{
@@ -605,37 +660,37 @@
 		}
 
 		/**
-		* Get the user_id for a particular contact
-		*
-		* @param integer $person_id the ID of the given contact
-		*
-		* @return user_id
-		*/
+		 * Get the user_id for a particular contact
+		 *
+		 * @param integer $person_id the ID of the given contact
+		 *
+		 * @return user_id
+		 */
 
 		public function get_contact_user_id($person_id)
 		{
 			$person_id = (int) $person_id;
-			$sql = "SELECT account_id FROM phpgw_accounts WHERE person_id ={$person_id} AND person_id > 0";
+			$sql = "SELECT account_id FROM phpgw_accounts WHERE person_id ={$person_id}";
 			$this->db->query($sql, __LINE__, __FILE__);
 			$this->db->next_record();
-			return $this->db->f('account_id');
+			return (int)$this->db->f('account_id');
 		}
 
 		/**
-		* Get the user_id for a particular responsibility
-		*
-		* @param integer $person_id the ID of the given contact
-		*
-		* @return user_id
-		*/
+		 * Get the user_id for a particular responsibility
+		 *
+		 * @param integer $person_id the ID of the given contact
+		 *
+		 * @return user_id
+		 */
 
 		public function get_responsible_user_id($responsibility_id)
 		{
 			$responsibility_id = (int)$responsibility_id;
 			$now = time();
 			$sql = "SELECT contact_id FROM fm_responsibility_contact"
-			 . " $this->join fm_responsibility ON fm_responsibility_contact.responsibility_id = fm_responsibility.id"
-			 . " AND active = 1 AND active_from < {$now} AND active_to > {$now} AND expired_on IS NULL";
+				. " $this->join fm_responsibility ON fm_responsibility_contact.responsibility_id = fm_responsibility.id"
+				. " AND active = 1 AND active_from < {$now} AND active_to > {$now} AND expired_on IS NULL";
 
 			$this->db->query($sql, __LINE__, __FILE__);
 			$this->db->next_record(); 
