@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.sotts.inc.php 6294 2010-09-01 10:41:59Z sigurd $
+ 	* @version $Id: class.sotts.inc.php 7197 2011-04-07 12:17:22Z sigurdne $
 	*/
 
 	phpgw::import_class('phpgwapi.datetime');
@@ -38,11 +38,28 @@
 	{
 		var $uicols_related = array();
 		var $acl_location = '.ticket';
+		public $total_records	= 0;
+		public $sum_budget		= 0;
+		public $sum_actual_cost	= 0;
+
+		public $soap_functions = array
+			(
+				'read' => array(
+					'in'  => array('array'),
+					'out' => array('array')
+				)
+			);
+
+
+		public $xmlrpc_methods = array
+			(
+				array
+				(
+					'name'       => 'read',
+					'decription' => 'Get list of tickets'
+				)
+			);
 
-		var $soap_enabled = array
-		(
-			'read'	=> true
-		);
 
 		function __construct()
 		{
@@ -55,32 +72,73 @@
 			$this->dateformat 	= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 		}
 
+
+		function list_methods($_type='xmlrpc')
+		{
+			/*
+			  This handles introspection or discovery by the logged in client,
+			  in which case the input might be an array.  The server always calls
+			  this function to fill the server dispatch map using a string.
+			 */
+			if (is_array($_type))
+			{
+				$_type = $_type['type'] ? $_type['type'] : $_type[0];
+			}
+			switch($_type)
+			{
+			case 'xmlrpc':
+				$xml_functions = array(
+					'read' => array(
+						'function'  => 'read',
+						'signature' => array(array(xmlrpcArray,xmlrpcArray)),
+						'docstring' => 'Get list of tickets'
+					),
+				);
+				return $xml_functions;
+				break;
+			case 'soap':
+				return $this->soap_functions;
+				break;
+			default:
+				return array();
+				break;
+			}
+		}
+
+
 		function get_category_name($cat_id)
 		{
 			$this->db->query("SELECT descr FROM fm_tts_category  WHERE id='$cat_id' ");
 			$this->db->next_record();
-			return stripslashes($this->db->f('descr'));
+			return $this->db->f('descr',true);
 		}
 
 		function read($data)
 		{
-			$start			= isset($data['start']) && $data['start'] ? $data['start']:0;
+			$start			= isset($data['start']) && $data['start'] ? (int)$data['start']:0;
 			$status_id		= isset($data['status_id']) && $data['status_id'] ? $data['status_id']:'O'; //O='Open'
 			$user_id		= isset($data['user_id']) && $data['user_id'] ? (int)$data['user_id']: 0;
 			$owner_id		= isset($data['owner_id'])?$data['owner_id']:'';
 			$query			= isset($data['query'])?$data['query']:'';
 			$sort			= isset($data['sort']) && $data['sort'] ? $data['sort']:'DESC';
 			$order			= isset($data['order'])?$data['order']:'';
-			$cat_id			= isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id']:0;
-			$district_id	= isset($data['district_id']) && $data['district_id'] ? $data['district_id']:0;
+			$cat_id			= isset($data['cat_id']) && $data['cat_id'] ? (int)$data['cat_id']:0;
+			$district_id	= isset($data['district_id']) && $data['district_id'] ? (int)$data['district_id']:0;
+			$part_of_town_id= isset($data['part_of_town_id']) && $data['part_of_town_id'] ? (int)$data['part_of_town_id']:0;
 			$allrows		= isset($data['allrows'])?$data['allrows']:'';
-			$start_date		= isset($data['start_date'])?$data['start_date']:'';
-			$end_date		= isset($data['end_date'])?$data['end_date']:'';
+			$start_date		= isset($data['start_date']) && $data['start_date'] ? (int)$data['start_date'] : 0;
+			$end_date		= isset($data['end_date']) && $data['end_date'] ? (int)$data['end_date'] : 0;
 			$external		= isset($data['external'])?$data['external']:'';
 			$dry_run		= isset($data['dry_run']) ? $data['dry_run'] : '';
 			$new			= isset($data['new']) ? $data['new'] : '';
 			$location_code	= isset($data['location_code']) ? $data['location_code'] : '';
 			$p_num			= isset($data['p_num']) ? $data['p_num'] : '';
+			$vendor_id		= isset($data['vendor_id']) && $data['vendor_id'] ? (int)$data['vendor_id']:0;
+			$ecodimb		= isset($data['ecodimb']) && $data['ecodimb'] ? (int)$data['ecodimb']:0;
+			$b_account		= isset($data['b_account']) && $data['b_account'] ? $data['b_account']:'';
+			$building_part	= isset($data['building_part']) && $data['building_part'] ? $data['building_part']:'';
+			$branch_id		= isset($data['branch_id']) && $data['branch_id'] ? (int)$data['branch_id']:0;
+			$order_dim1		= isset($data['order_dim1']) && $data['order_dim1'] ? (int)$data['order_dim1']:0;
 
 			$this->grants 	= $GLOBALS['phpgw']->session->appsession('grants_ticket','property');
 
@@ -109,7 +167,7 @@
 				{
 					$order_join = '';
 				}
-				
+
 				$ordermethod = " ORDER BY $order $sort";
 			}
 			else
@@ -119,28 +177,25 @@
 
 			$filtermethod = '';
 
-			$categories = $GLOBALS['phpgw']->locations->get_subs('property', '.ticket.category');
-			
-			$grant_category = array();
-			foreach ($categories as $location)
-			{
-				if ($GLOBALS['phpgw']->acl->check($location, PHPGW_ACL_READ, 'property'))
-				{
-					$category = explode('.',$location);
-					$grant_category[] = $category[3];
-				}
-			}
-
-			$grant_category[] = -1;//If no one found - not breaking the query
-
 			$where= 'WHERE';
 
 			$GLOBALS['phpgw']->config->read();
 
+			$public_user_list = array();
 			if(isset($GLOBALS['phpgw']->config->config_data['acl_at_tts_category']) && $GLOBALS['phpgw']->config->config_data['acl_at_tts_category'])
 			{
-				$filtermethod = " WHERE fm_tts_tickets.cat_id IN (" . implode(",", $grant_category) . ")";
-				$where= 'AND';
+				$categories = $GLOBALS['phpgw']->locations->get_subs('property', '.ticket.category');
+
+				$category_grants = array();
+				foreach ($categories as $location)
+				{
+					$category_grants	= array_merge($category_grants, $GLOBALS['phpgw']->acl->get_grants('property',$location));
+				}
+
+				foreach($category_grants as $user => $right)
+				{
+					$public_user_list[] = $user;
+				}
 			}
 
 			if(isset($GLOBALS['phpgw']->config->config_data['acl_at_location']) && $GLOBALS['phpgw']->config->config_data['acl_at_location'])
@@ -160,9 +215,14 @@
 				{
 					$public_user_list[] = $user;
 				}
+			}
+			
+			if($public_user_list)
+			{
+				$public_user_list = array_unique($public_user_list);
 				reset($public_user_list);
 				$filtermethod .= " $where ( fm_tts_tickets.user_id IN(" . implode(',',$public_user_list) . "))";
-				$where= 'AND';
+				$where= 'AND';			
 			}
 
 			if($tenant_id = $GLOBALS['phpgw']->session->appsession('tenant_id','property'))
@@ -220,7 +280,7 @@
 			{
 				$or = '';
 				$filtermethod .= "{$where} ((";
-				
+
 				foreach ($status_id as $value)
 				{
 					if($value)
@@ -255,6 +315,37 @@
 				$where = 'AND';
 			}
 
+			if ($vendor_id > 0)
+			{
+				$filtermethod .= " $where vendor_id=" . (int)$vendor_id;
+				$where = 'AND';
+			}
+			if ($ecodimb > 0)
+			{
+				$filtermethod .= " $where ecodimb=" . (int)$ecodimb;
+				$where = 'AND';
+			}
+			if ($b_account > 0)
+			{
+				$filtermethod .= " $where b_account_id='{$b_account}'";
+				$where = 'AND';
+			}
+			if ($building_part)
+			{
+				$filtermethod .= " $where building_part='{$building_part}'";
+				$where = 'AND';
+			}
+			if ($branch_id > 0)
+			{
+				$filtermethod .= " $where branch_id=" . (int)$branch_id;
+				$where = 'AND';
+			}
+			if ($order_dim1 > 0)
+			{
+				$filtermethod .= " $where order_dim1=" . (int)$order_dim1;
+				$where = 'AND';
+			}
+
 			if ($user_id > 0)
 			{
 				$filtermethod .= " {$where} (assignedto={$user_id}";
@@ -264,6 +355,12 @@
 				$filtermethod .= ' OR (assignedto IS NULL AND group_id IN (' . implode(',',array_keys($membership)) . ')))'; 
 			}
 
+			if ($user_id < 0)
+			{
+				$filtermethod .= " {$where} fm_tts_tickets.user_id=" . (int)abs($user_id);
+				$where = 'AND';
+			}
+
 			if ($owner_id > 0)
 			{
 				$filtermethod .= " $where fm_tts_tickets.user_id=" . (int)$owner_id;
@@ -276,8 +373,16 @@
 				$where = 'AND';
 			}
 
+			if ($part_of_town_id > 0)
+			{
+				$filtermethod .= " $where fm_part_of_town.part_of_town_id= " . (int)$part_of_town_id;
+				$where = 'AND';
+			}
+
 			if ($start_date)
 			{
+				$end_date	= $end_date + 3600 * 16 + phpgwapi_datetime::user_timezone();
+				$start_date	= $start_date - 3600 * 8 + phpgwapi_datetime::user_timezone();
 				$filtermethod .= " $where fm_tts_tickets.entry_date >= $start_date AND fm_tts_tickets.entry_date <= $end_date ";
 				$where= 'AND';
 			}
@@ -292,48 +397,72 @@
 			if($query)
 			{
 				$query = $this->db->db_addslashes($query);
-				$query = str_replace(",",'.',$query);
-				if(stristr($query, '.') && !$p_num)
+				$querymethod = " $where ((subject $this->like '%$query%'"
+					. " OR address $this->like '%$query%' "
+					. " OR fm_location1.loc1_name $this->like '%$query%'"
+					. " OR fm_tts_tickets.location_code $this->like '%$query%'";
+
+				if(ctype_digit($query))
 				{
-					$query=explode(".",$query);
-					$querymethod = " $where (fm_tts_tickets.loc1='" . $query[0] . "' AND fm_tts_tickets.loc4='" . $query[1] . "')";
-				}
-				else if(stristr($query, '.') && $p_num)
-				{
-					$query=explode(".",$query);
-					$querymethod = " $where (fm_tts_tickets.p_entity_id='" . (int)$query[1] . "' AND fm_tts_tickets.p_cat_id='" . (int)$query[2] . "' AND fm_tts_tickets.p_num='" . (int)$query[3] . "')";
+					$querymethod .= " OR fm_tts_tickets.order_id =" . (int)$query
+					. " OR fm_tts_tickets.id =" . (int)$query . ')';
 				}
 				else
 				{
-					$querymethod = " $where (subject $this->like '%$query%'"
-					. " OR address $this->like '%$query%' "
-					. " OR fm_location1.loc1_name $this->like '%$query%'"
-					. " OR fm_tts_tickets.location_code $this->like '%$query%'"
-					. " OR fm_tts_tickets.order_id =" . (int)$query . ')';
+					$querymethod .= ')';
+				}
+
+				$query = str_replace(",",'.',$query);
+				if(stristr($query, '.'))
+				{
+					if(!$p_num)
+					{
+						$query=explode(".",$query);
+						$querymethod .= " OR (fm_tts_tickets.loc1='{$query[0]}' AND fm_tts_tickets.loc4='{$query[1]}'))";
+					}
+					else
+					{
+						$query=explode(".",$query);
+						$querymethod = " {$where} (fm_tts_tickets.p_entity_id='" . (int)$query[1] . "' AND fm_tts_tickets.p_cat_id='" . (int)$query[2] . "' AND fm_tts_tickets.p_num='{$query[3]}')";
+					}
+				}
+				else
+				{
+					$querymethod .= ')';
 				}
 			}
 
-			$sql = "SELECT DISTINCT fm_tts_tickets.* ,fm_location1.loc1_name, fm_tts_views.id as view {$result_order_field},fm_district.descr as district  FROM fm_tts_tickets"
-			. " $this->join fm_location1 ON fm_tts_tickets.loc1=fm_location1.loc1"
-			. " $this->join fm_part_of_town ON fm_location1.part_of_town_id=fm_part_of_town.part_of_town_id"
-			. " $this->join fm_district ON fm_district.id = fm_part_of_town.district_id"
-			. " $order_join"
-			. " LEFT OUTER JOIN fm_tts_views ON (fm_tts_tickets.id = fm_tts_views.id AND fm_tts_views.account_id='{$this->account}')"
-			. " $filtermethod $querymethod";
+			$return_fields = "fm_tts_tickets.id,fm_tts_tickets.assignedto,fm_tts_tickets.status,fm_tts_tickets.user_id,"
+			. "fm_tts_tickets.subject,fm_tts_tickets.address,fm_tts_tickets.location_code,fm_tts_tickets.priority,fm_tts_tickets.cat_id,fm_tts_tickets.group_id,"
+			. "fm_tts_tickets.entry_date,fm_tts_tickets.finnish_date,fm_tts_tickets.finnish_date2,fm_tts_tickets.order_id,fm_tts_tickets.vendor_id,fm_tts_tickets.actual_cost,"
+			. "fm_tts_tickets.budget,fm_tts_tickets.billable_hours,fm_district.descr as district,fm_tts_views.id as view,fm_location1.loc1_name {$result_order_field}";
+			
+			//fm_tts_tickets.* ,fm_location1.loc1_name, fm_tts_views.id as view {$result_order_field},fm_district.descr as district
+			$sql = "SELECT DISTINCT {$return_fields}  FROM fm_tts_tickets"
+				. " {$this->join} fm_location1 ON fm_tts_tickets.loc1=fm_location1.loc1"
+				. " {$this->join} fm_part_of_town ON fm_location1.part_of_town_id=fm_part_of_town.part_of_town_id"
+				. " {$this->join} fm_district ON fm_district.id = fm_part_of_town.district_id"
+				. " {$order_join}"
+				. " LEFT OUTER JOIN fm_tts_views ON (fm_tts_tickets.id = fm_tts_views.id AND fm_tts_views.account_id='{$this->account}')"
+				. " {$filtermethod} {$querymethod}";
 
-/*
-				$sql2 = "SELECT fm_tts_tickets.* ,fm_location1.loc1_name, fm_tts_views.id as view FROM fm_tts_tickets"
+
+			$sql_cnt = "SELECT DISTINCT fm_tts_tickets.budget ,fm_tts_tickets.actual_cost, fm_tts_tickets.id FROM fm_tts_tickets"
 				. " $this->join fm_location1 ON fm_tts_tickets.loc1=fm_location1.loc1"
 				. " $this->join fm_part_of_town ON fm_location1.part_of_town_id=fm_part_of_town.part_of_town_id"
+				. " $this->join fm_district ON fm_district.id = fm_part_of_town.district_id"
 				. " $order_join"
+				. " LEFT OUTER JOIN fm_tts_views ON (fm_tts_tickets.id = fm_tts_views.id AND fm_tts_views.account_id='{$this->account}')"
 				. " $filtermethod $querymethod";
 
-				$sql2 = 'SELECT count(*) as cnt ' . substr($sql2,strripos($sql2,'FROM'));
-*/
-			$sql2 = "SELECT count(*) as cnt FROM ({$sql}) as t";
+//_debug_array($sql);
+
+			$sql2 = "SELECT count(*) as cnt, sum(budget) as sum_budget, sum(actual_cost) as sum_actual_cost FROM ({$sql_cnt}) as t";
 			$this->db->query($sql2,__LINE__,__FILE__);
 			$this->db->next_record();
-			$this->total_records = $this->db->f('cnt');
+			$this->total_records	= $this->db->f('cnt');
+			$this->sum_budget		= $this->db->f('sum_budget');
+			$this->sum_actual_cost	= $this->db->f('sum_actual_cost');
 			unset($sql2);
 
 			$tickets = array();
@@ -361,42 +490,29 @@
 				{
 					$tickets[]= array
 					(
-						'id'				=> (int) $this->db->f('id'),
-						'subject'			=> $this->db->f('subject',true),
-						'loc1_name'			=> $this->db->f('loc1_name',true),
-						'location_code'		=> $this->db->f('location_code'),
-						'district'			=> $this->db->f('district',true),
-						'user_id'			=> $this->db->f('user_id'),
-						'address'			=> $this->db->f('address',true),
-						'assignedto'		=> $this->db->f('assignedto'),
-						'status'			=> $this->db->f('status'),
-						'priority'			=> $this->db->f('priority'),
-						'cat_id'			=> $this->db->f('cat_id'),
-						'group_id'			=> $this->db->f('group_id'),
-						'entry_date'		=> $this->db->f('entry_date'),
-						'finnish_date'		=> $this->db->f('finnish_date'),
-						'finnish_date2'		=> $this->db->f('finnish_date2'),
-						'order_id'			=> $this->db->f('order_id'),
-						'vendor_id'			=> $this->db->f('vendor_id'),
-						'actual_cost'		=> $this->db->f('actual_cost'),
-						'estimate'			=> $this->db->f('budget'),
-						'new_ticket'		=> $this->db->f('view') ? false : true,
-						'billable_hours'	=> $this->db->f('billable_hours'),
+							'id'				=> (int) $this->db->f('id'),
+							'subject'			=> $this->db->f('subject',true),
+							'loc1_name'			=> $this->db->f('loc1_name',true),
+							'location_code'		=> $this->db->f('location_code'),
+							'district'			=> $this->db->f('district',true),
+							'user_id'			=> $this->db->f('user_id'),
+							'address'			=> $this->db->f('address',true),
+							'assignedto'		=> $this->db->f('assignedto'),
+							'status'			=> $this->db->f('status'),
+							'priority'			=> $this->db->f('priority'),
+							'cat_id'			=> $this->db->f('cat_id'),
+							'group_id'			=> $this->db->f('group_id'),
+							'entry_date'		=> $this->db->f('entry_date'),
+							'finnish_date'		=> $this->db->f('finnish_date'),
+							'finnish_date2'		=> $this->db->f('finnish_date2'),
+							'order_id'			=> $this->db->f('order_id'),
+							'vendor_id'			=> $this->db->f('vendor_id'),
+							'actual_cost'		=> $this->db->f('actual_cost'),
+							'estimate'			=> $this->db->f('budget'),
+							'new_ticket'		=> $this->db->f('view') ? false : true,
+							'billable_hours'	=> $this->db->f('billable_hours'),
 					);
 				}
-/*			
-				foreach ($tickets as &$ticket)
-				{
-					$this->db->query("SELECT count(*) as hits FROM fm_tts_views where id={$ticket['id']}"
-						. " AND account_id='{$this->account}'",__LINE__,__FILE__);
-					$this->db->next_record();
-	
-					if(! $this->db->f('hits'))
-					{
-						$ticket['new_ticket'] = true;
-					}
-				}
-*/
 			}
 
 			return $tickets;
@@ -405,11 +521,13 @@
 		function get_origin_entity_type()
 		{
 			$sql = "SELECT entity_id, id as cat_id,name"
-			. " FROM fm_entity_category "
-			. " WHERE tracking=1 ORDER by entity_id,cat_id";
+				. " FROM fm_entity_category "
+				. " WHERE tracking=1 ORDER by entity_id,cat_id";
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
+			$entity = array();
+			$uicols = array();
 			$i=0;
 			while ($this->db->next_record())
 			{
@@ -467,7 +585,7 @@
 				$ticket['order_dim1']		= $this->db->f('order_dim1');
 				$ticket['publish_note']		= $this->db->f('publish_note');
 				$ticket['billable_hours']	= $this->db->f('billable_hours');
-
+				$ticket['branch_id']		= $this->db->f('branch_id');
 				$user_id=(int)$this->db->f('user_id');
 
 				$ticket['user_name']	= $GLOBALS['phpgw']->accounts->get($user_id)->__toString();
@@ -485,13 +603,13 @@
 			// Have they viewed this ticket before ?
 			$id = (int) $id;
 			$this->db->query("SELECT count(*) as cnt FROM fm_tts_views where id={$id}"
-					. " AND account_id='" . $GLOBALS['phpgw_info']['user']['account_id'] . "'",__LINE__,__FILE__);
+				. " AND account_id='" . $GLOBALS['phpgw_info']['user']['account_id'] . "'",__LINE__,__FILE__);
 			$this->db->next_record();
 
 			if (! $this->db->f('cnt'))
 			{
 				$this->db->query("INSERT INTO fm_tts_views (id,account_id,time) values ({$id},'"
-					. $GLOBALS['phpgw_info']['user']['account_id'] . "','" . phpgwapi_datetime::user_localtime() . "')",__LINE__,__FILE__);
+					. $GLOBALS['phpgw_info']['user']['account_id'] . "','" . time() . "')",__LINE__,__FILE__);
 			}
 		}
 
@@ -503,8 +621,7 @@
 				{
 					if(isset($value) && $value)
 					{
-						$cols[] = $input_name;
-						$vals[] = $value;
+						$value_set[$input_name] = $value;
 					}
 				}
 			}
@@ -515,61 +632,75 @@
 				{
 					if(isset($value) && $value)
 					{
-						$cols[] = $input_name;
-						$vals[] = $value;
+						$value_set[$input_name] = $value;
+					}
+				}
+
+				if($ticket['extra']['p_num'] && $ticket['extra']['p_entity_id'] && $ticket['extra']['p_cat_id'])
+				{
+					$entity	= CreateObject('property.soadmin_entity');
+					$entity_category = $entity->read_single_category($ticket['extra']['p_entity_id'],$ticket['extra']['p_cat_id']);
+				}
+			}
+
+			$_address = array();
+			if(isset($ticket['street_name']) && $ticket['street_name'])
+			{
+				$_address[] = "{$ticket['street_name']} {$ticket['street_number']}";
+			}
+
+			if(isset($ticket['location_name']) && $ticket['location_name'])
+			{
+				$_address[] = $ticket['location_name'];
+			}
+
+			if(isset($ticket['additional_info']) && $ticket['additional_info'])
+			{
+				foreach($ticket['additional_info'] as $key => $value)
+				{
+					if($value)
+					{
+						$_address[] = "{$key}|{$value}";
 					}
 				}
 			}
 
-			if($cols)
+			if(isset($entity_category) && $entity_category)
 			{
-				$cols	= "," . implode(",", $cols);
-				$vals	= ",'" . implode("','", $vals) . "'";
+				$_address[] = "{$entity_category['name']}::{$ticket['extra']['p_num']}";				
 			}
 
-			$address = '';
-			if(isset($ticket['street_name']) && $ticket['street_name'])
-			{
-				$address[]= $ticket['street_name'];
-				$address[]= $ticket['street_number'];
-				$address	= $this->db->db_addslashes(implode(" ", $address));
-			}
+			$address	= $this->db->db_addslashes(implode('::', $_address));
 
-			if(!$address)
-			{
-				$address = $this->db->db_addslashes($ticket['location_name']);
-			}
+			unset($_address);
 
-			$values= array
-			(
-				isset($ticket['priority'])?$ticket['priority']:0,
-				$GLOBALS['phpgw_info']['user']['account_id'],
-				$ticket['assignedto'],
-				$ticket['group_id'],
-				$this->db->db_addslashes($ticket['subject']),
-				$ticket['cat_id'],
-				$ticket['status'],
-				$this->db->db_addslashes($ticket['details']),
-				$ticket['location_code'],
-				$address,
-				phpgwapi_datetime::user_localtime(),
-				$ticket['finnish_date'],
-				$ticket['contact_id'],
-				1
-			);
+			$value_set['priority']		= isset($ticket['priority'])?$ticket['priority']:0;
+			$value_set['user_id']		= $GLOBALS['phpgw_info']['user']['account_id'];
+			$value_set['assignedto']	= $ticket['assignedto'];
+			$value_set['group_id']		= $ticket['group_id'];
+			$value_set['subject']		= $this->db->db_addslashes($ticket['subject']);
+			$value_set['cat_id']		= $ticket['cat_id'];
+			$value_set['status']		= $ticket['status'];
+			$value_set['details']		= $this->db->db_addslashes($ticket['details']);
+			$value_set['location_code']	= $ticket['location_code'];
+			$value_set['address']		= $address;
+			$value_set['entry_date']	= time();
+			$value_set['finnish_date']	= $ticket['finnish_date'];
+			$value_set['contact_id']	= $ticket['contact_id'];
+			$value_set['publish_note']	= 1;
 
-			$values	= $this->db->validate_insert($values);
+
+			$cols = implode(',', array_keys($value_set));
+			$values	= $this->db->validate_insert(array_values($value_set));
 			$this->db->transaction_begin();
 
-			$this->db->query("insert into fm_tts_tickets (priority,user_id,"
-				. "assignedto,group_id,subject,cat_id,status,details,location_code,"
-				. "address,entry_date,finnish_date,contact_id,publish_note $cols)"
-				. "VALUES ($values $vals )",__LINE__,__FILE__);
+			$table = 'fm_tts_tickets';
+			$this->db->query("INSERT INTO {$table} ({$cols}) VALUES ({$values})",__LINE__,__FILE__);
 
-			$id = $this->db->get_last_insert_id('fm_tts_tickets','id');
+			$id = $this->db->get_last_insert_id($table,'id');
 			if(isset($ticket['extra']['contact_phone']) && $ticket['extra']['contact_phone'] && isset($ticket['extra']['tenant_id']) && $ticket['extra']['tenant_id'])
 			{
-				$this->db->query("update fm_tenant set contact_phone='". $ticket['extra']['contact_phone']. "' where id='". $ticket['extra']['tenant_id']. "'",__LINE__,__FILE__);
+				$this->db->query("UPDATE fm_tenant SET contact_phone='{$ticket['extra']['contact_phone']}' WHERE id='{$ticket['extra']['tenant_id']}'",__LINE__,__FILE__);
 			}
 
 			if(isset($ticket['origin']) && is_array($ticket['origin']))
@@ -577,13 +708,13 @@
 				if($ticket['origin'][0]['data'][0]['id'])
 				{
 					$interlink_data = array
-					(
-						'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $ticket['origin'][0]['location']),
-						'location1_item_id' => $ticket['origin'][0]['data'][0]['id'],
-						'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.ticket'),			
-						'location2_item_id' => $id,
-						'account_id'		=> $this->account
-					);
+						(
+							'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $ticket['origin'][0]['location']),
+							'location1_item_id' => $ticket['origin'][0]['data'][0]['id'],
+							'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.ticket'),			
+							'location2_item_id' => $id,
+							'account_id'		=> $this->account
+						);
 
 					$interlink 	= CreateObject('property.interlink');
 					$interlink->add($interlink_data,$this->db);
@@ -592,7 +723,7 @@
 
 			if($this->db->transaction_commit())
 			{
-				$this->historylog->add('O',$id, phpgwapi_datetime::user_localtime(),'');
+				$this->historylog->add('O',$id, time(),'');
 				if($ticket['finnish_date'])
 				{
 					$this->historylog->add('IF',$id,$ticket['finnish_date'],'');
@@ -605,10 +736,10 @@
 		}
 
 		/**
-		* Get a list of user(admin)-configured status
-		*
-		* @return array with list of custom status
-		*/
+		 * Get a list of user(admin)-configured status
+		 *
+		 * @return array with list of custom status
+		 */
 
 		public function get_custom_status()
 		{
@@ -619,11 +750,11 @@
 			while ($this->db->next_record())
 			{
 				$status[] = array
-				(
-					'id'	=> $this->db->f('id'),
-					'name'	=> $this->db->f('name', true),
-					'color'	=> $this->db->f('color')
-				);
+					(
+						'id'	=> $this->db->f('id'),
+						'name'	=> $this->db->f('name', true),
+						'color'	=> $this->db->f('color')
+					);
 			}
 			return $status;
 		}
@@ -639,23 +770,23 @@
 			$this->db->transaction_begin();
 
 			/*
-			** phpgw_fm_tts_append.append_type - Defs
-			** R - Reopen ticket
-			** X - Ticket closed
-			** O - Ticket opened
-			** C - Comment appended
-			** A - Ticket assignment
-			** G - Ticket group assignment
-			** P - Priority change
-			** T - Category change
-			** S - Subject change
-			** B - Budget
-			** H - Billing hours
-			** F - finnish date
-			** C% - Status changed
-			** L - Location changed
-			** M - Mail sent to vendor
-			*/
+			 ** phpgw_fm_tts_append.append_type - Defs
+			 ** R - Reopen ticket
+			 ** X - Ticket closed
+			 ** O - Ticket opened
+			 ** C - Comment appended
+			 ** A - Ticket assignment
+			 ** G - Ticket group assignment
+			 ** P - Priority change
+			 ** T - Category change
+			 ** S - Subject change
+			 ** B - Budget
+			 ** H - Billing hours
+			 ** F - finnish date
+			 ** C% - Status changed
+			 ** L - Location changed
+			 ** M - Mail sent to vendor
+			 */
 
 			if ($old_status != $ticket['status'])
 			{
@@ -689,10 +820,9 @@
 
 		}
 
-		function update_ticket($ticket,$id = 0)
+		function update_ticket($ticket,$id = 0, $receipt = array())
 		{
 			$id = (int) $id;
-			$receipt = array();
 			// DB Content is fresher than http posted value.
 			$this->db->query("select * from fm_tts_tickets where id='$id'",__LINE__,__FILE__);
 			$this->db->next_record();
@@ -708,7 +838,7 @@
 			$old_status  		= $this->db->f('status');
 			$old_budget  		= $this->db->f('budget');
 			$old_billable_hours	= $this->db->f('billable_hours');
-		//	$old_billable_rate	= $this->db->f('billable_rate');
+			//	$old_billable_rate	= $this->db->f('billable_rate');
 			$old_subject		= $this->db->f('subject');
 			$old_contact_id		= $this->db->f('contact_id');
 			$old_actual_cost	= $this->db->f('actual_cost');
@@ -716,7 +846,7 @@
 			$old_building_part	= $this->db->f('building_part',true);
 			$old_order_dim1		= (int)$this->db->f('order_dim1');
 
-	
+
 			if($oldcat_id ==0){$oldcat_id ='';}
 			if($old_order_cat_id ==0){$old_order_cat_id ='';}
 			if($oldassigned ==0){$oldassigned ='';}
@@ -732,27 +862,26 @@
 				$old_note = $this->db->f('details');
 			}
 
-
 			$this->db->transaction_begin();
 
 			/*
-			** phpgw_fm_tts_append.append_type - Defs
-			** R - Reopen ticket
-			** X - Ticket closed
-			** O - Ticket opened
-			** C - Comment appended
-			** A - Ticket assignment
-			** G - Ticket group assignment
-			** P - Priority change
-			** T - Category change
-			** S - Subject change
-			** B - Budget change
-			** H - Billing hours
-			** F - finnish date
-			** C% - Status change
-			** L - Location changed
-			** M - Mail sent to vendor
-			*/
+			 ** phpgw_fm_tts_append.append_type - Defs
+			 ** R - Reopen ticket
+			 ** X - Ticket closed
+			 ** O - Ticket opened
+			 ** C - Comment appended
+			 ** A - Ticket assignment
+			 ** G - Ticket group assignment
+			 ** P - Priority change
+			 ** T - Category change
+			 ** S - Subject change
+			 ** B - Budget change
+			 ** H - Billing hours
+			 ** F - finnish date
+			 ** C% - Status change
+			 ** L - Location changed
+			 ** M - Mail sent to vendor
+			 */
 
 			$this->db->query("UPDATE fm_tts_tickets SET publish_note = NULL WHERE id = {$id}",__LINE__,__FILE__);
 			$this->db->query("UPDATE fm_tts_history SET publish = NULL WHERE history_record_id = {$id}",__LINE__,__FILE__);
@@ -774,17 +903,16 @@
 
 			$finnish_date	= (isset($ticket['finnish_date']) ? phpgwapi_datetime::date_to_timestamp($ticket['finnish_date']):'');
 
-			if ($oldfinnish_date && isset($ticket['finnish_date']) && $ticket['finnish_date']):
+			if ($oldfinnish_date && isset($ticket['finnish_date']) && $ticket['finnish_date'])
 			{
 				$this->db->query("update fm_tts_tickets set finnish_date2='" . $finnish_date
 					. "' where id='$id'",__LINE__,__FILE__);
 			}
-			elseif(!$oldfinnish_date && isset($ticket['finnish_date']) && $ticket['finnish_date']):
+			else if(!$oldfinnish_date && isset($ticket['finnish_date']) && $ticket['finnish_date'])
 			{
 				$this->db->query("update fm_tts_tickets set finnish_date='" . $finnish_date
 					. "' where id='$id'",__LINE__,__FILE__);
 			}
-			endif;
 
 			if($oldfinnish_date2>0)
 			{
@@ -880,7 +1008,7 @@
 					. "' where id='$id'",__LINE__,__FILE__);
 				$this->historylog->add('B',$id,$ticket['billable_rate'],$old_billable_rate);
 			}
-	*/
+	 */
 			if ($old_subject != $ticket['subject'])
 			{
 				$this->db->query("UPDATE fm_tts_tickets SET subject='" . $ticket['subject']
@@ -906,7 +1034,7 @@
 				$this->db->query("UPDATE fm_tts_tickets SET actual_cost='" . (float)$ticket['actual_cost']
 					. "' WHERE id='$id'",__LINE__,__FILE__);
 				$this->historylog->add('AC',$id,(float)$ticket['actual_cost'] , $old_actual_cost);
-				$receipt['message'][]= array('msg' => lang('actual_cost has been updated'));
+				$receipt['message'][]= array('msg' => lang('actual cost has been updated'));
 			}
 
 			if ((int)$old_order_cat_id != (int)$ticket['order_cat_id'])
@@ -958,22 +1086,46 @@
 				{
 					$value_set	= array();
 
+					$_address = array();
 					if(isset($ticket['street_name']) && $ticket['street_name'])
 					{
-						$address[]= $ticket['street_name'];
-						$address[]= $ticket['street_number'];
-						$value_set['address'] = $this->db->db_addslashes(implode(" ", $address));
+						$_address[] = "{$ticket['street_name']} {$ticket['street_number']}";
 					}
 
-					if(!isset($address) || !$address)
+					if(isset($ticket['location_name']) && $ticket['location_name'])
 					{
-						$address = isset($ticket['location_name']) ? $this->db->db_addslashes($ticket['location_name']) : '';
-						if($address)
+						$_address[] = $ticket['location_name'];
+					}
+
+					if(isset($ticket['additional_info']) && $ticket['additional_info'])
+					{
+						foreach($ticket['additional_info'] as $key => $value)
 						{
-							$value_set['address'] = $address;
+							if($value)
+							{
+								$_address[] = "{$key}|{$value}";
+							}
 						}
 					}
 
+
+					if(isset($ticket['extra']['p_num']) && $ticket['extra']['p_num'] && $ticket['extra']['p_entity_id'] && $ticket['extra']['p_cat_id'])
+					{
+						$entity	= CreateObject('property.soadmin_entity');
+						$entity_category = $entity->read_single_category($ticket['extra']['p_entity_id'],$ticket['extra']['p_cat_id']);
+					}
+
+					if(isset($entity_category) && $entity_category)
+					{
+						$_address[] = "{$entity_category['name']}::{$ticket['extra']['p_num']}";				
+					}
+
+					$address	= $this->db->db_addslashes(implode('::', $_address));
+
+					unset($_address);
+
+					$value_set['address'] = $address;
+
 					if (isset($ticket['location_code']) && $ticket['location_code'])
 					{
 						$value_set['location_code'] = $ticket['location_code'];
@@ -982,7 +1134,7 @@
 					$admin_location	= CreateObject('property.soadmin_location');
 					$admin_location->read(false);
 
-				// Delete old values for location - in case of moving up in the hierarchy
+					// Delete old values for location - in case of moving up in the hierarchy
 					$metadata = $this->db->metadata('fm_tts_tickets');
 					for ($i = 1;$i < $admin_location->total_records + 1; $i++)
 					{
@@ -1034,6 +1186,7 @@
 			$value_set['order_descr']	= $this->db->db_addslashes($ticket['order_descr']);
 			$value_set['ecodimb']		= $ticket['ecodimb'];
 			$value_set['budget']		= $ticket['budget'];
+			$value_set['branch_id']		= $ticket['branch_id'];
 			$value_set					= $this->db->validate_update($value_set);
 			$this->db->query("UPDATE fm_tts_tickets SET $value_set WHERE id={$id}",__LINE__,__FILE__);
 
@@ -1044,11 +1197,11 @@
 				$receipt['message'][]= array('msg' => lang('Ticket has been updated'));
 
 				$criteria = array
-				(
-					'appname'	=> 'property',
-					'location'	=> $this->acl_location,
-					'allrows'	=> true
-				);
+					(
+						'appname'	=> 'property',
+						'location'	=> $this->acl_location,
+						'allrows'	=> true
+					);
 
 				$custom_functions = $GLOBALS['phpgw']->custom_functions->find($criteria);
 
@@ -1080,16 +1233,16 @@
 			if ($this->db->f('approved') )
 			{
 				$action_params = array
-				(
-					'appname'			=> 'property',
-					'location'			=> '.ticket',
-					'id'				=> $id,
-					'responsible'		=> $this->account,
-					'responsible_type'  => 'user',
-					'action'			=> 'approval',
-					'remark'			=> '',
-					'deadline'			=> ''
-				);
+					(
+						'appname'			=> 'property',
+						'location'			=> '.ticket',
+						'id'				=> $id,
+						'responsible'		=> $this->account,
+						'responsible_type'  => 'user',
+						'action'			=> 'approval',
+						'remark'			=> '',
+						'deadline'			=> ''
+					);
 
 				execMethod('property.sopending_action.close_pending_action', $action_params);
 				unset($action_params);
@@ -1097,16 +1250,16 @@
 			if ($this->db->f('in_progress') )
 			{
 				$action_params = array
-				(
-					'appname'			=> 'property',
-					'location'			=> '.ticket',
-					'id'				=> $id,
-					'responsible'		=> $ticket['vendor_id'],
-					'responsible_type'  => 'vendor',
-					'action'			=> 'remind',
-					'remark'			=> '',
-					'deadline'			=> ''
-				);
+					(
+						'appname'			=> 'property',
+						'location'			=> '.ticket',
+						'id'				=> $id,
+						'responsible'		=> $ticket['vendor_id'],
+						'responsible_type'  => 'vendor',
+						'action'			=> 'remind',
+						'remark'			=> '',
+						'deadline'			=> ''
+					);
 
 				execMethod('property.sopending_action.close_pending_action', $action_params);
 				unset($action_params);
@@ -1147,4 +1300,114 @@
 				return false;
 			}
 		}
+
+		public function get_vendors()
+		{
+			$values = array();
+			$sql = "SELECT DISTINCT fm_vendor.id, fm_vendor.org_name FROM fm_tts_tickets {$this->join} fm_vendor ON fm_tts_tickets.vendor_id = fm_vendor.id ORDER BY org_name ASC";
+			
+			$this->db->query($sql, __LINE__,__FILE__);
+
+			while ($this->db->next_record())
+			{
+				$values[] = array
+				(
+					'id'	=> $this->db->f('id'),
+					'name'	=> $this->db->f('org_name', true)
+				);
+			}
+	
+			return $values;
+		}
+		public function get_ecodimb()
+		{
+			$values = array();
+			$sql = "SELECT DISTINCT fm_ecodimb.id, fm_ecodimb.descr as name FROM fm_tts_tickets {$this->join} fm_ecodimb ON fm_tts_tickets.ecodimb = fm_ecodimb.id ORDER BY name ASC";
+			
+			$this->db->query($sql, __LINE__,__FILE__);
+
+			while ($this->db->next_record())
+			{
+				$values[] = array
+				(
+					'id'	=> $this->db->f('id'),
+					'name'	=> $this->db->f('name', true)
+				);
+			}
+	
+			return $values;
+		}
+		public function get_b_account()
+		{
+			$values = array();
+			$sql = "SELECT DISTINCT fm_b_account.id, fm_b_account.descr as name FROM fm_tts_tickets {$this->join} fm_b_account ON fm_tts_tickets.b_account_id = fm_b_account.id ORDER BY id ASC";
+			
+			$this->db->query($sql, __LINE__,__FILE__);
+
+			while ($this->db->next_record())
+			{
+				$values[] = array
+				(
+					'id'	=> $this->db->f('id'),
+					'name'	=> $this->db->f('name', true)
+				);
+			}
+	
+			return $values;
+		}
+		public function get_building_part()
+		{
+			$values = array();
+			$sql = "SELECT DISTINCT fm_building_part.id, fm_building_part.descr as name FROM fm_tts_tickets {$this->join} fm_building_part ON fm_tts_tickets.building_part = fm_building_part.id ORDER BY id ASC";
+			
+			$this->db->query($sql, __LINE__,__FILE__);
+
+			while ($this->db->next_record())
+			{
+				$id	= $this->db->f('id');
+				$values[] = array
+				(
+					'id'	=> $id,
+					'name'	=> $id . ' ' . $this->db->f('name', true)
+				);
+			}
+	
+			return $values;
+		}
+		public function get_branch()
+		{
+			$values = array();
+			$sql = "SELECT DISTINCT fm_branch.id, fm_branch.descr as name FROM fm_tts_tickets {$this->join} fm_branch ON fm_tts_tickets.branch_id = fm_branch.id ORDER BY name ASC";
+			
+			$this->db->query($sql, __LINE__,__FILE__);
+
+			while ($this->db->next_record())
+			{
+				$values[] = array
+				(
+					'id'	=> $this->db->f('id'),
+					'name'	=> $this->db->f('name', true)
+				);
+			}
+	
+			return $values;
+		}
+		public function get_order_dim1()
+		{
+			$values = array();
+			$sql = "SELECT DISTINCT fm_order_dim1.id, fm_order_dim1.descr as name FROM fm_tts_tickets {$this->join} fm_order_dim1 ON fm_tts_tickets.order_dim1 = fm_order_dim1.id ORDER BY name ASC";
+			
+			$this->db->query($sql, __LINE__,__FILE__);
+
+			while ($this->db->next_record())
+			{
+				$values[] = array
+				(
+					'id'	=> $this->db->f('id'),
+					'name'	=> $this->db->f('name', true)
+				);
+			}
+	
+			return $values;
+		}
 	}
