@@ -24,9 +24,11 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.soworkorder.inc.php 6271 2010-08-25 12:08:16Z sigurd $
+ 	* @version $Id: class.soworkorder.inc.php 7197 2011-04-07 12:17:22Z sigurdne $
 	*/
 
+	phpgw::import_class('phpgwapi.datetime');
+
 	/**
 	 * Description
 	 * @package property
@@ -34,7 +36,6 @@
 
 	class property_soworkorder
 	{
-
 		var $total_records = 0;
 
 		function __construct()
@@ -129,9 +130,9 @@
 			$sort			= isset($data['sort']) && $data['sort'] ? $data['sort'] : 'DESC';
 			$order			= isset($data['order']) ? $data['order'] : '';
 			$cat_id			= isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id'] : 0;
-			$status_id		= isset($data['status_id']) && $data['status_id'] ? $data['status_id'] : 0;
-			$start_date		= isset($data['start_date']) ? $data['start_date'] : '';
-			$end_date		= isset($data['end_date']) ? $data['end_date'] : '';
+			$status_id		= isset($data['status_id']) && $data['status_id'] ? $data['status_id'] : 'open';
+			$start_date		= isset($data['start_date']) && $data['start_date'] ? (int)$data['start_date'] : 0;
+			$end_date		= isset($data['end_date']) && $data['end_date'] ? (int)$data['end_date'] : 0;
 			$allrows		= isset($data['allrows']) ? $data['allrows'] : '';
 			$wo_hour_cat_id	= isset($data['wo_hour_cat_id']) ? $data['wo_hour_cat_id'] : '';
 			$b_group		= isset($data['b_group']) ? $data['b_group'] : '';
@@ -143,7 +144,7 @@
 
 			$GLOBALS['phpgw']->config->read();
 			$sql = $this->bocommon->fm_cache('sql_workorder'.!!$search_vendor . '_' . !!$wo_hour_cat_id . '_' . !!$b_group);
-//echo $sql;
+			//echo $sql;
 			if(!$sql)
 			{
 				$entity_table = 'fm_project';
@@ -156,6 +157,7 @@
 				$uicols['statustext'][]		= lang('Project ID');
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= true;
 
 				$cols .= ",fm_workorder.id as workorder_id";
 				$cols_return[] 				= 'workorder_id';
@@ -165,6 +167,7 @@
 				$uicols['statustext'][]		= lang('Workorder ID');
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= true;
 
 				$cols .= ",fm_workorder.title as title";
 				$cols_return[] 				= 'title';
@@ -174,6 +177,7 @@
 				$uicols['statustext'][]		= lang('Workorder title');
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= '';
 
 				$cols .= ",fm_workorder_status.descr as status";
 				$cols_return[] 				= 'status';
@@ -183,16 +187,26 @@
 				$uicols['statustext'][]		= lang('Workorder status');
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= '';
 
 				$cols .= ",fm_workorder.entry_date as entry_date";
 				$cols_return[] 				= 'entry_date';
+				$cols .= ",fm_workorder.start_date as start_date";
+				$cols_return[] 				= 'start_date';
+				$cols .= ",fm_workorder.end_date as end_date";
+				$cols_return[] 				= 'end_date';
+				$cols.= ",fm_workorder.ecodimb";
+				$cols_return[] 				= 'ecodimb';
+				$cols.= ",fm_workorder.contract_sum";
+				$cols_return[] 				= 'contract_sum';
+/*
 				$uicols['input_type'][]		= 'text';
 				$uicols['name'][]			= 'entry_date';
 				$uicols['descr'][]			= lang('Entry date');
 				$uicols['statustext'][]		= lang('Workorder entry date');
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
-
+*/
 				$cols .= ",phpgw_accounts.account_lid as user_lid";
 				$cols_return[] 				= 'user_lid';
 				$uicols['input_type'][]		= 'text';
@@ -201,6 +215,7 @@
 				$uicols['statustext'][]		= lang('Workorder User');
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= '';
 
 				$cols .= ',fm_workorder.vendor_id';
 				$cols_return[] = 'vendor_id';
@@ -210,17 +225,19 @@
 				$uicols['statustext'][]		= lang('Vendor ID');
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= '';
 
 				$cols.= ",loc1_name";
-				$cols_return[] 				= 'loc1_name';
+//				$cols_return[] 				= 'loc1_name';
+/*
 				$uicols['input_type'][]		= 'hidden';
 				$uicols['name'][]			= 'loc1_name';
 				$uicols['descr'][]			= '';
 				$uicols['statustext'][]		= '';
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
-
-
+				$uicols['sortable'][]		= '';
+*/
 				$cols .= ",fm_project.user_id as project_owner";
 
 				$joinmethod .= " $this->join  fm_workorder ON ($entity_table.id = fm_workorder.project_id) $this->join  phpgw_accounts ON (fm_workorder.user_id = phpgw_accounts.account_id))";
@@ -237,6 +254,7 @@
 				$uicols['statustext'][]		= lang('Vendor name');
 				$uicols['formatter'][]		= '';
 				$uicols['classname'][]		= '';
+				$uicols['sortable'][]		= '';
 
 				$cols .= ',fm_workorder.combined_cost';
 				$cols_return[] = 'combined_cost';
@@ -246,6 +264,7 @@
 				$uicols['statustext'][]		= lang('Cost - either budget or calculation');
 				$uicols['formatter'][]		= 'myFormatCount2';
 				$uicols['classname'][]		= 'rightClasss';
+				$uicols['sortable'][]		= true;
 
 				$cols .= ',fm_workorder.act_mtrl_cost + fm_workorder.act_vendor_cost as actual_cost';
 				$cols_return[] = 'actual_cost';
@@ -255,6 +274,7 @@
 				$uicols['statustext'][]		= lang('Actual cost - paid so far');
 				$uicols['formatter'][]		= 'myFormatCount2';
 				$uicols['classname'][]		= 'rightClasss';
+				$uicols['sortable'][]		= true;
 
 				$joinmethod .= " $this->left_join  fm_vendor ON (fm_workorder.vendor_id = fm_vendor.id))";
 				$paranthesis .='(';
@@ -284,32 +304,35 @@
 				//----- b_group
 
 
-			$cols_return[] = 'location_code';
-			$cols_return[] = 'billable_hours';
-			$cols .= ',fm_workorder.billable_hours';
-			$no_address = false;
-			if(isset($GLOBALS['phpgw']->config->config_data['location_at_workorder']) && $GLOBALS['phpgw']->config->config_data['location_at_workorder'])
-			{
-				$no_address = true;
-				$cols .= ',fm_workorder.location_code';
-				$cols .= ',fm_workorder.address';
-				$cols_return[] 				= 'address';
-				$uicols['input_type'][]		= 'text';
-				$uicols['name'][]			= 'address';
-				$uicols['descr'][]			= lang('address');
-				$uicols['statustext'][]		= lang('address');
-				$uicols['exchange'][]		= false;
-				$uicols['align'][] 			= '';
-				$uicols['datatype'][]		= '';
-			}
-			else
-			{
-				$cols .= ",{$entity_table}.location_code";
-			}
+				$cols_return[] = 'location_code';
+				$cols_return[] = 'billable_hours';
+				$cols .= ',fm_workorder.billable_hours';
+				$no_address = false;
+				if(isset($GLOBALS['phpgw']->config->config_data['location_at_workorder']) && $GLOBALS['phpgw']->config->config_data['location_at_workorder'])
+				{
+					$no_address = true;
+					$cols .= ',fm_workorder.location_code';
+					$cols .= ',fm_workorder.address';
+					$cols_return[] 				= 'address';
+					$uicols['input_type'][]		= 'text';
+					$uicols['name'][]			= 'address';
+					$uicols['descr'][]			= lang('address');
+					$uicols['statustext'][]		= lang('address');
+					$uicols['exchange'][]		= false;
+					$uicols['align'][] 			= '';
+					$uicols['datatype'][]		= '';
+					$uicols['formatter'][]		= '';
+					$uicols['classname'][]		= '';
+					$uicols['sortable'][]		= true;
+				}
+				else
+				{
+					$cols .= ",{$entity_table}.location_code";
+				}
 
 				$sql	= $this->bocommon->generate_sql(array('entity_table'=>$entity_table,'cols'=>$cols,'cols_return'=>$cols_return,
-									'uicols'=>$uicols,'joinmethod'=>$joinmethod,'paranthesis'=>$paranthesis,'query'=>$query,
-									'force_location'=>true, 'no_address' => $no_address));
+					'uicols'=>$uicols,'joinmethod'=>$joinmethod,'paranthesis'=>$paranthesis,'query'=>$query,
+					'force_location'=>true, 'no_address' => $no_address));
 
 				$this->bocommon->fm_cache('sql_workorder'.!!$search_vendor . '_' . !!$wo_hour_cat_id . '_' . !!$b_group,$sql);
 
@@ -345,11 +368,20 @@
 
 			if ($order)
 			{
-				$ordermethod = " order by $order $sort";
+				if($order == 'workorder_id')
+				{
+	//				$ordermethod = " ORDER BY fm_workorder.project_id {$sort},fm_workorder.id {$sort}";	
+					$ordermethod = " ORDER BY fm_workorder.id {$sort}";	
+				}
+				else
+				{
+					$ordermethod = " ORDER BY $order $sort";
+				}
 			}
 			else
 			{
-				$ordermethod = ' order by fm_workorder.id DESC';
+	//			$ordermethod = ' ORDER BY fm_workorder.project_id DESC,fm_workorder.id DESC';
+				$ordermethod = ' ORDER BY fm_workorder.id DESC';
 			}
 
 			$where= 'WHERE';
@@ -366,13 +398,36 @@
 
 			if ($cat_id > 0)
 			{
-				$filtermethod .= " $where fm_project.category=$cat_id ";
+				$cats	= CreateObject('phpgwapi.categories', -1,  'property', '.project');
+				$cats->supress_info	= true;
+				$cat_list_project	= $cats->return_sorted_array(0, false, '', '', '', false, $cat_id, false);
+				$cat_filter = array($cat_id);
+				foreach ($cat_list_project as $_category)
+				{
+					$cat_filter[] = $_category['id'];
+				}
+				$filtermethod .= " {$where} fm_project.category IN (" .  implode(',', $cat_filter) .')';
+
 				$where= 'AND';
 			}
 
-			if ($status_id)
+			if ($status_id && $status_id != 'all')
 			{
-				$filtermethod .= " $where fm_workorder.status='$status_id' ";
+
+				if($status_id == 'open')
+				{
+					$_status_filter = array();
+					$this->db->query("SELECT * FROM fm_workorder_status WHERE delivered IS NULL AND closed IS NULL");
+					while($this->db->next_record())
+					{
+						$_status_filter[] = $this->db->f('id');
+					}
+					$filtermethod .= " $where fm_workorder.status IN ('" . implode("','", $_status_filter) . "')"; 
+				}
+				else
+				{
+					$filtermethod .= " $where fm_workorder.status='$status_id' ";
+				}
 				$where= 'AND';
 			}
 
@@ -429,6 +484,9 @@
 
 			if ($start_date)
 			{
+				$end_date	= $end_date + 3600 * 16 + phpgwapi_datetime::user_timezone();
+				$start_date	= $start_date - 3600 * 8 + phpgwapi_datetime::user_timezone();
+
 				$filtermethod .= " $where fm_workorder.start_date >= $start_date AND fm_workorder.start_date <= $end_date ";
 				$where= 'AND';
 			}
@@ -446,10 +504,10 @@
 				else
 				{
 					$matchtypes = array
-					(
-						'exact' => '=',
-						'like'	=> $this->like
-					);
+						(
+							'exact' => '=',
+							'like'	=> $this->like
+						);
 
 					if(count($criteria) > 1)
 					{
@@ -473,7 +531,7 @@
 						}
 						$querymethod = $where . ' (' . implode(' OR ', $_querymethod) . ')';
 						unset($_querymethod);
-//_debug_array($querymethod);
+						//_debug_array($querymethod);
 					}
 					else
 					{
@@ -500,10 +558,10 @@
 
 			$sql .= " $filtermethod $querymethod";
 
-//_debug_array($sql);
+			//_debug_array($sql);
 			if($GLOBALS['phpgw_info']['server']['db_type']=='postgres')
 			{
-				$sql2 = 'SELECT count(*) as cnt FROM (SELECT fm_workorder.id ' . substr($sql,strripos($sql,'from'))  . ') as cnt';
+				$sql2 = 'SELECT count(fm_workorder.id) as cnt ' . substr($sql,strripos($sql,'from'));
 				$this->db->query($sql2,__LINE__,__FILE__);
 				$this->db->next_record();
 				$this->total_records = $this->db->f('cnt');
@@ -549,7 +607,7 @@
 				}
 
 				$location_code=	$this->db->f('location_code');
-				$location = split('-',$location_code);
+				$location = explode('-',$location_code);
 				$count_location =count($location);
 				for ($m=0;$m<$count_location;$m++)
 				{
@@ -565,13 +623,13 @@
 
 		function read_single($workorder_id = 0)
 		{
-		//	$this->update_actual_cost_global();
-		//	$this->update_planned_cost_global();
+			//	$this->update_actual_cost_global();
+			//	$this->update_planned_cost_global();
 
 			$sql = "SELECT fm_workorder.*, fm_chapter.descr as chapter ,fm_workorder.user_id as user_id FROM fm_workorder"
 	//			. " $this->join fm_project on fm_workorder.project_id=fm_project.id"
 				. " $this->left_join fm_chapter on "
-				. " fm_workorder.chapter_id = fm_chapter.id where fm_workorder.id={$workorder_id}";
+				. " fm_workorder.chapter_id = fm_chapter.id WHERE fm_workorder.id='{$workorder_id}'";
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
@@ -579,50 +637,51 @@
 			if ($this->db->next_record())
 			{
 				$workorder = array
-				(
-					'id'					=> $this->db->f('id'),
-					'workorder_id'			=> $this->db->f('id'), // FIXME
-					'project_id'			=> $this->db->f('project_id'),
-					'title'					=> $this->db->f('title'),
-					'name'					=> $this->db->f('name'),
-					'key_fetch'				=> $this->db->f('key_fetch'),
-					'key_deliver'			=> $this->db->f('key_deliver'),
-					'key_responsible'		=> $this->db->f('key_responsible'),
-					'charge_tenant'			=> $this->db->f('charge_tenant'),
-					'descr'					=> stripslashes($this->db->f('descr')),
-					'status'				=> $this->db->f('status'),
-					'budget'				=> (int)$this->db->f('budget'),
-					'calculation'			=> $this->db->f('calculation'),
-					'b_account_id'			=> (int)$this->db->f('account_id'),
-					'addition_percentage'	=> (int)$this->db->f('addition'),
-					'addition_rs'			=> (int)$this->db->f('rig_addition'),
-					'act_mtrl_cost'			=> $this->db->f('act_mtrl_cost'),
-					'act_vendor_cost'		=> $this->db->f('act_vendor_cost'),
-					'user_id'				=> $this->db->f('user_id'),
-					'vendor_id'				=> $this->db->f('vendor_id'),
-		//			'coordinator'			=> $this->db->f('coordinator'),
-					'access'				=> $this->db->f('access'),
-					'start_date'			=> $this->db->f('start_date'),
-					'end_date'				=> $this->db->f('end_date'),
-					'cat_id'				=> $this->db->f('category'),
-					'chapter_id'			=> $this->db->f('chapter_id'),
-					'chapter'				=> $this->db->f('chapter'),
-					'deviation'				=> $this->db->f('deviation'),
-					'ecodimb'				=> $this->db->f('ecodimb'),
-					'location_code'			=> $this->db->f('location_code'),
-					'p_num'					=> $this->db->f('p_num'),
-					'p_entity_id'			=> $this->db->f('p_entity_id'),
-					'p_cat_id'				=> $this->db->f('p_cat_id'),
-					'contact_phone'			=> $this->db->f('contact_phone'),
-					'tenant_id'				=> $this->db->f('tenant_id'),
-					'cat_id'				=> $this->db->f('category'),
-					'grants'				=> (int)$this->grants[$this->db->f('user_id')],
-					'billable_hours'		=> $this->db->f('billable_hours'),
-				);
+					(
+						'id'					=> $this->db->f('id'),
+						'workorder_id'			=> $this->db->f('id'), // FIXME
+						'project_id'			=> $this->db->f('project_id'),
+						'title'					=> $this->db->f('title'),
+						'name'					=> $this->db->f('name'),
+						'key_fetch'				=> $this->db->f('key_fetch'),
+						'key_deliver'			=> $this->db->f('key_deliver'),
+						'key_responsible'		=> $this->db->f('key_responsible'),
+						'charge_tenant'			=> $this->db->f('charge_tenant'),
+						'descr'					=> stripslashes($this->db->f('descr')),
+						'status'				=> $this->db->f('status'),
+						'budget'				=> (int)$this->db->f('budget'),
+						'calculation'			=> $this->db->f('calculation'),
+						'b_account_id'			=> (int)$this->db->f('account_id'),
+						'addition_percentage'	=> (int)$this->db->f('addition'),
+						'addition_rs'			=> (int)$this->db->f('rig_addition'),
+						'act_mtrl_cost'			=> $this->db->f('act_mtrl_cost'),
+						'act_vendor_cost'		=> $this->db->f('act_vendor_cost'),
+						'user_id'				=> $this->db->f('user_id'),
+						'vendor_id'				=> $this->db->f('vendor_id'),
+			//			'coordinator'			=> $this->db->f('coordinator'),
+						'access'				=> $this->db->f('access'),
+						'start_date'			=> $this->db->f('start_date'),
+						'end_date'				=> $this->db->f('end_date'),
+						'cat_id'				=> $this->db->f('category'),
+						'chapter_id'			=> $this->db->f('chapter_id'),
+						'chapter'				=> $this->db->f('chapter'),
+						'deviation'				=> $this->db->f('deviation'),
+						'ecodimb'				=> $this->db->f('ecodimb'),
+						'location_code'			=> $this->db->f('location_code'),
+						'p_num'					=> $this->db->f('p_num'),
+						'p_entity_id'			=> $this->db->f('p_entity_id'),
+						'p_cat_id'				=> $this->db->f('p_cat_id'),
+						'contact_phone'			=> $this->db->f('contact_phone'),
+						'tenant_id'				=> $this->db->f('tenant_id'),
+						'cat_id'				=> $this->db->f('category'),
+						'grants'				=> (int)$this->grants[$this->db->f('user_id')],
+						'billable_hours'		=> $this->db->f('billable_hours'),
+						'contract_sum'			=> $this->db->f('contract_sum'),
+					);
 			}
 
-//_debug_array($workorder);
-				return $workorder;
+			//_debug_array($workorder);
+			return $workorder;
 		}
 
 
@@ -636,20 +695,20 @@
 				$budget[] = array(
 					'workorder_id'	=> $this->db->f('workorder_id'),
 					'budget'	=> sprintf("%01.2f",$this->db->f('budget'))
-					);
+				);
 			}
 			return $budget;
 		}
 
 		/**
-		* planned cost start out as the project budget - and reflect the amount yet to be spent on the project
-		* When an order is placed  - the "planned cost" is reduced with expected cost for that order.
-		* When an invoice is paid -  the "planned cost" is reduced with actual cost for that order (replace the expected cost).
-		*
-		* @param integer $project_id the project in question
-		*
-		* @return void
-		*/
+		 * planned cost start out as the project budget - and reflect the amount yet to be spent on the project
+		 * When an order is placed  - the "planned cost" is reduced with expected cost for that order.
+		 * When an invoice is paid -  the "planned cost" is reduced with actual cost for that order (replace the expected cost).
+		 *
+		 * @param integer $project_id the project in question
+		 *
+		 * @return void
+		 */
 
 		function update_planned_cost($project_id)
 		{
@@ -658,12 +717,12 @@
 			while ($this->db->next_record())
 			{
 				$workorders[] = array
-				(
-					'paid'			=> $this->db->f('paid'), //0-cancelled /1-invoice received but not paid / 2 - paid
-					'paid_percent'	=> $this->db->f('paid_percent')/100,
-					'actual_cost'	=> $this->db->f('act_mtrl_cost') + $this->db->f('act_vendor_cost'),
-					'cost'			=> abs($this->db->f('combined_cost')) > 0 ? $this->db->f('combined_cost') : $this->db->f('budget'),
-				);
+					(
+						'paid'			=> $this->db->f('paid'), //0-cancelled /1-invoice received but not paid / 2 - paid
+						'paid_percent'	=> $this->db->f('paid_percent')/100,
+						'actual_cost'	=> $this->db->f('act_mtrl_cost') + $this->db->f('act_vendor_cost'),
+						'cost'			=> abs($this->db->f('combined_cost')) > 0 ? $this->db->f('combined_cost') : $this->db->f('budget'),
+					);
 			}
 
 			$orded_or_paid = 0;
@@ -684,9 +743,9 @@
 				}
 			}
 
-            $this->db->query("SELECT budget, reserve FROM fm_project WHERE id={$project_id}"); 
-            $this->db->next_record(); 
-            $project_sum = $this->db->f('budget') + $this->db->f('reserve'); 
+			$this->db->query("SELECT budget, reserve FROM fm_project WHERE id={$project_id}"); 
+			$this->db->next_record(); 
+			$project_sum = $this->db->f('budget') + $this->db->f('reserve'); 
 
 			$project_planned_cost = round($project_sum - $orded_or_paid);
 
@@ -695,7 +754,7 @@
 				$project_planned_cost = 0;
 			}
 
-//_debug_array("UPDATE fm_project SET planned_cost = {$project_planned_cost} WHERE id = {$project_id}");
+			//_debug_array("UPDATE fm_project SET planned_cost = {$project_planned_cost} WHERE id = {$project_id}");
 			$this->db->query("UPDATE fm_project SET planned_cost = {$project_planned_cost} WHERE id = {$project_id}");
 		}
 
@@ -708,7 +767,7 @@
 			{
 				$workorders[] = $this->db->f('id');
 			}
-//_debug_array($workorders);die();
+			//_debug_array($workorders);die();
 
 			foreach ($workorders as $workorder_id)
 			{
@@ -725,7 +784,7 @@
 			{
 				$projects[] = $this->db->f('id');
 			}
-//_debug_array($projects);die();
+			//_debug_array($projects);die();
 
 			foreach ($projects as $project_id)
 			{
@@ -740,10 +799,10 @@
 			while ($this->db->next_record())
 			{
 				$cost[] = array
-				(
-					'godkjentbelop' => $this->db->f('godkjentbelop'),
-					'dimd' => $this->db->f('dimd'),
-				);
+					(
+						'godkjentbelop' => $this->db->f('godkjentbelop'),
+						'dimd' => $this->db->f('dimd'),
+					);
 			}
 			$act_mtrl_cost = 0;
 			$act_vendor_cost = 0;
@@ -758,7 +817,7 @@
 					$act_vendor_cost = $act_vendor_cost + $entry['godkjentbelop'];
 				}
 			}
-//_debug_array("UPDATE fm_workorder SET act_mtrl_cost = {$act_mtrl_cost}, act_vendor_cost = {$act_vendor_cost}  WHERE id = {$workorder_id}");
+			//_debug_array("UPDATE fm_workorder SET act_mtrl_cost = {$act_mtrl_cost}, act_vendor_cost = {$act_vendor_cost}  WHERE id = {$workorder_id}");
 			$this->db->query("UPDATE fm_workorder SET act_mtrl_cost = {$act_mtrl_cost}, act_vendor_cost = {$act_vendor_cost}  WHERE id = {$workorder_id}");
 
 		}
@@ -843,36 +902,37 @@
 			}
 
 			$values= array
-			(
-				$id,
-				$workorder['workorder_num'],
-				$workorder['project_id'],
-				$workorder['title'],
-				'public',
-				time(),
-				$workorder['start_date'],
-				$workorder['end_date'],
-				$workorder['status'],
-				$workorder['descr'],
-				(int) $workorder['budget'],
-				(int) $workorder['budget'],
-				$workorder['b_account_id'],
-				$workorder['addition_rs'],
-				$workorder['addition_percentage'],
-				$workorder['key_deliver'],
-				$workorder['key_fetch'],
-				$workorder['vendor_id'],
-				$workorder['charge_tenant'],
-				$this->account,
-				$workorder['ecodimb'],
-				$workorder['cat_id'],
-				$workorder['billable_hours']
-			);
+				(
+					$id,
+					$workorder['workorder_num'],
+					$workorder['project_id'],
+					$workorder['title'],
+					'public',
+					time(),
+					$workorder['start_date'],
+					$workorder['end_date'],
+					$workorder['status'],
+					$workorder['descr'],
+					(int) $workorder['budget'],
+					(int) $workorder['budget'],
+					$workorder['b_account_id'],
+					$workorder['addition_rs'],
+					$workorder['addition_percentage'],
+					$workorder['key_deliver'],
+					$workorder['key_fetch'],
+					$workorder['vendor_id'],
+					$workorder['charge_tenant'],
+					$this->account,
+					$workorder['ecodimb'],
+					$workorder['cat_id'],
+					$workorder['billable_hours'],
+					$workorder['contract_sum']
+				);
 
 			$values	= $this->bocommon->validate_db_insert($values);
 
 			$this->db->query("INSERT INTO fm_workorder (id,num,project_id,title,access,entry_date,start_date,end_date,status,"
-				. "descr,budget,combined_cost,account_id,rig_addition,addition,key_deliver,key_fetch,vendor_id,charge_tenant,user_id,ecodimb,category,billable_hours $cols) "
+				. "descr,budget,combined_cost,account_id,rig_addition,addition,key_deliver,key_fetch,vendor_id,charge_tenant,user_id,ecodimb,category,billable_hours,contract_sum $cols) "
 				. "VALUES ( $values $vals)",__LINE__,__FILE__);
 
 			$this->db->query("INSERT INTO fm_orders (id,type) VALUES ({$id},'workorder')");
@@ -882,20 +942,20 @@
 			{
 				$this->db->query("UPDATE fm_project set charge_tenant = 1 WHERE id =" . $workorder['project_id']);
 			}
-*/
+ */
 
 			if(is_array($workorder['origin']))
 			{
 				if($workorder['origin'][0]['data'][0]['id'])
 				{
 					$interlink_data = array
-					(
-						'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $workorder['origin'][0]['location']),
-						'location1_item_id' => $workorder['origin'][0]['data'][0]['id'],
-						'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project.workorder'),
-						'location2_item_id' => $id,
-						'account_id'		=> $this->account
-					);
+						(
+							'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $workorder['origin'][0]['location']),
+							'location1_item_id' => $workorder['origin'][0]['data'][0]['id'],
+							'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.project.workorder'),
+							'location2_item_id' => $id,
+							'account_id'		=> $this->account
+						);
 
 					$this->interlink->add($interlink_data,$this->db);
 				}
@@ -965,25 +1025,26 @@
 
 
 			$value_set = array
-			(
-				'title'			=> $workorder['title'],
-				'status'		=> $workorder['status'],
-				'start_date'	=> $workorder['start_date'],
-				'end_date'		=> $workorder['end_date'],
-				'descr'			=> $workorder['descr'],
-				'budget'		=> (int)$workorder['budget'],
-				'combined_cost'	=> $combined_cost,
-				'key_deliver'	=> $workorder['key_deliver'],
-				'key_fetch'		=> $workorder['key_fetch'],
-				'account_id'	=> $workorder['b_account_id'],
-				'rig_addition'	=> $workorder['addition_rs'],
-				'addition'		=> $workorder['addition_percentage'],
-				'charge_tenant'	=> $workorder['charge_tenant'],
-				'vendor_id'		=> $workorder['vendor_id'],
-				'ecodimb'		=> $workorder['ecodimb'],
-				'category'		=> $workorder['cat_id'],
-				'billable_hours'=> $workorder['billable_hours']
-			);
+				(
+					'title'			=> $workorder['title'],
+					'status'		=> $workorder['status'],
+					'start_date'	=> $workorder['start_date'],
+					'end_date'		=> $workorder['end_date'],
+					'descr'			=> $workorder['descr'],
+					'budget'		=> (int)$workorder['budget'],
+					'combined_cost'	=> $combined_cost,
+					'key_deliver'	=> $workorder['key_deliver'],
+					'key_fetch'		=> $workorder['key_fetch'],
+					'account_id'	=> $workorder['b_account_id'],
+					'rig_addition'	=> $workorder['addition_rs'],
+					'addition'		=> $workorder['addition_percentage'],
+					'charge_tenant'	=> $workorder['charge_tenant'],
+					'vendor_id'		=> $workorder['vendor_id'],
+					'ecodimb'		=> $workorder['ecodimb'],
+					'category'		=> $workorder['cat_id'],
+					'billable_hours'=> $workorder['billable_hours'],
+					'contract_sum'	=> $workorder['contract_sum'],
+				);
 
 			if($workorder['status'] == 'closed')
 			{
@@ -1028,7 +1089,7 @@
 			{
 				$this->db->query("UPDATE fm_project set charge_tenant = 1 WHERE id =" . $workorder['project_id']);
 			}
-*/
+ */
 			$this->update_planned_cost($workorder['project_id']); // at project
 
 			$check_pending_action = false;
@@ -1059,16 +1120,16 @@
 				if ($this->db->f('approved') )
 				{
 					$action_params = array
-					(
-						'appname'			=> 'property',
-						'location'			=> '.project.workorder',
-						'id'				=> $workorder['id'],
-						'responsible'		=> $this->account,
-						'responsible_type'  => 'user',
-						'action'			=> 'approval',
-						'remark'			=> '',
-						'deadline'			=> ''
-					);
+						(
+							'appname'			=> 'property',
+							'location'			=> '.project.workorder',
+							'id'				=> $workorder['id'],
+							'responsible'		=> $this->account,
+							'responsible_type'  => 'user',
+							'action'			=> 'approval',
+							'remark'			=> '',
+							'deadline'			=> ''
+						);
 
 					execMethod('property.sopending_action.close_pending_action', $action_params);
 					unset($action_params);
@@ -1076,16 +1137,16 @@
 				if ($this->db->f('in_progress') )
 				{
 					$action_params = array
-					(
-						'appname'			=> 'property',
-						'location'			=> '.project.workorder',
-						'id'				=> $workorder['id'],
-						'responsible'		=> $workorder['vendor_id'],
-						'responsible_type'  => 'vendor',
-						'action'			=> 'remind',
-						'remark'			=> '',
-						'deadline'			=> ''
-					);
+						(
+							'appname'			=> 'property',
+							'location'			=> '.project.workorder',
+							'id'				=> $workorder['id'],
+							'responsible'		=> $workorder['vendor_id'],
+							'responsible_type'  => 'vendor',
+							'action'			=> 'remind',
+							'remark'			=> '',
+							'deadline'			=> ''
+						);
 
 					execMethod('property.sopending_action.close_pending_action', $action_params);
 					unset($action_params);
