@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.uijasper.inc.php 6321 2010-09-09 10:51:00Z sigurd $
+ 	* @version $Id: class.uijasper.inc.php 6757 2011-01-12 12:49:58Z sigurdne $
 	*/
 	phpgw::import_class('phpgwapi.yui');
 
@@ -43,13 +43,14 @@
 		var $allrows;
 
 		var $public_functions = array
-		(
-			'index'  	=> true,
-			'edit'   	=> true,
-			'delete' 	=> true,
-			'download'	=> true,
-			'view'		=> true
-		);
+			(
+				'index'  	=> true,
+				'edit'   	=> true,
+				'delete' 	=> true,
+				'download'	=> true,
+				'view'		=> true,
+				'get_file'	=> true
+			);
 
 		function __construct()
 		{
@@ -80,14 +81,14 @@
 		function save_sessiondata()
 		{
 			$data = array
-			(
-				'start'		=> $this->start,
-				'query'		=> $this->query,
-				'sort'		=> $this->sort,
-				'order'		=> $this->order,
-				'allrows'	=> $this->allrows,
-				'app'		=> $this->app,
-			);
+				(
+					'start'		=> $this->start,
+					'query'		=> $this->query,
+					'sort'		=> $this->sort,
+					'order'		=> $this->order,
+					'allrows'	=> $this->allrows,
+					'app'		=> $this->app,
+				);
 			$this->bo->save_sessiondata($data);
 		}
 
@@ -117,6 +118,21 @@
 			$this->bocommon->download($list,$uicols['name'],$uicols['descr'],$uicols['input_type']);
 		}
 
+		function get_file()
+		{
+			if(!$this->acl_read)
+			{
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+			}
+
+			$jasper_id			= phpgw::get_var('jasper_id', 'int');
+			$values				= $this->bo->read_single($jasper_id);
+
+			$bofiles	= CreateObject('property.bofiles');
+			$file      = "{$bofiles->fakebase}/jasper/{$jasper_id}/{$values['file_name']}";
+			$bofiles->view_file('', $file);
+		}
+
 		function index()
 		{
 			if(!$this->acl_read)
@@ -130,36 +146,36 @@
 			if( phpgw::get_var('phpgw_return_as') != 'json' )
 			{
 				$datatable['config']['base_url'] = $GLOBALS['phpgw']->link('/index.php', array
-				(
-					'menuaction'	=> 'property.uijasper.index',
-					'app'			=> $this->app
-   				));
+					(
+						'menuaction'	=> 'property.uijasper.index',
+						'app'			=> $this->app
+					));
 
-   				$datatable['config']['base_java_url'] = "menuaction:'property.uijasper.index',"
-   				 										."app: '{$this->app}',"
-														."allrows:'{$this->allrows}'";
+				$datatable['config']['base_java_url'] = "menuaction:'property.uijasper.index',"
+					."app: '{$this->app}',"
+					."allrows:'{$this->allrows}'";
 
 
 				$link_data = array
-				(
-					'menuaction'	=> 'property.uijasper.index',
-					'app'			=> $this->app
-				);
+					(
+						'menuaction'	=> 'property.uijasper.index',
+						'app'			=> $this->app
+					);
 
 				$values_combo_box[0]  = $this->bo->get_apps();
 
 				$datatable['config']['allow_allrows'] = true;
 
 				$datatable['actions']['form'] = array
-				(
-					array
 					(
-						'action'	=> $GLOBALS['phpgw']->link('/index.php',
-								array
-								(
-									'menuaction'	=> 'property.uijasper.index'//,
-								)
-							),
+						array
+						(
+							'action'	=> $GLOBALS['phpgw']->link('/index.php',
+							array
+							(
+								'menuaction'	=> 'property.uijasper.index'//,
+							)
+						),
 						'fields'	=> array
 						(
 							'field' => array
@@ -172,7 +188,7 @@
 									'type' => 'button',
 									'style' => 'filter',
 									'tab_index' => 1
-									),
+								),
 								array
 								(
 									'type'	=> 'button',
@@ -195,8 +211,8 @@
 									'type' => 'button',
 									'tab_index' => 7
 								),
-				   				array // TEXT INPUT
-				   				(
+								array // TEXT INPUT
+								(
 									'name'	 => 'query',
 									'id'	 => 'txt_query',
 									'value'	=> '',//$query,
@@ -256,73 +272,88 @@
 			$datatable['rowactions']['action'] = array();
 
 			$parameters = array
-			(
-				'parameter' => array
 				(
-					array
+					'parameter' => array
 					(
-						'name'		=> 'id',
-						'source'	=> 'id'
-					),
-				)
-			);
+						array
+						(
+							'name'		=> 'id',
+							'source'	=> 'id'
+						),
+					)
+				);
 
 			$parameters_view = array
-			(
-				'parameter' => array
 				(
-					array
+					'parameter' => array
 					(
-						'name'		=> 'jasper_id',
-						'source'	=> 'id'
-					),
-				)
-			);
+						array
+						(
+							'name'		=> 'jasper_id',
+							'source'	=> 'id'
+						),
+					)
+				);
 
 			if($this->acl_edit)
 			{
-				$datatable['rowactions']['action'][] = array(
-							'my_name' 			=> 'edit',
-							'statustext' 	=> lang('edit the jasper entry'),
-							'text'			=> lang('edit'),
-							'action'		=> $GLOBALS['phpgw']->link('/index.php',array
-									(
-										'menuaction'	=> 'property.uijasper.edit'
-									)),
+				$datatable['rowactions']['action'][] = array
+					(
+						'my_name' 			=> 'edit',
+						'statustext' 	=> lang('edit the jasper entry'),
+						'text'			=> lang('edit'),
+						'action'		=> $GLOBALS['phpgw']->link('/index.php',array
+						(
+							'menuaction'	=> 'property.uijasper.edit'
+						)),
 						'parameters'	=> $parameters
-						);
+					);
 			}
 
 			if($this->acl_read)
 			{
-				$datatable['rowactions']['action'][] = array(
+				$datatable['rowactions']['action'][] = array
+					(
 						'my_name'		=> 'edit',
 						'text'	 		=> lang('open JasperReport %1 in new window', $report['title']),
 						'action'		=> $GLOBALS['phpgw']->link('/index.php',array
-														(
-																'menuaction'	=> 'property.uijasper.view',
-																'target'		=> '_blank'
-														)),
+						(
+							'menuaction'	=> 'property.uijasper.view',
+							'target'		=> '_blank'
+						)),
 						'parameters'			=> $parameters_view
-				);
+					);
+				$datatable['rowactions']['action'][] = array
+					(
+						'my_name'		=> 'edit',
+						'text'	 		=> lang('download JasperReport %1 definition', $report['title']),
+						'action'		=> $GLOBALS['phpgw']->link('/index.php',array
+						(
+							'menuaction'	=> 'property.uijasper.get_file',
+							'target'		=> '_blank'
+						)),
+						'parameters'			=> $parameters_view
+					);
 			}
 
 			if($this->acl_delete)
 			{
-				$datatable['rowactions']['action'][] = array(
-							'my_name' 			=> 'delete',
-							'statustext' 	=> lang('delete the jasper entry'),
-							'text'			=> lang('delete'),
-							'confirm_msg'	=> lang('do you really want to delete this entry'),
-							'action'		=> $GLOBALS['phpgw']->link('/index.php',array
-									(
-										'menuaction'	=> 'property.uijasper.delete'
-									)),
+				$datatable['rowactions']['action'][] = array
+					(
+						'my_name' 			=> 'delete',
+						'statustext' 	=> lang('delete the jasper entry'),
+						'text'			=> lang('delete'),
+						'confirm_msg'	=> lang('do you really want to delete this entry'),
+						'action'		=> $GLOBALS['phpgw']->link('/index.php',array
+						(
+							'menuaction'	=> 'property.uijasper.delete'
+						)),
 						'parameters'	=> $parameters
-						);
+					);
 			}
 
-			$datatable['rowactions']['action'][] = array(
+			$datatable['rowactions']['action'][] = array
+				(
 					'my_name' 		=> 'add',
 					'text' 			=> lang('add'),
 					'action'		=> $GLOBALS['phpgw']->link('/index.php',array
@@ -371,14 +402,14 @@
 			//-- BEGIN----------------------------- JSON CODE ------------------------------
 			//values for Pagination
 			$json = array
-			(
-				'recordsReturned' 	=> $datatable['pagination']['records_returned'],
-				'totalRecords' 		=> (int)$datatable['pagination']['records_total'],
-				'startIndex' 		=> $datatable['pagination']['records_start'],
-				'sort'				=> $datatable['sorting']['order'],
-				'dir'				=> $datatable['sorting']['sort'],
-				'records'			=> array()
-			);
+				(
+					'recordsReturned' 	=> $datatable['pagination']['records_returned'],
+					'totalRecords' 		=> (int)$datatable['pagination']['records_total'],
+					'startIndex' 		=> $datatable['pagination']['records_start'],
+					'sort'				=> $datatable['sorting']['order'],
+					'dir'				=> $datatable['sorting']['sort'],
+					'records'			=> array()
+				);
 
 			// values for datatable
 			if(isset($datatable['rows']['row']) && is_array($datatable['rows']['row'])){
@@ -393,11 +424,11 @@
 						}
 						elseif(isset($column['format']) && $column['format']== "link")
 						{
-						  $json_row[$column['name']] = "<a href='".$column['link']."'>" .$column['value']."</a>";
+							$json_row[$column['name']] = "<a href='".$column['link']."'>" .$column['value']."</a>";
 						}
 						else
 						{
-						  $json_row[$column['name']] = $column['value'];
+							$json_row[$column['name']] = $column['value'];
 						}
 					}
 					$json['records'][] = $json_row;
@@ -416,10 +447,10 @@
 			}
 
 			phpgwapi_yui::load_widget('dragdrop');
-		  	phpgwapi_yui::load_widget('datatable');
-		  	phpgwapi_yui::load_widget('menu');
-		  	phpgwapi_yui::load_widget('connection');
-		  	phpgwapi_yui::load_widget('loader');
+			phpgwapi_yui::load_widget('datatable');
+			phpgwapi_yui::load_widget('menu');
+			phpgwapi_yui::load_widget('connection');
+			phpgwapi_yui::load_widget('loader');
 			phpgwapi_yui::load_widget('tabview');
 			phpgwapi_yui::load_widget('paginator');
 			phpgwapi_yui::load_widget('animation');
@@ -430,16 +461,16 @@
 			$template_vars = array();
 			$template_vars['datatable'] = $datatable;
 			$GLOBALS['phpgw']->xslttpl->add_file(array('datatable'));
-		  	$GLOBALS['phpgw']->xslttpl->set_var('phpgw', $template_vars);
+			$GLOBALS['phpgw']->xslttpl->set_var('phpgw', $template_vars);
 
-		  	if ( !isset($GLOBALS['phpgw']->css) || !is_object($GLOBALS['phpgw']->css) )
-		  	{
+			if ( !isset($GLOBALS['phpgw']->css) || !is_object($GLOBALS['phpgw']->css) )
+			{
 				$GLOBALS['phpgw']->css = createObject('phpgwapi.css');
-		  	}
+			}
 
-		  	$GLOBALS['phpgw']->css->validate_file('datatable');
-		  	$GLOBALS['phpgw']->css->validate_file('property');
-		  	$GLOBALS['phpgw']->css->add_external_file('property/templates/base/css/property.css');
+			$GLOBALS['phpgw']->css->validate_file('datatable');
+			$GLOBALS['phpgw']->css->validate_file('property');
+			$GLOBALS['phpgw']->css->add_external_file('property/templates/base/css/property.css');
 			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/datatable/assets/skins/sam/datatable.css');
 			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/paginator/assets/skins/sam/paginator.css');
 			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/container/assets/skins/sam/container.css');
@@ -494,20 +525,20 @@
 					$receipt = $this->bo->save($values);
 					$id = $receipt['id'];
 
-//-------------start files
+					//-------------start files
 					$bofiles	= CreateObject('property.bofiles');
 					$file = array();
 					if(isset($_FILES['file']['name']) && $_FILES['file']['name'])
 					{
 						$file_name = str_replace (' ','_',$_FILES['file']['name']);
 						$values['file_name'] = $file_name;
-						
+
 						$to_file	= "{$bofiles->fakebase}/jasper/{$id}/{$file_name}";
 
 						if ($old_file = $bofiles->vfs->ls(array(
-								'string' => "{$bofiles->fakebase}/jasper/{$id}",
-								'relatives' => Array(RELATIVE_NONE)
-							)))
+							'string' => "{$bofiles->fakebase}/jasper/{$id}",
+							'relatives' => Array(RELATIVE_NONE)
+						)))
 						{
 							$bofiles->vfs->rm(array(
 								'string' => "{$bofiles->fakebase}/jasper/{$id}/{$old_file[0]['name']}",
@@ -518,10 +549,10 @@
 
 
 						$file = array
-						(
-							'from_file'	=> $_FILES['file']['tmp_name'],
-							'to_file'	=> $to_file
-						);
+							(
+								'from_file'	=> $_FILES['file']['tmp_name'],
+								'to_file'	=> $to_file
+							);
 
 
 						unset($to_file);
@@ -531,7 +562,7 @@
 						{
 							$bofiles->create_document_dir("jasper/{$id}");
 							$bofiles->vfs->override_acl = 1;
-	
+
 							if($bofiles->vfs->cp (array (
 								'from'	=> $file['from_file'],
 								'to'	=> $file['to_file'],
@@ -548,7 +579,7 @@
 						unset($file);
 						unset($file_name);
 					}
-//-------------end files
+					//-------------end files
 
 					if (isset($values['save']) && $values['save'])
 					{
@@ -560,7 +591,7 @@
 
 			if (isset($values['cancel']) && $values['cancel'])
 			{
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uijasper.index', 'app' => $this->app));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uijasper.index', 'app' => $this->app));
 			}
 
 			if ($id)
@@ -580,11 +611,11 @@
 			}
 
 			$link_data = array
-			(
-				'menuaction'	=> 'property.uijasper.edit',
-				'id'		=> $id,
-				'app'		=> $this->app
-			);
+				(
+					'menuaction'	=> 'property.uijasper.edit',
+					'id'		=> $id,
+					'app'		=> $this->app
+				);
 
 			$locations = $GLOBALS['phpgw']->locations->get_locations(false, $this->app);
 			$selected_location = isset($values['location']) ? $values['location'] : '';
@@ -598,23 +629,23 @@
 			foreach ( $locations as $location => $descr )
 			{
 				$location_list[] = array
-				(
-					'id'		=> $location,
-					'name'		=> "{$location} [{$descr}]",
-					'selected'	=> $location == $selected_location
-				);
+					(
+						'id'		=> $location,
+						'name'		=> "{$location} [{$descr}]",
+						'selected'	=> $location == $selected_location
+					);
 			}
 
 			$formats = isset($values['formats']) && $values['formats'] ? $values['formats'] : array();
 			$format_type_list	= $this->bo->get_format_type_list($formats);
 
 			$type_def = array
-			(
-				array('key' => 'counter',	'label'=>'#','sortable'=>true,'resizeable'=>true),
-	   			array('key' => 'type_name',	'label'=>lang('type'),'sortable'=>true,'resizeable'=>true),
-	  			array('key' => 'input_name','label'=>lang('name'),'sortable'=>true,'resizeable'=>true),
-				array('key' => 'is_id',	'label'=>lang('is id'),'sortable'=>false,'resizeable'=>true,'formatter'=>'FormatterCenter')
-			);
+				(
+					array('key' => 'counter',	'label'=>'#','sortable'=>true,'resizeable'=>true),
+					array('key' => 'type_name',	'label'=>lang('type'),'sortable'=>true,'resizeable'=>true),
+					array('key' => 'input_name','label'=>lang('name'),'sortable'=>true,'resizeable'=>true),
+					array('key' => 'is_id',	'label'=>lang('is id'),'sortable'=>false,'resizeable'=>true,'formatter'=>'FormatterCenter')
+				);
 
 			$inputs = isset($values['input']) && $values['input'] ? $values['input'] : array();
 
@@ -631,49 +662,49 @@
 
 			//---datatable settings--------------------------
 			$datavalues[0] = array
-			(
+				(
 					'name'					=> "0",
 					'values' 				=> json_encode($inputs),
 					'total_records'			=> count($inputs),
 					'is_paginator'			=> 0,
 					'footer'				=> 0
-			);					
-	   		$myColumnDefs[0] = array
-	   		(
-	   			'name'		=> "0",
-				'values'	=>	json_encode($type_def)
-			);		
+				);					
+			$myColumnDefs[0] = array
+				(
+					'name'		=> "0",
+					'values'	=>	json_encode($type_def)
+				);		
 			//-----------------------------------------------
 
 			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
 
 			$data = array
-			(
-				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'value_app'						=> $this->app,
-				'value_id'						=> $id,
-				'value_file_name'				=> $values['file_name'],
-				'value_title'					=> $values['title'],
-				'value_descr'					=> $values['descr'],
-				'value_access'					=> $values['access'],
-				'apps_list'						=> $this->bo->get_apps($this->app),
-				'input_type_list'				=> $this->bo->get_input_type_list(),
-				'format_type_list'				=> $format_type_list,
-				'location_list'					=> $location_list,
-				'td_count'						=> '""',
-				'base_java_url'					=> "{menuaction:'property.uijasper.edit'}",
-				'property_js'					=> json_encode($GLOBALS['phpgw_info']['server']['webserver_url']."/property/js/yahoo/property2.js"),
-				'datatable'						=> $datavalues,
-				'myColumnDefs'					=> $myColumnDefs,
-			);
+				(
+					'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+					'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+					'value_app'						=> $this->app,
+					'value_id'						=> $id,
+					'value_file_name'				=> $values['file_name'],
+					'value_title'					=> $values['title'],
+					'value_descr'					=> $values['descr'],
+					'value_access'					=> $values['access'],
+					'apps_list'						=> $this->bo->get_apps($this->app),
+					'input_type_list'				=> $this->bo->get_input_type_list(),
+					'format_type_list'				=> $format_type_list,
+					'location_list'					=> $location_list,
+					'td_count'						=> '""',
+					'base_java_url'					=> "{menuaction:'property.uijasper.edit'}",
+					'property_js'					=> json_encode($GLOBALS['phpgw_info']['server']['webserver_url']."/property/js/yahoo/property2.js"),
+					'datatable'						=> $datavalues,
+					'myColumnDefs'					=> $myColumnDefs,
+				);
 
 			//---datatable settings--------------------
 			phpgwapi_yui::load_widget('dragdrop');
-		  	phpgwapi_yui::load_widget('datatable');
-		  	phpgwapi_yui::load_widget('loader');
+			phpgwapi_yui::load_widget('datatable');
+			phpgwapi_yui::load_widget('loader');
 
-		  	$GLOBALS['phpgw']->css->validate_file('property');
+			$GLOBALS['phpgw']->css->validate_file('property');
 			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/datatable/assets/skins/sam/datatable.css');
 			$GLOBALS['phpgw']->js->validate_file( 'yahoo', 'jasper.edit', 'property' );
 			//-----------------------datatable settings---
@@ -686,18 +717,18 @@
 
 		function view()
 		{
-			$jasper_id	= phpgw::get_var('jasper_id');
-			$values = $this->bo->read_single($jasper_id);
-			$values_attribute = phpgw::get_var('values_attribute');
-			$sel_format = phpgw::get_var('sel_format');
-			$first_run = true;
+			$jasper_id			= phpgw::get_var('jasper_id');
+			$values				= $this->bo->read_single($jasper_id);
+			$values_attribute	= phpgw::get_var('values_attribute');
+			$sel_format			= phpgw::get_var('sel_format');
+			$first_run			= true;
 
 			if($values_attribute)
 			{
 				$values['input'] = $values_attribute;
 				$first_run = false;
 			}
-			if(!$this->bocommon->check_perms($this->grants[$values['user_id']], PHPGW_ACL_DELETE))
+			if(!$this->bocommon->check_perms($this->grants[$values['user_id']], PHPGW_ACL_READ))
 			{
 				echo lang('not allowed');
 				$GLOBALS['phpgw']->common->phpgw_exit();
@@ -709,6 +740,7 @@
 			{
 				foreach ($values['input'] as &$input)
 				{
+					$input['name'] = $input['input_name'];
 					if(!($input['value'] = phpgw::get_var(strtolower($input['input_name']))) || !$input['is_id'])
 					{
 						$user_input = true;
@@ -723,9 +755,15 @@
 			{
 				foreach ($values['input'] as &$input)
 				{
+					$input['name'] = $input['input_name'];
 					if(!$input['value'])
 					{
 						$user_input = true;
+						$input['name'] = $input['input_name'];
+						if ( ($input['value'] = phpgw::get_var(strtolower($input['input_name']))))
+						{
+							$user_input = false;					
+						}						
 					}
 					else
 					{
@@ -740,9 +778,10 @@
 					}
 				}
 			}
-
 			if(!$user_input)
 			{
+				$GLOBALS['phpgw_info']['flags']['noheader'] = true;
+				$GLOBALS['phpgw_info']['flags']['nofooter'] = true;
 				$GLOBALS['phpgw_info']['flags']['xslt_app'] = false;
 
 				$jasper_parameters = '';
@@ -778,11 +817,11 @@
 
 				$report_source		= "{$GLOBALS['phpgw_info']['server']['files_dir']}/property/jasper/{$jasper_id}/{$values['file_name']}";
 				$jasper_wrapper		= CreateObject('phpgwapi.jasper_wrapper');
-/*
-_debug_array($jasper_parameters);
-_debug_array($output_type);
-_debug_array($report_source);die();
-*/
+
+				//_debug_array($jasper_parameters);
+				//_debug_array($output_type);
+				//_debug_array($report_source);die();
+
 				try
 				{
 					$jasper_wrapper->execute($jasper_parameters, $output_type, $report_source);
@@ -805,6 +844,7 @@ _debug_array($report_source);die();
 				$custom_fields			= CreateObject('property.custom_fields');
 				$values['attributes']	= $values['input'];
 				unset($values['input']);
+
 				$values = $custom_fields->prepare($values);
 
 				$receipt['error'][] = array('msg' => lang('enter input'));
@@ -812,31 +852,32 @@ _debug_array($report_source);die();
 				$function_msg	= lang('parameters');
 
 				$link_data = array
-				(
-					'menuaction'	=> 'property.uijasper.view',
-					'jasper_id'		=> $jasper_id
-				);
+					(
+						'menuaction'	=> 'property.uijasper.view',
+						'jasper_id'		=> $jasper_id
+					);
 
 				$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
-				
+
 				$formats = array();
 				foreach($values['formats'] as $format)
 				{
 					$formats[] = array
-					(
-						'id'	=> $format,
-						'name'	=> $format,
-						'selected' => $format == $sel_format
-					);
+						(
+							'id'	=> $format,
+							'name'	=> $format,
+							'selected' => $format == $sel_format
+						);
 				}
 
 				$data = array
-				(
-					'msgbox_data'		=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-					'form_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-					'attributes'		=> $values['attributes'],
-					'formats'			=> $formats
-				);
+					(
+						'msgbox_data'		=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+						'form_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+						'attributes'		=> $values['attributes'],
+						'lookup_functions'	=> isset($values['lookup_functions'])?$values['lookup_functions']:'',
+						'formats'			=> $formats
+					);
 
 				$GLOBALS['phpgw_info']['flags']['app_header'] = $function_msg;
 				$GLOBALS['phpgw']->xslttpl->add_file(array('jasper'));
@@ -862,9 +903,9 @@ _debug_array($report_source);die();
 			{
 				$bofiles	= CreateObject('property.bofiles');
 				if ($old_file = $bofiles->vfs->ls(array(
-						'string' => "{$bofiles->fakebase}/jasper/{$id}",
-						'relatives' => Array(RELATIVE_NONE)
-					)))
+					'string' => "{$bofiles->fakebase}/jasper/{$id}",
+					'relatives' => Array(RELATIVE_NONE)
+				)))
 				{
 					$bofiles->vfs->rm(array(
 						'string' => "{$bofiles->fakebase}/jasper/{$id}/{$old_file[0]['name']}",
