@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage core
- 	* @version $Id: hook_home.inc.php 4725 2010-02-03 15:15:34Z sigurd $
+	* @version $Id: hook_home.inc.php 6731 2011-01-05 14:53:57Z sigurdne $
 	*/
 
 
@@ -33,12 +33,12 @@
 	$GLOBALS['phpgw_info']['flags']['currentapp'] = 'property';
 	$maxmatches = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
 	$GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'] = 5;
-	
+
 	$prefs = $GLOBALS['phpgw_info']['user']['preferences'];
 
 
 	if ( isset($prefs['property']['mainscreen_show_new_updated_tts'])
-		&& $prefs['property']['mainscreen_show_new_updated_tts'] == 'yes')
+	&& $prefs['property']['mainscreen_show_new_updated_tts'] == 'yes')
 	{
 
 		$default_status 	= isset($prefs['property']['tts_status']) ? $prefs['property']['tts_status'] : '';
@@ -73,7 +73,7 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
 		$category_name = array(); // caching
@@ -118,7 +118,7 @@
 
 
 	if ( isset($prefs['property']['mainscreen_show_new_updated_tts_2'])
-		&& $prefs['property']['mainscreen_show_new_updated_tts_2'] == 'yes')
+	&& $prefs['property']['mainscreen_show_new_updated_tts_2'] == 'yes')
 	{
 
 		$default_status 	= isset($prefs['property']['tts_status_2']) ? $prefs['property']['tts_status_2'] : '';
@@ -153,7 +153,7 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
 		$category_name = array(); // caching
@@ -199,7 +199,7 @@
 
 
 	if ( isset($prefs['property']['mainscreen_show_new_updated_tts_3'])
-		&& $prefs['property']['mainscreen_show_new_updated_tts_3'] == 'yes')
+	&& $prefs['property']['mainscreen_show_new_updated_tts_3'] == 'yes')
 	{
 
 		$default_status 	= isset($prefs['property']['tts_status_3']) ? $prefs['property']['tts_status_3'] : '';
@@ -234,7 +234,7 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
 		$category_name = array(); // caching
@@ -278,7 +278,7 @@
 	}
 
 	if ( isset($prefs['property']['mainscreen_show_new_updated_tts_4'])
-		&& $prefs['property']['mainscreen_show_new_updated_tts_4'] == 'yes')
+	&& $prefs['property']['mainscreen_show_new_updated_tts_4'] == 'yes')
 	{
 
 		$default_status 	= isset($prefs['property']['tts_status_4']) ? $prefs['property']['tts_status_4'] : '';
@@ -313,28 +313,28 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
-				$status = array();
-				$status['X'] = array
-				(
-					'name'			=> lang('closed'),
-				);
-				$status['O'] = array
-				(
-					'name'			=> lang('open'),
-				);
+		$status = array();
+		$status['X'] = array
+		(
+			'name'			=> lang('closed'),
+		);
+		$status['O'] = array
+		(
+			'name'			=> lang('open'),
+		);
 
-				$custom_status	= execMethod('property.botts.get_custom_status');
+		$custom_status	= execMethod('property.botts.get_custom_status');
 
-				foreach($custom_status as $custom)
-				{
-					$status["C{$custom['id']}"] = array
-					(
-						'status'			=> $custom['name'],
-					);
-				}
+		foreach($custom_status as $custom)
+		{
+			$status["C{$custom['id']}"] = array
+			(
+				'status'			=> $custom['name'],
+			);
+		}
 
 		$category_name = array(); // caching
 
@@ -370,7 +370,7 @@
 	}
 
 	if ( isset($prefs['property']['mainscreen_project_1'])
-		&& $prefs['property']['mainscreen_project_1'] == 'yes')
+	&& $prefs['property']['mainscreen_project_1'] == 'yes')
 	{
 
 		$default_status 	= isset($prefs['property']['project_status_mainscreen_1']) ? $prefs['property']['project_status_mainscreen_1'] : '';
@@ -405,7 +405,7 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
 		$portalbox->data = array();
@@ -426,7 +426,7 @@
 	}
 
 	if ( isset($prefs['property']['mainscreen_workorder_1'])
-		&& $prefs['property']['mainscreen_workorder_1'] == 'yes')
+	&& $prefs['property']['mainscreen_workorder_1'] == 'yes')
 	{
 
 		$default_status 	= isset($prefs['property']['workorder_status_mainscreen_1']) ? $prefs['property']['workorder_status_mainscreen_1'] : '';
@@ -461,7 +461,7 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
 		$portalbox->data = array();
@@ -481,7 +481,7 @@
 		unset($default_status);
 	}
 	if ( isset($prefs['property']['mainscreen_workorder_2'])
-		&& $prefs['property']['mainscreen_workorder_2'] == 'yes')
+	&& $prefs['property']['mainscreen_workorder_2'] == 'yes')
 	{
 
 		$default_status 	= isset($prefs['property']['workorder_status_mainscreen_2']) ? $prefs['property']['workorder_status_mainscreen_2'] : '';
@@ -516,7 +516,7 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
 		$portalbox->data = array();
@@ -537,11 +537,11 @@
 	}
 
 	if ( isset($prefs['property']['mainscreen_showapprovals_request'])
-		&& $prefs['property']['mainscreen_showapprovals_request'] == 'yes' )
+	&& $prefs['property']['mainscreen_showapprovals_request'] == 'yes' )
 	{
 		$total_records = 0;
 		$title = isset($prefs['property']['mainscreen_showapprovals_request_title']) && $prefs['property']['mainscreen_showapprovals_request_title']? "{$prefs['property']['mainscreen_showapprovals_request_title']} ({$total_records})" : lang('approvals request') . " ({$total_records})";
-	
+
 		//TODO Make listbox css compliant
 		$portalbox = CreateObject('phpgwapi.listbox', array
 		(
@@ -572,19 +572,20 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
 		$action_params = array
 		(
 			'appname'			=> 'property',
 			'location'			=> '.project',
-		//	'id'				=> $id,
+			//	'id'				=> $id,
 			'responsible'		=> '',
 			'responsible_type'  => 'user',
 			'action'			=> 'approval',
 			'deadline'			=> '',
-			'created_by'		=> $accound_id
+			'created_by'		=> $accound_id,
+			'allrows'			=> true
 		);
 
 		$obj = CreateObject('property.sopending_action');
@@ -605,12 +606,13 @@
 		(
 			'appname'			=> 'property',
 			'location'			=> '.project.workorder',
-		//	'id'				=> $id,
+			//	'id'				=> $id,
 			'responsible'		=> '',
 			'responsible_type'  => 'user',
 			'action'			=> 'approval',
 			'deadline'			=> '',
-			'created_by'		=> $accound_id
+			'created_by'		=> $accound_id,
+			'allrows'			=> true
 		);
 
 		$pending_approvals = $obj->get_pending_action($action_params);
@@ -629,12 +631,13 @@
 		(
 			'appname'			=> 'property',
 			'location'			=> '.ticket',
-		//	'id'				=> $id,
+			//	'id'				=> $id,
 			'responsible'		=> '',
 			'responsible_type'  => 'user',
 			'action'			=> 'approval',
 			'deadline'			=> '',
-			'created_by'		=> $accound_id
+			'created_by'		=> $accound_id,
+			'allrows'			=> true
 		);
 
 		$pending_approvals = $obj->get_pending_action($action_params);
@@ -649,7 +652,7 @@
 				'link' => $entry['url']
 			);
 		}
-		
+
 		echo "\n".'<!-- BEGIN approval info -->'."\n".$portalbox->draw()."\n".'<!-- END approval info -->'."\n";
 		unset($portalbox);
 		unset($obj);
@@ -657,9 +660,10 @@
 	}
 
 	if ( isset($prefs['property']['mainscreen_showapprovals'])
-		&& $prefs['property']['mainscreen_showapprovals'] == 'yes' )
+	&& $prefs['property']['mainscreen_showapprovals'] == 'yes' )
 	{
-		$title = isset($prefs['property']['mainscreen_showapprovals_title']) && $prefs['property']['mainscreen_showapprovals_title']? "{$prefs['property']['mainscreen_showapprovals_title']} ({$total_records})" : lang('approvals') . " ({$total_records})";	
+		$total_records = 0;
+		$title = 'dummy';	
 		//TODO Make listbox css compliant
 		$portalbox = CreateObject('phpgwapi.listbox', array
 		(
@@ -690,19 +694,20 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
 		$action_params = array
 		(
 			'appname'			=> 'property',
 			'location'			=> '.project',
-		//	'id'				=> $id,
+			//	'id'				=> $id,
 			'responsible'		=> $accound_id,
 			'responsible_type'  => 'user',
 			'action'			=> 'approval',
 			'deadline'			=> '',
 			'created_by'		=> '',
+			'allrows'			=> true
 		);
 
 		$pending_approvals = execMethod('property.sopending_action.get_pending_action', $action_params);
@@ -715,25 +720,27 @@
 				'text' => 'Prosjekt venter på godkjenning: ' . $entry['item_id'],
 				'link' => $entry['url']
 			);
+			$total_records++;
 		}
-		
-//		echo "\n".'<!-- BEGIN approval info -->'."\n".$portalbox->draw()."\n".'<!-- END approval info -->'."\n";
+
+		//		echo "\n".'<!-- BEGIN approval info -->'."\n".$portalbox->draw()."\n".'<!-- END approval info -->'."\n";
 
 		$action_params = array
 		(
 			'appname'			=> 'property',
 			'location'			=> '.project.workorder',
-		//	'id'				=> $id,
+			//	'id'				=> $id,
 			'responsible'		=> $accound_id,
 			'responsible_type'  => 'user',
 			'action'			=> 'approval',
 			'deadline'			=> '',
 			'created_by'		=> '',
+			'allrows'			=> true
 		);
 
 		$pending_approvals = execMethod('property.sopending_action.get_pending_action', $action_params);
 
-//		$portalbox->data = array();
+		//		$portalbox->data = array();
 		foreach ($pending_approvals as $entry)
 		{
 			$portalbox->data[] = array
@@ -741,23 +748,25 @@
 				'text' => 'Ordre venter på godkjenning: ' . $entry['item_id'],
 				'link' => $entry['url']
 			);
+			$total_records++;
 		}
 
 		$action_params = array
 		(
 			'appname'			=> 'property',
 			'location'			=> '.ticket',
-		//	'id'				=> $id,
+			//	'id'				=> $id,
 			'responsible'		=> $accound_id,
 			'responsible_type'  => 'user',
 			'action'			=> 'approval',
 			'deadline'			=> '',
 			'created_by'		=> '',
+			'allrows'			=> true
 		);
 
 		$pending_approvals = execMethod('property.sopending_action.get_pending_action', $action_params);
 
-//		$portalbox->data = array();
+		//		$portalbox->data = array();
 		foreach ($pending_approvals as $entry)
 		{
 			$portalbox->data[] = array
@@ -765,17 +774,23 @@
 				'text' => 'Melding venter på godkjenning: ' . $entry['item_id'],
 				'link' => $entry['url']
 			);
+			$total_records++;
 		}
-		
+		//Hack
+		$title = isset($prefs['property']['mainscreen_showapprovals_title']) && $prefs['property']['mainscreen_showapprovals_title']? "{$prefs['property']['mainscreen_showapprovals_title']} ({$total_records})" : lang('approvals') . " ({$total_records})";	
+		$portalbox->setvar('title', $title);
+		$portalbox->start_template();
+
 		echo "\n".'<!-- BEGIN approval info -->'."\n".$portalbox->draw()."\n".'<!-- END approval info -->'."\n";
 		unset($portalbox);
 		unset($pending_approvals);
 	}
 
 	if ( isset($prefs['property']['mainscreen_showvendor_reminder'])
-		&& $prefs['property']['mainscreen_showvendor_reminder']  == 'yes' )
+	&& $prefs['property']['mainscreen_showvendor_reminder']  == 'yes' )
 	{
-		$title = isset($prefs['property']['mainscreen_showvendor_reminder_title']) && $prefs['property']['mainscreen_showvendor_reminder_title']? "{$prefs['property']['mainscreen_showvendor_reminder_title']} ({$total_records})" : lang('vendor reminder') . " ({$total_records})";	
+		$total_records = 0;
+		$title = 'dummy';
 		//TODO Make listbox css compliant
 		$portalbox = CreateObject('phpgwapi.listbox', array
 		(
@@ -805,19 +820,20 @@
 
 		foreach ( $var as $key => $value )
 		{
-//			$portalbox->set_controls($key,$value);
+			//			$portalbox->set_controls($key,$value);
 		}
 
 		$action_params = array
 		(
 			'appname'			=> 'property',
 			'location'			=> '.project.workorder',
-		//	'id'				=> $id,
+			//	'id'				=> $id,
 			'responsible'		=> '',
 			'responsible_type'  => 'vendor',
 			'action'			=> 'remind',
 			'deadline'			=> '',
 			'created_by'		=> $accound_id,
+			'allrows'			=> true
 		);
 
 		$pending_reminder = execMethod('property.sopending_action.get_pending_action', $action_params);
@@ -836,13 +852,18 @@
 				'text' => "påminning nr {$entry['reminder']} til leverandør {$vendor_name}- ordre nr: {$entry['item_id']}",
 				'link' => $entry['url']
 			);
+			$total_records++;
 		}
-		
+
+		$title = isset($prefs['property']['mainscreen_showvendor_reminder_title']) && $prefs['property']['mainscreen_showvendor_reminder_title']? "{$prefs['property']['mainscreen_showvendor_reminder_title']} ({$total_records})" : lang('vendor reminder') . " ({$total_records})";	
+		$portalbox->setvar('title', $title);
+		$portalbox->start_template();
+
 		echo "\n".'<!-- BEGIN reminder info -->'."\n".$portalbox->draw()."\n".'<!-- END reminder info -->'."\n";
 		unset($pending_reminder);
 		unset($portalbox);
 	}
-	
+
 	$GLOBALS['phpgw_info']['flags']['currentapp'] = $save_app;
 	$GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'] = $maxmatches;
 
