@@ -319,26 +319,58 @@
 	}
 
 
-
  /********************************************************************************
  *
  */
 	this.onSearchClick = function()
 	{
-		//no es necesario actualizar los valores actuales de path_value. Este es global y siempre esta actualizado
-		for(i=0;i<textImput.length;i++)
+		var callback4 =
 		{
-			var busq = encodeURIComponent(YAHOO.util.Dom.get(textImput[i].id).value);
-			eval("path_values."+textImput[i].name+"='"+busq+"'")
-		}
+			success: function(o)
+			{
+				var values = [];
+				try
+				{
+					values = JSON.parse(o.responseText);
+				}
+				catch (e)
+				{
+					return;
+				}
 
-		//si esta configurado que la busqueda sea por fechas
-		if(config_values.date_search != undefined && config_values.date_search != 0)
-		{
-			path_values.start_date = YAHOO.util.Dom.get('start_date').value;
-			path_values.end_date = YAHOO.util.Dom.get('end_date').value;
-		}
-		execute_ds();
+				if(values['sessionExpired'] == true)
+				{
+					window.alert('sessionExpired - please log in');
+					lightboxlogin('onSearchClick');//defined i phpgwapi/templates/portico/js/base.js
+				}
+				else
+				{
+					//no es necesario actualizar los valores actuales de path_value. Este es global y siempre esta actualizado
+					for(i=0;i<textImput.length;i++)
+					{
+						var busq = encodeURIComponent(YAHOO.util.Dom.get(textImput[i].id).value);
+						eval("path_values."+textImput[i].name+"='"+busq+"'")
+					}
+
+					//si esta configurado que la busqueda sea por fechas
+					if(config_values.date_search != undefined && config_values.date_search != 0)
+					{
+						path_values.start_date = YAHOO.util.Dom.get('start_date').value;
+						path_values.end_date = YAHOO.util.Dom.get('end_date').value;
+					}
+					execute_ds();
+				}
+			},
+			failure: function(o)
+			{
+				window.alert('failure - try again - once')
+			},
+			timeout: 5000
+		};
+
+		var oArgs = {menuaction:'property.bocommon.confirm_session'};
+		var strURL = phpGWLink('index.php', oArgs, true);
+		var request = YAHOO.util.Connect.asyncRequest('POST', strURL, callback4);
 	}
  /********************************************************************************
  *
@@ -405,7 +437,11 @@
 		control.set("label", ("<em>" + p_oItem[1] + "</em>"));
 		control.set("value", p_oItem[0]);
 		eval("path_values."+selectsButtons[p_oItem[2]].var_URL+"='"+p_oItem[0]+"'")
-
+		if(selectsButtons[p_oItem[2]].reload)
+		{
+	 		ds = phpGWLink('index.php',path_values);
+			window.open(ds,'_self');
+		}
 		// tiene dependiente asociado?
 		if(selectsButtons[p_oItem[2]].dependiente.length)
 		{
@@ -551,6 +587,7 @@
  */
 	this.onContextMenuBeforeShow = function(p_sType, p_aArgs)
 	{
+		var prefixSelected = '';
 		var oTarget = this.contextEventTarget;
 		if (this.getRoot() == this)
 		{
@@ -569,6 +606,7 @@
  */
 	this.onContextMenuHide = function(p_sType, p_aArgs)
 	{
+		var prefixSelected = '';
 		if (this.getRoot() == this && oSelectedTR)
 		{
 			oSelectedTR.style.backgroundColor  = "" ;
@@ -630,6 +668,12 @@
 						{
 							window.open(sUrl,'_blank');
 						}
+						else if(substr_count(sUrl,'target=_lightbox')>0)
+						{
+							//have to be defined as a local function. Example in invoice.list_sub.js
+							//console.log(sUrl); // firebug
+							showlightbox(sUrl);
+						}
 						else
 						{
 							window.open(sUrl,'_self');
@@ -741,12 +785,20 @@
 				{
 					myLoading.hide();
 				}
-				eval('values_ds ='+o.responseText);
-				flag_particular_setting='update';
-				particular_setting();
-				myPaginator.setRowsPerPage(values_ds.recordsReturned,true);
-				update_datatable();
-				update_filter();
+				values_ds = JSON.parse(o.responseText);
+				if(values_ds && values_ds['sessionExpired'] == true)
+				{
+					window.alert('sessionExpired - please log in');
+					lightboxlogin();//defined i phpgwapi/templates/portico/js/base.js
+				}
+				else
+				{
+					flag_particular_setting='update';
+					particular_setting();
+					myPaginator.setRowsPerPage(values_ds.recordsReturned,true);
+					update_datatable();
+					update_filter();
+				}
 			},
 			failure: function(o) {window.alert('Server or your connection is dead.')},
 			timeout: 10000,
@@ -827,9 +879,12 @@
 		}
 		flag++;
 
+		myinitialPage = 1 + values_ds.startIndex/myrowsPerPage;
+
 		myPaginatorConfig = {
 								containers			: ['paging'],
 								totalRecords		: mytotalRows,
+							    initialPage			: myinitialPage,
 								pageLinks			: 10,
 								rowsPerPage			: values_ds.recordsReturned, //MAXIMO el PHPGW me devuelve 15 valor configurado por preferencias
 								rowsPerPageOptions	: [myrowsPerPage, mytotalRows],
