@@ -1,4 +1,5 @@
 <?php
+
 	/**
 	* phpGroupWare
 	*
@@ -24,12 +25,15 @@
 	*
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: login.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: login.php 4120 2009-11-13 15:13:52Z sigurd $
 	*/
 
+	// FIXME this should be changed significantly - it duplicates a lot of login code, most of which has been improved
+
 	$phpgw_info = array();
-	
-	$GLOBALS['phpgw_info']['flags'] = array(
+
+	$GLOBALS['phpgw_info']['flags'] = array
+	(
 		'disable_template_class' => true,
 		'login'                  => true,
 		'currentapp'             => 'login',
@@ -37,12 +41,12 @@
 	);
 	if(file_exists('../header.inc.php'))
 	{
-	
+
 		/**
 		* Include phpgroupware header
 		*/
 		include_once('../header.inc.php');
-		
+
 		$GLOBALS['phpgw']->sessions = createObject('phpgwapi.sessions');
 	}
 	else
@@ -52,9 +56,9 @@
 	}
 	$GLOBALS['phpgw_info']['server']['template_set'] = $GLOBALS['phpgw_info']['login_template_set'];
 
-	$GLOBALS['phpgw_info']['server']['template_dir'] = PHPGW_SERVER_ROOT 
+	$GLOBALS['phpgw_info']['server']['template_dir'] = PHPGW_SERVER_ROOT
 							. "/phpgwapi/templates/{$GLOBALS['phpgw_info']['login_template_set']}";
-							
+
 	$tmpl = CreateObject('phpgwapi.Template', PHPGW_SERVER_ROOT . '/property/templates/base');
 
 	// This is used for system downtime, to prevent new logins.
@@ -71,7 +75,7 @@
 		$tmpl->pfp('loginout','login_form');
 		exit;
 	}
-	
+
 	/**
 	* Check logout error code
 	*
@@ -82,32 +86,41 @@
 	{
 		switch($code)
 		{
-			case 1:
-				return lang('You have been successfully logged out');
-			case 2:
-				return lang('Sorry, your login has expired');
-			case 5:
-				return lang('Bad login or password');
-			case 99:
-				return lang('Blocked, too many attempts');
-			case 10:
-				$GLOBALS['phpgw']->sessions->phpgw_setcookie('sessionid');
-				$GLOBALS['phpgw']->sessions->phpgw_setcookie('kp3');
-				$GLOBALS['phpgw']->sessions->phpgw_setcookie('domain');
+				case 1:
+					return lang('You have been successfully logged out');
+				case 2:
+					return lang('Sorry, your login has expired');
+				case 5:
+					return lang('Bad login or password');
+				case 20:
+					return lang('Cannot find the mapping ! (please advice your adminstrator)');
+				case 21:
+					return lang('you had inactive mapping to %1 account', phpgw::get_var('phpgw_account', 'string', 'GET', ''));
+				case 22:
+					$GLOBALS['phpgw']->session->phpgw_setcookie('sessionid');
+					$GLOBALS['phpgw']->session->phpgw_setcookie('kp3');
+					$GLOBALS['phpgw']->session->phpgw_setcookie('domain');
+					return lang('you seemed to have an active session elsewhere for the domain "%1", now set to expired - please try again', phpgw::get_var('domain', 'string', 'COOKIE'));
+				case 99:
+					return lang('Blocked, too many attempts');
+				case 10:
+					$GLOBALS['phpgw']->session->phpgw_setcookie('sessionid');
+					$GLOBALS['phpgw']->session->phpgw_setcookie('kp3');
+					$GLOBALS['phpgw']->session->phpgw_setcookie('domain');
 
-				// fix for bug in php expired sessions not being cleared
-				if($GLOBALS['phpgw_info']['server']['sessions_type'] == 'php')
-				{
-					$GLOBALS['phpgw']->sessions->phpgw_setcookie(PHPGW_PHPSESSID);
-				}
+					// fix for bug php4 expired sessions bug
+					if($GLOBALS['phpgw_info']['server']['sessions_type'] == 'php')
+					{
+						$GLOBALS['phpgw']->session->phpgw_setcookie('phpgwsessid');
+					}
 
-				return lang('Your session could not be verified.');
-			default:
-				return '&nbsp;';
+					return lang('Your session could not be verified.');
+				default:
+					return '&nbsp;';
 		}
 	}
-	
-	
+
+
 	/**
 	* Check languages
 	*/
@@ -124,21 +137,21 @@
 			$GLOBALS['phpgw_info']['server']['lang_ctimes'] = array();
 		}
 		// _debug_array($GLOBALS['phpgw_info']['server']['lang_ctimes']);
-		
+
 		$lang = $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'];
 		$apps = $GLOBALS['phpgw_info']['user']['apps'];
 		$apps['phpgwapi'] = true;	// check the api too
 		while (list($app,$data) = each($apps))
 		{
 			$fname = PHPGW_SERVER_ROOT . "/$app/setup/phpgw_$lang.lang";
-			
+
 			if (file_exists($fname))
 			{
 				$ctime = filectime($fname);
-				$ltime = isset($GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app]) 
+				$ltime = isset($GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app])
 						? intval($GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app]) : 0;
 				//echo "checking lang='$lang', app='$app', ctime='$ctime', ltime='$ltime'<br>\n";
-				
+
 				if ($ctime != $ltime)
 				{
 					update_langs();		// update all langs
@@ -147,8 +160,8 @@
 			}
 		}
 	}
-	
-	
+
+
 	/**
 	* Update languages
 	*/
@@ -156,7 +169,7 @@
 	{
 		$GLOBALS['phpgw_setup'] = CreateObject('phpgwapi.setup');
 		$GLOBALS['phpgw_setup']->db = $GLOBALS['phpgw']->db;
-		
+
 		$GLOBALS['phpgw_setup']->detection->check_lang(false);	// get installed langs
 		$langs = $GLOBALS['phpgw_info']['setup']['installed_langs'];
 		while (list($lang) = @each($langs))
@@ -167,7 +180,7 @@
 		$_POST['lang_selected'] = $langs;
 		$_POST['upgrademethod'] = 'dumpold';
 		$included = 'from_login';
-		
+
 		/**
 		* Include languages setup
 		*/
@@ -175,19 +188,26 @@
 	}
 
 	/* Program starts here */
-	$login = isset($_POST['login']) ? $_POST['login'] : '';
-	$passwd = isset($_POST['passwd']) ? $_POST['passwd'] : '';
+	$GLOBALS['phpgw']->session->phpgw_setcookie('sessionphpgwsessid');
+//	$GLOBALS['phpgw']->session->phpgw_setcookie('sessionid');
+	$GLOBALS['phpgw']->session->phpgw_setcookie('kp3');
+	$GLOBALS['phpgw']->session->phpgw_setcookie('domain');
+
+	$login = phpgw::get_var('login', 'string' , 'POST');
+	$passwd = phpgw::get_var('passwd', 'string' , 'POST');
+
 	if ($GLOBALS['phpgw_info']['server']['auth_type'] == 'http' && isset($_SERVER['PHP_AUTH_USER']))
 	{
 		$submit = true;
-		$login  = $_SERVER['PHP_AUTH_USER'];
-		$passwd = $_SERVER['PHP_AUTH_PW'];
+		$login = phpgw::get_var('PHP_AUTH_USER', 'string' , 'SERVER');
+		$passwd = phpgw::get_var('PHP_AUTH_PW', 'string' , 'SERVER');
 	}
-	
+
 	if ($GLOBALS['phpgw_info']['server']['auth_type'] == 'ntlm' && isset($_SERVER['REMOTE_USER']))
 	{
 		$submit = true;
-		$login  = $_SERVER['REMOTE_USER'];
+		$login = phpgw::get_var('REMOTE_USER', 'string' , 'SERVER');
+
 		$passwd = '';
 	}
 
@@ -198,7 +218,8 @@
 		# an X.509 subject looks like:
 		# /CN=john.doe/OU=Department/O=Company/C=xx/Email=john@comapy.tld/L=City/
 		# the username is deliberately lowercase, to ease LDAP integration
-		$sslattribs = explode('/',$_SERVER['SSL_CLIENT_S_DN']);
+		$sslattribs = phpgw::get_var('SSL_CLIENT_S_DN', 'string' , 'SERVER');
+		$sslattribs = explode('/',$sslattribs);
 		# skip the part in front of the first '/' (nothing)
 		while ($sslattrib = next($sslattribs))
 		{
@@ -215,7 +236,7 @@
 			if (!isset($_POST['login'])&&isset($sslattributes['Email'])) {
 				$login = $sslattributes['Email'];
 				# not checked against the database, but delivered to authentication module
-				$passwd = $_SERVER['SSL_CLIENT_S_DN'];
+				$passwd = phpgw::get_var('SSL_CLIENT_S_DN', 'string' , 'SERVER');
 			}
 		}
 		unset($key);
@@ -223,7 +244,7 @@
 		unset($sslattributes);
 	}
 
-	if (isset($_POST['passwd_type']) && (isset($_POST['submitit']) || isset($_POST['submit_x']) || isset($_POST['submit_y']) ) )
+	if ( (isset($_POST['submitit']) || isset($_POST['submit_x']) || isset($_POST['submit_y']) ) )
 	{
 		if ( $_SERVER['REQUEST_METHOD'] != 'POST' &&
 		   !isset($_SERVER['PHP_AUTH_USER']) &&
@@ -239,38 +260,40 @@
 		{
 			$db = & $GLOBALS['phpgw']->db;
 			$join = $db->join;
-			
+
 			$_passwd = md5($passwd);
 
-			$db->query("SELECT fm_tenant.id, phpgw_accounts.account_lid,phpgw_accounts.account_pwd  FROM fm_tenant $join phpgw_accounts ON fm_tenant.phpgw_account_id = phpgw_accounts.account_id WHERE fm_tenant.account_lid = '$login' AND "
-				. "fm_tenant.account_pwd='" . $_passwd . "' AND fm_tenant.account_status ='1'",__LINE__,__FILE__);
+			$db->query("SELECT fm_tenant.id, phpgw_accounts.account_lid,phpgw_accounts.account_pwd"
+				. " FROM fm_tenant {$join} phpgw_accounts ON fm_tenant.phpgw_account_id = phpgw_accounts.account_id"
+				. " WHERE phpgw_accounts.account_status = 'A' AND"
+				. " fm_tenant.account_lid = '{$login}' AND"
+				. " fm_tenant.account_pwd='{$_passwd}' AND"
+				. " fm_tenant.account_status =1",__LINE__,__FILE__);
 			$db->next_record();
 
 			if (!$db->f('account_lid'))
 			{
 				$GLOBALS['phpgw']->redirect('login.php?cd=5');
-				exit;			
+				exit;
 			}
 
 			$tenant_id = $db->f('id');
 			$login = $db->f('account_lid');
 			$passwd = $db->f('account_pwd');
-
-			$_POST['passwd_type'] = 'md5';
-
+//_debug_array($passwd);die();
 			if ( isset($GLOBALS['phpgw_info']['server']['usecookies']) && $GLOBALS['phpgw_info']['server']['usecookies'] )
-			{ 
-				$GLOBALS['phpgw']->session->phpgw_setcookie('last_usertype', $_POST['loginusertype'] ,time()+1209600); /* For 2 weeks */
+			{
+				$GLOBALS['phpgw']->session->phpgw_setcookie('last_usertype', phpgw::get_var('loginusertype') ,time()+1209600); /* For 2 weeks */
 			}
 		}
 // end mapping
 
 		if (strstr($login,'@') === false && isset($_POST['logindomain']))
 		{
-			$login .= '@' . $_POST['logindomain'];
+			$login .= '@' . phpgw::get_var('logindomain', 'string', 'POST');
 		}
 
-		$GLOBALS['sessionid'] = $GLOBALS['phpgw']->session->create($login,$passwd,$_POST['passwd_type']);
+		$GLOBALS['sessionid'] = $GLOBALS['phpgw']->session->create($login, '', true);
 
 		$GLOBALS['phpgw']->session->appsession('tenant_id','property',$tenant_id);
 
@@ -289,7 +312,7 @@
 			{
 				if (preg_match('/phpgw_/',$name))
 				{
-					$extra_vars[$name] = $value;
+					$extra_vars[$name] = phpgw::clean_value($value);
 				}
 			}
 		}
@@ -298,38 +321,28 @@
 			check_langs();
 		}
 		$extra_vars['cd'] = 'yes';
-		
-		$GLOBALS['phpgw']->hooks->process('login');
 
-		if( isset($GLOBALS['phpgw_info']['server']['shm_lang']) 
-			&& $GLOBALS['phpgw_info']['server']['shm_lang'] 
-			&& function_exists('sem_get'))
-		{
-			if(!$GLOBALS['phpgw']->shm->get_value('lang_en'))
-			{
-				$GLOBALS['phpgw']->translation->populate_shm();
-			}
-		}
+		$GLOBALS['phpgw']->hooks->process('login');
 
 		$GLOBALS['phpgw']->redirect_link('/home.php', $extra_vars);
 		exit;
 	}
-		
+
 	$tmpl->set_file(array('login_form'  => 'login.tpl'));
 	$tmpl->set_var('charset', lang('charset'));
 	$tmpl->set_block('login_form', 'domain_option', 'domain_options');
-	$tmpl->set_block('login_form', 'domain_select', 'domain_selects'); 
+	$tmpl->set_block('login_form', 'domain_select', 'domain_selects');
 	$tmpl->set_block('login_form', 'domain_from_host', 'domain_from_hosts');
 	$tmpl->set_block('login_form', 'usertype_option', 'usertype_options');
-	$tmpl->set_block('login_form', 'usertype_select', 'usertype_selects'); 
+	$tmpl->set_block('login_form', 'usertype_select', 'usertype_selects');
 
-	if( $GLOBALS['phpgw_info']['server']['domain_from_host'] 
+	if( $GLOBALS['phpgw_info']['server']['domain_from_host']
 		&& !$GLOBALS['phpgw_info']['server']['show_domain_selectbox'] )
 	{
 		$tmpl->set_var(
 				array(
 					'domain_selects'	=> '',
-					'logindomain'		=> $_SERVER['SERVER_NAME']
+					'logindomain'		=> phpgw::get_var('SERVER_NAME', 'string' , 'SERVER')
 				)
 			);
 		$tmpl->parse('domain_from_hosts', 'domain_from_host');
@@ -337,7 +350,7 @@
 	elseif( $GLOBALS['phpgw_info']['server']['show_domain_selectbox'] )
 	{
 		foreach($GLOBALS['phpgw_domain'] as $domain_name => $domain_vars)
-		{	
+		{
 			$tmpl->set_var('domain_name', $domain_name);
 
 			if (isset($_COOKIE['last_domain']) && $_COOKIE['last_domain'] == $domain_name)
@@ -366,12 +379,12 @@
 					'domain_from_hosts'	=> ''
 				)
 			);
-		
+
 	}
 
 	$usertypes = array('tenant'=>lang('tenant'),'internal'=>lang('internal'));
 	foreach($usertypes as $usertype_id => $usertype_name)
-	{	
+	{
 		$tmpl->set_var('usertype_id', $usertype_id);
 		$tmpl->set_var('usertype_name', $usertype_name);
 
@@ -381,7 +394,7 @@
 		}
 		else
 		{
-			$tmpl->set_var('usertype_selected', '');		
+			$tmpl->set_var('usertype_selected', '');
 		}
 		$tmpl->parse('usertype_options', 'usertype_option', true);
 	}
@@ -389,14 +402,14 @@
 	$tmpl->set_var(
 			array(
 				'usertype_from_hosts'	=> '',
-				'lang_usertype'		=> lang('Usertype')
+				'lang_usertype'		=> lang('usertype')
 			)
 		);
 
 	if (isset($_COOKIE['last_loginid']))
 	{
 		$accounts = CreateObject('phpgwapi.accounts');
-		$prefs = CreateObject('phpgwapi.preferences', $accounts->name2id($_COOKIE['last_loginid']));
+		$prefs = CreateObject('phpgwapi.preferences', $accounts->name2id(phpgw::get_var('last_loginid', 'string', 'COOKIE')));
 
 		if (! $prefs->account_id)
 		{
@@ -404,7 +417,7 @@
 		}
 		else
 		{
-			$GLOBALS['phpgw_info']['user']['preferences'] = $prefs->read_repository();
+			$GLOBALS['phpgw_info']['user']['preferences'] = $prefs->read();
 		}
 		#print 'LANG:' . $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] . '<br>';
 	}
@@ -443,8 +456,8 @@
 		}
 
 	}
-	
-	$last_loginid = isset($_COOKIE['last_loginid']) ? $_COOKIE['last_loginid'] : '';
+
+	$last_loginid = phpgw::get_var('last_loginid', 'string', 'COOKIE');
 	if($GLOBALS['phpgw_info']['server']['show_domain_selectbox'] && $last_loginid !== '')
 	{
 		reset($GLOBALS['phpgw_domain']);
@@ -452,7 +465,7 @@
 
 		if ($_COOKIE['last_domain'] != $default_domain && !empty($_COOKIE['last_domain']))
 		{
-			$last_loginid .= '@' . $_COOKIE['last_domain'];
+			$last_loginid .= '@' . phpgw::get_var('last_domain', 'string', 'COOKIE');
 		}
 	}
 
@@ -462,7 +475,7 @@
 	{
 		if (preg_match('/phpgw_/',$name))
 		{
-			$extra_vars[$name] = urlencode($value);
+			$extra_vars[$name] = urlencode(phpgw::clean_value($value));
 		}
 	}
 
@@ -485,30 +498,30 @@
 	$tmpl->set_var('lang_testjs', lang('Your browser does not support javascript and/or css, please use a modern standards compliant browser.  If you have disabled either of these features please enable them for this site.') );
 
 	$tmpl->set_var('website_title', isset($GLOBALS['phpgw_info']['server']['site_title'])
-						? $GLOBALS['phpgw_info']['server']['site_title'] 
+						? $GLOBALS['phpgw_info']['server']['site_title']
 						: 'phpGroupWare'
 						);
 
 	$tmpl->set_var('template_set', $GLOBALS['phpgw_info']['login_template_set']);
-	
-	if( is_file( PHPGW_SERVER_ROOT . SEP . 'property' . SEP . 'templates' 
-		. SEP . $GLOBALS['phpgw_info']['login_template_set'] . SEP . 'css' . SEP . 'base.css') )
+
+	// This really should just use the API CSS, which would fix any conflicts
+	if( is_file(PHPGW_SERVER_ROOT . "/property/templates/{$GLOBALS['phpgw_info']['login_template_set']}/css/base.css") )
 	{
-		$base_css = '../property/templates/' . $GLOBALS['phpgw_info']['login_template_set'] . '/css/base.css';
+		$base_css = "{$GLOBALS['phpgw_info']['server']['webserver_url']}/property/templates/{$GLOBALS['phpgw_info']['login_template_set']}/css/base.css";
 	}
 	else
 	{
-		$base_css = '../property/templates/base/css/base.css';
+		$base_css = "{$GLOBALS['phpgw_info']['server']['webserver_url']}/property/templates/base/css/base.css";
 	}
 
-	if( is_file( PHPGW_SERVER_ROOT . SEP . 'property' . SEP . 'templates' 
-		. SEP . $GLOBALS['phpgw_info']['login_template_set'] . SEP . 'css' . SEP . 'login.css') )
+	// ditto
+	if( is_file(PHPGW_SERVER_ROOT . "/property/templates/{$GLOBALS['phpgw_info']['login_template_set']}/css/login.css") )
 	{
-		$login_css = '../property/templates/' . $GLOBALS['phpgw_info']['login_template_set'] . '/css/login.css';
+		$login_css = "{$GLOBALS['phpgw_info']['server']['webserver_url']}/property/templates/{$GLOBALS['phpgw_info']['login_template_set']}/css/login.css";
 	}
 	else
 	{
-		$login_css = '../property/templates/base/css/login.css';
+		$login_css = "{$GLOBALS['phpgw_info']['server']['webserver_url']}/property/templates/base/css/login.css";
 	}
 
 	$tmpl->set_var('base_css', $base_css);
@@ -524,4 +537,4 @@
 	unset($autocomplete);
 
 	$tmpl->pfp('loginout','login_form');
-?>
+
