@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage setup
- 	* @version $Id: default_records.inc.php 6401 2010-09-24 13:59:33Z sigurd $
+ 	* @version $Id: default_records.inc.php 7500 2011-08-12 10:50:18Z sigurdne $
 	*/
 
 
@@ -39,7 +39,7 @@ $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name, descr) VALUES ({$app_id}, '.custom', 'custom queries')");
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name, descr, allow_grant, allow_c_function, allow_c_attrib, c_attrib_table) VALUES ({$app_id}, '.project', 'Demand -> Workorder', 1, 1, 1, 'fm_project')");
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name, descr, allow_grant, allow_c_function, allow_c_attrib, c_attrib_table) VALUES ({$app_id}, '.project.workorder', 'Workorder', 1, 1 ,1, 'fm_workorder')");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name, descr, allow_grant, allow_c_function) VALUES ({$app_id}, '.project.request', 'Request', 1, 1)");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name, descr, allow_grant, allow_c_function, allow_c_attrib, c_attrib_table) VALUES ({$app_id}, '.project.request', 'Request', 1, 1 ,1, 'fm_request')");
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name, descr, allow_grant, allow_c_function, allow_c_attrib, c_attrib_table) VALUES ({$app_id}, '.ticket', 'Helpdesk', 1, 1, 1, 'fm_tts_tickets')");
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name, descr) VALUES ({$app_id}, '.ticket.external', 'Helpdesk External user')");
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name, descr) VALUES ({$app_id}, '.ticket.order', 'Helpdesk ad hock order')");
@@ -71,6 +71,24 @@ $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_locations (app_id, name
 
 $GLOBALS['phpgw']->locations->add('.jasper', 'JasperReport', 'property', $allow_grant = true);
 
+$GLOBALS['phpgw']->locations->add('.invoice.dimb', 'A dimension for accounting', 'property');
+$GLOBALS['phpgw']->locations->add('.scheduled_events', 'Scheduled events', 'property');
+
+$locations = array
+(
+	'property.ticket'	=> '.ticket',
+	'property.project'	=> '.project',
+	'property.document' => '.document',
+	'fm_vendor'			=> '.vendor',
+	'fm_tenant'			=> '.tenant',
+	'fm_owner'			=> '.owner'
+);
+
+foreach($locations as $dummy => $location)
+{
+	$GLOBALS['phpgw']->locations->add("{$location}.category", 'Categories', 'property');
+}
+
 
 $GLOBALS['phpgw_setup']->oProc->query("DELETE from phpgw_config WHERE config_app='property'");
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO phpgw_config (config_app, config_name, config_value) VALUES ('property','meter_table', 'fm_entity_1_1')");
@@ -196,12 +214,12 @@ $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_status (id, descr)
 # fm_request_condition_type
 #
 
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, descr, priority_key) VALUES (1, 'safety', 10)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, descr, priority_key) VALUES (2, 'aesthetics', 2)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, descr, priority_key) VALUES (3, 'indoor climate', 5)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, descr, priority_key) VALUES (4, 'consequential damage', 5)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, descr, priority_key) VALUES (5, 'user gratification', 4)");
-$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, descr, priority_key) VALUES (6, 'residential environment', 6)");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, name, priority_key) VALUES (1, 'safety', 10)");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, name, priority_key) VALUES (2, 'aesthetics', 2)");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, name, priority_key) VALUES (3, 'indoor climate', 5)");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, name, priority_key) VALUES (4, 'consequential damage', 5)");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, name, priority_key) VALUES (5, 'user gratification', 4)");
+$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_request_condition_type (id, name, priority_key) VALUES (6, 'residential environment', 6)");
 
 
 #
@@ -705,3 +723,6 @@ $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_jasper_format_type (id) VA
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_jasper_format_type (id) VALUES ('XLS')");
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_jasper_format_type (id) VALUES ('XHTML')");
 $GLOBALS['phpgw_setup']->oProc->query("INSERT INTO fm_jasper_format_type (id) VALUES ('DOCX')");
+
+$solocation = createObject('property.solocation');
+$solocation->update_location();
