@@ -8,11 +8,11 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage setup
- 	* @version $Id: setup.inc.php 6383 2010-09-23 10:20:10Z sigurd $
+ 	* @version $Id: setup.inc.php 7500 2011-08-12 10:50:18Z sigurdne $
 	*/
 
 	$setup_info['property']['name']			= 'property';
-	$setup_info['property']['version']		= '0.9.17.594';
+	$setup_info['property']['version']		= '0.9.17.622';
 	$setup_info['property']['app_order']	= 8;
 	$setup_info['property']['enable']		= 1;
 	$setup_info['property']['app_group']	= 'office';
@@ -110,11 +110,14 @@
 		'fm_wo_hours_category',
 		'fm_wo_h_deviation',
 		'fm_key_loc',
+		'fm_authorities_demands',
 		'fm_request',
 		'fm_request_condition_type',
 		'fm_request_condition',
 		'fm_request_status',
 		'fm_request_history',
+		'fm_request_consume',
+		'fm_request_planning',
 		'fm_template',
 		'fm_template_hours',
 		'fm_chapter',
@@ -130,6 +133,7 @@
 		'fm_tts_views',
 		'fm_ecoart',
 		'fm_ecoavvik',
+		'fm_ecobilag_process_code',
 		'fm_ecobilag',
 		'fm_ecobilagkilde',
 		'fm_ecobilagoverf',
@@ -168,6 +172,7 @@
 		'fm_orders',
 		'fm_order_dim1',
 		'fm_order_template',
+		'fm_response_template',
 		'fm_s_agreement',
 		'fm_s_agreement_budget',
 		'fm_s_agreement_category',
@@ -178,24 +183,21 @@
 		'fm_cron_log',
 		'fm_tenant_claim',
 		'fm_tenant_claim_category',
-		'fm_r_agreement',
-		'fm_r_agreement_category',
-		'fm_r_agreement_item',
-		'fm_r_agreement_item_history',
-		'fm_r_agreement_common',
-		'fm_r_agreement_c_history',
 		'fm_budget_basis',
 		'fm_budget',
 		'fm_budget_period',
 		'fm_budget_cost',
 		'fm_responsibility',
+		'fm_responsibility_role',
 		'fm_responsibility_contact',
 		'fm_action_pending',
 		'fm_action_pending_category',
 		'fm_jasper',
 		'fm_jasper_input_type',
 		'fm_jasper_format_type',
-		'fm_jasper_input'
+		'fm_jasper_input',
+		'fm_custom_menu_items',
+		'fm_regulations'
 	);
 
 	/* The hooks this app includes, needed for hooks registration */
