@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: install.apache.sh 6213 2010-07-31 11:30:48Z sigurd $ 
+# $Id: install.apache.sh 6878 2011-01-31 07:55:15Z sigurdne $ 
 
 #/**
 #  * installscript for APACHE with PHP, IMAP, POSTGRESQL, MYSQL, LIBXML, XSLT, FREEDTS(MSSQL) and EACCELERATOR
@@ -27,8 +27,8 @@ FREETDSTAR="freetds-stable.tgz"
 FREETDS="freetds-0.82"
 
 # Download: http://xmlsoft.org/downloads.html
-LIBXMLTAR="libxml2-2.7.7.tar.gz"
-LIBXML="libxml2-2.7.7"
+LIBXMLTAR="libxml2-2.7.8.tar.gz"
+LIBXML="libxml2-2.7.8"
 
 LIBXSLTAR="libxslt-1.1.26.tar.gz"
 LIBXSL="libxslt-1.1.26"
@@ -45,8 +45,8 @@ PHP_PREFIX="/usr/local"
 #  * @var               string APACHE, APACHETAR
 #  * Download: http://php.net/
 #  */
-APACHETAR="httpd-2.2.16.tar.gz"
-APACHE="httpd-2.2.16"
+APACHETAR="httpd-2.2.17.tar.gz"
+APACHE="httpd-2.2.17"
 
 #/**
 #  * Name of the PHP tarball e.g php-5.2.tar.gz
@@ -54,8 +54,8 @@ APACHE="httpd-2.2.16"
 #  * @var               string PHP, PHPTAR
 #  * Download: http://httpd.apache.org/
 #  */
-PHPTAR="php-5.3.3.tar.bz2"
-PHP="php-5.3.3"
+PHPTAR="php-5.3.5.tar.bz2"
+PHP="php-5.3.5"
 
 #/**
 #  * Name of the EACCELERATOR tarball e.g eaccelerator-0.9.5.tar.bz2
@@ -217,9 +217,11 @@ cd ../apr-util &&\
 make &&\
 make install &&\
 # Configure httpd
+#cd ../../ &&\
+#./configure --with-apr=/usr/local/apr-httpd/\
+# --with-apr-util=/usr/local/apr-util-httpd/\
 cd ../../ &&\
-./configure --with-apr=/usr/local/apr-httpd/\
- --with-apr-util=/usr/local/apr-util-httpd/\
+./configure --with-included-apr\
  --with-mpm=prefork\
  --enable-so\
  --enable-deflate\
