@@ -108,6 +108,7 @@ class rental_socontract extends rental_socommon
 					$like_clauses[] = "party.last_name $this->like $like_pattern";
 					$like_clauses[] = "party.company_name $this->like $like_pattern";
 					$like_clauses[] = "composite.name $this->like $like_pattern";
+					$like_clauses[] = "r_u.location_code $this->like $like_pattern";
 					break;
 			}
 			
@@ -179,9 +180,22 @@ class rental_socontract extends rental_socommon
 			$adjustment_interval = $this->marshal($filters['adjustment_interval'],'int');
 			$adjustment_year = $this->marshal($filters['adjustment_year'],'int');
 			
+			if($filters['adjustment_is_executed']){
+				$filter_clauses[] = "contract.adjustment_year = {$adjustment_year}";
+			}
+			else{
+				$filter_clauses[] = "contract.adjustment_year + {$adjustment_interval} <= {$adjustment_year}";
+			}
+			
+			$firstJanAdjYear = mktime(0,0,0,1,1,$adjustment_year);
+			
+			//make sure the contracts are active
+			$filter_clauses[] = "(contract.date_end is null OR contract.date_end >= {$firstJanAdjYear})";
+			$filter_clauses[] = "contract.date_start is not null AND contract.date_start <= {$firstJanAdjYear}";
+			
 			$filter_clauses[] = "contract.adjustable IS true";
-			//$filter_clauses[] = "contract.adjustment_interval = {$adjustment_interval}";
-			//$filter_clauses[] = "contract.adjustment_year + {$adjustment_interval} = {$adjustment_year}";
+			$filter_clauses[] = "contract.adjustment_interval = {$adjustment_interval}";
+			
 		}
 		
 		/* 
