@@ -18,6 +18,8 @@
 
 	class rental_uicontract extends rental_uicommon
 	{
+		private $pdf_templates = array();
+		
 		public $public_functions = array
 		(
 			'add'					=> true,
@@ -41,6 +43,7 @@
 
 		public function __construct()
 		{
+			$this->get_pdf_templates();
 			parent::__construct();
 			self::set_active_menu('rental::contracts');
 			$GLOBALS['phpgw_info']['flags']['app_header'] .= '::'.lang('contracts');
@@ -48,6 +51,7 @@
 
 		public function query()
 		{
+			
 			if($GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'] > 0)
 			{
 				$user_rows_per_page = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
@@ -67,6 +71,7 @@
 			$result_objects = array();
 			$result_count = 0;
 			
+			$price_items_only = phpgw::get_var('price_items'); //should only export contract price items
 			$exp_param 	= phpgw::get_var('export');
 			$export = false;
 			if(isset($exp_param)){
@@ -80,9 +85,7 @@
 				case 'contracts_for_adjustment':
 					$adjustment_id = (int)phpgw::get_var('id');
 					$adjustment = rental_soadjustment::get_instance()->get_single($adjustment_id);
-					$adjustment_date = $adjustment->get_adjustment_date();
-					$adjustment_year = date('Y',$adjustment_date);
-					$filters = array('contract_type' => $adjustment->get_responsibility_id(), 'adjustment_interval' => $adjustment->get_interval(), 'adjustment_year' => $adjustment_year);
+					$filters = array('contract_type' => $adjustment->get_responsibility_id(), 'adjustment_interval' => $adjustment->get_interval(), 'adjustment_year' => $adjustment->get_year(), 'adjustment_is_executed' => $adjustment->is_executed());
 					break;
 				case 'contracts_part': 						// Contracts for this party
 					$filters = array('party_id' => phpgw::get_var('party_id'),'contract_status' => phpgw::get_var('contract_status'), 'contract_type' => phpgw::get_var('contract_type'), 'status_date_hidden' => phpgw::get_var('status_date_hidden'));
@@ -176,15 +179,45 @@
 				foreach ($result_objects as $result) {
 					if(isset($result))
 					{
-						$rows[] = $result->serialize();
+						if(isset($price_items_only))
+						{
+							//export contract price items
+							$result_objects_pi = rental_socontract_price_item::get_instance()->get(null, null, null, null, null, null, array('contract_id' => $result->get_id(),'export'=>'true','include_billed'=>'true'));
+							foreach ($result_objects_pi as $result_pi) {
+								if(isset($result_pi))
+								{
+									$rows[] = $result_pi->serialize();
+								}
+							}
+						}
+						else
+						{
+							//export contracts
+							$rows[] = $result->serialize();
+						}
 					}
 				}
 				//var_dump("Usage " .memory_get_usage() . " bytes after serializing");
 			}
 			
+			
+			
 			if(!$export){
 				//Add context menu columns (actions and labels)
-				array_walk($rows, array($this, 'add_actions'), array($type,$ids));
+				$config	= CreateObject('phpgwapi.config','rental');
+				
+				//Check if user has access to Catch module
+				$access = $this->acl->check('.',PHPGW_ACL_READ,'catch');
+				if($access)
+				{
+					$config->read();
+					$entity_id_in = $config->config_data['entity_config_move_in'];
+					$entity_id_out = $config->config_data['entity_config_move_out'];
+					$category_id_in = $config->config_data['category_config_move_in'];	
+					$category_id_out = $config->config_data['category_config_move_out'];		
+				}
+				
+				array_walk($rows, array($this, 'add_actions'), array($type,$ids,$adjustment_id,$entity_id_in,$entity_id_out,$category_id_in,$category_id_out));
 			}
 			//var_dump("Usage " .memory_get_usage() . " bytes after menu");
 			
@@ -209,6 +242,12 @@
 
 			$type = $params[0];
 			$ids = $params[1];
+			$adjustment_id = $params[2];
+			$entity_id_in = $params[3];
+			$entity_id_out = $params[4];
+			$category_id_in = $params[5];
+			$category_id_out = $params[6];
+			
 			
 			switch($type)
 			{
@@ -230,6 +269,29 @@
 						$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uicontract.view', 'id' => $value['id'], 'initial_load' => 'no')));
 						$value['labels'][] = lang('show');
 					}
+					break;
+				case 'contracts_for_adjustment':
+					if(!isset($ids) || count($ids) > 0)
+					{
+						$value['ajax'][] = false;
+						$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uicontract.edit',
+																					'id' => $value['id'], 
+																					'initial_load' => 'no',
+																					'adjustment_id' => $adjustment_id)));
+						$value['labels'][] = lang('edit');
+						$value['ajax'][] = false;
+						$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uicontract.copy_contract',
+																									'id' => $value['id'],
+																									'adjustment_id' => $adjustment_id)));
+						$value['labels'][] = lang('copy');
+					}
+					$value['ajax'][] = false;
+					$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uicontract.view',
+																									'id' => $value['id'], 
+																									'initial_load' => 'no',
+																									'adjustment_id' => $adjustment_id)));
+					$value['labels'][] = lang('show');
+			
 					break;
 				default:
 					if(!isset($ids) || count($ids) > 0)
@@ -244,7 +306,28 @@
 					$value['ajax'][] = false;
 					$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uicontract.view', 'id' => $value['id'], 'initial_load' => 'no')));
 					$value['labels'][] = lang('show');
-					
+					$temlate_counter = 0;
+					foreach ($this->pdf_templates as $pdf_template){
+						
+						$value['ajax'][] = false;
+						$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uimakepdf.view', 'id' => $value['id'], 'pdf_template' => $temlate_counter )));
+						$value['labels'][] = lang('make_pdf').": ". $pdf_template[0];
+						$temlate_counter++;
+					}
+					//http://portico/pe/index.php?menuaction=property.uientity.index&second_display=1&entity_id=3&cat_id=1&type=catch&district_id=0&query=Tes&start_date=&end_date=&click_history=06014d0abc7293bfb52ff5d1c04f3cb8&phpgw_return_as=json
+					if(isset($entity_id_in) && $entity_id_in != '' && isset($category_id_in) && $category_id_in != '')
+					{
+						$value['ajax'][] = false;
+						$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'property.uientity.index', 'entity_id' => $entity_id_in, 'cat_id' => $category_id_in,'query' => $value['old_contract_id'], 'type' => 'catch')));
+						$value['labels'][] = lang('show_move_in_reports');
+					}
+
+					if(isset($entity_id_out) && $entity_id_out != '' && isset($category_id_out) && $category_id_out != '')
+					{
+						$value['ajax'][] = false;
+						$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'property.uientity.index', 'entity_id' => $entity_id_out, 'cat_id' => $category_id_out,'query' => $value['old_contract_id'], 'type' => 'catch')));
+						$value['labels'][] = lang('show_move_out_reports');
+					}
 				}
 		}
 
@@ -253,6 +336,7 @@
 		 */
 		public function index()
 		{
+
 			$search_for = phpgw::get_var('search_for');
 			if($search_for)
 			{
@@ -272,7 +356,13 @@
 		 * @param $contract_id the id of the contract to show
 		 */
 		public function viewedit($editable, $contract_id, $contract = null, $location_id = null, $notification = null, string $message = null, string $error = null)
-		{
+		{				
+			$cancel_link = self::link(array('menuaction' => 'rental.uicontract.index', 'populate_form' => 'yes'));
+			$adjustment_id = (int)phpgw::get_var('adjustment_id');
+			if($adjustment_id){
+				$cancel_link = self::link(array('menuaction' => 'rental.uiadjustment.show_affected_contracts','id' => $adjustment_id));
+				$cancel_text = 'contract_regulation_back';
+			}
 			
 			if (isset($contract_id) && $contract_id > 0) {
 				if($contract == null){
@@ -299,7 +389,8 @@
 						'editable' => $editable,
 						'message' => isset($message) ? $message : phpgw::get_var('message'),
 						'error' => isset($error) ? $error : phpgw::get_var('error'),
-						'cancel_link' => self::link(array('menuaction' => 'rental.uicontract.index', 'populate_form' => 'yes')),
+						'cancel_link' => $cancel_link,
+						'cancel_text' => $cancel_text
 					);
 					$contract->check_consistency();
 					$this->render('contract.php', $data);
@@ -322,7 +413,8 @@
 							'editable' => true,
 							'message' => isset($message) ? $message : phpgw::get_var('message'),
 							'error' => isset($error) ? $error : phpgw::get_var('error'),
-							'cancel_link' => self::link(array('menuaction' => 'rental.uicontract.index')),
+							'cancel_link' => $cancel_link,
+							'cancel_text' => $cancel_text
 						);
 						$this->render('contract.php', $data);
 					}
@@ -358,12 +450,22 @@
 			$message = null;
 			$error = null;
 			$add_default_price_items = false;
-
+			
 			if(isset($_POST['save_contract']))
 			{
 				if(isset($contract_id) && $contract_id > 0)
 				{
 					$contract = rental_socontract::get_instance()->get_single($contract_id);
+					
+					// Gets responsibility area from db (ex: eksternleie, internleie)
+					$responsibility_area = rental_socontract::get_instance()->get_responsibility_title($contract->get_location_id());
+					
+					// Redirect with error message if responsibility area is eksternleie and contract type not set
+					if( !is_numeric( phpgw::get_var('contract_type') ) && (strcmp($responsibility_area, "contract_type_eksternleie") == 0) ){
+						$error = lang('billing_removed_external_contract');
+						$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'id' => $contract->get_id(), 'message' => $message, 'error' => $error));	
+					}
+					
 					if(!$contract->has_permission(PHPGW_ACL_EDIT))
 					{
 						unset($contract);
@@ -372,6 +474,16 @@
 				}
 				else
 				{
+					// Gets responsibility area from db (ex: eksternleie, internleie) 
+					$responsibility_area = rental_socontract::get_instance()->get_responsibility_title($location_id);
+					
+					// Redirect with error message if responsibility area is eksternleie and contract type not set
+					if( !is_numeric( phpgw::get_var('contract_type') ) && (strcmp($responsibility_area, "contract_type_eksternleie") == 0) ){
+						$error = lang('billing_removed_external_contract');
+						
+						$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'location_id' => $location_id, 'message' => $message, 'error' => $error));
+					}
+				
 					if(isset($location_id) && ($this->isExecutiveOfficer() || $this->isAdministrator())){
 						$contract = new rental_contract();
 						$fields = rental_socontract::get_instance()->get_fields_of_responsibility();
@@ -384,7 +496,7 @@
 				$date_start =  strtotime(phpgw::get_var('date_start_hidden'));
 				$date_end =  strtotime(phpgw::get_var('date_end_hidden'));
 				
-				if(isset($contract)){
+				if(isset($contract)){ 
 					$contract->set_contract_date(new rental_contract_date($date_start, $date_end));
 					$contract->set_security_type(phpgw::get_var('security_type'));
 					$contract->set_security_amount(phpgw::get_var('security_amount'));
@@ -492,7 +604,8 @@
 						return $this->viewedit(true, $contract_id, $contract, $location_id,$notification, $message, $error);
 					}
 				}
-				$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'id' => $contract->get_id(), 'message' => $message, 'error' => $error));
+				
+				$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'id' => $contract->get_id(), 'message' => $message, 'error' => $error));		
 			}
 			else if(isset($_POST['add_notification']))
 			{
@@ -582,6 +695,8 @@
 		 */
 		public function copy_contract()
 		{
+			$adjustment_id = (int)phpgw::get_var('adjustment_id');
+			
 			$so_contract = rental_socontract::get_instance();
 			$contract = $so_contract->get_single(phpgw::get_var('id'));
 			$old_contract_old_id = $contract->get_old_contract_id();
@@ -602,17 +717,17 @@
 					if($success){
 						$db_contract->transaction_commit();
 						$message = lang(messages_new_contract_copied).' '.$old_contract_old_id;
-						$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'id' => $contract->get_id(), 'message' => $message));
+						$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'id' => $contract->get_id(), 'message' => $message, 'adjustment_id' => $adjustment_id));
 					}
 					else{
 						$db_contract->transaction_abort();
-						$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'id' => $contract->get_id(), 'message' => lang('messages_form_error')));
+						$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'id' => $contract->get_id(), 'message' => lang('messages_form_error'),'adjustment_id' => $adjustment_id));
 					}
 				}
 				else
 				{
 					$db_contract->transaction_abort();
-					$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'id' => $contract->get_id(), 'message' => lang('messages_form_error')));
+					$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uicontract.edit', 'id' => $contract->get_id(), 'message' => lang('messages_form_error'),'adjustment_id' => $adjustment_id));
 				}
 			}
 		
@@ -793,5 +908,23 @@
 			$result_data = array('results' => $result_array, 'total_records' => 1);
 			return $this->yui_results($result_data, 'total_records', 'results');
 		}
+		
+
+		/**
+		 * 
+		 * Public function scans the contract template directory for pdf contract templates 
+		 */
+		public function get_pdf_templates(){
+			$get_template_config= true;
+			$files = scandir('rental/templates/base/pdf/');			
+			foreach ($files as $file){
+				$ending = substr($file, -3, 3);
+				if($ending=='php'){
+					include 'rental/templates/base/pdf/'.$file;
+					$template_files = array($template_name,$file);
+					$this->pdf_templates[] = $template_files;
+				}
+			}	
+		}
 	}
 ?>
