@@ -2,18 +2,18 @@
 	/**
 	* Setup
 	*
-	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
+	* @copyright Copyright (C) 2000-2009 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: ldapexport.php 15836 2005-04-17 13:18:24Z powerstat $
+	* @version $Id: ldapexport.php 2319 2009-02-08 22:32:13Z sigurd $
 	*/
 
-	$phpgw_info = array();
-	$phpgw_info["flags"] = array(
-		'noheader'   => True,
-		'nonavbar'   => True,
+	$GLOBALS['phpgw_info']['flags'] = array
+	(
+		'noheader'   => true,
+		'nonavbar'   => true,
 		'currentapp' => 'home',
-		'noapi'      => True
+		'noapi'      => true
 	);
 	
 	/**
@@ -29,6 +29,45 @@
 	}
 	// Does not return unless user is authorized
 
+
+	/**
+	 * Add account
+	 * 
+	 * @param array  $acct    Account name and other information to use
+	 * @param string $type    Account type: u = user | g = group
+	 * @param array  $groups  Groups to add account to
+	 * @param array  $modules Modules to grant account access to
+	 * @param array  $acls    ACLs to set for account
+	 *
+	 * @return integer Account ID
+	 */
+	function add_account($acct, $type, $groups = array(), $modules = array(), $acls = array())
+	{
+		if ( $type == 'u' )
+		{
+			$account			= new phpgwapi_user();
+			$account->id		= $acct['id'];
+			$account->lid		= $acct['lid'];
+			$account->firstname	= $acct['firstname'];
+			$account->lastname	= $acct['lastname'];
+			$account->passwd	= $acct['password'];
+			$account->enabled	= true;
+			$account->expires	= -1;
+			$account->person_id	= $acct['person_id'];
+		}
+		else
+		{
+			$account			= new phpgwapi_group();
+			$account->id		= $acct['id'];
+			$account->lid		= $acct['lid'];
+			$account->firstname = ucfirst($acct['lid']);
+			$account->person_id	= $acct['person_id'];
+		}
+
+		return $GLOBALS['phpgw']->accounts->create($account, $groups, $acls, $modules);
+	}
+
+
 	//This stops timeout problems for larger conversions
 	@set_time_limit(0);
 
@@ -37,38 +76,13 @@
 	* @package setup
 	* @ignore
 	*/
-	class phpgw
-	{
-		/**
-		 * Common
-		 * @var object
-		 */
-		var $common;
-		
-		/**
-		 * Accounts
-		 * @var object
-		 */
-		var $accounts;
-		
-		/**
-		 * Applications
-		 * @var object
-		 */
-		var $applications;
-		
-		/**
-		 * Database
-		 * @var object
-		 */
-		var $db;
-	}
-	$phpgw = new phpgw;
-	$phpgw->common = CreateObject('phpgwapi.common');
 
-	$common = $phpgw->common;
+	$common = $GLOBALS['phpgw']->common;
 	$GLOBALS['phpgw_setup']->loaddb();
-	$phpgw->db = $GLOBALS['phpgw_setup']->db;
+	$GLOBALS['phpgw']->db = $GLOBALS['phpgw_setup']->db;
+	$GLOBALS['phpgw']->hooks = createObject('phpgwapi.hooks');	
+	$GLOBALS['phpgw']->acl = createObject('phpgwapi.acl');
+
 
 	$tpl_root = $GLOBALS['phpgw_setup']->html->setup_tpl_dir('setup');
 	$setup_tpl = CreateObject('phpgwapi.Template',$tpl_root);
@@ -94,11 +108,6 @@
 
 	// connect to ldap server
 	if(!$ldap = $common->ldapConnect())
-	{
-		$noldapconnection = True;
-	}
-
-	if($noldapconnection)
 	{
 		Header('Location: config.php?error=badldapconnection');
 		exit;
@@ -109,17 +118,19 @@
 	while($GLOBALS['phpgw_setup']->db->next_record())
 	{
 		$i = $GLOBALS['phpgw_setup']->db->f('account_id');
-		$account_info[$i]['account_id']        = $GLOBALS['phpgw_setup']->db->f('account_id');
-		$account_info[$i]['account_lid']       = $GLOBALS['phpgw_setup']->db->f('account_lid');
-		$account_info[$i]['account_firstname'] = $GLOBALS['phpgw_setup']->db->f('account_firstname');
-		$account_info[$i]['account_lastname']  = $GLOBALS['phpgw_setup']->db->f('account_lastname');
-		$account_info[$i]['account_status']    = $GLOBALS['phpgw_setup']->db->f('account_status');
-		$account_info[$i]['account_expires']   = $GLOBALS['phpgw_setup']->db->f('account_expires');
+		$account_info[$i]['id']        = $GLOBALS['phpgw_setup']->db->f('account_id');
+		$account_info[$i]['lid']       = $GLOBALS['phpgw_setup']->db->f('account_lid');
+		$account_info[$i]['firstname'] = $GLOBALS['phpgw_setup']->db->f('account_firstname');
+		$account_info[$i]['lastname']  = $GLOBALS['phpgw_setup']->db->f('account_lastname');
+		$account_info[$i]['status']    = $GLOBALS['phpgw_setup']->db->f('account_status');
+		$account_info[$i]['expires']   = $GLOBALS['phpgw_setup']->db->f('account_expires');
+		$account_info[$i]['person_id'] = $GLOBALS['phpgw_setup']->db->f('person_id');
 	}
 
+	$newaccount = array();
 	while(list($key,$data) = @each($account_info))
 	{
-		$tmp = $data['account_id'];
+		$tmp = $data['id'];
 		$newaccount[$tmp] = $data;
 	}
 	$account_info = $newaccount;
@@ -129,49 +140,48 @@
 	while($GLOBALS['phpgw_setup']->db->next_record())
 	{
 		$i = $GLOBALS['phpgw_setup']->db->f('account_id');
-		$group_info[$i]['account_id']        = $GLOBALS['phpgw_setup']->db->f('account_id');
-		$group_info[$i]['account_lid']       = $GLOBALS['phpgw_setup']->db->f('account_lid');
-		$group_info[$i]['account_firstname'] = $GLOBALS['phpgw_setup']->db->f('account_firstname');
-		$group_info[$i]['account_lastname']  = $GLOBALS['phpgw_setup']->db->f('account_lastname');
-		$group_info[$i]['account_status']    = $GLOBALS['phpgw_setup']->db->f('account_status');
-		$group_info[$i]['account_expires']   = $GLOBALS['phpgw_setup']->db->f('account_expires');
+		$group_info[$i]['id']        = $GLOBALS['phpgw_setup']->db->f('account_id');
+		$group_info[$i]['lid']       = $GLOBALS['phpgw_setup']->db->f('account_lid');
+		$group_info[$i]['firstname'] = $GLOBALS['phpgw_setup']->db->f('account_firstname');
+		$group_info[$i]['lastname']  = $GLOBALS['phpgw_setup']->db->f('account_lastname');
+		$group_info[$i]['status']    = $GLOBALS['phpgw_setup']->db->f('account_status');
+		$group_info[$i]['expires']   = $GLOBALS['phpgw_setup']->db->f('account_expires');
+		$group_info[$i]['person_id'] = $GLOBALS['phpgw_setup']->db->f('person_id');
 	}
-
-	if($_POST['cancel'])
+	if(isset($_POST['cancel']) && $_POST['cancel'])
 	{
 		Header('Location: ldap.php');
 		exit;
 	}
 
-	if($_POST['submit'])
+	if(isset($_POST['submit']) && $_POST['submit'])
 	{
-		if($_POST['ldapgroups'] && is_array($_POST['ldapgroups']))
+		if(isset($_POST['ldapgroups']) && $_POST['ldapgroups'] && is_array($_POST['ldapgroups']))
 		{
-
+			$groups = CreateObject('phpgwapi.accounts');
 			foreach($_POST['ldapgroups'] as $key => $groupid)
 			{
 				$id_exist = 0;
-				$thisacctid    = $group_info[$groupid]['account_id'];
-				$thisacctlid   = $group_info[$groupid]['account_lid'];
-				$thisfirstname = $group_info[$groupid]['account_firstname'];
-				$thislastname  = $group_info[$groupid]['account_lastname'];
-				$thismembers   = $group_info[$groupid]['members'];
+				$thisacctid    = $group_info[$groupid]['id'];
+				$thisacctlid   = $group_info[$groupid]['lid'];
+				$thisfirstname = $group_info[$groupid]['firstname'];
+				$thislastname  = $group_info[$groupid]['lastname'];
+		//		$thismembers   = $group_info[$groupid]['members'];
+				$thisperson    = $group_info[$groupid]['person_id'];
 
 				// Do some checks before we try to import the data to LDAP.
 				if(!empty($thisacctid) && !empty($thisacctlid))
 				{
-					$groups = CreateObject('phpgwapi.accounts',intval($thisacctid));
-					$groups->db = $GLOBALS['phpgw_setup']->db;
-
+				//	$groups->set_account($thisacctid, 'g');
 					// Check if the account is already there.
 					// If so, we won't try to create it again.
-					$acct_exist = $acct->groupName2id($thisacctlid);
+					$acct_exist = $groups->name2id($thisacctlid);
 					if($acct_exist)
 					{
 						$thisacctid = $acct_exist;
 					}
-					$id_exist = $groups->group_exists(intval($thisacctid));
-					
+					$id_exist = $groups->exists(intval($thisacctid));
+
 					/*
 					echo '<br />accountid: ' . $thisacctid;
 					echo '<br />accountlid: ' . $thisacctlid;
@@ -182,18 +192,20 @@
 					if(!$id_exist)
 					{
 						echo "<br />\nAdding Group:  $thisacctlid (gid: $thisacctid)";
-						$groups->create(
-							array(
-								'account_type'      => 'g',
-								'account_id'        => $thisacctid,
-								'account_lid'       => $thisacctlid,
-								'account_passwd'    => 'x',
-								'account_firstname' => $thisfirstname,
-								'account_lastname'  => $thislastname,
-								'account_status'    => 'A',
-								'account_expires'   => -1
-							)
+						$thisgroup_info = array
+						(
+								'type'      => 'g',
+								'id'        => $thisacctid,
+								'lid'       => $thisacctlid,
+						//		'passwd'    => 'x',
+								'firstname' => $thisfirstname,
+								'lastname'  => $thislastname,
+								'status'    => 'A',
+								'expires'   => -1,
+								'person_id' => $thisperson
 						);
+
+						add_account($thisgroup_info, 'g');
 					}
 					else
 					{
@@ -203,21 +215,22 @@
 			}
 		}
 
-		if($_POST['users'] && is_array($_POST['users']))
+		if(isset($_POST['users']) && $_POST['users'] && is_array($_POST['users']))
 		{
+			$accounts = CreateObject('phpgwapi.accounts');
 			foreach($_POST['users'] as $key => $accountid)
 			{
 				$id_exist = 0; $acct_exist = 0;
-				$thisacctid    = $account_info[$accountid]['account_id'];
-				$thisacctlid   = $account_info[$accountid]['account_lid'];
-				$thisfirstname = $account_info[$accountid]['account_firstname'];
-				$thislastname  = $account_info[$accountid]['account_lastname'];
+				$thisacctid    = $account_info[$accountid]['id'];
+				$thisacctlid   = $account_info[$accountid]['lid'];
+				$thisfirstname = $account_info[$accountid]['firstname'];
+				$thislastname  = $account_info[$accountid]['lastname'];
+				$thisperson    = $account_info[$accountid]['person_id'];				
 
 				// Do some checks before we try to import the data.
 				if(!empty($thisacctid) && !empty($thisacctlid))
 				{
-					$accounts = CreateObject('phpgwapi.accounts',intval($thisacctid));
-					$accounts->db = $GLOBALS['phpgw_setup']->db;
+					$accounts->set_account($thisacctid, 'u');
 
 					// Check if the account is already there.
 					// If so, we won't try to create it again.
@@ -226,28 +239,30 @@
 					{
 						$thisacctid = $acct_exist;
 					}
-					/* create_account handles existing accounts
+
 					$id_exist = $accounts->exists(intval($thisacctid));
-					*/
+
 					// If not, create it now.
-					if(!$id_exist)
+					if($id_exist)
 					{
 						echo "<br />\nAdding User: $thisacctlid (uid: $thisacctid)";
-						$accounts->create(
-								array(
-									'account_type'      => 'u',
-									'account_id'        => $thisacctid,
-									'account_lid'       => $thisacctlid,
-									'account_passwd'    => 'x',
-									'account_firstname' => $thisfirstname,
-									'account_lastname'  => $thislastname,
-									'account_status'    => 'A',
-									'account_expires'   => -1,
-									'homedirectory'     => $config['ldap_account_home'] 
-												. '/' . $thisacctlid,
-									'loginshell'        => $config['ldap_account_shell']
-								)
+						$thisaccount_info  = array
+						(
+									'type'      => 'u',
+									'id'        => $thisacctid,
+									'lid'       => $thisacctlid,
+									'password'    => '12345678XXxx_&',
+									'firstname' => $thisfirstname,
+									'lastname'  => $thislastname,
+									'status'    => 'A',
+									'expires'   => -1,
+									'person_id' => $thisperson
+							//		'homedirectory'     => $config['ldap_account_home'] 
+							//					. '/' . $thisacctlid,
+							//		'loginshell'        => $config['ldap_account_shell']
 						);
+
+						add_account($thisaccount_info, 'u');
 					}
 					else
 					{
@@ -261,13 +276,13 @@
 
 	$GLOBALS['phpgw_setup']->html->show_header('LDAP Export','','config',$ConfigDomain);
 
-	if($error)
+	if(isset($error) && $error)
 	{
 		//echo '<br /><center><b>Error:</b> '.$error.'</center>';
 		$GLOBALS['phpgw_setup']->html->show_alert_msg('Error',$error);
 	}
 
-	if($setup_complete)
+	if(isset($setup_complete) && $setup_complete)
 	{
 		echo '<br /><center>'.lang('Export has been completed!  You will need to set the user passwords manually.').'</center>';
 		echo '<br /><center>'.lang('Click <a href="index.php">here</a> to return to setup.').'</center>';
@@ -283,25 +298,28 @@
 	$setup_tpl->set_block('ldap','submit','submit');
 	$setup_tpl->set_block('ldap','footer','footer');
 
+	$user_list = '';
 	while(list($key,$account) = @each($account_info))
 	{
-		$user_list .= '<option value="' . $account['account_id'] . '">'
-			. $common->display_fullname($account['account_lid'],$account['account_firstname'],$account['account_lastname'])
+		$user_list .= '<option value="' . $account['id'] . '">'
+			. $common->display_fullname($account['lid'],$account['firstname'],$account['lastname'])
 			. '</option>';
 	}
 
 	@reset($account_info);
+	$admin_list = '';
 	while(list($key,$account) = @each($account_info))
 	{
-		$admin_list .= '<option value="' . $account['account_id'] . '">'
-			. $common->display_fullname($account['account_lid'],$account['account_firstname'],$account['account_lastname'])
+		$admin_list .= '<option value="' . $account['id'] . '">'
+			. $common->display_fullname($account['lid'],$account['firstname'],$account['lastname'])
 			. '</option>';
 	}
 
+	$group_list = '';
 	while(list($key,$group) = @each($group_info))
 	{
-		$group_list .= '<option value="' . $group['account_id'] . '">'
-			. $group['account_lid']
+		$group_list .= '<option value="' . $group['id'] . '">'
+			. $group['lid']
 			. '</option>';
 	}
 
@@ -309,7 +327,7 @@
 	$setup_tpl->set_var('users',$user_list);
 	$setup_tpl->set_var('admins',$admin_list);
 	$setup_tpl->set_var('ldapgroups',$group_list);
-	$setup_tpl->set_var('s_apps',$app_list);
+//	$setup_tpl->set_var('s_apps',$app_list);
 
 	$setup_tpl->set_var('ldap_import',lang('LDAP export users'));
 	$setup_tpl->set_var('description',lang("This section will help you export users and groups from phpGroupWare's account tables into your LDAP tree").'.');
