@@ -5,7 +5,7 @@
 	* @copyright Portions Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: manageheader.php 6436 2010-10-04 09:53:32Z sigurdne $
+	* @version $Id: manageheader.php 6640 2010-12-03 14:59:43Z sigurdne $
 	*/
 
 	$phpgw_info = array();
@@ -272,6 +272,19 @@ HTML;
 				
 			}
 
+			$get_max_value_length = '';
+			if(ini_get('suhosin.get.max_value_length'))
+			{
+				if (ini_get('suhosin.get.max_value_length') < 2000)
+				{
+					$get_max_value_length = '<li class="warn">Speed could be gained from setting suhosin.get.max_value_length = 2000 in php.ini'. "</li>\n";
+				}
+				else
+				{
+					$get_max_value_length = '<li>' . lang('You appear to have suhosin.get.max_value_length > 2000') . "</li>\n";
+				}
+			}
+
 			$phpver = '<li>' . lang('You appear to be using PHP %1+', 5.2) . "</li>\n";
 			$supported_sessions_type = array('php', 'db');
 
@@ -289,17 +302,9 @@ HTML;
 
 			$detected .= '<tr class="th"><td colspan="2">' . lang('Analysis') . "</td></tr><tr><td colspan=\"2\">\n<ul id=\"analysis\">\n$phpver";
 			$detected .= $request_order;
+			$detected .= $get_max_value_length;
 
 			$supported_db = array();
-			if (extension_loaded('mysql') || function_exists('mysql_connect'))
-			{
-				$detected .= '<li>' . lang('You appear to have MySQL support enabled') . "</li>\n";
-				$supported_db[] = 'mysql';
-			}
-			else
-			{
-				$detected .= '<li class="warn">' . lang('No MySQL support found. Disabling') . "</li>\n";
-			}
 			if (extension_loaded('pgsql') || function_exists('pg_connect'))
 			{
 				$detected .= '<li>' . lang('You appear to have Postgres-DB support enabled') . "</li>\n";
@@ -309,6 +314,15 @@ HTML;
 			{
 				$detected .= '<li class="warn">' . lang('No Postgres-DB support found. Disabling') . "</li>\n";
 			}
+			if (extension_loaded('mysql') || function_exists('mysql_connect'))
+			{
+				$detected .= '<li>' . lang('You appear to have MySQL support enabled') . "</li>\n";
+				$supported_db[] = 'mysql';
+			}
+			else
+			{
+				$detected .= '<li class="warn">' . lang('No MySQL support found. Disabling') . "</li>\n";
+			}
 			if (extension_loaded('mssql') || function_exists('mssql_connect'))
 			{
 				$detected .= '<li>' . lang('You appear to have Microsoft SQL Server support enabled') . "</li>\n";
@@ -494,6 +508,7 @@ HTML;
 						$found_dbtype = False;
 						foreach ( $supported_db as $db )
 						{
+							$GLOBALS['phpgw_domain'][$key]['db_type'] = $GLOBALS['phpgw_domain'][$key]['db_type'] == 'pgsql' ? 'postgres' : $GLOBALS['phpgw_domain'][$key]['db_type']; // upgrade from 0.9.16
 							if ( $db == $GLOBALS['phpgw_domain'][$key]['db_type'] )
 							{
 								$selected = ' selected';
@@ -596,7 +611,7 @@ HTML;
 				$setup_tpl->set_var('comment_r',' -->');
 
 				$GLOBALS['phpgw_info']['server']['header_admin_password'] = '';
-				$GLOBALS['phpgw_info']['server']['db_persistent'] = false;
+				$GLOBALS['phpgw_info']['server']['db_persistent'] = true;
 				$GLOBALS['phpgw_info']['server']['sessions_type'] = 'php';
 //				$GLOBALS['phpgw_info']['server']['mcrypt_enabled'] = extension_loaded('mcrypt');
 				$GLOBALS['phpgw_info']['server']['show_domain_selectbox'] = false;
@@ -622,7 +637,7 @@ HTML;
 			$setup_tpl->set_var('include_root', $GLOBALS['phpgw_info']['server']['include_root']);
 			$setup_tpl->set_var('header_admin_password', isset($GLOBALS['phpgw_info']['server']['header_admin_password']) ? $GLOBALS['phpgw']->crypto->decrypt($GLOBALS['phpgw_info']['server']['header_admin_password']) : '');
 //			$setup_tpl->set_var('header_admin_password', isset($GLOBALS['phpgw_info']['server']['header_admin_password']) ? $GLOBALS['phpgw_info']['server']['header_admin_password'] : '');
-			$setup_tpl->set_var('system_name', isset($GLOBALS['phpgw_info']['server']['system_name']) ? $GLOBALS['phpgw_info']['server']['system_name'] : 'phpGroupWare');
+			$setup_tpl->set_var('system_name', isset($GLOBALS['phpgw_info']['server']['system_name']) ? $GLOBALS['phpgw_info']['server']['system_name'] : 'Portico Estate');
 			$setup_tpl->set_var('default_lang', isset($GLOBALS['phpgw_info']['server']['default_lang']) ? $GLOBALS['phpgw_info']['server']['default_lang'] : phpgw::get_var('ConfigLang', 'string', 'POST'));
 
 			if ( isset($GLOBALS['phpgw_info']['server']['db_persistent']) && $GLOBALS['phpgw_info']['server']['db_persistent'] )
