@@ -6,14 +6,14 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package sms
-	* @version $Id: addressbook.php 16796 2006-06-12 11:19:40Z sigurdne $
+	* @version $Id: addressbook.php 1014 2008-05-20 06:45:13Z sigurd $
 	*/
 
 	$GLOBALS['phpgw_info']['flags'] = array(
-		'noheader' => True,
-		'nonavbar' => True,
+		'noheader' => true,
+		'nonavbar' => true,
 		'currentapp' => 'sms',
-		'enable_nextmatchs_class' => True
+		'enable_nextmatchs_class' => true
 	);
 
 	/**
@@ -28,14 +28,14 @@
 	$GLOBALS['phpgw']->template->set_block('addressbook_list_t','addressbook_list','list');
 
 	$d = CreateObject('phpgwapi.contacts');
-	
+
 	//We do it this way so the cats class gets the right rights, alright? - skwashd Dec-2005
 	$GLOBALS['phpgw_info']['flags']['currentapp'] = 'addressbook';
  	$c = CreateObject('phpgwapi.categories');
 	$GLOBALS['phpgw_info']['flags']['currentapp'] = 'sms';
-	
-	$include_personal = True;
-	
+
+	$include_personal = true;
+
 	$charset = $GLOBALS['phpgw']->translation->translate('charset');
 	$GLOBALS['phpgw']->template->set_var('charset',$charset);
 	$GLOBALS['phpgw']->template->set_var('title',$GLOBALS['phpgw_info']['site_title']);
@@ -54,12 +54,12 @@
 	$query = get_var('query',array('get','post'));
 	$sort = get_var('sort',array('get','post'));
 	$order = get_var('order',array('get','post'));
-	
+
 	if(!$cat_id)
-	{		
+	{
 		$cat_id = $prefs['default_category'];
 	}
-			
+
 	switch ($filter)
 	{
 	case 'user_only':
@@ -86,7 +86,7 @@
 	{
 		$limit = 15;
 	}
-			
+
 	if($cat_id && $cat_id!=-1)
 	{
 		$category_filter = $cat_id;
@@ -128,8 +128,8 @@
 	$GLOBALS['phpgw']->template->set_var('right',$right);
 
 	//$lang_showing = $GLOBALS['phpgw']->nextmatchs->show_hits($total_records,$this->start);
-	$lang_showing = lang('%1 - %2 of %3 ', 
-			     ($d->total_records!=0)?$start+1:$start, 
+	$lang_showing = lang('%1 - %2 of %3 ',
+			     ($d->total_records!=0)?$start+1:$start,
 			     $start+$d->total_records,$total_all_persons);
 	$GLOBALS['phpgw']->template->set_var('lang_showing', $lang_showing);
 
@@ -143,9 +143,9 @@
 	$GLOBALS['phpgw']->template->set_var('sort_company',$GLOBALS['phpgw']->nextmatchs->show_sort_order($sort,'org_name',$order,'/'.$GLOBALS['phpgw_info']['flags']['currentapp'].'/addressbook.php',lang('Company')));
 	$GLOBALS['phpgw']->template->set_var('lang_email',lang('Select work email address'));
 	$GLOBALS['phpgw']->template->set_var('lang_hemail',lang('Select home email address'));
-	$GLOBALS['phpgw']->template->set_var('cats_list',$c->formated_list('select','all',$cat_id,'True'));
+	$GLOBALS['phpgw']->template->set_var('cats_list',$c->formated_list('select','all',$cat_id,'true'));
 	$GLOBALS['phpgw']->template->set_var('lang_select',lang('Select'));
-	
+
 	//$GLOBALS['phpgw']->template->set_var('cats_action',$GLOBALS['phpgw']->link('/'.$GLOBALS['phpgw_info']['flags']['currentapp'].'/addressbook.php',"sort=$sort&order=$order&filter=$filter&start=$start&query=$query&cat_id=$cat_id"));
 	// thanks to  dave.hall@mbox.com.au for fixing drop down list filtering by categories
 	$GLOBALS['phpgw']->template->set_var('cats_action',$GLOBALS['phpgw']->link('/'.$GLOBALS['phpgw_info']['flags']['currentapp'].'/addressbook.php',"sort=$sort&order=$order&filter=$filter&start=$start&query=$query"));
@@ -171,7 +171,7 @@
 		{
 			$company = '&nbsp;';
 		}
-		
+
 		$personal_firstname = '';
 		$personal_lastname = '';
 		$personal_part = '';
@@ -188,11 +188,11 @@
 			$personal_lastname = $lastname;
 		}
 		$personal_part = $personal_firstname.$personal_lastname;
-		
+
 		$tmp_email  = get_comm_value($entries[$i]['contact_id'], 'work email', $entries_comm);
 		$tmp_hemail = get_comm_value($entries[$i]['contact_id'], 'home email', $entries_comm);
 		if (($personal_part == '') ||
-			($include_personal == False))
+			($include_personal == false))
 		{
 			$id     = $entries[$i]['contact_id'];
 			$email  = $tmp_email;
@@ -220,7 +220,7 @@
 				$hemail = $tmp_hemail;
 			}
 		}
-		
+
 		// --------------------- template declaration for list records --------------------------
 		$GLOBALS['phpgw']->template->set_var(array(
 			'firstname' => $firstname,
@@ -232,12 +232,12 @@
 		$GLOBALS['phpgw']->template->set_var('email',$email);
 		$GLOBALS['phpgw']->template->set_var('hemail',$hemail);
 
-		$GLOBALS['phpgw']->template->parse('list','addressbook_list',True);
+		$GLOBALS['phpgw']->template->parse('list','addressbook_list',true);
 	}
 	// --------------------------- end record declaration ---------------------------
 
 	$GLOBALS['phpgw']->template->set_var('lang_done',lang('Done'));
-	$GLOBALS['phpgw']->template->parse('out','addressbook_list_t',True);
+	$GLOBALS['phpgw']->template->parse('out','addressbook_list_t',true);
 	$GLOBALS['phpgw']->template->p('out');
 
 	$GLOBALS['phpgw']->common->phpgw_exit();
@@ -248,13 +248,13 @@
 		{
 			$entries_comm=array();
 		}
-	
+
 		foreach($entries_comm as $comms)
 		{
 			if($contact_id == $comms['comm_contact_id'] && $column == $comms['comm_description'])
-			{	
+			{
 				return $comms['comm_data'];
-			}	
+			}
 		}
 	}
-?>
+
