@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
- 	* @version $Id: index.php 17889 2007-01-16 11:24:51Z sigurdne $
+ 	* @version $Id: index.php 979 2008-05-11 08:39:14Z sigurd $
 	*/
 
 	/**
@@ -21,19 +21,19 @@
 	$currentapp='sms';
 
 	$GLOBALS['phpgw_info']['flags'] = array(
-		'noheader'   => True,
-		'nonavbar'   => True,
+		'noheader'   => true,
+		'nonavbar'   => true,
 		'currentapp'	=> $currentapp
 		);
 
 	include('../header.inc.php');
 
-	$start_page = 'sms';
+	$start_page = 'sms.index';
 
-	if ( isset($GLOBALS['phpgw_info']['user']['preferences']['property']['default_start_page'])
-		&& $GLOBALS['phpgw_info']['user']['preferences']['property']['default_start_page'] )
+	if ( isset($GLOBALS['phpgw_info']['user']['preferences']['sms']['default_start_page'])
+		&& $GLOBALS['phpgw_info']['user']['preferences']['sms']['default_start_page'] )
 	{
-		$start_page = $GLOBALS['phpgw_info']['user']['preferences']['property']['default_start_page'];
+		$start_page = $GLOBALS['phpgw_info']['user']['preferences']['sms']['default_start_page'];
 	}
 
-	$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction' => "sms.ui{$start_page}.index"));
+	$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction' => "sms.ui{$start_page}"));
